@@ -1,9 +1,4 @@
-#!/usr/bin/python
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
+#!/usr/bin/python3
 import sys
 import os
 import locale
