@@ -1,78 +1,41 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-import sys
 import json
 from functools import partial
 
-from pcs import (
-    usage,
-    utils,
-)
+from pcs import usage
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.parse_args import prepare_options, group_by_keywords
 from pcs.cli.common.console_report import indent
-from pcs.lib.errors import LibraryError
+from pcs.cli.common.routing import create_router
 
 parse_cmd_sections = partial(group_by_keywords, implicit_first_group_key="main")
 
-def alert_cmd(*args):
-    argv = args[1]
-    if not argv:
-        sub_cmd = "config"
-    else:
-        sub_cmd = argv.pop(0)
-    try:
-        if sub_cmd == "help":
-            usage.alert(argv)
-        elif sub_cmd == "create":
-            alert_add(*args)
-        elif sub_cmd == "update":
-            alert_update(*args)
-        elif sub_cmd == "remove":
-            alert_remove(*args)
-        elif sub_cmd == "config" or sub_cmd == "show":
-            print_alert_config(*args)
-        elif sub_cmd == "recipient":
-            recipient_cmd(*args)
-        elif sub_cmd == "get_all_alerts":
-            print_alerts_in_json(*args)
-        else:
-            raise CmdLineInputError()
-    except LibraryError as e:
-        utils.process_library_reports(e.args)
-    except CmdLineInputError as e:
-        utils.exit_on_cmdline_input_errror(e, "alert", sub_cmd)
-
-
-def recipient_cmd(*args):
-    argv = args[1]
-
-    if not argv:
-        usage.alert(["recipient"])
-        sys.exit(1)
-
-    sub_cmd = argv.pop(0)
-    try:
-        if sub_cmd == "help":
-            usage.alert(["recipient"])
-        elif sub_cmd == "add":
-            recipient_add(*args)
-        elif sub_cmd == "update":
-            recipient_update(*args)
-        elif sub_cmd == "remove":
-            recipient_remove(*args)
-        else:
-            raise CmdLineInputError()
-    except CmdLineInputError as e:
-        utils.exit_on_cmdline_input_errror(
-            e, "alert", "recipient {0}".format(sub_cmd)
-        )
-
-
+def alert_cmd(lib, argv, modifiers):
+    create_router(
+        {
+            "help": lambda _lib, _argv, _modifiers: usage.alert(_argv),
+            "create": alert_add,
+            "update": alert_update,
+            "delete": alert_remove,
+            "remove": alert_remove,
+            "config": print_alert_config,
+            "show": print_alert_config,
+            "recipient": create_router(
+                {
+                    "help": lambda _lib, _argv, _modifiers: usage.alert(
+                        ["recipient"]
+                    ),
+                    "add": recipient_add,
+                    "update": recipient_update,
+                    "delete": recipient_remove,
+                    "remove": recipient_remove,
+                },
+                ["alert", "recipient"],
+            ),
+            "get_all_alerts": print_alerts_in_json,
+        },
+        ["alert"],
+        default_cmd="config",
+    )(lib, argv, modifiers)
 
 
 def ensure_only_allowed_options(parameter_dict, allowed_list):
@@ -84,6 +47,11 @@ def ensure_only_allowed_options(parameter_dict, allowed_list):
 
 
 def alert_add(lib, argv, modifiers):
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+    """
+    modifiers.ensure_only_supported("-f")
     if not argv:
         raise CmdLineInputError()
 
@@ -101,6 +69,11 @@ def alert_add(lib, argv, modifiers):
 
 
 def alert_update(lib, argv, modifiers):
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+    """
+    modifiers.ensure_only_supported("-f")
     if not argv:
         raise CmdLineInputError()
 
@@ -120,13 +93,24 @@ def alert_update(lib, argv, modifiers):
 
 
 def alert_remove(lib, argv, modifiers):
-    if len(argv) < 1:
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+    """
+    modifiers.ensure_only_supported("-f")
+    if not argv:
         raise CmdLineInputError()
 
     lib.alert.remove_alert(argv)
 
 
 def recipient_add(lib, argv, modifiers):
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+      * --force - allows not unique recipient values
+    """
+    modifiers.ensure_only_supported("-f", "--force")
     if len(argv) < 2:
         raise CmdLineInputError()
 
@@ -143,12 +127,18 @@ def recipient_add(lib, argv, modifiers):
         prepare_options(sections["meta"]),
         recipient_id=main_args.get("id", None),
         description=main_args.get("description", None),
-        allow_same_value=modifiers["force"]
+        allow_same_value=modifiers.get("--force")
     )
 
 
 def recipient_update(lib, argv, modifiers):
-    if len(argv) < 1:
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+      * --force - allows not unique recipient values
+    """
+    modifiers.ensure_only_supported("-f", "--force")
+    if not argv:
         raise CmdLineInputError()
 
     recipient_id = argv[0]
@@ -163,12 +153,17 @@ def recipient_update(lib, argv, modifiers):
         prepare_options(sections["meta"]),
         recipient_value=main_args.get("value", None),
         description=main_args.get("description", None),
-        allow_same_value=modifiers["force"]
+        allow_same_value=modifiers.get("--force")
     )
 
 
 def recipient_remove(lib, argv, modifiers):
-    if len(argv) < 1:
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+    """
+    modifiers.ensure_only_supported("-f")
+    if not argv:
         raise CmdLineInputError()
 
     lib.alert.remove_recipient(argv)
@@ -204,7 +199,7 @@ def _alert_to_str(alert):
 
     recipients = []
     for recipient in alert.get("recipient_list", []):
-        recipients.extend( _recipient_to_str(recipient))
+        recipients.extend(_recipient_to_str(recipient))
 
     if recipients:
         content.append("Recipients:")
@@ -222,6 +217,11 @@ def _recipient_to_str(recipient):
 
 
 def print_alert_config(lib, argv, modifiers):
+    """
+    Options:
+      * -f - CIB file (in lib wrapper)
+    """
+    modifiers.ensure_only_supported("-f")
     if argv:
         raise CmdLineInputError()
 
@@ -234,10 +234,15 @@ def print_alert_config(lib, argv, modifiers):
         print(" No alerts defined")
 
 
-def print_alerts_in_json(lib, argv, dummy_modifiers):
-    # This is used only by pcsd, will be removed in new architecture
+def print_alerts_in_json(lib, argv, modifiers):
+    """
+    This is used only by pcsd, will be removed in new architecture
+
+    Options:
+      * -f - CIB file (in lib wrapper)
+    """
+    modifiers.ensure_only_supported("-f")
     if argv:
         raise CmdLineInputError()
 
     print(json.dumps(lib.alert.get_all_alerts()))
-
