@@ -1,10 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from pcs.test.tools.pcs_unittest import TestCase
+from unittest import TestCase
 
 from pcs.cli.booth.console_report import CODE_TO_MESSAGE_BUILDER_MAP
 from pcs.common import report_codes as codes
