@@ -1,33 +1,25 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import logging
 import sys
 from collections import namedtuple
 
 from pcs.cli.common import middleware
-from pcs.cli.common.reports import (
-    LibraryReportProcessorToConsole,
-    process_library_reports
-)
+from pcs.cli.common.reports import process_library_reports
 from pcs.lib.commands import (
     acl,
     alert,
     booth,
+    cib_options,
     cluster,
     fencing_topology,
     node,
+    pcsd,
     qdevice,
     quorum,
     remote_node,
-    resource_agent,
     resource,
-    cib_options,
-    stonith,
+    resource_agent,
     sbd,
+    stonith,
     stonith_agent,
 )
 from pcs.lib.commands.constraint import (
@@ -47,14 +39,13 @@ def wrapper(dictionary):
 def cli_env_to_lib_env(cli_env):
     return LibraryEnvironment(
         logging.getLogger("pcs"),
-        LibraryReportProcessorToConsole(cli_env.debug),
+        cli_env.report_processor,
         cli_env.user,
         cli_env.groups,
         cli_env.cib_data,
         cli_env.corosync_conf_data,
         booth=cli_env.booth,
-        token_file_data_getter=cli_env.token_file_data_getter,
-        cluster_conf_data=cli_env.cluster_conf_data,
+        known_hosts_getter=cli_env.known_hosts_getter,
         request_timeout=cli_env.request_timeout,
     )
 
@@ -63,8 +54,6 @@ def lib_env_to_cli_env(lib_env, cli_env):
         cli_env.cib_data = lib_env.final_mocked_cib_content
     if not lib_env.is_corosync_conf_live:
         cli_env.corosync_conf_data = lib_env.get_corosync_conf_data()
-    if not lib_env.is_cluster_conf_live:
-        cli_env.cluster_conf_data = lib_env.get_cluster_conf_data()
 
     #TODO
     #now we know: if is in cli_env booth is in lib_env as well
@@ -116,6 +105,7 @@ def get_module(env, middleware_factory, name):
 
 
 def load_module(env, middleware_factory, name):
+    # pylint: disable=too-many-return-statements, too-many-branches
     if name == "acl":
         return bind_all(
             env,
@@ -185,12 +175,13 @@ def load_module(env, middleware_factory, name):
     if name == "cluster":
         return bind_all(
             env,
-            middleware.build(
-                middleware_factory.cib,
-                middleware_factory.corosync_conf_existing,
-            ),
+            middleware.build(middleware_factory.cib),
             {
+                "add_nodes": cluster.add_nodes,
                 "node_clear": cluster.node_clear,
+                "remove_nodes": cluster.remove_nodes,
+                "remove_nodes_from_cib": cluster.remove_nodes_from_cib,
+                "setup": cluster.setup,
                 "verify": cluster.verify,
             }
         )
@@ -273,6 +264,15 @@ def load_module(env, middleware_factory, name):
             }
         )
 
+    if name == "pcsd":
+        return bind_all(
+            env,
+            middleware.build(),
+            {
+                "synchronize_ssl_certificate": pcsd.synchronize_ssl_certificate,
+            }
+        )
+
     if name == "qdevice":
         return bind_all(
             env,
@@ -338,12 +338,12 @@ def load_module(env, middleware_factory, name):
                 "bundle_create": resource.bundle_create,
                 "bundle_update": resource.bundle_update,
                 "create": resource.create,
-                "create_as_master": resource.create_as_master,
                 "create_as_clone": resource.create_as_clone,
                 "create_in_group": resource.create_in_group,
                 "create_into_bundle": resource.create_into_bundle,
                 "disable": resource.disable,
                 "enable": resource.enable,
+                "get_failcounts": resource.get_failcounts,
                 "manage": resource.manage,
                 "unmanage": resource.unmanage,
             }
@@ -371,6 +371,9 @@ def load_module(env, middleware_factory, name):
             {
                 "create": stonith.create,
                 "create_in_group": stonith.create_in_group,
+                "history_get_text": stonith.history_get_text,
+                "history_cleanup": stonith.history_cleanup,
+                "history_update": stonith.history_update,
             }
         )
 
@@ -388,6 +391,9 @@ def load_module(env, middleware_factory, name):
                 "initialize_block_devices": sbd.initialize_block_devices,
                 "get_local_devices_info": sbd.get_local_devices_info,
                 "set_message": sbd.set_message,
+                "get_local_available_watchdogs":
+                    sbd.get_local_available_watchdogs,
+                "test_local_watchdog": sbd.test_local_watchdog,
             }
         )
 
@@ -403,7 +409,8 @@ def load_module(env, middleware_factory, name):
 
     raise Exception("No library part '{0}'".format(name))
 
-class Library(object):
+class Library():
+    # pylint: disable=too-few-public-methods
     def __init__(self, env, middleware_factory):
         self.env = env
         self.middleware_factory = middleware_factory
