@@ -1,9 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+from pcs.cli.common.console_report import format_list
 from pcs.cli.common.errors import CmdLineInputError
 
 
@@ -11,27 +6,18 @@ ARG_TYPE_DELIMITER = "%"
 
 # h = help, f = file,
 # p = password (cluster auth), u = user (cluster auth),
-# V = verbose (cluster verify)
-PCS_SHORT_OPTIONS = "hf:p:u:V"
+PCS_SHORT_OPTIONS = "hf:p:u:"
 PCS_LONG_OPTIONS = [
     "debug", "version", "help", "fullhelp",
-    "force", "skip-offline", "autocorrect", "interactive", "autodelete",
-    "all", "full", "groups", "local", "wait", "config", "async",
+    "force", "skip-offline", "interactive", "autodelete",
+    "all", "full", "local", "wait", "config",
     "start", "enable", "disabled", "off", "request-timeout=",
     "pacemaker", "corosync",
     "no-default-ops", "defaults", "nodesc",
-    "clone", "master", "name=", "group=", "node=",
+    "master", "name=", "group=", "node=",
     "from=", "to=", "after=", "before=",
-    "transport=", "rrpmode=", "ipv6",
-    "addr0=", "bcast0=", "mcast0=", "mcastport0=", "ttl0=", "broadcast0",
-    "addr1=", "bcast1=", "mcast1=", "mcastport1=", "ttl1=", "broadcast1",
-    "wait_for_all=", "auto_tie_breaker=", "last_man_standing=", "netmtu=",
-    "last_man_standing_window=",
-    "token=", "token_coefficient=", "consensus=", "join=",
-    "miss_count_const=", "fail_recv_const=",
-    "corosync_conf=", "cluster_conf=",
-    "booth-conf=", "booth-key=",
-    "remote", "watchdog=", "device=", "encryption=", "no-watchdog-validation",
+    "corosync_conf=",
+    "booth-conf=", "booth-key=", "no-watchdog-validation", "no-keys-sync",
     #in pcs status - do not display resorce status on inactive node
     "hide-inactive",
     # pcs resource (un)manage - enable or disable monitor operations
@@ -44,6 +30,37 @@ def split_list(arg_list, separator):
     bounds = zip([0]+[i+1 for i in separator_indexes], separator_indexes+[None])
     return [arg_list[i:j] for i, j in bounds]
 
+def split_list_by_any_keywords(arg_list, keyword_label):
+    """
+    Return a list of lists of args using any arg not containing = as a delimiter
+
+    iterable arg_list -- (part of) argv
+    string keyword_label -- description of all keywords
+    """
+    if "=" in arg_list[0]:
+        raise CmdLineInputError(
+            "Invalid character '=' in {} '{}'".format(
+                keyword_label,
+                arg_list[0],
+            )
+        )
+    current_keyword = None
+    groups = {}
+    for arg in arg_list:
+        if "=" in arg:
+            groups[current_keyword].append(arg)
+        else:
+            current_keyword = arg
+            if current_keyword in groups:
+                raise CmdLineInputError(
+                    "{} '{}' defined multiple times".format(
+                        keyword_label.capitalize(),
+                        current_keyword
+                    )
+                )
+            groups[current_keyword] = []
+    return groups
+
 def split_option(arg):
     """
     Get (key, value) from a key=value commandline argument.
@@ -52,6 +69,8 @@ def split_option(arg):
     CmdLineInputError if the argument cannot be splitted.
 
     string arg -- commandline argument
+
+    Commandline options: no options
     """
     if "=" not in arg:
         raise CmdLineInputError("missing value of '{0}' option".format(arg))
@@ -59,13 +78,22 @@ def split_option(arg):
         raise CmdLineInputError("missing key in '{0}' option".format(arg))
     return arg.split("=", 1)
 
-def prepare_options(cmdline_args):
-    """return dictionary of options from commandline key=value args"""
+def prepare_options(cmdline_args, allowed_repeatable_options=()):
+    """
+    return dictionary of options from commandline key=value args
+
+    Commandline options: no options
+    """
     options = dict()
     for arg in cmdline_args:
         name, value = split_option(arg)
         if name not in options:
-            options[name] = value
+            if name in allowed_repeatable_options:
+                options[name] = [value]
+            else:
+                options[name] = value
+        elif name in allowed_repeatable_options:
+            options[name].append(value)
         elif options[name] != value:
             raise CmdLineInputError(
                 "duplicate option '{0}' with different values '{1}' and '{2}'"
@@ -274,32 +302,79 @@ def filter_out_options(arg_list):
             args_without_options.append(arg)
     return args_without_options
 
-def upgrade_args(arg_list):
-    """
-    Return modified copy of arg_list.
-    This function transform some old syntax to new syntax to keep backward
-    compatibility.
 
-    list arg_list contains command line arguments
-    """
-    upgraded_args = []
-    args_without_options = filter_out_options(arg_list)
-    for arg in arg_list:
-        if arg in ["--cloneopt", "--clone"]:
-            #for every commands - kept as it was previously
-            upgraded_args.append("clone")
-        elif arg.startswith("--cloneopt="):
-            #for every commands - kept as it was previously
-            upgraded_args.append("clone")
-            upgraded_args.append(arg.split('=', 1)[1])
-        elif(
-            #only for resource create - currently the only known problematic
-            #place
-            arg == "--master"
-            and
-            args_without_options[:2] == ["resource", "create"]
-        ):
-            upgraded_args.append("master")
-        else:
-            upgraded_args.append(arg)
-    return upgraded_args
+class InputModifiers():
+    def __init__(self, options):
+        self._defined_options = set(options.keys())
+        self._options = dict(options)
+        self._options.update({
+            # boolean values
+            "--all": "--all" in options,
+            "--autodelete": "--autodelete" in options,
+            "--config": "--config" in options,
+            "--corosync": "--corosync" in options,
+            "--debug": "--debug" in options,
+            "--defaults": "--defaults" in options,
+            "--disabled": "--disabled" in options,
+            "--enable": "--enable" in options,
+            "--force": "--force" in options,
+            "--full": "--full" in options,
+            "--hide-inactive": "--hide-inactive" in options,
+            "--interactive": "--interactive" in options,
+            "--local": "--local" in options,
+            "--master": "--master" in options,
+            "--monitor": "--monitor" in options,
+            "--no-default-ops": "--no-default-ops" in options,
+            "--nodesc": "--nodesc" in options,
+            "--no-keys-sync": "--no-keys-sync" in options,
+            "--no-watchdog-validation": "--no-watchdog-validation" in options,
+            "--off": "--off" in options,
+            "--pacemaker": "--pacemaker" in options,
+            "--skip-offline": "--skip-offline" in options,
+            "--start": "--start" in options,
+            # string values
+            "--after": options.get("--after", None),
+            "--before": options.get("--before", None),
+            "--booth-conf": options.get("--booth-conf", None),
+            "--booth-key": options.get("--booth-key", None),
+            "--corosync_conf": options.get("--corosync_conf", None),
+            "--from": options.get("--from", None),
+            "--group": options.get("--group", None),
+            "--name": options.get("--name", None),
+            "--node": options.get("--node", None),
+            "--request-timeout": options.get("--request-timeout", None),
+            "--to": options.get("--to", None),
+            "--wait": options.get("--wait", False),
+            "-f": options.get("-f", None),
+            "-p": options.get("-p", None),
+            "-u": options.get("-u", None),
+        })
+
+    def get_subset(self, *options):
+        return InputModifiers(
+            {opt: self.get(opt) for opt in options if self.is_specified(opt)}
+        )
+
+    def ensure_only_supported(self, *supported_options):
+        unsupported_options = (
+            # --debug is supported in all commands
+            self._defined_options - set(supported_options) - set(["--debug"])
+        )
+        if unsupported_options:
+            raise CmdLineInputError(
+                "Specified options {} are not supported in this command".format(
+                    format_list(list(unsupported_options))
+                )
+            )
+
+    def is_specified(self, option):
+        return option in self._defined_options
+
+    def get(self, option, default=None):
+        if option in self._defined_options:
+            return self._options[option]
+        if default is not None:
+            return default
+        if option in self._options:
+            return self._options[option]
+        raise AssertionError(f"Non existing default value for '{option}'")
