@@ -1,11 +1,5 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import mock, TestCase
 
-from pcs.test.tools.pcs_unittest import TestCase
-from pcs.test.tools.pcs_unittest import mock
 from pcs.cli.common import env_file
 from pcs.test.tools.misc import create_patcher, create_setup_patch_mixin
 
@@ -123,6 +117,7 @@ class ProcessNoExistingFileExpectation(TestCase, SetupPatchMixin):
 class ReportMissing(TestCase):
     @patch_env_file("console_report.error")
     def test_report_to_console(self, error):
+        # pylint: disable=no-self-use
         env_file.report_missing("role", "path")
         error.assert_called_once_with("role 'path' does not exist")
 
