@@ -1,10 +1,5 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import TestCase
 
-from pcs.test.tools.pcs_unittest import TestCase
 from pcs.cli.common.parse_args import(
     group_by_keywords,
     parse_typed_arg,
@@ -17,7 +12,7 @@ from pcs.cli.common.parse_args import(
     is_short_option_expecting_value,
     is_long_option_expecting_value,
     is_option_expecting_value,
-    upgrade_args,
+    InputModifiers,
 )
 from pcs.cli.common.errors import CmdLineInputError
 
@@ -44,9 +39,29 @@ class PrepareOptionsTest(TestCase):
             CmdLineInputError, lambda: prepare_options(['a=a', "a=b"])
         )
 
-    def test_accept_options_with_ssame_key_and_same_value(self):
+    def test_accept_options_with_same_key_and_same_value(self):
         self.assertEqual({'a': '1'}, prepare_options(["a=1", "a=1"]))
 
+    def test_allow_repeatable(self):
+        self.assertEqual(
+            {'a': ['1', '2']},
+            prepare_options(["a=1", "a=2"], allowed_repeatable_options=("a"))
+        )
+
+    def test_allow_repeatable_only_once(self):
+        self.assertEqual(
+            {'a': ['1']},
+            prepare_options(["a=1"], allowed_repeatable_options=("a"))
+        )
+
+    def test_allow_repeatable_multiple(self):
+        self.assertEqual(
+            {'a': ['1', '3', '2', '4']},
+            prepare_options(
+                ["a=1", "a=3", "a=2", "a=4"], allowed_repeatable_options=("a")
+            )
+        )
+
 
 class SplitListTest(TestCase):
     def test_returns_list_with_original_when_separator_not_in_original(self):
@@ -61,7 +76,7 @@ class SplitListTest(TestCase):
     def test_behave_like_string_split_when_the_separator_edges(self):
         self.assertEqual(
             [[], ['a', 'b'], ['c', 'd'], []],
-            split_list(['|','a', 'b', '|', 'c', 'd', "|"], '|')
+            split_list(['|', 'a', 'b', '|', 'c', 'd', "|"], '|')
         )
 
 class SplitByKeywords(TestCase):
@@ -304,8 +319,8 @@ class FilterOutNonOptionNegativeNumbers(TestCase):
 
     def test_remove_follower_of_long_unsigned_option(self):
         self.assertEqual(
-            ["first", "--master"],
-            filter_out_non_option_negative_numbers(["first", "--master", "-1"])
+            ["first", "--clone"],
+            filter_out_non_option_negative_numbers(["first", "--clone", "-1"])
         )
 
     def test_does_not_remove_dash(self):
@@ -346,7 +361,7 @@ class FilterOutOptions(TestCase):
     def test_remove_unsigned_long_option(self):
         self.assertEqual(
             ["first", "second"],
-            filter_out_options(["first", "--master", "second"])
+            filter_out_options(["first", "--clone", "second"])
         )
 
     def test_remove_signed_long_option_with_value(self):
@@ -420,10 +435,12 @@ class IsLongOptionExpectingValue(TestCase):
         self.assertTrue(is_long_option_expecting_value("--name"))
 
     def test_returns_false_on_long_option_without_value(self):
-        self.assertFalse(is_long_option_expecting_value("--master"))
+        self.assertFalse(is_long_option_expecting_value("--clone"))
 
     def test_returns_false_on_unknown_long_option(self):
-        self.assertFalse(is_long_option_expecting_value("--not-specified-long-opt"))
+        self.assertFalse(
+            is_long_option_expecting_value("--not-specified-long-opt")
+        )
 
     def test_returns_false_on_dash_dash(self):
         self.assertFalse(is_long_option_expecting_value("--"))
@@ -445,7 +462,7 @@ class IsOptionExpectingValue(TestCase):
         self.assertFalse(is_option_expecting_value("-h"))
 
     def test_returns_false_on_long_option_without_value(self):
-        self.assertFalse(is_option_expecting_value("--master"))
+        self.assertFalse(is_option_expecting_value("--clone"))
 
     def test_returns_false_on_unknown_short_option(self):
         self.assertFalse(is_option_expecting_value("-x"))
@@ -463,49 +480,155 @@ class IsOptionExpectingValue(TestCase):
         self.assertFalse(is_option_expecting_value("--name=Name"))
         self.assertFalse(is_option_expecting_value("-fvalue"))
 
-class UpgradeArgs(TestCase):
-    def test_returns_the_same_args_when_no_older_versions_detected(self):
-        args = ["first", "second"]
-        self.assertEqual(args, upgrade_args(args))
 
-    def test_upgrade_2dash_cloneopt(self):
-        self.assertEqual(
-            ["first", "clone", "second"],
-            upgrade_args(["first", "--cloneopt", "second"])
+class InputModifiersTest(TestCase):
+    # pylint: disable=too-many-public-methods, no-self-use
+    def setUp(self):
+        self.supported = ["a", "b", "c"]
+        self.bool_opts = [
+            "--all",
+            "--autodelete",
+            "--config",
+            "--corosync",
+            "--debug",
+            "--defaults",
+            "--disabled",
+            "--enable",
+            "--force",
+            "--full",
+            "--hide-inactive",
+            "--interactive",
+            "--local",
+            "--master",
+            "--monitor",
+            "--no-default-ops",
+            "--no-watchdog-validation",
+            "--nodesc",
+            "--off",
+            "--pacemaker",
+            "--skip-offline",
+            "--start",
+        ]
+        self.val_opts = [
+            "--after",
+            "--before",
+            "--booth-conf",
+            "--booth-key",
+            "--corosync_conf",
+            "--from",
+            "--group",
+            "--name",
+            "--node",
+            "--request-timeout",
+            "--to",
+            # "--wait", # --wait is a special case, it has its own tests
+            "-f",
+            "-p",
+            "-u",
+        ]
+
+    def _get_specified(self, *keys):
+        return {key: i for i, key in enumerate(keys)}
+
+    def ensure(self, *specified):
+        InputModifiers(self._get_specified(*specified)).ensure_only_supported(
+            *self.supported
         )
 
-    def test_upgrade_2dash_clone(self):
+    def test_supported_one(self):
+        self.ensure("a")
+
+    def test_supported_multiple(self):
+        self.ensure("a", "b")
+
+    def test_not_supported_one(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            self.ensure("a", "e")
         self.assertEqual(
-            ["first", "clone", "second"],
-            upgrade_args(["first", "--clone", "second"])
+            "Specified options 'e' are not supported in this command",
+            cm.exception.message
         )
 
-    def test_upgrade_2dash_cloneopt_with_value(self):
+    def test_not_supported_multiple(self):
+        with self.assertRaises(CmdLineInputError) as cm:
+            self.ensure("a", "g", "d", "c", "b", "e")
         self.assertEqual(
-            ["first", "clone", "1", "second"],
-            upgrade_args(["first", "--cloneopt=1", "second"])
+            "Specified options 'd', 'e', 'g' are not supported in this command",
+            cm.exception.message
         )
 
-    def test_upgrade_2dash_master_in_resource_create(self):
+    def test_get_existing(self):
+        self.assertEqual(1, InputModifiers({"a": 1}).get("a"))
+
+    def test_get_existing_with_default(self):
+        self.assertEqual(1, InputModifiers({"a": 1}).get("a", default=2))
+
+    def test_multiple_get_existing(self):
         self.assertEqual(
-            ["resource", "create", "master", "second"],
-            upgrade_args(["resource", "create", "--master", "second"])
+            2, InputModifiers(dict(c=3, a=1, b=2)).get("b")
         )
 
-    def test_dont_upgrade_2dash_master_outside_of_resource_create(self):
+    def test_multiple_get_existing_with_default(self):
         self.assertEqual(
-            ["first", "--master", "second"],
-            upgrade_args(["first", "--master", "second"])
+            2, InputModifiers(dict(c=3, a=1, b=2)).get("b", default=1)
         )
 
-    def test_upgrade_2dash_master_in_resource_create_with_complications(self):
+    def test_default(self):
+        self.assertEqual(2, InputModifiers({"a": 1}).get("b", default=2))
+
+    def test_debug_implicit(self):
+        InputModifiers({"--debug": ""}).ensure_only_supported()
+
+    def test_bool_options(self):
+        for opt in self.bool_opts:
+            with self.subTest(opt=opt):
+                self.assertTrue(InputModifiers({opt: ""}).get(opt), opt)
+
+    def test_bool_options_defaults(self):
+        for opt in self.bool_opts:
+            with self.subTest(opt=opt):
+                self.assertFalse(InputModifiers({}).get(opt), opt)
+
+    def test_val_options(self):
+        val = "something"
+        for opt in self.val_opts:
+            with self.subTest(opt=opt):
+                self.assertEqual(val, InputModifiers({opt: val}).get(opt), opt)
+
+    def test_val_options_defaults(self):
+        for opt in self.val_opts:
+            with self.subTest(opt=opt):
+                self.assertIsNone(InputModifiers({}).get(opt), opt)
+
+    def test_wait(self):
+        opt = "--wait"
+        val = "something"
+        self.assertEqual(val, InputModifiers({opt: val}).get(opt))
+
+    def test_wait_default(self):
+        self.assertFalse(InputModifiers({}).get("--wait"))
+
+    def test_explicit_default(self):
+        val = "something"
+        self.assertEqual(val, InputModifiers({}).get("--force", default=val))
+
+    def test_explicit_default_not_used(self):
+        opt = "--force"
+        self.assertTrue(InputModifiers({opt: ""}).get(opt, default=False))
+
+    def test_get_non_existing(self):
+        opt = "not_existing_option"
+        with self.assertRaises(AssertionError) as cm:
+            InputModifiers({}).get(opt)
         self.assertEqual(
-            [
-                "-f", "path/to/file", "resource", "-V", "create", "master",
-                "second"
-            ],
-            upgrade_args([
-                "-f", "path/to/file", "resource", "-V", "create", "--master",
-                "second"
-            ])
+            f"Non existing default value for '{opt}'", str(cm.exception)
         )
+
+    def test_is_specified(self):
+        self.assertTrue(InputModifiers({"a": "1"}).is_specified("a"))
+
+    def test_not_specified(self):
+        self.assertFalse(InputModifiers({"a": "1"}).is_specified("b"))
+
+    def test_not_specified_default(self):
+        self.assertFalse(InputModifiers({"a": "1"}).is_specified("--debug"))
