@@ -1,9 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.constraint import command
 from pcs.cli.constraint_colocation import console_report
 
@@ -15,8 +10,13 @@ def create_with_set(lib, argv, modifiers):
     list argv see usage for "constraint colocation set"
     dict like object modifiers can contain
         "force" allows resource in clone/master and constraint duplicity
-        "autocorrect" allows correct resource to its clone/master parent
+
+    Options:
+      * --force - allow resource inside clone (or master), allow duplicate
+        element
+      * -f - CIB file
     """
+    modifiers.ensure_only_supported("-f", "--force")
     command.create_with_set(
         lib.constraint_colocation.set,
         argv,
@@ -29,7 +29,14 @@ def show(lib, argv, modifiers):
     object lib exposes library
     list argv see usage for "constraint colocation show"
     dict like object modifiers can contain "full"
+
+    Options:
+      * --full - print more details
+      * -f - CIB file
     """
+    modifiers.ensure_only_supported("-f", "--full")
+    if argv:
+        raise CmdLineInputError()
     print("\n".join(command.show(
          "Colocation Constraints:",
         lib.constraint_colocation.show,
