@@ -1,24 +1,24 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+# pylint: disable=line-too-long
 
 # force cathegories
-FORCE_ACTIVE_RRP = "ACTIVE_RRP"
+FORCE = "FORCE"
 FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE = "FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE"
+FORCE_ALREADY_IN_CLUSTER = "FORCE_ALREADY_IN_CLUSTER"
 FORCE_BOOTH_DESTROY = "FORCE_BOOTH_DESTROY"
 FORCE_BOOTH_REMOVE_FROM_CIB = "FORCE_BOOTH_REMOVE_FROM_CIB"
 FORCE_REMOVE_MULTIPLE_NODES = "FORCE_REMOVE_MULTIPLE_NODES"
-FORCE_CONSTRAINT_DUPLICATE = "CONSTRAINT_DUPLICATE"
-FORCE_CONSTRAINT_MULTIINSTANCE_RESOURCE = "CONSTRAINT_MULTIINSTANCE_RESOURCE"
+FORCE_CONSTRAINT_DUPLICATE = "FORCE_CONSTRAINT_DUPLICATE"
+FORCE_CONSTRAINT_MULTIINSTANCE_RESOURCE = "FORCE_CONSTRAINT_MULTIINSTANCE_RESOURCE"
 FORCE_FILE_OVERWRITE = "FORCE_FILE_OVERWRITE"
-FORCE_LOAD_THRESHOLD = "LOAD_THRESHOLD"
-FORCE_METADATA_ISSUE = "METADATA_ISSUE"
+FORCE_LOAD_NODES_FROM_CIB = "FORCE_LOAD_NODES_FROM_CIB"
+FORCE_LOAD_THRESHOLD = "FORCE_LOAD_THRESHOLD"
+FORCE_METADATA_ISSUE = "FORCE_METADATA_ISSUE"
+FORCE_NODE_ADDRESSES_UNRESOLVABLE = "FORCE_NODE_ADDRESSES_UNRESOLVABLE"
 FORCE_NODE_DOES_NOT_EXIST = "FORCE_NODE_DOES_NOT_EXIST"
-FORCE_OPTIONS = "OPTIONS"
-FORCE_QDEVICE_MODEL = "QDEVICE_MODEL"
-FORCE_QDEVICE_USED = "QDEVICE_USED"
+FORCE_OPTIONS = "FORCE_OPTIONS"
+FORCE_QDEVICE_MODEL = "FORCE_QDEVICE_MODEL"
+FORCE_QDEVICE_USED = "FORCE_QDEVICE_USED"
+FORCE_QUORUM_LOSS = "FORCE_QUORUM_LOSS"
 FORCE_STONITH_RESOURCE_DOES_NOT_EXIST = "FORCE_STONITH_RESOURCE_DOES_NOT_EXIST"
 FORCE_NOT_SUITABLE_COMMAND = "FORCE_NOT_SUITABLE_COMMAND"
 FORCE_CLEAR_CLUSTER_NODE = "FORCE_CLEAR_CLUSTER_NODE"
@@ -27,7 +27,6 @@ SKIP_OFFLINE_NODES = "SKIP_OFFLINE_NODES"
 SKIP_FILE_DISTRIBUTION_ERRORS = "SKIP_FILE_DISTRIBUTION_ERRORS"
 SKIP_ACTION_ON_NODES_ERRORS = "SKIP_ACTION_ON_NODES_ERRORS"
 SKIP_UNREADABLE_CONFIG = "SKIP_UNREADABLE_CONFIG"
-SKIP_WATCHDOG_VALIDATION = "SKIP_WATCHDOG_VALIDATION"
 
 AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE = "AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE"
 AGENT_NAME_GUESS_FOUND_NONE = "AGENT_NAME_GUESS_FOUND_NONE"
@@ -61,6 +60,7 @@ BOOTH_TICKET_NAME_INVALID = "BOOTH_TICKET_NAME_INVALID"
 BOOTH_TICKET_OPERATION_FAILED = "BOOTH_TICKET_OPERATION_FAILED"
 BOOTH_TICKET_STATUS_ERROR = "BOOTH_TICKET_STATUS_ERROR"
 BOOTH_UNSUPORTED_FILE_LOCATION = "BOOTH_UNSUPORTED_FILE_LOCATION"
+CANNOT_REMOVE_ALL_CLUSTER_NODES = "CANNOT_REMOVE_ALL_CLUSTER_NODES"
 CIB_ACL_ROLE_IS_ALREADY_ASSIGNED_TO_TARGET = "CIB_ACL_ROLE_IS_ALREADY_ASSIGNED_TO_TARGET"
 CIB_ACL_ROLE_IS_NOT_ASSIGNED_TO_TARGET = "CIB_ACL_ROLE_IS_NOT_ASSIGNED_TO_TARGET"
 CIB_ACL_TARGET_ALREADY_EXISTS = "CIB_ACL_TARGET_ALREADY_EXISTS"
@@ -72,6 +72,7 @@ CIB_FENCING_LEVEL_ALREADY_EXISTS = "CIB_FENCING_LEVEL_ALREADY_EXISTS"
 CIB_FENCING_LEVEL_DOES_NOT_EXIST = "CIB_FENCING_LEVEL_DOES_NOT_EXIST"
 CIB_LOAD_ERROR_BAD_FORMAT = "CIB_LOAD_ERROR_BAD_FORMAT"
 CIB_LOAD_ERROR = "CIB_LOAD_ERROR"
+CIB_LOAD_ERROR_GET_NODES_FOR_VALIDATION = "CIB_LOAD_ERROR_GET_NODES_FOR_VALIDATION"
 CIB_LOAD_ERROR_SCOPE_MISSING = "CIB_LOAD_ERROR_SCOPE_MISSING"
 CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET = "CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET"
 CIB_PUSH_ERROR = "CIB_PUSH_ERROR"
@@ -79,49 +80,70 @@ CIB_SAVE_TMP_ERROR = "CIB_SAVE_TMP_ERROR"
 CIB_UPGRADE_FAILED = "CIB_UPGRADE_FAILED"
 CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION = "CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION"
 CIB_UPGRADE_SUCCESSFUL = "CIB_UPGRADE_SUCCESSFUL"
-CLUSTER_CONF_LOAD_ERROR_INVALID_FORMAT = "CLUSTER_CONF_LOAD_ERROR_INVALID_FORMAT"
-CLUSTER_CONF_READ_ERROR = "CLUSTER_CONF_READ_ERROR"
+CLUSTER_DESTROY_STARTED = "CLUSTER_DESTROY_STARTED"
+CLUSTER_DESTROY_SUCCESS = "CLUSTER_DESTROY_SUCCESS"
+CLUSTER_ENABLE_STARTED = "CLUSTER_ENABLE_STARTED"
+CLUSTER_ENABLE_SUCCESS = "CLUSTER_ENABLE_SUCCESS"
 CLUSTER_RESTART_REQUIRED_TO_APPLY_CHANGES = "CLUSTER_RESTART_REQUIRED_TO_APPLY_CHANGES"
-CMAN_BROADCAST_ALL_RINGS = 'CMAN_BROADCAST_ALL_RINGS'
-CMAN_UDPU_RESTART_REQUIRED = 'CMAN_UDPU_RESTART_REQUIRED'
-CMAN_UNSUPPORTED_COMMAND = "CMAN_UNSUPPORTED_COMMAND"
-COMMON_ERROR = 'COMMON_ERROR'
-COMMON_INFO = 'COMMON_INFO'
+CLUSTER_SETUP_SUCCESS = "CLUSTER_SETUP_SUCCESS"
+CLUSTER_START_STARTED = "CLUSTER_START_STARTED"
+CLUSTER_START_SUCCESS = "CLUSTER_START_SUCCESS"
+CLUSTER_WILL_BE_DESTROYED = "CLUSTER_WILL_BE_DESTROYED"
 LIVE_ENVIRONMENT_REQUIRED = "LIVE_ENVIRONMENT_REQUIRED"
 LIVE_ENVIRONMENT_REQUIRED_FOR_LOCAL_NODE = "LIVE_ENVIRONMENT_REQUIRED_FOR_LOCAL_NODE"
+COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK = "COROSYNC_ADDRESS_IP_VERSION_WRONG_FOR_LINK"
+COROSYNC_BAD_NODE_ADDRESSES_COUNT = "COROSYNC_BAD_NODE_ADDRESSES_COUNT"
 COROSYNC_CONFIG_ACCEPTED_BY_NODE = "COROSYNC_CONFIG_ACCEPTED_BY_NODE"
 COROSYNC_CONFIG_DISTRIBUTION_STARTED = "COROSYNC_CONFIG_DISTRIBUTION_STARTED"
 COROSYNC_CONFIG_DISTRIBUTION_NODE_ERROR = "COROSYNC_CONFIG_DISTRIBUTION_NODE_ERROR"
 COROSYNC_CONFIG_RELOADED = "COROSYNC_CONFIG_RELOADED"
 COROSYNC_CONFIG_RELOAD_ERROR = "COROSYNC_CONFIG_RELOAD_ERROR"
+COROSYNC_CONFIG_RELOAD_NOT_POSSIBLE = "COROSYNC_CONFIG_RELOAD_NOT_POSSIBLE"
+COROSYNC_IP_VERSION_MISMATCH_IN_LINKS = "COROSYNC_IP_VERSION_MISMATCH_IN_LINKS"
+COROSYNC_LINK_NUMBER_DUPLICATION = "COROSYNC_LINK_NUMBER_DUPLICATION"
+COROSYNC_NODE_ADDRESS_COUNT_MISMATCH = "COROSYNC_NODE_ADDRESS_COUNT_MISMATCH"
+COROSYNC_NODE_CONFLICT_CHECK_SKIPPED = "COROSYNC_NODE_CONFLICT_CHECK_SKIPPED"
+COROSYNC_NODES_MISSING = "COROSYNC_NODES_MISSING"
 COROSYNC_NOT_RUNNING_CHECK_STARTED = "COROSYNC_NOT_RUNNING_CHECK_STARTED"
 COROSYNC_NOT_RUNNING_CHECK_NODE_ERROR = "COROSYNC_NOT_RUNNING_CHECK_NODE_ERROR"
 COROSYNC_NOT_RUNNING_ON_NODE = "COROSYNC_NOT_RUNNING_ON_NODE"
 COROSYNC_OPTIONS_INCOMPATIBLE_WITH_QDEVICE = "COROSYNC_OPTIONS_INCOMPATIBLE_WITH_QDEVICE"
-COROSYNC_QUORUM_CANNOT_DISABLE_ATB_DUE_TO_SBD = "COROSYNC_QUORUM_CANNOT_DISABLE_ATB_DUE_TO_SBD"
+COROSYNC_QUORUM_ATB_CANNOT_BE_DISABLED_DUE_TO_SBD = "COROSYNC_QUORUM_ATB_CANNOT_BE_DISABLED_DUE_TO_SBD"
+COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD = "COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD"
 COROSYNC_QUORUM_GET_STATUS_ERROR = "COROSYNC_QUORUM_GET_STATUS_ERROR"
 COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC = "COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC"
 COROSYNC_QUORUM_SET_EXPECTED_VOTES_ERROR = "COROSYNC_QUORUM_SET_EXPECTED_VOTES_ERROR"
+COROSYNC_QUORUM_WILL_BE_LOST = "COROSYNC_QUORUM_WILL_BE_LOST"
+COROSYNC_QUORUM_LOSS_UNABLE_TO_CHECK = "COROSYNC_QUORUM_LOSS_UNABLE_TO_CHECK"
 COROSYNC_RUNNING_ON_NODE = "COROSYNC_RUNNING_ON_NODE"
+COROSYNC_TOO_MANY_LINKS = "COROSYNC_TOO_MANY_LINKS"
+COROSYNC_TRANSPORT_UNSUPPORTED_OPTIONS = "COROSYNC_TRANSPORT_UNSUPPORTED_OPTIONS"
 CRM_MON_ERROR = "CRM_MON_ERROR"
 DEFAULTS_CAN_BE_OVERRIDEN = "DEFAULTS_CAN_BE_OVERRIDEN"
 DEPRECATED_OPTION = "DEPRECATED_OPTION"
 DUPLICATE_CONSTRAINTS_EXIST = "DUPLICATE_CONSTRAINTS_EXIST"
 EMPTY_RESOURCE_SET_LIST = "EMPTY_RESOURCE_SET_LIST"
 EMPTY_ID = "EMPTY_ID"
-FILE_ALREADY_EXISTS = "FILE_ALREADY_EXISTS"
-FILE_DOES_NOT_EXIST = "FILE_DOES_NOT_EXIST"
-FILE_IO_ERROR = "FILE_IO_ERROR"
+FENCE_HISTORY_COMMAND_ERROR = "FENCE_HISTORY_COMMAND_ERROR"
+FENCE_HISTORY_NOT_SUPPORTED = "FENCE_HISTORY_NOT_SUPPORTED"
+FILES_DISTRIBUTION_SKIPPED = "FILES_DISTRIBUTION_SKIPPED"
 FILES_DISTRIBUTION_STARTED = "FILES_DISTRIBUTION_STARTED"
+FILES_REMOVE_FROM_NODES_STARTED = "FILES_REMOVE_FROM_NODES_STARTED"
+FILES_REMOVE_FROM_NODES_SKIPPED = "FILES_REMOVE_FROM_NODES_SKIPPED"
+FILE_ALREADY_EXISTS = "FILE_ALREADY_EXISTS"
 FILE_DISTRIBUTION_ERROR = "FILE_DISTRIBUTION_ERROR"
 FILE_DISTRIBUTION_SUCCESS = "FILE_DISTRIBUTION_SUCCESS"
-FILES_REMOVE_FROM_NODE_STARTED = "FILES_REMOVE_FROM_NODE_STARTED"
+FILE_DOES_NOT_EXIST = "FILE_DOES_NOT_EXIST"
+FILE_IO_ERROR = "FILE_IO_ERROR"
 FILE_REMOVE_FROM_NODE_ERROR = "FILE_REMOVE_FROM_NODE_ERROR"
 FILE_REMOVE_FROM_NODE_SUCCESS = "FILE_REMOVE_FROM_NODE_SUCCESS"
+HOST_NOT_FOUND = "HOST_NOT_FOUND"
+HOST_ALREADY_AUTHORIZED = "HOST_ALREADY_AUTHORIZED"
+HOST_ALREADY_IN_CLUSTER_CONFIG = "HOST_ALREADY_IN_CLUSTER_CONFIG"
+HOST_ALREADY_IN_CLUSTER_SERVICES = "HOST_ALREADY_IN_CLUSTER_SERVICES"
 ID_ALREADY_EXISTS = 'ID_ALREADY_EXISTS'
 ID_BELONGS_TO_UNEXPECTED_TYPE = "ID_BELONGS_TO_UNEXPECTED_TYPE"
 ID_NOT_FOUND = 'ID_NOT_FOUND'
-IGNORED_CMAN_UNSUPPORTED_OPTION = 'IGNORED_CMAN_UNSUPPORTED_OPTION'
 INVALID_CIB_CONTENT = "INVALID_CIB_CONTENT"
 INVALID_ID = "INVALID_ID"
 INVALID_OPTIONS = "INVALID_OPTIONS"
@@ -137,8 +159,9 @@ INVALID_TIMEOUT_VALUE = "INVALID_TIMEOUT_VALUE"
 MULTIPLE_SCORE_OPTIONS = "MULTIPLE_SCORE_OPTIONS"
 MULTIPLE_RESULTS_FOUND = "MULTIPLE_RESULTS_FOUND"
 MUTUALLY_EXCLUSIVE_OPTIONS = "MUTUALLY_EXCLUSIVE_OPTIONS"
-CANNOT_ADD_NODE_IS_IN_CLUSTER = "CANNOT_ADD_NODE_IS_IN_CLUSTER"
-CANNOT_ADD_NODE_IS_RUNNING_SERVICE = "CANNOT_ADD_NODE_IS_RUNNING_SERVICE"
+NODE_ADDRESSES_ALREADY_EXIST = "NODE_ADDRESSES_ALREADY_EXIST"
+NODE_ADDRESSES_DUPLICATION = "NODE_ADDRESSES_DUPLICATION"
+NODE_ADDRESSES_UNRESOLVABLE = "NODE_ADDRESSES_UNRESOLVABLE"
 NODE_COMMUNICATION_COMMAND_UNSUCCESSFUL = "NODE_COMMUNICATION_COMMAND_UNSUCCESSFUL"
 NODE_COMMUNICATION_DEBUG_INFO = "NODE_COMMUNICATION_DEBUG_INFO"
 NODE_COMMUNICATION_ERROR = "NODE_COMMUNICATION_ERROR"
@@ -153,12 +176,13 @@ NODE_COMMUNICATION_NO_MORE_ADDRESSES = "NODE_COMMUNICATION_NO_MORE_ADDRESSES"
 NODE_COMMUNICATION_PROXY_IS_SET = "NODE_COMMUNICATION_PROXY_IS_SET"
 NODE_COMMUNICATION_RETRYING = "NODE_COMMUNICATION_RETRYING"
 NODE_COMMUNICATION_STARTED = "NODE_COMMUNICATION_STARTED"
+NODE_NAMES_ALREADY_EXIST = "NODE_NAMES_ALREADY_EXIST"
+NODE_NAMES_DUPLICATION = "NODE_NAMES_DUPLICATION"
 NODE_NOT_FOUND = "NODE_NOT_FOUND"
 NODE_REMOVE_IN_PACEMAKER_FAILED = "NODE_REMOVE_IN_PACEMAKER_FAILED"
-NON_UDP_TRANSPORT_ADDR_MISMATCH = 'NON_UDP_TRANSPORT_ADDR_MISMATCH'
-NOLIVE_SKIP_FILES_DISTRIBUTION="NOLIVE_SKIP_FILES_DISTRIBUTION"
-NOLIVE_SKIP_FILES_REMOVE="NOLIVE_SKIP_FILES_REMOVE"
-NOLIVE_SKIP_SERVICE_COMMAND_ON_NODES="NOLIVE_SKIP_SERVICE_COMMAND_ON_NODES"
+NONE_HOST_FOUND = "NONE_HOST_FOUND"
+NODE_USED_AS_TIE_BREAKER = "NODE_USED_AS_TIE_BREAKER"
+NODES_TO_REMOVE_UNREACHABLE = "NODES_TO_REMOVE_UNREACHABLE"
 NODE_TO_CLEAR_IS_STILL_IN_CLUSTER = "NODE_TO_CLEAR_IS_STILL_IN_CLUSTER"
 OMITTING_NODE = "OMITTING_NODE"
 OBJECT_WITH_ID_IN_UNEXPECTED_CONTEXT = "OBJECT_WITH_ID_IN_UNEXPECTED_CONTEXT"
@@ -166,6 +190,12 @@ PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND = "PACEMAKER_LOCAL_NODE_NAME_NOT_FOUND"
 PARSE_ERROR_COROSYNC_CONF_MISSING_CLOSING_BRACE = "PARSE_ERROR_COROSYNC_CONF_MISSING_CLOSING_BRACE"
 PARSE_ERROR_COROSYNC_CONF = "PARSE_ERROR_COROSYNC_CONF"
 PARSE_ERROR_COROSYNC_CONF_UNEXPECTED_CLOSING_BRACE = "PARSE_ERROR_COROSYNC_CONF_UNEXPECTED_CLOSING_BRACE"
+PCSD_VERSION_TOO_OLD = "PCSD_VERSION_TOO_OLD"
+PCSD_SSL_CERT_AND_KEY_DISTRIBUTION_STARTED = "PCSD_SSL_CERT_AND_KEY_DISTRIBUTION_STARTED"
+PCSD_SSL_CERT_AND_KEY_SET_SUCCESS = "PCSD_SSL_CERT_AND_KEY_SET_SUCCESS"
+PREREQUISITE_OPTION_MUST_BE_ENABLED_AS_WELL = "PREREQUISITE_OPTION_MUST_BE_ENABLED_AS_WELL"
+PREREQUISITE_OPTION_MUST_BE_DISABLED = "PREREQUISITE_OPTION_MUST_BE_DISABLED"
+PREREQUISITE_OPTION_MUST_NOT_BE_SET = "PREREQUISITE_OPTION_MUST_NOT_BE_SET"
 PREREQUISITE_OPTION_IS_MISSING = "PREREQUISITE_OPTION_IS_MISSING"
 QDEVICE_ALREADY_DEFINED = "QDEVICE_ALREADY_DEFINED"
 QDEVICE_ALREADY_INITIALIZED = "QDEVICE_ALREADY_INITIALIZED"
@@ -189,6 +219,7 @@ QDEVICE_USED_BY_CLUSTERS = "QDEVICE_USED_BY_CLUSTERS"
 REQUIRED_OPTION_IS_MISSING = "REQUIRED_OPTION_IS_MISSING"
 REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING = "REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING"
 RESOURCE_BUNDLE_ALREADY_CONTAINS_A_RESOURCE = "RESOURCE_BUNDLE_ALREADY_CONTAINS_A_RESOURCE"
+RESOURCE_BUNDLE_UNSUPPORTED_CONTAINER_TYPE = "RESOURCE_BUNDLE_UNSUPPORTED_CONTAINER_TYPE"
 RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE = "RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE"
 RESOURCE_CANNOT_BE_NEXT_TO_ITSELF_IN_GROUP = "RESOURCE_CANNOT_BE_NEXT_TO_ITSELF_IN_GROUP"
 RESOURCE_CLEANUP_ERROR = "RESOURCE_CLEANUP_ERROR"
@@ -202,7 +233,6 @@ RESOURCE_OPERATION_INTERVAL_ADAPTED = "RESOURCE_OPERATION_INTERVAL_ADAPTED"
 RESOURCE_REFRESH_ERROR = "RESOURCE_REFRESH_ERROR"
 RESOURCE_REFRESH_TOO_TIME_CONSUMING = 'RESOURCE_REFRESH_TOO_TIME_CONSUMING'
 RESOURCE_RUNNING_ON_NODES = "RESOURCE_RUNNING_ON_NODES"
-RRP_ACTIVE_NOT_SUPPORTED = 'RRP_ACTIVE_NOT_SUPPORTED'
 RUN_EXTERNAL_PROCESS_ERROR = "RUN_EXTERNAL_PROCESS_ERROR"
 RUN_EXTERNAL_PROCESS_FINISHED = "RUN_EXTERNAL_PROCESS_FINISHED"
 RUN_EXTERNAL_PROCESS_STARTED = "RUN_EXTERNAL_PROCESS_STARTED"
@@ -225,8 +255,9 @@ SBD_LIST_WATCHDOG_ERROR = "SBD_LIST_WATCHDOG_ERROR"
 SBD_NO_DEVICE_FOR_NODE = "SBD_NO_DEVICE_FOR_NODE"
 SBD_NOT_ENABLED = "SBD_NOT_ENABLED"
 SBD_NOT_INSTALLED = "SBD_NOT_INSTALLED"
-SBD_REQUIRES_ATB = "SBD_REQUIRES_ATB"
+SBD_NOT_USED_CANNOT_SET_SBD_OPTIONS = "SBD_NOT_USED_CANNOT_SET_SBD_OPTIONS"
 SBD_TOO_MANY_DEVICES_FOR_NODE = "SBD_TOO_MANY_DEVICES_FOR_NODE"
+SBD_WITH_DEVICES_NOT_USED_CANNOT_SET_DEVICE = "SBD_WITH_DEVICES_NOT_USED_CANNOT_SET_DEVICE"
 SBD_WATCHDOG_NOT_SUPPORTED = "SBD_WATCHDOG_NOT_SUPPORTED"
 SBD_WATCHDOG_VALIDATION_INACTIVE = "SBD_WATCHDOG_VALIDATION_INACTIVE"
 SBD_WATCHDOG_TEST_ERROR = "SBD_WATCHDOG_TEST_ERROR"
@@ -241,6 +272,7 @@ SERVICE_ENABLE_SKIPPED = "SERVICE_ENABLE_SKIPPED"
 SERVICE_ENABLE_SUCCESS = "SERVICE_ENABLE_SUCCESS"
 SERVICE_KILL_ERROR = "SERVICE_KILL_ERROR"
 SERVICE_KILL_SUCCESS = "SERVICE_KILL_SUCCESS"
+SERVICE_NOT_INSTALLED = "SERVICE_NOT_INSTALLED"
 SERVICE_START_ERROR = "SERVICE_START_ERROR"
 SERVICE_START_SKIPPED = "SERVICE_START_SKIPPED"
 SERVICE_START_STARTED = "SERVICE_START_STARTED"
@@ -248,12 +280,16 @@ SERVICE_START_SUCCESS = "SERVICE_START_SUCCESS"
 SERVICE_STOP_ERROR = "SERVICE_STOP_ERROR"
 SERVICE_STOP_STARTED = "SERVICE_STOP_STARTED"
 SERVICE_STOP_SUCCESS = "SERVICE_STOP_SUCCESS"
+SERVICE_VERSION_MISMATCH = "SERVICE_VERSION_MISMATCH"
 STONITH_RESOURCES_DO_NOT_EXIST = "STONITH_RESOURCES_DO_NOT_EXIST"
 SERVICE_COMMANDS_ON_NODES_STARTED = "SERVICE_COMMANDS_ON_NODES_STARTED"
+SERVICE_COMMANDS_ON_NODES_SKIPPED = "SERVICE_COMMANDS_ON_NODES_SKIPPED"
 SERVICE_COMMAND_ON_NODE_ERROR = "SERVICE_COMMAND_ON_NODE_ERROR"
 SERVICE_COMMAND_ON_NODE_SUCCESS = "SERVICE_COMMAND_ON_NODE_SUCCESS"
 SYSTEM_WILL_RESET = "SYSTEM_WILL_RESET"
 TMP_FILE_WRITE = "TMP_FILE_WRITE"
+UNABLE_TO_CONNECT_TO_ANY_REMAINING_NODE = "UNABLE_TO_CONNECT_TO_ANY_REMAINING_NODE"
+UNABLE_TO_CONNECT_TO_ALL_REMAINING_NODE = "UNABLE_TO_CONNECT_TO_ALL_REMAINING_NODE"
 UNABLE_TO_DETERMINE_USER_UID = "UNABLE_TO_DETERMINE_USER_UID"
 UNABLE_TO_DETERMINE_GROUP_GID = "UNABLE_TO_DETERMINE_GROUP_GID"
 UNABLE_TO_GET_AGENT_METADATA = 'UNABLE_TO_GET_AGENT_METADATA'
@@ -267,8 +303,14 @@ UNSUPPORTED_OPERATION_ON_NON_SYSTEMD_SYSTEMS = "UNSUPPORTED_OPERATION_ON_NON_SYS
 USE_COMMAND_NODE_ADD_REMOTE = "USE_COMMAND_NODE_ADD_REMOTE"
 USE_COMMAND_NODE_ADD_GUEST = "USE_COMMAND_NODE_ADD_GUEST"
 USE_COMMAND_NODE_REMOVE_GUEST = "USE_COMMAND_NODE_REMOVE_GUEST"
+USING_KNOWN_HOST_ADDRESS_FOR_HOST = "USING_KNOWN_HOST_ADDRESS_FOR_HOST"
+USING_DEFAULT_WATCHDOG = "USING_DEFAULT_WATCHDOG"
 WAIT_FOR_IDLE_ERROR = "WAIT_FOR_IDLE_ERROR"
 WAIT_FOR_IDLE_NOT_LIVE_CLUSTER = "WAIT_FOR_IDLE_NOT_LIVE_CLUSTER"
 WAIT_FOR_IDLE_NOT_SUPPORTED = "WAIT_FOR_IDLE_NOT_SUPPORTED"
 WAIT_FOR_IDLE_TIMED_OUT = "WAIT_FOR_IDLE_TIMED_OUT"
+WAIT_FOR_NODE_STARTUP_ERROR = "WAIT_FOR_NODE_STARTUP_ERROR"
+WAIT_FOR_NODE_STARTUP_STARTED = "WAIT_FOR_NODE_STARTUP_STARTED"
+WAIT_FOR_NODE_STARTUP_TIMED_OUT = "WAIT_FOR_NODE_STARTUP_TIMED_OUT"
+WAIT_FOR_NODE_STARTUP_WITHOUT_START = "WAIT_FOR_NODE_STARTUP_WITHOUT_START"
 WATCHDOG_NOT_FOUND = "WATCHDOG_NOT_FOUND"
