@@ -1,22 +1,61 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import io
+from unittest import mock, TestCase
 
-from pcs.test.tools.pcs_unittest import mock, TestCase
 from pcs.test.tools.custom_mock import (
     MockCurl,
     MockCurlMulti,
 )
 
 from pcs import settings
-from pcs.common import pcs_pycurl as pycurl
-from pcs.lib.node import NodeAddresses
+from pcs.common import (
+    host,
+    pcs_pycurl as pycurl,
+)
+from pcs.common.host import Destination
 import pcs.common.node_communicator as lib
 
+PORT = settings.pcsd_default_port
+
+
+class NodeTargetFactory(TestCase):
+    def setUp(self):
+        self.known_name = "node"
+        self.unknown_name = "none"
+        self.known_host = host.PcsKnownHost(
+            self.known_name, "token", [host.Destination("addr", "port")]
+        )
+        self.factory = lib.NodeTargetFactory({self.known_name: self.known_host})
+
+    def assert_equal_known_host_target(self, known_host, target):
+        self.assertEqual(known_host.name, target.label)
+        self.assertEqual(known_host.token, target.token)
+        self.assertEqual(known_host.dest_list, target.dest_list)
+
+    def test_get_target_success(self):
+        self.assert_equal_known_host_target(
+            self.known_host, self.factory.get_target(self.known_name)
+        )
+
+    def test_get_target_not_found(self):
+        # pylint: disable=invalid-name
+        with self.assertRaises(lib.HostNotFound) as cm:
+            self.factory.get_target(self.unknown_name)
+        self.assertEqual(self.unknown_name, cm.exception.name)
+
+    def test_from_hostname_known(self):
+        self.assert_equal_known_host_target(
+            self.known_host,
+            self.factory.get_target_from_hostname(self.known_name)
+        )
+
+    def test_from_hostname_unknown(self):
+        target = self.factory.get_target_from_hostname(self.unknown_name)
+        self.assertEqual(self.unknown_name, target.label)
+        self.assertEqual(None, target.token)
+        self.assertEqual(
+            [host.Destination(self.unknown_name, PORT)], target.dest_list
+        )
+
 
 class RequestDataUrlEncodeTest(TestCase):
     def test_no_data(self):
@@ -35,11 +74,19 @@ class RequestDataUrlEncodeTest(TestCase):
         data = lib.RequestData(action, orig_data)
         self.assertEqual(action, data.action)
         self.assertEqual(orig_data, data.structured_data)
-        expected_raw_data = (
-            "key1=value1&spacial+characters=%2B-%2B%2F%25%26%3F%27%22%3B%5B" +
-            "%5D%28%29%2A%5E%24%23%40%21%7E%60%7B%3A%7D%3C%3E"
+        expected_raw_data_variants = (
+            "key1=value1&spacial+characters=%2B-%2B%2F%25%26%3F%27%22%3B%5B"
+                "%5D%28%29%2A%5E%24%23%40%21%7E%60%7B%3A%7D%3C%3E"
+            ,
+            "key1=value1&spacial+characters=%2B-%2B%2F%25%26%3F%27%22%3B%5B"
+                "%5D%28%29%2A%5E%24%23%40%21~%60%7B%3A%7D%3C%3E"
+            ,
         )
-        self.assertEqual(expected_raw_data, data.data)
+        self.assertTrue(data.data in expected_raw_data_variants)
+
+
+def _addr_list_to_dest(addr_list, port=None):
+    return [Destination(addr, port) for addr in addr_list]
 
 
 class RequestTargetConstructorTest(TestCase):
@@ -47,53 +94,38 @@ class RequestTargetConstructorTest(TestCase):
         label = "label"
         target = lib.RequestTarget(label)
         self.assertEqual(label, target.label)
-        self.assertEqual([label], target.address_list)
+        self.assertEqual(
+            _addr_list_to_dest([label], port=PORT), target.dest_list
+        )
 
     def test_with_adresses(self):
         label = "label"
         address_list = ["a1", "a2"]
         original_list = list(address_list)
-        target = lib.RequestTarget(label, address_list=address_list)
+        target = lib.RequestTarget(
+            label, dest_list=_addr_list_to_dest(address_list)
+        )
         address_list.append("a3")
         self.assertEqual(label, target.label)
-        self.assertIsNot(address_list, target.address_list)
-        self.assertEqual(original_list, target.address_list)
+        self.assertIsNot(_addr_list_to_dest(address_list), target.dest_list)
+        self.assertEqual(_addr_list_to_dest(original_list), target.dest_list)
 
 
-class RequestTargetFromNodeAdressesTest(TestCase):
-    def test_ring0(self):
-        ring0 = "ring0"
-        target = lib.RequestTarget.from_node_addresses(NodeAddresses(ring0))
-        self.assertEqual(ring0, target.label)
-        self.assertEqual([ring0], target.address_list)
-
-    def test_ring1(self):
-        ring0 = "ring0"
-        ring1 = "ring1"
-        target = lib.RequestTarget.from_node_addresses(
-            NodeAddresses(ring0, ring1)
+class RequestTargetFromKnownHost(TestCase):
+    def test_success(self):
+        known_host = host.PcsKnownHost(
+            "name",
+            "token",
+            [
+                host.Destination("addr1", "addr2"),
+                host.Destination("addr2", "port2"),
+            ]
         )
-        self.assertEqual(ring0, target.label)
-        self.assertEqual([ring0, ring1], target.address_list)
+        target = lib.RequestTarget.from_known_host(known_host)
+        self.assertEqual(known_host.name, target.label)
+        self.assertEqual(known_host.token, target.token)
+        self.assertEqual(known_host.dest_list, target.dest_list)
 
-    def test_ring0_with_label(self):
-        ring0 = "ring0"
-        label = "label"
-        target = lib.RequestTarget.from_node_addresses(
-            NodeAddresses(ring0, name=label)
-        )
-        self.assertEqual(label, target.label)
-        self.assertEqual([ring0], target.address_list)
-
-    def test_ring1_with_label(self):
-        ring0 = "ring0"
-        ring1 = "ring1"
-        label = "label"
-        target = lib.RequestTarget.from_node_addresses(
-            NodeAddresses(ring0, ring1, name=label)
-        )
-        self.assertEqual(label, target.label)
-        self.assertEqual([ring0, ring1], target.address_list)
 
 
 class RequestUrlTest(TestCase):
@@ -102,45 +134,49 @@ class RequestUrlTest(TestCase):
     def _get_request(self, target):
         return lib.Request(target, lib.RequestData(self.action))
 
-    def assert_url(self, actual_url, host, action, port=None):
+    def assert_url(self, actual_url, hostname, action, port=None):
         if port is None:
             port = settings.pcsd_default_port
         self.assertEqual(
-            "https://{host}:{port}/{action}".format(
-                host=host, action=action, port=port
-            ),
+            f"https://{hostname}:{port}/{action}",
             actual_url
         )
 
     def test_url_basic(self):
-        host = "host"
+        hostname = "host"
         self.assert_url(
-            self._get_request(lib.RequestTarget(host)).url, host, self.action,
+            self._get_request(lib.RequestTarget(hostname)).url,
+            hostname,
+            self.action,
         )
 
     def test_url_with_port(self):
-        host = "host"
+        hostname = "host"
         port = 1234
         self.assert_url(
-            self._get_request(lib.RequestTarget(host, port=port)).url,
-            host, self.action, port=port,
+            self._get_request(
+                lib.RequestTarget(
+                    hostname, dest_list=[Destination(hostname, port)]
+                )
+            ).url,
+            hostname, self.action, port=port,
         )
 
     def test_url_ipv6(self):
-        host = "::1"
+        host_addr = "::1"
         self.assert_url(
-            self._get_request(lib.RequestTarget(host)).url,
-            "[{0}]".format(host), self.action,
+            self._get_request(lib.RequestTarget(host_addr)).url,
+            "[{0}]".format(host_addr), self.action,
         )
 
     def test_url_multiaddr(self):
         hosts = ["ring0", "ring1"]
         action = "action"
-        request = self._get_request(
-            lib.RequestTarget.from_node_addresses(NodeAddresses(*hosts))
-        )
+        request = self._get_request(lib.RequestTarget(
+            "label", dest_list=_addr_list_to_dest(hosts)
+        ))
         self.assert_url(request.url, hosts[0], action)
-        request.next_host()
+        request.next_dest()
         self.assert_url(request.url, hosts[1], action)
 
 
@@ -151,24 +187,27 @@ class RequestHostTest(TestCase):
         return lib.Request(target, lib.RequestData(self.action))
 
     def test_one_host(self):
-        host = "host"
-        request = self._get_request(lib.RequestTarget(host))
-        self.assertEqual(host, request.host)
-        self.assertRaises(StopIteration, request.next_host)
+        hostname = "host"
+        request = self._get_request(lib.RequestTarget(hostname))
+        self.assertEqual(Destination(hostname, PORT), request.dest)
+        self.assertRaises(StopIteration, request.next_dest)
 
     def test_multiple_hosts(self):
         hosts = ["host1", "host2", "host3"]
-        request = self._get_request(lib.RequestTarget("label", hosts))
-        for host in hosts:
-            self.assertEqual(host, request.host)
-            if host == hosts[-1]:
-                self.assertRaises(StopIteration, request.next_host)
+        request = self._get_request(lib.RequestTarget(
+            "label", dest_list=_addr_list_to_dest(hosts)
+        ))
+        for hostname in hosts:
+            self.assertEqual(Destination(hostname, None), request.dest)
+            if hostname == hosts[-1]:
+                self.assertRaises(StopIteration, request.next_dest)
             else:
-                request.next_host()
+                request.next_dest()
 
 
 class RequestCookiesTest(TestCase):
-    def _get_request(self, token=None):
+    @staticmethod
+    def _get_request(token=None):
         return lib.Request(
             lib.RequestTarget("host", token=token), lib.RequestData("action")
         )
@@ -182,7 +221,8 @@ class RequestCookiesTest(TestCase):
 
 
 class ResponseTest(TestCase):
-    def fixture_handle(self, info, request, data, debug):
+    @staticmethod
+    def fixture_handle(info, request, data, debug):
         handle = MockCurl(info)
         handle.request_obj = request
         handle.output_buffer = io.BytesIO()
@@ -231,6 +271,7 @@ class ResponseTest(TestCase):
 
 @mock.patch("pcs.common.node_communicator.pycurl.Curl")
 class CreateRequestHandleTest(TestCase):
+    # pylint: disable=no-member, protected-access
     _common_opts = {
         pycurl.PROTOCOLS: pycurl.PROTO_HTTPS,
         pycurl.VERBOSE: 1,
@@ -248,7 +289,9 @@ class CreateRequestHandleTest(TestCase):
         )
         request = lib.Request(
             lib.RequestTarget(
-                "label", ["host1", "host2"], port=123, token="token_val",
+                "label",
+                token="token_val",
+                dest_list=_addr_list_to_dest(["host1", "host2"], port=123),
             ),
             lib.RequestData("action", [("data", "value")])
         )
@@ -346,8 +389,11 @@ class CommunicatorSimpleTest(CommunicatorBaseTest):
         return response
 
     def assert_common_checks(self, com, response):
+        # pylint: disable=protected-access
         self.assertEqual(response.handle.error is None, response.was_connected)
-        self.mock_com_log.log_request_start.assert_called_once_with(response.request)
+        self.mock_com_log.log_request_start.assert_called_once_with(
+            response.request
+        )
         self.mock_com_log.log_response.assert_called_once_with(response)
         self.assertEqual(0, self.mock_com_log.log_retry.call_count)
         self.assertEqual(0, self.mock_com_log.log_no_more_addresses.call_count)
@@ -376,7 +422,7 @@ class CommunicatorMultiTest(CommunicatorBaseTest):
         "pcs.common.node_communicator.pycurl.CurlMulti",
         side_effect=lambda: MockCurlMulti([1, 1])
     )
-    def test_call_start_loop_multiple_times(self, _,  mock_create_handle):
+    def test_call_start_loop_multiple_times(self, _, mock_create_handle):
         com = self.get_communicator()
         mock_create_handle.side_effect = lambda request, _, __: MockCurl(
             request=request
@@ -408,7 +454,7 @@ class CommunicatorMultiTest(CommunicatorBaseTest):
         self.assertEqual(0, self.mock_com_log.log_request_start.call_count)
         response_list = []
         for response in com.start_loop():
-            if len(response_list) == 0:
+            if not response_list:
                 request = fixture_request(3, action)
                 request_list.append(request)
                 com.add_requests([request])
@@ -437,14 +483,15 @@ class CommunicatorMultiTest(CommunicatorBaseTest):
             ]
         )
         self.assertEqual(logger_calls, self.mock_com_log.mock_calls)
+        # pylint: disable=no-member, protected-access
         com._multi_handle.assert_no_handle_left()
 
 
-def fixture_logger_request_retry_calls(response, host):
+def fixture_logger_request_retry_calls(response, hostname):
     return [
         mock.call.log_request_start(response.request),
         mock.call.log_response(response),
-        mock.call.log_retry(response, host),
+        mock.call.log_retry(response, hostname),
     ]
 
 
@@ -486,7 +533,12 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
         mock_con_failure.side_effect = _con_failure
         mock_create_handle.side_effect = _mock_create_request_handle
         request = lib.Request(
-            lib.RequestTarget("label", ["host{0}".format(i) for i in range(4)]),
+            lib.RequestTarget(
+                "label",
+                dest_list=_addr_list_to_dest(
+                    ["host{0}".format(i) for i in range(4)]
+                )
+            ),
             lib.RequestData("action")
         )
         com.add_requests([request])
@@ -496,7 +548,7 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
         self.assertIs(response, expected_response_list[-1])
         self.assertTrue(response.was_connected)
         self.assertIs(request, response.request)
-        self.assertEqual("host2", request.host)
+        self.assertEqual(Destination("host2", None), request.dest)
         self.assertEqual(3, mock_create_handle.call_count)
         self.assertEqual(3, len(expected_response_list))
         mock_create_handle.assert_has_calls([
@@ -505,11 +557,11 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
         ])
         logger_calls = (
             fixture_logger_request_retry_calls(
-                expected_response_list[0], "host0"
+                expected_response_list[0], Destination("host0", None)
             )
             +
             fixture_logger_request_retry_calls(
-                expected_response_list[1], "host1"
+                expected_response_list[1], Destination("host1", None)
             )
             +
             [
@@ -518,6 +570,7 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
             ]
         )
         self.assertEqual(logger_calls, self.mock_com_log.mock_calls)
+        # pylint: disable=no-member, protected-access
         com._multi_handle.assert_no_handle_left()
 
     def test_failure(
@@ -535,7 +588,12 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
             error=(pycurl.E_SEND_ERROR, "reason"), request=request,
         )
         request = lib.Request(
-            lib.RequestTarget("label", ["host{0}".format(i) for i in range(4)]),
+            lib.RequestTarget(
+                "label",
+                dest_list=_addr_list_to_dest(
+                    ["host{0}".format(i) for i in range(4)]
+                ),
+            ),
             lib.RequestData("action")
         )
         com.add_requests([request])
@@ -544,7 +602,7 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
         response = response_list[0]
         self.assertFalse(response.was_connected)
         self.assertIs(request, response.request)
-        self.assertEqual("host3", request.host)
+        self.assertEqual(Destination("host3", None), request.dest)
         self.assertEqual(4, mock_create_handle.call_count)
         mock_con_successful.assert_not_called()
         self.assertEqual(4, len(expected_response_list))
@@ -554,15 +612,15 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
         ])
         logger_calls = (
             fixture_logger_request_retry_calls(
-                expected_response_list[0], "host0"
+                expected_response_list[0], Destination("host0", None)
             )
             +
             fixture_logger_request_retry_calls(
-                expected_response_list[1], "host1"
+                expected_response_list[1], Destination("host1", None)
             )
             +
             fixture_logger_request_retry_calls(
-                expected_response_list[2], "host2"
+                expected_response_list[2], Destination("host2", None)
             )
             +
             [
@@ -572,5 +630,5 @@ class MultiaddressCommunicatorTest(CommunicatorBaseTest):
             ]
         )
         self.assertEqual(logger_calls, self.mock_com_log.mock_calls)
+        # pylint: disable=no-member, protected-access
         com._multi_handle.assert_no_handle_left()
-
