@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import sys
 import os
 import os.path
@@ -49,70 +43,82 @@ import pcs.cli.constraint_colocation.command as colocation_command
 import pcs.cli.constraint_order.command as order_command
 import pcs.cli.constraint_ticket.command as ticket_command
 from pcs.cli.common.console_report import indent
+from pcs.cli.common.errors import CmdLineInputError
 
+# pylint: disable=too-many-branches, too-many-locals, too-many-statements
 
-def config_cmd(argv):
-    if len(argv) == 0:
-        config_show(argv)
+def config_cmd(lib, argv, modifiers):
+    if not argv:
+        config_show(lib, argv, modifiers)
         return
 
-    sub_cmd = argv.pop(0)
-    if sub_cmd == "help":
-        usage.config(argv)
-    elif sub_cmd == "show":
-        config_show(argv)
-    elif sub_cmd == "backup":
-        config_backup(argv)
-    elif sub_cmd == "restore":
-        config_restore(argv)
-    elif sub_cmd == "checkpoint":
-        if not argv:
-            config_checkpoint_list()
-        elif argv[0] == "view":
-            config_checkpoint_view(argv[1:])
-        elif argv[0] == "restore":
-            config_checkpoint_restore(argv[1:])
+    try:
+        sub_cmd = argv.pop(0)
+        if sub_cmd == "help":
+            usage.config(argv)
+        elif sub_cmd == "show":
+            config_show(lib, argv, modifiers)
+        elif sub_cmd == "backup":
+            config_backup(lib, argv, modifiers)
+        elif sub_cmd == "restore":
+            config_restore(lib, argv, modifiers)
+        elif sub_cmd == "checkpoint":
+            if not argv:
+                config_checkpoint_list(lib, argv, modifiers)
+            elif argv[0] == "view":
+                config_checkpoint_view(lib, argv[1:], modifiers)
+            elif argv[0] == "restore":
+                config_checkpoint_restore(lib, argv[1:], modifiers)
+            else:
+                raise CmdLineInputError()
+        elif sub_cmd == "import-cman":
+            config_import_cman(lib, argv, modifiers)
+        elif sub_cmd == "export":
+            if not argv:
+                raise CmdLineInputError()
+            elif argv[0] == "pcs-commands":
+                config_export_pcs_commands(lib, argv[1:], modifiers)
+            elif argv[0] == "pcs-commands-verbose":
+                config_export_pcs_commands(
+                    lib, argv[1:], modifiers, verbose=True
+                )
+            else:
+                raise CmdLineInputError()
         else:
-            usage.config(["checkpoint"])
-            sys.exit(1)
-    elif sub_cmd == "import-cman":
-        config_import_cman(argv)
-    elif sub_cmd == "export":
-        if not argv:
-            usage.config(["export"])
-            sys.exit(1)
-        elif argv[0] == "pcs-commands":
-            config_export_pcs_commands(argv[1:])
-        elif argv[0] == "pcs-commands-verbose":
-            config_export_pcs_commands(argv[1:], True)
-        else:
-            usage.config(["export"])
-            sys.exit(1)
-    else:
-        usage.config()
-        sys.exit(1)
+            raise CmdLineInputError()
+    except LibraryError as e:
+        utils.process_library_reports(e.args)
+    except CmdLineInputError as e:
+        utils.exit_on_cmdline_input_errror(e, "config", sub_cmd)
 
-def config_show(argv):
+def config_show(lib, argv, modifiers):
+    """
+    Options:
+      * -f - CIB file, when getting cluster name on remote node (corosync.conf
+        doesn't exist)
+      * --corosync_conf - corosync.conf file
+    """
+    modifiers.ensure_only_supported("-f", "--corosync_conf")
+    if argv:
+        raise CmdLineInputError()
     print("Cluster Name: %s" % utils.getClusterName())
-    status.nodes_status(["config"])
+    status.nodes_status(lib, ["config"], modifiers.get_subset("-f"))
     print()
-    config_show_cib()
+    config_show_cib(lib)
     if (
         utils.hasCorosyncConf()
         and
-        (
-            utils.is_rhel6()
-            or
-            (not utils.usefile and "--corosync_conf" not in utils.pcs_options)
-        )
+        not modifiers.is_specified("-f")
+        and
+        not modifiers.is_specified("--corosync_conf")
     ):
-        # with corosync 1 and cman, uid gid is part of cluster.conf file
-        # with corosync 2, uid gid is in a separate directory
-        cluster.cluster_uidgid([], True)
+        cluster.cluster_uidgid(
+            lib, [], modifiers.get_subset(), silent_list=True
+        )
     if (
-        "--corosync_conf" in utils.pcs_options
+        modifiers.is_specified("--corosync_conf")
         or
-        (not utils.is_rhel6() and utils.hasCorosyncConf())
+        utils.hasCorosyncConf()
     ):
         print()
         print("Quorum:")
@@ -122,18 +128,30 @@ def config_show(argv):
         except LibraryError as e:
             utils.process_library_reports(e.args)
 
-def config_show_cib():
-    lib = utils.get_library_wrapper()
-    modifiers = utils.get_modifiers()
-
+def config_show_cib(lib):
+    """
+    Commandline options:
+      * -f - CIB file
+    """
     print("Resources:")
-    utils.pcs_options["--all"] = 1
+    # update of pcs_options will change output of constraint show
     utils.pcs_options["--full"] = 1
-    resource.resource_show([])
+    # get latest modifiers object after updating pcs_options
+    modifiers = utils.get_input_modifiers()
+    resource.resource_config(
+        lib,
+        [],
+        modifiers.get_subset("-f")
+    )
 
     print()
     print("Stonith Devices:")
-    resource.resource_show([], True)
+    resource.resource_config(
+        lib,
+        [],
+        modifiers.get_subset("-f"),
+        stonith=True,
+    )
     print("Fencing Levels:")
     levels = stonith.stonith_level_config_to_str(
         lib.fencing_topology.get_config()
@@ -142,24 +160,31 @@ def config_show_cib():
         print("\n".join(indent(levels, 2)))
 
     print()
-    constraint.location_show([])
-    order_command.show(lib, [], modifiers)
-    colocation_command.show(lib, [], modifiers)
-    ticket_command.show(lib, [], modifiers)
+    constraint.location_show(lib, [], modifiers.get_subset("-f", "--full"))
+    order_command.show(lib, [], modifiers.get_subset("-f", "--full"))
+    colocation_command.show(lib, [], modifiers.get_subset("-f", "--full"))
+    ticket_command.show(lib, [], modifiers.get_subset("-f", "--full"))
 
     print()
-    alert.print_alert_config(lib, [], modifiers)
+    alert.print_alert_config(lib, [], modifiers.get_subset("-f"))
 
     print()
-    del utils.pcs_options["--all"]
     print("Resources Defaults:")
     resource.show_defaults("rsc_defaults", indent=" ")
     print("Operations Defaults:")
     resource.show_defaults("op_defaults", indent=" ")
     print()
-    prop.list_property([])
+    prop.list_property(
+        lib, [], modifiers.get_subset("--defaults", "--all", "-f")
+    )
 
-def config_backup(argv):
+def config_backup(lib, argv, modifiers):
+    """
+    Options:
+      * --force - overwrite file if already exists
+    """
+    del lib
+    modifiers.ensure_only_supported("--force")
     if len(argv) > 1:
         usage.config(["backup"])
         sys.exit(1)
@@ -179,12 +204,12 @@ def config_backup(argv):
             utils.err(message)
     else:
         # in python3 stdout accepts str so we need to use buffer
-        if hasattr(sys.stdout, "buffer"):
-            sys.stdout.buffer.write(tar_data)
-        else:
-            sys.stdout.write(tar_data)
+        sys.stdout.buffer.write(tar_data)
 
 def config_backup_local():
+    """
+    Commandline options: no options
+    """
     file_list = config_backup_path_list()
     tar_data = BytesIO()
 
@@ -207,7 +232,15 @@ def config_backup_local():
     tar_data.close()
     return tar
 
-def config_restore(argv):
+def config_restore(lib, argv, modifiers):
+    """
+    Options:
+      * --local - restore config only on local node
+      * --request-timeout - timeout for HTTP requests, used only if --local was
+        not defined or user is not root
+    """
+    del lib
+    modifiers.ensure_only_supported("--local", "--request-timeout")
     if len(argv) > 1:
         usage.config(["restore"])
         sys.exit(1)
@@ -217,27 +250,24 @@ def config_restore(argv):
         infile_name = argv[0]
     if not infile_name:
         # in python3 stdin returns str so we need to use buffer
-        if hasattr(sys.stdin, "buffer"):
-            infile_obj = BytesIO(sys.stdin.buffer.read())
-        else:
-            infile_obj = BytesIO(sys.stdin.read())
+        infile_obj = BytesIO(sys.stdin.buffer.read())
 
     if os.getuid() == 0:
-        if "--local" in utils.pcs_options:
+        if modifiers.get("--local"):
             config_restore_local(infile_name, infile_obj)
         else:
             config_restore_remote(infile_name, infile_obj)
     else:
         new_argv = ['config', 'restore']
         new_stdin = None
-        if '--local' in utils.pcs_options:
+        if modifiers.get("--local"):
             new_argv.append('--local')
         if infile_name:
             new_argv.append(os.path.abspath(infile_name))
         else:
             new_stdin = infile_obj.read()
         err_msgs, exitcode, std_out, std_err = utils.call_local_pcsd(
-            new_argv, True, new_stdin
+            new_argv, new_stdin
         )
         if err_msgs:
             for msg in err_msgs:
@@ -248,10 +278,13 @@ def config_restore(argv):
         sys.exit(exitcode)
 
 def config_restore_remote(infile_name, infile_obj):
+    """
+    Commandline options:
+      * --request-timeout - timeout for HTTP requests
+    """
     extracted = {
         "version.txt": "",
         "corosync.conf": "",
-        "cluster.conf": "",
     }
     try:
         tarball = tarfile.open(infile_name, "r|*", infile_obj)
@@ -270,9 +303,9 @@ def config_restore_remote(infile_name, infile_obj):
 
     config_backup_check_version(extracted["version.txt"])
 
-    node_list = utils.getNodesFromCorosyncConf(
-        extracted["cluster.conf" if utils.is_rhel6() else "corosync.conf"].decode("utf-8")
-    )
+    node_list = utils.get_corosync_conf_facade(
+        conf_text=extracted["corosync.conf"].decode("utf-8")
+    ).get_nodes_names()
     if not node_list:
         utils.err("no nodes found in the tarball")
 
@@ -283,16 +316,14 @@ def config_restore_remote(infile_name, infile_obj):
             if retval != 0:
                 err_msgs.append(output)
                 continue
-            status = json.loads(output)
+            _status = json.loads(output)
             if (
-                status["corosync"]
+                _status["corosync"]
                 or
-                status["pacemaker"]
-                or
-                status["cman"]
+                _status["pacemaker"]
                 or
                 # not supported by older pcsd, do not fail if not present
-                status.get("pacemaker_remote", False)
+                _status.get("pacemaker_remote", False)
             ):
                 err_msgs.append(
                     "Cluster is currently running on node %s. You need to stop "
@@ -331,9 +362,10 @@ def config_restore_remote(infile_name, infile_obj):
         utils.err("unable to restore all nodes\n" + "\n".join(error_list))
 
 def config_restore_local(infile_name, infile_obj):
+    """
+    Commandline options: no options
+    """
     if (
-        status.is_service_running("cman")
-        or
         status.is_service_running("corosync")
         or
         status.is_service_running("pacemaker")
@@ -403,8 +435,9 @@ def config_restore_local(infile_name, infile_obj):
                     tmp_dir = tempfile.mkdtemp()
                 tarball.extractall(tmp_dir, [tar_member_info])
                 path_full = extract_info["path"]
-                os.rename(
-                    os.path.join(tmp_dir, tar_member_info.name), path_full
+                shutil.move(
+                    os.path.join(tmp_dir, tar_member_info.name),
+                    path_full
                 )
             else:
                 dir_path = os.path.dirname(extract_info["path"])
@@ -427,8 +460,11 @@ def config_restore_local(infile_name, infile_obj):
     except EnvironmentError as e:
         utils.err("unable to remove %s: %s" % (sig_path, e))
 
-def config_backup_path_list(with_uid_gid=False, force_rhel6=None):
-    rhel6 = utils.is_rhel6() if force_rhel6 is None else force_rhel6
+def config_backup_path_list(with_uid_gid=False):
+    """
+    Commandline options: no option
+    NOTE: corosync.conf path may be altered using --corosync_conf
+    """
     corosync_attrs = {
         "mtime": int(time.time()),
         "mode": 0o644,
@@ -472,25 +508,17 @@ def config_backup_path_list(with_uid_gid=False, force_rhel6=None):
             "rename": True,
             "pre_store_call": _ensure_etc_pacemaker_exists,
         },
-    }
-    if rhel6:
-        file_list["cluster.conf"] = {
-            "path": settings.cluster_conf_file,
-            "required": True,
-            "attrs": dict(corosync_attrs),
-        }
-    else:
-        file_list["corosync.conf"] = {
+        "corosync.conf": {
             "path": settings.corosync_conf_file,
             "required": True,
             "attrs": dict(corosync_attrs),
-        }
-        file_list["uidgid.d"] = {
+        },
+        "uidgid.d": {
             "path": settings.corosync_uidgid_dir.rstrip("/"),
             "required": False,
             "attrs": dict(corosync_attrs),
-        }
-        file_list["pcs_settings.conf"] = {
+        },
+        "pcs_settings.conf": {
             "path": settings.pcsd_settings_conf_location,
             "required": False,
             "attrs": {
@@ -502,10 +530,14 @@ def config_backup_path_list(with_uid_gid=False, force_rhel6=None):
                 "gid": 0,
             },
         }
+    }
     return file_list
 
 
 def _get_uid(user_name):
+    """
+    Commandline options: no options
+    """
     try:
         return pwd.getpwnam(user_name).pw_uid
     except KeyError:
@@ -513,6 +545,9 @@ def _get_uid(user_name):
 
 
 def _get_gid(group_name):
+    """
+    Commandline options: no options
+    """
     try:
         return grp.getgrnam(group_name).gr_gid
     except KeyError:
@@ -522,6 +557,9 @@ def _get_gid(group_name):
 
 
 def _ensure_etc_pacemaker_exists():
+    """
+    Commandline options: no options
+    """
     dir_name = os.path.dirname(settings.pacemaker_authkey_file)
     if not os.path.exists(dir_name):
         os.mkdir(dir_name)
@@ -534,6 +572,9 @@ def _ensure_etc_pacemaker_exists():
 
 
 def config_backup_check_version(version):
+    """
+    Commandline options: no options
+    """
     try:
         version_number = int(version)
         supported_version = config_backup_version()
@@ -553,19 +594,32 @@ def config_backup_check_version(version):
         utils.err("Cannot determine version of the backup")
 
 def config_backup_add_version_to_tarball(tarball, version=None):
+    """
+    Commandline options: no options
+    """
     ver = version if version is not None else str(config_backup_version())
     return utils.tar_add_file_data(tarball, ver.encode("utf-8"), "version.txt")
 
 def config_backup_version():
+    """
+    Commandline options: no options
+    """
     return 1
 
-def config_checkpoint_list():
+def config_checkpoint_list(lib, argv, modifiers):
+    """
+    Options: no options
+    """
+    del lib
+    modifiers.ensure_only_supported()
+    if argv:
+        raise CmdLineInputError()
     try:
         file_list = os.listdir(settings.cib_dir)
     except OSError as e:
         utils.err("unable to list checkpoints: %s" % e)
     cib_list = []
-    cib_name_re = re.compile("^cib-(\d+)\.raw$")
+    cib_name_re = re.compile(r"^cib-(\d+)\.raw$")
     for filename in file_list:
         match = cib_name_re.match(filename)
         if not match:
@@ -588,7 +642,11 @@ def config_checkpoint_list():
             % (cib_info[1], datetime.datetime.fromtimestamp(round(cib_info[0])))
         )
 
-def config_checkpoint_view(argv):
+def config_checkpoint_view(lib, argv, modifiers):
+    """
+    Options: no options
+    """
+    modifiers.ensure_only_supported()
     if len(argv) != 1:
         usage.config(["checkpoint", "view"])
         sys.exit(1)
@@ -597,9 +655,16 @@ def config_checkpoint_view(argv):
     utils.filename = os.path.join(settings.cib_dir, "cib-%s.raw" % argv[0])
     if not os.path.isfile(utils.filename):
         utils.err("unable to read the checkpoint")
-    config_show_cib()
+    config_show_cib(lib)
 
-def config_checkpoint_restore(argv):
+def config_checkpoint_restore(lib, argv, modifiers):
+    """
+    Options:
+      * -f - CIB file, a checkpoint will be restored into a specified file
+    """
+    # pylint: disable=broad-except
+    del lib
+    modifiers.ensure_only_supported("-f")
     if len(argv) != 1:
         usage.config(["checkpoint", "restore"])
         sys.exit(1)
@@ -611,13 +676,29 @@ def config_checkpoint_restore(argv):
         utils.err("unable to read the checkpoint: %s" % e)
     utils.replace_cib_configuration(snapshot_dom)
 
-def config_import_cman(argv):
+def config_import_cman(lib, argv, modifiers):
+    """
+    Options:
+      * --force - skip checks, overwrite files
+      * --interactive - interactive issue resolving
+      * --request-timeout - effective only when ouput is not specified
+    """
+    # pylint: disable=no-member
+    del lib
+    modifiers.ensure_only_supported(
+        "--force", "interactive", "--request-timeout",
+    )
     if no_clufter:
-        utils.err("Unable to perform a CMAN cluster conversion due to missing python-clufter package")
+        utils.err(
+            "Unable to perform a CMAN cluster conversion due to missing "
+            "python-clufter package"
+        )
+    clufter_supports_corosync3 = hasattr(clufter.facts, "cluster_pcs_camelback")
+
     # prepare convertor options
     cluster_conf = settings.cluster_conf_file
     dry_run_output = None
-    output_format = "cluster.conf" if utils.is_rhel6() else "corosync.conf"
+    output_format = "corosync.conf"
     dist = None
     invalid_args = False
     for arg in argv:
@@ -629,7 +710,7 @@ def config_import_cman(argv):
                 dry_run_output = value
             elif name == "output-format":
                 if value in (
-                    "cluster.conf", "corosync.conf",
+                    "corosync.conf",
                     "pcs-commands", "pcs-commands-verbose",
                 ):
                     output_format = value
@@ -650,30 +731,23 @@ def config_import_cman(argv):
     if invalid_args or not dry_run_output:
         usage.config(["import-cman"])
         sys.exit(1)
-    debug = "--debug" in utils.pcs_options
-    force = "--force" in utils.pcs_options
-    interactive = "--interactive" in utils.pcs_options
+    debug = modifiers.get("--debug")
+    force = modifiers.get("--force")
+    interactive = modifiers.get("--interactive")
 
     if dist is not None:
-        if output_format == "cluster.conf":
-            if not clufter.facts.cluster_pcs_flatiron("linux", dist.split(",")):
-                utils.err("dist does not match output-format")
-        elif output_format == "corosync.conf":
-            if not clufter.facts.cluster_pcs_needle("linux", dist.split(",")):
-                utils.err("dist does not match output-format")
-    elif (
-        (output_format == "cluster.conf" and utils.is_rhel6())
-        or
-        (output_format == "corosync.conf" and not utils.is_rhel6())
-    ):
-        dist = ",".join(platform.linux_distribution(full_distribution_name=0))
-    elif output_format == "cluster.conf":
-        dist = "redhat,6.7,Santiago"
+        if not clufter_supports_corosync3:
+            utils.err(
+                "Unable to perform a CMAN cluster conversion due to clufter "
+                "not supporting Corosync 3. Please, upgrade clufter packages."
+            )
+        if not clufter.facts.cluster_pcs_camelback("linux", dist.split(",")):
+            utils.err("dist does not match output-format")
     elif output_format == "corosync.conf":
-        dist = "redhat,7.1,Maipo"
+        dist = _get_linux_dist()
     else:
         # for output-format=pcs-command[-verbose]
-        dist = ",".join(platform.linux_distribution(full_distribution_name=0))
+        dist = _get_linux_dist()
 
     clufter_args = {
         "input": str(cluster_conf),
@@ -690,12 +764,9 @@ def config_import_cman(argv):
         clufter_args["editor"] = os.environ["EDITOR"]
     if debug:
         logging.getLogger("clufter").setLevel(logging.DEBUG)
-    if output_format == "cluster.conf":
-        clufter_args["ccs_pcmk"] = {"passin": "bytestring"}
-        cmd_name = "ccs2pcs-flatiron"
-    elif output_format == "corosync.conf":
+    if output_format == "corosync.conf":
         clufter_args["coro"] = {"passin": "struct"}
-        cmd_name = "ccs2pcs-needle"
+        cmd_name = "ccs2pcs-camelback"
     elif output_format in ("pcs-commands", "pcs-commands-verbose"):
         clufter_args["output"] = {"passin": "bytestring"}
         clufter_args["start_wait"] = "60"
@@ -712,6 +783,12 @@ def config_import_cman(argv):
             cmd_name = "ccs2pcscmd-flatiron"
         elif clufter.facts.cluster_pcs_needle("linux", dist.split(",")):
             cmd_name = "ccs2pcscmd-needle"
+        elif (
+            clufter_supports_corosync3
+            and
+            clufter.facts.cluster_pcs_camelback("linux", dist.split(","))
+        ):
+            cmd_name = "ccs2pcscmd-camelback"
         else:
             utils.err(
                 "unrecognized dist, try something recognized"
@@ -736,9 +813,7 @@ def config_import_cman(argv):
         return
 
     # put new config files into tarball
-    file_list = config_backup_path_list(
-        force_rhel6=(output_format == "cluster.conf")
-    )
+    file_list = config_backup_path_list()
     for file_item in file_list.values():
         file_item["attrs"]["uname"] = "root"
         file_item["attrs"]["gname"] = "root"
@@ -755,52 +830,44 @@ def config_import_cman(argv):
             "cib.xml",
             **file_list["cib.xml"]["attrs"]
         )
-        if output_format == "cluster.conf":
-            utils.tar_add_file_data(
-                tarball,
-                clufter_args_obj.ccs_pcmk["passout"],
-                "cluster.conf",
-                **file_list["cluster.conf"]["attrs"]
-            )
-        else:
-            # put uidgid into separate files
-            fmt_simpleconfig = clufter.format_manager.FormatManager.init_lookup(
-                'simpleconfig'
-            ).plugins['simpleconfig']
-            corosync_struct = []
-            uidgid_list = []
-            for section in clufter_args_obj.coro["passout"][2]:
-                if section[0] == "uidgid":
-                    uidgid_list.append(section[1])
-                else:
-                    corosync_struct.append(section)
-            corosync_conf_data = fmt_simpleconfig(
-                "struct", ("corosync", (), corosync_struct)
+        # put uidgid into separate files
+        fmt_simpleconfig = clufter.format_manager.FormatManager.init_lookup(
+            'simpleconfig'
+        ).plugins['simpleconfig']
+        corosync_struct = []
+        uidgid_list = []
+        for section in clufter_args_obj.coro["passout"][2]:
+            if section[0] == "uidgid":
+                uidgid_list.append(section[1])
+            else:
+                corosync_struct.append(section)
+        corosync_conf_data = fmt_simpleconfig(
+            "struct", ("corosync", (), corosync_struct)
+        )("bytestring")
+        utils.tar_add_file_data(
+            tarball,
+            corosync_conf_data,
+            "corosync.conf",
+            **file_list["corosync.conf"]["attrs"]
+        )
+        for uidgid in uidgid_list:
+            uid = ""
+            gid = ""
+            for item in uidgid:
+                if item[0] == "uid":
+                    uid = item[1]
+                if item[0] == "gid":
+                    gid = item[1]
+            filename = utils.get_uid_gid_file_name(uid, gid)
+            uidgid_data = fmt_simpleconfig(
+                "struct", ("corosync", (), [("uidgid", uidgid, None)])
             )("bytestring")
             utils.tar_add_file_data(
                 tarball,
-                corosync_conf_data,
-                "corosync.conf",
-                **file_list["corosync.conf"]["attrs"]
+                uidgid_data,
+                "uidgid.d/" + filename,
+                **file_list["uidgid.d"]["attrs"]
             )
-            for uidgid in uidgid_list:
-                uid = ""
-                gid = ""
-                for item in uidgid:
-                    if item[0] == "uid":
-                        uid = item[1]
-                    if item[0] == "gid":
-                        gid = item[1]
-                filename = utils.get_uid_gid_file_name(uid, gid)
-                uidgid_data = fmt_simpleconfig(
-                    "struct", ("corosync", (), [("uidgid", uidgid, None)])
-                )("bytestring")
-                utils.tar_add_file_data(
-                    tarball,
-                    uidgid_data,
-                    "uidgid.d/" + filename,
-                    **file_list["uidgid.d"]["attrs"]
-                )
         tarball.close()
     except (tarfile.TarError, EnvironmentError) as e:
         utils.err("unable to create tarball: %s" % e)
@@ -817,16 +884,31 @@ def config_import_cman(argv):
         config_restore_remote(None, tar_data)
     tar_data.close()
 
-def config_export_pcs_commands(argv, verbose=False):
+def _get_linux_dist():
+    # pylint: disable=deprecated-method
+    return ",".join(platform.linux_distribution(full_distribution_name=0))
+
+def config_export_pcs_commands(lib, argv, modifiers, verbose=False):
+    """
+    Options:
+      * --force - skip checks, overwrite files
+      * --interactive - interactive issue resolving
+      * -f - CIB file
+      * --corosync_conf
+    """
+    del lib
+    modifiers.ensure_only_supported(
+        "--force", "--interactive", "-f", "--corosync_conf"
+    )
     if no_clufter:
         utils.err(
             "Unable to perform export due to missing python-clufter package"
         )
 
     # parse options
-    debug = "--debug" in utils.pcs_options
-    force = "--force" in utils.pcs_options
-    interactive = "--interactive" in utils.pcs_options
+    debug = modifiers.get("--debug")
+    force = modifiers.get("--force")
+    interactive = modifiers.get("--interactive")
     invalid_args = False
     output_file = None
     dist = None
@@ -847,7 +929,7 @@ def config_export_pcs_commands(argv, verbose=False):
         sys.exit(1)
     # complete optional options
     if dist is None:
-        dist = ",".join(platform.linux_distribution(full_distribution_name=0))
+        dist = _get_linux_dist()
 
     # prepare convertor options
     clufter_args = {
@@ -856,7 +938,6 @@ def config_export_pcs_commands(argv, verbose=False):
         "sys": "linux",
         "dist": dist,
         "coro": settings.corosync_conf_file,
-        "ccs": settings.cluster_conf_file,
         "start_wait": "60",
         "tmp_cib": "tmp-cib.xml",
         "force": force,
@@ -884,7 +965,7 @@ def config_export_pcs_commands(argv, verbose=False):
         clufter_args["silent"] = False
         clufter_args["noguidance"] = False
     clufter_args_obj = type(str("ClufterOptions"), (object, ), clufter_args)
-    cmd_name = "pcs2pcscmd-flatiron" if utils.is_rhel6() else "pcs2pcscmd-needle"
+    cmd_name = "pcs2pcscmd-camelback"
 
     # run convertor
     run_clufter(
@@ -894,6 +975,7 @@ def config_export_pcs_commands(argv, verbose=False):
 
     # save commands if not printed to stdout by clufter
     if output_file:
+        # pylint: disable=no-member
         ok, message = utils.write_file(
             output_file,
             clufter_args_obj.output["passout"].decode()
@@ -902,6 +984,11 @@ def config_export_pcs_commands(argv, verbose=False):
             utils.err(message)
 
 def run_clufter(cmd_name, cmd_args, debug, force, err_prefix):
+    """
+    Commandline options: no options used but messages which include --force,
+      --debug and --interactive are generated
+    """
+    # pylint: disable=broad-except
     try:
         result = None
         cmd_manager = clufter.command_manager.CommandManager.init_lookup(
