@@ -1,15 +1,10 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import TestCase
 
 from pcs.common import report_codes
 from pcs.lib.booth import config_parser
 from pcs.lib.booth.config_structure import ConfigItem
 from pcs.lib.errors import ReportItemSeverity as severities
 from pcs.test.tools.assertions import assert_raise_library_error
-from pcs.test.tools.pcs_unittest import TestCase
 
 
 class BuildTest(TestCase):
@@ -56,6 +51,7 @@ class OrganizeLinesTest(TestCase):
         )
 
     def test_use_ticket_key_as_ticket_detail(self):
+        # pylint: disable=invalid-name
         self.maxDiff = None
         self.assertEqual(
             [
@@ -147,6 +143,7 @@ class ParseRawLinesTest(TestCase):
        )
 
 class ParseTest(TestCase):
+    # pylint: disable=no-self-use
     def test_raises_when_invalid_lines_appear(self):
         invalid_line_list = [
             "first invalid line",
