@@ -1,10 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-
 from lxml import etree
 
 from pcs.common import report_codes
@@ -32,14 +25,12 @@ def _validate_attrib_names(attrib_names, options):
             reports.invalid_options(invalid_names, attrib_names, None)
         )
 
-def find_valid_resource_id(
-    report_processor, cib, can_repair_to_clone, in_clone_allowed, id
-):
+def find_valid_resource_id(report_processor, cib, in_clone_allowed, _id):
     parent_tags = resource.clone.ALL_TAGS + [resource.bundle.TAG]
     resource_element = find_element_by_tag_and_id(
         parent_tags + [resource.primitive.TAG, resource.group.TAG],
         cib,
-        id,
+        _id,
     )
 
     if resource_element.tag in parent_tags:
@@ -49,16 +40,11 @@ def find_valid_resource_id(
     if clone is None:
         return resource_element.attrib["id"]
 
-    if can_repair_to_clone:
-        #this is workaround for web ui, console should not use it, so we do not
-        #warn about it
-        return clone.attrib["id"]
-
     if in_clone_allowed:
         report_processor.process(
             reports.resource_for_constraint_is_multiinstance(
                 resource_element.attrib["id"],
-                clone.tag,
+                "clone" if clone.tag == "master" else clone.tag,
                 clone.attrib["id"],
                 ReportItemSeverity.WARNING,
             )
@@ -67,7 +53,7 @@ def find_valid_resource_id(
 
     raise LibraryError(reports.resource_for_constraint_is_multiinstance(
         resource_element.attrib["id"],
-        clone.tag,
+        "clone" if clone.tag == "master" else clone.tag,
         clone.attrib["id"],
         ReportItemSeverity.ERROR,
         #repair to clone is workaround for web ui, so we put only information
@@ -75,12 +61,12 @@ def find_valid_resource_id(
         forceable=report_codes.FORCE_CONSTRAINT_MULTIINSTANCE_RESOURCE
     ))
 
-def prepare_options(attrib_names, options, create_id, validate_id):
+def prepare_options(attrib_names, options, create_id_fn, validate_id):
     _validate_attrib_names(attrib_names+("id",), options)
     options = options.copy()
 
     if "id" not in options:
-        options["id"] = create_id()
+        options["id"] = create_id_fn()
     else:
         validate_id(options["id"])
     return options
@@ -98,11 +84,11 @@ def export_plain(element):
     return {"options": export_attributes(element)}
 
 def create_id(cib, type_prefix, resource_set_list):
-    id = "pcs_" +type_prefix +"".join([
+    _id = "pcs_" +type_prefix +"".join([
         "_set_"+"_".join(id_set)
         for id_set in resource_set.extract_id_set_list(resource_set_list)
     ])
-    return find_unique_id(cib, id)
+    return find_unique_id(cib, _id)
 
 def have_duplicate_resource_sets(element, other_element):
     get_id_set_list = lambda element: [
