@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from functools import partial
 
 from pcs.lib import reports
@@ -23,7 +17,7 @@ def prepare_options_with_set(cib, options, resource_set_list):
     options = constraint.prepare_options(
         tuple(ATTRIB.keys()),
         options,
-        create_id=partial(
+        create_id_fn=partial(
             constraint.create_id, cib, TAG_NAME, resource_set_list
         ),
         validate_id=partial(check_new_id_applicable, cib, DESCRIPTION),
