@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from lxml import etree
 
 from pcs.lib import reports
@@ -32,7 +26,7 @@ def validate_options(options):
     for name, value in options.items():
         if name not in ATTRIB:
             raise LibraryError(
-                reports.invalid_option([name], list(ATTRIB.keys()), None)
+                reports.invalid_options([name], list(ATTRIB.keys()), None)
             )
         if value not in ATTRIB[name]:
             raise LibraryError(
@@ -53,8 +47,8 @@ def create(parent, resource_set):
         "pcs_rsc_set_{0}".format("_".join(resource_set["ids"]))
     )
 
-    for id in resource_set["ids"]:
-        etree.SubElement(element, "resource_ref").attrib["id"] = id
+    for _id in resource_set["ids"]:
+        etree.SubElement(element, "resource_ref").attrib["id"] = _id
 
     return element
 
