@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from lxml import etree
 
 from pcs.common import report_codes
@@ -22,6 +16,7 @@ def add_level(
     reporter, topology_el, resources_el, level, target_type, target_value,
     devices, cluster_status_nodes, force_device=False, force_node=False
 ):
+    # pylint: disable=too-many-arguments
     """
     Validate and add a new fencing level. Raise LibraryError if not valid.
 
@@ -179,6 +174,8 @@ def verify(reporter, topology_el, resources_el, cluster_status_nodes):
         )
 
 def _validate_level(reporter, level):
+    # TODO this should not rely on the report to be sent and the execution
+    # ended in a caller
     try:
         candidate = int(level)
         if candidate > 0:
@@ -188,6 +185,7 @@ def _validate_level(reporter, level):
     reporter.append(
         reports.invalid_option_value("level", level, "a positive integer")
     )
+    return None
 
 def _validate_target(
     reporter, cluster_status_nodes, target_type, target_value,
