@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from lxml import etree
 
 from pcs.common import report_codes
@@ -16,6 +10,7 @@ from pcs.lib.cib.resource.primitive import TAG as TAG_PRIMITIVE
 from pcs.lib.cib.tools import find_element_by_tag_and_id
 from pcs.lib.errors import (
     LibraryError,
+    ReportItemSeverity,
     ReportListAnalyzer,
 )
 from pcs.lib.pacemaker.values import sanitize_id
@@ -27,11 +22,14 @@ from pcs.lib.xml_tools import (
 
 TAG = "bundle"
 
-_docker_options = set((
+GENERIC_CONTAINER_TYPES = {"docker", "podman", "rkt"}
+
+_generic_container_options = set((
     "image",
     "masters",
     "network",
     "options",
+    "promoted-max",
     "run-command",
     "replicas",
     "replicas-per-host",
@@ -81,7 +79,7 @@ def validate_new(
         report_list.extend(
             # TODO call the proper function once more container_types are
             # supported by pacemaker
-            _validate_container_docker_options_new(
+            _validate_generic_container_options_new(
                 container_options,
                 force_options
             )
@@ -102,6 +100,7 @@ def append_new(
     parent_element, id_provider, bundle_id, container_type, container_options,
     network_options, port_map, storage_map, meta_attributes
 ):
+    # pylint: disable=too-many-arguments
     """
     Create new bundle and add it to the CIB
 
@@ -118,10 +117,10 @@ def append_new(
     bundle_element = etree.SubElement(parent_element, TAG, {"id": bundle_id})
     # TODO create the proper element once more container_types are supported
     # by pacemaker
-    docker_element = etree.SubElement(bundle_element, "docker")
+    container_element = etree.SubElement(bundle_element, container_type)
     # Do not add options with empty values. When updating, an empty value means
     # remove the option.
-    update_attributes_remove_empty(docker_element, container_options)
+    update_attributes_remove_empty(container_element, container_options)
     if network_options or port_map:
         network_element = etree.SubElement(bundle_element, "network")
         # Do not add options with empty values. When updating, an empty value
@@ -146,6 +145,7 @@ def validate_update(
     port_map_add, port_map_remove, storage_map_add, storage_map_remove,
     force_options=False
 ):
+    # pylint: disable=too-many-arguments
     """
     Validate modifying an existing bundle, return list of report items
 
@@ -161,17 +161,27 @@ def validate_update(
     """
     report_list = []
 
-    container_el = _get_container_element(bundle_el)
-    if container_el.tag == "docker":
-        # TODO call the proper function once more container types are
-        # supported by pacemaker
-        report_list.extend(
-            _validate_container_docker_options_update(
-                container_el,
-                container_options,
-                force_options
+    # validate container options only if they are being updated
+    if container_options:
+        container_el = _get_container_element(bundle_el)
+        if (
+            container_el is not None
+            and
+            container_el.tag in GENERIC_CONTAINER_TYPES
+        ):
+            report_list.extend(
+                _validate_generic_container_options_update(
+                    container_el,
+                    container_options,
+                    force_options
+                )
+            )
+        else:
+            report_list.append(
+                reports.resource_bundle_unsupported_container_type(
+                    bundle_el.get("id"), GENERIC_CONTAINER_TYPES
+                )
             )
-        )
 
     network_el = bundle_el.find("network")
     if network_el is None:
@@ -214,6 +224,7 @@ def update(
     port_map_add, port_map_remove, storage_map_add, storage_map_remove,
     meta_attributes
 ):
+    # pylint: disable=too-many-arguments
     """
     Modify an existing bundle (does not touch encapsulated resources)
 
@@ -311,23 +322,41 @@ def get_inner_resource(bundle_el):
     return None
 
 def _validate_container_type(container_type):
-    return validate.value_in("type", ("docker", ), "container type")({
-        "type": container_type,
-    })
+    return validate.value_in(
+        "type",
+        GENERIC_CONTAINER_TYPES,
+        "container type"
+    )(
+        {
+            "type": container_type,
+        }
+    )
 
-def _validate_container_docker_options_new(options, force_options):
+def _validate_generic_container_options_new(options, force_options):
     validators = [
         validate.is_required("image", "container"),
         validate.value_not_empty("image", "image name"),
         validate.value_nonnegative_integer("masters"),
+        validate.value_nonnegative_integer("promoted-max"),
+        validate.mutually_exclusive(["masters", "promoted-max"], "container"),
         validate.value_positive_integer("replicas"),
         validate.value_positive_integer("replicas-per-host"),
     ]
+    deprecation_reports = []
+    if "masters" in options:
+        deprecation_reports.append(
+            reports.deprecated_option(
+                "masters", ["promoted-max"], "container",
+                severity=ReportItemSeverity.WARNING
+            )
+        )
     return (
         validate.run_collection_of_option_validators(options, validators)
         +
+        deprecation_reports
+        +
         validate.names_in(
-            _docker_options,
+            _generic_container_options,
             options.keys(),
             "container",
             report_codes.FORCE_OPTIONS,
@@ -335,7 +364,7 @@ def _validate_container_docker_options_new(options, force_options):
         )
     )
 
-def _validate_container_docker_options_update(
+def _validate_generic_container_options_update(
     docker_el, options, force_options
 ):
     validators = [
@@ -345,6 +374,10 @@ def _validate_container_docker_options_update(
             "masters",
             validate.value_nonnegative_integer("masters")
         ),
+        validate.value_empty_or_valid(
+            "promoted-max",
+            validate.value_nonnegative_integer("promoted-max")
+        ),
         validate.value_empty_or_valid(
             "replicas",
             validate.value_positive_integer("replicas")
@@ -354,12 +387,64 @@ def _validate_container_docker_options_update(
             validate.value_positive_integer("replicas-per-host")
         ),
     ]
+    # CIB does not allow both to be set. Deleting both is not a problem,
+    # though. Deleting one while setting another also works and is further
+    # checked bellow.
+    if not (
+        options.get("masters", "") == ""
+        or
+        options.get("promoted-max", "") == ""
+    ):
+        validators.append(
+            validate.mutually_exclusive(
+                ["masters", "promoted-max"],
+                "container"
+            )
+        )
+
+    deprecation_reports = []
+    if options.get("masters"):
+        # If the user wants to delete the masters option, do not report it is
+        # deprecated. They may be removing it because they just found out it is
+        # deprecated.
+        deprecation_reports.append(
+            reports.deprecated_option(
+                "masters", ["promoted-max"], "container",
+                severity=ReportItemSeverity.WARNING
+            )
+        )
+    # Do not allow to set masters if promoted-max is set unless promoted-max is
+    # going to be removed now. Do the same check also the other way around. CIB
+    # only allows one of them to be set.
+    if (
+        options.get("masters")
+        and
+        docker_el.get("promoted-max") and options.get("promoted-max") != ""
+    ):
+        deprecation_reports.append(
+            reports.prerequisite_option_must_not_be_set(
+                "masters", "promoted-max", "container", "container"
+            )
+        )
+    if (
+        options.get("promoted-max")
+        and
+        docker_el.get("masters") and options.get("masters") != ""
+    ):
+        deprecation_reports.append(
+            reports.prerequisite_option_must_not_be_set(
+                "promoted-max", "masters", "container", "container"
+            )
+        )
+
     return (
         validate.run_collection_of_option_validators(options, validators)
         +
+        deprecation_reports
+        +
         validate.names_in(
             # allow to remove options even if they are not allowed
-            _docker_options | _options_to_remove(options),
+            _generic_container_options | _options_to_remove(options),
             options.keys(),
             "container",
             report_codes.FORCE_OPTIONS,
@@ -467,7 +552,7 @@ def _validate_port_map_list(options_list, id_provider, force_options):
         validate.value_port_range(
             "range",
             code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
-            allow_extra_values=force_options
+            extra_values_allowed=force_options
         ),
     ]
     report_list = []
@@ -517,10 +602,10 @@ def _validate_storage_map_list(options_list, id_provider, force_options):
 
 def _validate_map_ids_exist(bundle_el, map_type, map_label, id_list):
     report_list = []
-    for id in id_list:
+    for _id in id_list:
         try:
             find_element_by_tag_and_id(
-                map_type, bundle_el, id, id_types=[map_label]
+                map_type, bundle_el, _id, id_types=[map_label]
             )
         except LibraryError as e:
             report_list.extend(e.args)
@@ -534,7 +619,7 @@ def _value_host_netmask(option_name, force_options):
         # Leaving a possibility to force this validation, if pacemaker
         # starts supporting IPv6 or other format of the netmask
         code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
-        allow_extra_values=force_options
+        extra_values_allowed=force_options
     )
 
 def _append_port_map(parent_element, id_provider, id_base, port_map_options):
@@ -569,8 +654,12 @@ def _append_storage_map(
     return storage_map_element
 
 def _get_container_element(bundle_el):
-    # TODO get different types of container once supported by pacemaker
-    return bundle_el.find("docker")
+    container_el = None
+    for container_type in GENERIC_CONTAINER_TYPES:
+        container_el = bundle_el.find(container_type)
+        if container_el is not None:
+            return container_el
+    return None
 
 def _remove_map_elements(element_list, id_to_remove_list):
     for el in element_list:
@@ -578,7 +667,7 @@ def _remove_map_elements(element_list, id_to_remove_list):
             el.getparent().remove(el)
 
 def _options_to_remove(options):
-    return set([
+    return {
         name for name, value in options.items()
         if validate.is_empty_string(value)
-    ])
+    }
