@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from collections import defaultdict
 
 from lxml import etree
@@ -35,7 +29,6 @@ ATTRIBUTES = [
     "name",
     "on-fail",
     "record-pending",
-    "requires",
     "role",
     "start-delay",
     "timeout",
@@ -49,13 +42,6 @@ ROLE_VALUES = [
     "Master",
 ]
 
-REQUIRES_VALUES = [
-    "nothing",
-    "quorum",
-    "fencing",
-    "unfencing",
-]
-
 ON_FAIL_VALUES = [
     "ignore",
     "block",
@@ -76,7 +62,6 @@ BOOLEAN_VALUES = [
 #normalize(key, value) -> normalized_value
 normalize = validate.option_value_normalization({
     "role": lambda value: value.lower().capitalize(),
-    "requires": lambda value: value.lower(),
     "on-fail": lambda value: value.lower(),
     "record-pending": lambda value: value.lower(),
     "enabled": lambda value: value.lower(),
@@ -137,7 +122,6 @@ def validate_operation_list(
     options_validators = [
         validate.is_required("name", "resource operation"),
         validate.value_in("role", ROLE_VALUES),
-        validate.value_in("requires", REQUIRES_VALUES),
         validate.value_in("on-fail", ON_FAIL_VALUES),
         validate.value_in("record-pending", BOOLEAN_VALUES),
         validate.value_in("enabled", BOOLEAN_VALUES),
@@ -150,7 +134,7 @@ def validate_operation_list(
             allowed_operation_name_list,
             option_name_for_report="operation name",
             code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
-            allow_extra_values=allow_invalid,
+            extra_values_allowed=allow_invalid,
         ),
         validate.value_id("id", option_name_for_report="operation id"),
     ]
