@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from lxml import etree
 
 from pcs.lib import reports
@@ -33,6 +27,7 @@ def create(
     use_default_operations=True,
     resource_type="resource"
 ):
+    # pylint: disable=too-many-arguments
     """
     Prepare all parts of primitive resource and append it into cib.
 
@@ -72,10 +67,9 @@ def create(
     )
 
     report_processor.process_list(
-        resource_agent.validate_parameters(
+        resource_agent.validate_parameters_create(
             instance_attributes,
-            parameters_type=resource_type,
-            allow_invalid=allow_invalid_instance_attributes,
+            force=allow_invalid_instance_attributes,
         )
     )
 
