@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 # TODO replace by the new finding function
 def is_stonith_resource(resources_el, name):
     return len(
@@ -11,4 +5,3 @@ def is_stonith_resource(resources_el, name):
             "primitive[@id='{0}' and @class='stonith']".format(name)
         )
     ) > 0
-
