@@ -1,11 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from pcs.test.tools.pcs_unittest import TestCase
-
+from unittest import TestCase
 from lxml import etree
 
 from pcs.common import report_codes
@@ -20,6 +13,7 @@ from pcs.test.tools.custom_mock import MockLibraryReportProcessor
 
 
 class UpdateOptionalAttributeTest(TestCase):
+    # pylint: disable=protected-access
     def test_add(self):
         element = etree.Element("element")
         alert._update_optional_attribute(element, "attr", "value1")
@@ -120,6 +114,7 @@ class CreateAlertTest(TestCase):
         )
 
     def test_no_alerts(self):
+        # pylint: disable=no-self-use
         tree = etree.XML(
             """
             <cib>
