@@ -1,13 +1,7 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+from unittest import TestCase
 from lxml import etree
 
 from pcs.lib.cib.resource import bundle
-from pcs.test.tools.pcs_unittest import TestCase
 
 # pcs.lib.cib.resource.bundle is covered by:
 # - pcs.lib.commands.test.resource.test_bundle_create
