@@ -1,14 +1,8 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+from unittest import TestCase
 from lxml import etree
 
 from pcs.lib.cib.resource import common
 from pcs.test.tools.assertions import assert_xml_equal
-from pcs.test.tools.pcs_unittest import TestCase
 from pcs.test.tools.xml import etree_to_str
 
 
@@ -210,7 +204,8 @@ class FindResourcesToEnable(TestCase):
 
 
 class Enable(TestCase):
-    def assert_enabled(self, pre, post):
+    @staticmethod
+    def assert_enabled(pre, post):
         resource = etree.fromstring(pre)
         common.enable(resource)
         assert_xml_equal(post, etree_to_str(resource))
@@ -268,7 +263,8 @@ class Enable(TestCase):
 
 
 class Disable(TestCase):
-    def assert_disabled(self, pre, post):
+    @staticmethod
+    def assert_disabled(pre, post):
         resource = etree.fromstring(pre)
         common.disable(resource)
         assert_xml_equal(post, etree_to_str(resource))
@@ -453,7 +449,8 @@ class FindResourcesToUnmanage(TestCase):
 
 
 class Manage(TestCase):
-    def assert_managed(self, pre, post):
+    @staticmethod
+    def assert_managed(pre, post):
         resource = etree.fromstring(pre)
         common.manage(resource)
         assert_xml_equal(post, etree_to_str(resource))
@@ -511,7 +508,8 @@ class Manage(TestCase):
 
 
 class Unmanage(TestCase):
-    def assert_unmanaged(self, pre, post):
+    @staticmethod
+    def assert_unmanaged(pre, post):
         resource = etree.fromstring(pre)
         common.unmanage(resource)
         assert_xml_equal(post, etree_to_str(resource))
