@@ -1,10 +1,5 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from functools import partial
+from unittest import mock, TestCase
 from lxml import etree
 
 from pcs.common import report_codes
@@ -14,8 +9,8 @@ from pcs.lib.validate import ValuePair
 from pcs.test.tools.assertions import assert_report_item_list_equal
 from pcs.test.tools.custom_mock import MockLibraryReportProcessor
 from pcs.test.tools.misc import create_patcher
-from pcs.test.tools.pcs_unittest import TestCase, mock
 
+# pylint: disable=no-self-use
 
 patch_operations = create_patcher("pcs.lib.cib.resource.operations")
 
@@ -204,10 +199,13 @@ class Normalize(TestCase):
             "timeout": "10",
         }
 
-        self.assertEqual(operation, dict([
-            (key, operations.normalize(key, value))
-            for key, value in operation.items()
-        ]))
+        self.assertEqual(
+            operation,
+            {
+                key: operations.normalize(key, value)
+                for key, value in operation.items()
+            }
+        )
 
     def test_return_operation_with_normalized_values(self):
         self.assertEqual(
@@ -215,20 +213,18 @@ class Normalize(TestCase):
                 "name": "monitor",
                 "role": "Master",
                 "timeout": "10",
-                "requires": "nothing",
                 "on-fail": "ignore",
                 "record-pending": "true",
                 "enabled": "1",
             },
-            dict([(key, operations.normalize(key, value)) for key, value in {
+            {key: operations.normalize(key, value) for key, value in {
                 "name": "monitor",
                 "role": "master",
                 "timeout": "10",
-                "requires": "Nothing",
                 "on-fail": "Ignore",
                 "record-pending": "True",
                 "enabled": "1",
-            }.items()])
+            }.items()}
         )
 
 class ValidateOperation(TestCase):
@@ -349,7 +345,7 @@ class GetRemainingDefaults(TestCase):
         self.assertEqual(
             operations.get_remaining_defaults(
                 report_processor=None,
-                operation_list =[{"name": "monitor"}],
+                operation_list=[{"name": "monitor"}],
                 default_operation_list=[{"name": "monitor"}, {"name": "start"}]
             ),
             [{"name": "start"}]
