@@ -1,15 +1,8 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from functools import partial
-
+from unittest import mock, TestCase
 from lxml import etree
 
 from pcs.lib.cib.resource import primitive
-from pcs.test.tools.pcs_unittest import TestCase, mock
 
 @mock.patch("pcs.lib.cib.resource.primitive.append_new_instance_attributes")
 @mock.patch("pcs.lib.cib.resource.primitive.append_new_meta_attributes")
