@@ -1,21 +1,13 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from functools import partial
-
+from unittest import mock, TestCase
 from lxml import etree
 
-from pcs.test.tools.pcs_unittest import TestCase
 from pcs.test.tools.assertions import (
     assert_raise_library_error,
     assert_report_item_list_equal,
 )
 from pcs.test.tools import fixture
 from pcs.test.tools.misc import get_test_resource as rc
-from pcs.test.tools.pcs_unittest import mock
 from pcs.test.tools.xml import get_xml_manipulation_creator_from_file
 
 from pcs.common import report_codes
@@ -24,6 +16,8 @@ from pcs.lib.errors import ReportItemSeverity as severities
 
 from pcs.lib.cib import tools as lib
 
+# pylint: disable=no-self-use, line-too-long
+
 class CibToolsTest(TestCase):
     def setUp(self):
         self.create_cib = get_xml_manipulation_creator_from_file(
@@ -44,12 +38,13 @@ class IdProviderTest(CibToolsTest):
         super(IdProviderTest, self).setUp()
         self.provider = lib.IdProvider(self.cib.tree)
 
-    def fixture_report(self, id):
+    @staticmethod
+    def fixture_report(_id):
         return (
             severities.ERROR,
             report_codes.ID_ALREADY_EXISTS,
             {
-                "id": id,
+                "id": _id,
             },
             None
         )
@@ -115,15 +110,15 @@ class IdProviderBook(IdProviderTest):
 
 class IdProviderAllocate(IdProviderTest):
     def test_nonexisting_id(self):
-        self.assertEqual("myId",  self.provider.allocate_id("myId"))
+        self.assertEqual("myId", self.provider.allocate_id("myId"))
 
     def test_existing_id(self):
         self.fixture_add_primitive_with_id("myId")
-        self.assertEqual("myId-1",  self.provider.allocate_id("myId"))
+        self.assertEqual("myId-1", self.provider.allocate_id("myId"))
 
     def test_allocate_books(self):
-        self.assertEqual("myId",  self.provider.allocate_id("myId"))
-        self.assertEqual("myId-1",  self.provider.allocate_id("myId"))
+        self.assertEqual("myId", self.provider.allocate_id("myId"))
+        self.assertEqual("myId-1", self.provider.allocate_id("myId"))
 
     def test_booked_ids(self):
         self.fixture_add_primitive_with_id("myId")
@@ -131,7 +126,7 @@ class IdProviderAllocate(IdProviderTest):
             self.provider.book_ids("myId-1"),
             []
         )
-        self.assertEqual("myId-2",  self.provider.allocate_id("myId"))
+        self.assertEqual("myId-2", self.provider.allocate_id("myId"))
 
 
 class DoesIdExistTest(CibToolsTest):
@@ -380,9 +375,9 @@ class GetFencingTopology(CibToolsTest):
         )
 
     def test_success_if_missing(self):
-        ft = lib.get_fencing_topology(self.cib.tree)
-        self.assertEqual("fencing-topology", ft.tag)
-        self.assertEqual("configuration", ft.getparent().tag)
+        ft_el = lib.get_fencing_topology(self.cib.tree)
+        self.assertEqual("fencing-topology", ft_el.tag)
+        self.assertEqual("configuration", ft_el.getparent().tag)
 
 
 @mock.patch('pcs.lib.cib.tools.does_id_exist')
@@ -436,6 +431,21 @@ class GetPacemakerVersionByWhichCibWasValidatedTest(TestCase):
             )
         )
 
+    def test_invalid_version_at_end(self):
+        assert_raise_library_error(
+            lambda: lib.get_pacemaker_version_by_which_cib_was_validated(
+                etree.XML('<cib validate-with="pacemaker-1.2.3x"/>')
+            ),
+            (
+                severities.ERROR,
+                report_codes.CIB_LOAD_ERROR_BAD_FORMAT,
+                {
+                    "reason": "the attribute 'validate-with' of the element"
+                        " 'cib' has an invalid value: 'pacemaker-1.2.3x'"
+                }
+            )
+        )
+
     def test_no_revision(self):
         self.assertEqual(
             Version(1, 2),
@@ -453,7 +463,7 @@ class GetPacemakerVersionByWhichCibWasValidatedTest(TestCase):
         )
 
 
-class getCibCrmFeatureSet(TestCase):
+class GetCibCrmFeatureSet(TestCase):
     def test_success(self):
         self.assertEqual(
             Version(3, 0, 9),
@@ -507,6 +517,20 @@ class getCibCrmFeatureSet(TestCase):
             )
         )
 
+    def test_invalid_version_at_end(self):
+        assert_raise_library_error(
+            lambda: lib.get_cib_crm_feature_set(
+                etree.XML('<cib crm_feature_set="3.0.9x" />')
+            ),
+            fixture.error(
+                report_codes.CIB_LOAD_ERROR_BAD_FORMAT,
+                reason=(
+                    "the attribute 'crm_feature_set' of the element 'cib' has "
+                    "an invalid value: '3.0.9x'"
+                )
+            )
+        )
+
 
 find_group = partial(lib.find_element_by_tag_and_id, "group")
 class FindTagWithId(TestCase):
