@@ -1,12 +1,6 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import re
 
-from pcs.common.tools import is_string, Version
+from pcs.common.tools import Version
 from pcs.lib import reports
 from pcs.lib.cib import sections
 from pcs.lib.errors import LibraryError
@@ -16,9 +10,9 @@ from pcs.lib.pacemaker.values import (
 )
 from pcs.lib.xml_tools import get_root, get_sub_element
 
-_VERSION_FORMAT = r"(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<rev>\d+))?"
+VERSION_FORMAT = r"(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<rev>\d+))?$"
 
-class IdProvider(object):
+class IdProvider:
     """
     Book ids for future use in the CIB and generate new ids accordingly
     """
@@ -45,14 +39,14 @@ class IdProvider(object):
         """
         reported_ids = set()
         report_list = []
-        for id in id_list:
-            if id in reported_ids:
+        for _id in id_list:
+            if _id in reported_ids:
                 continue
-            if id in self._booked_ids or does_id_exist(self._cib, id):
-                report_list.append(reports.id_already_exists(id))
-                reported_ids.add(id)
+            if _id in self._booked_ids or does_id_exist(self._cib, _id):
+                report_list.append(reports.id_already_exists(_id))
+                reported_ids.add(_id)
                 continue
-            self._booked_ids.add(id)
+            self._booked_ids.add(_id)
         return report_list
 
 
@@ -98,12 +92,12 @@ def does_id_exist(tree, check_id):
     """.format(check_id))
     return len(existing) > 0
 
-def validate_id_does_not_exist(tree, id):
+def validate_id_does_not_exist(tree, _id):
     """
     tree cib etree node
     """
-    if does_id_exist(tree, id):
-        raise LibraryError(reports.id_already_exists(id))
+    if does_id_exist(tree, _id):
+        raise LibraryError(reports.id_already_exists(_id))
 
 def find_unique_id(tree, check_id, reserved_ids=None):
     """
@@ -137,10 +131,10 @@ def find_element_by_tag_and_id(
         or raise a LibraryError if False
     list id_types optional list of descriptions for id / expected types of id
     """
-    tag_list = [tag] if is_string(tag) else tag
+    tag_list = [tag] if isinstance(tag, str) else tag
     if id_types is None:
         id_type_list = tag_list
-    elif is_string(id_types):
+    elif isinstance(id_types, str):
         id_type_list = [id_types]
     else:
         id_type_list = id_types
@@ -163,7 +157,7 @@ def find_element_by_tag_and_id(
         raise LibraryError(
             reports.id_belongs_to_unexpected_type(
                 element_id,
-                expected_types=tag_list,
+                expected_types=id_type_list,
                 current_type=element.tag
             ) if element.tag not in tag_list
             else reports.object_with_id_in_unexpected_context(
@@ -194,9 +188,9 @@ def create_subelement_id(context_element, suffix, id_provider=None):
         return id_provider.allocate_id(proposed_id)
     return find_unique_id(context_element, proposed_id)
 
-def check_new_id_applicable(tree, description, id):
-    validate_id(id, description)
-    validate_id_does_not_exist(tree, id)
+def check_new_id_applicable(tree, description, _id):
+    validate_id(_id, description)
+    validate_id_does_not_exist(tree, _id)
 
 def get_configuration(tree):
     """
@@ -289,7 +283,7 @@ def get_pacemaker_version_by_which_cib_was_validated(cib):
     return _get_cib_version(
         cib,
         "validate-with",
-        re.compile(r"pacemaker-{0}".format(_VERSION_FORMAT))
+        re.compile(r"pacemaker-{0}".format(VERSION_FORMAT))
     )
 
 def get_cib_crm_feature_set(cib, none_if_missing=False):
@@ -303,6 +297,6 @@ def get_cib_crm_feature_set(cib, none_if_missing=False):
     return _get_cib_version(
         cib,
         "crm_feature_set",
-        re.compile(_VERSION_FORMAT),
+        re.compile(VERSION_FORMAT),
         none_if_missing=none_if_missing
     )
