@@ -1,11 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from contextlib import contextmanager
-from functools import partial
 
 from pcs.common import report_codes
 from pcs.common.tools import Version
@@ -21,7 +14,7 @@ from pcs.lib.cib.tools import (
     get_status,
     IdProvider,
 )
-from pcs.lib.env_tools import get_nodes
+from pcs.lib.env_tools import get_existing_nodes_names_addrs
 from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.values import (
     timeout_to_seconds,
@@ -66,7 +59,7 @@ def _ensure_disabled_after_wait(disabled_after_wait):
     return inner
 
 def _validate_remote_connection(
-    resource_agent, nodes_to_validate_against, resource_id, instance_attributes,
+    resource_agent, existing_nodes_addrs, resource_id, instance_attributes,
     allow_not_suitable_command
 ):
     if resource_agent.get_name() != remote_node.AGENT_NAME.full_name:
@@ -82,7 +75,7 @@ def _validate_remote_connection(
 
     report_list.extend(
         remote_node.validate_host_not_conflicts(
-            nodes_to_validate_against,
+            existing_nodes_addrs,
             resource_id,
             instance_attributes
         )
@@ -90,7 +83,7 @@ def _validate_remote_connection(
     return report_list
 
 def _validate_guest_change(
-    tree, nodes_to_validate_against, meta_attributes,
+    tree, existing_nodes_names, existing_nodes_addrs, meta_attributes,
     allow_not_suitable_command, detect_remove=False
 ):
     if not guest_node.is_node_name_in_options(meta_attributes):
@@ -113,7 +106,8 @@ def _validate_guest_change(
     report_list.extend(
         guest_node.validate_conflicts(
             tree,
-            nodes_to_validate_against,
+            existing_nodes_names,
+            existing_nodes_addrs,
             node_name,
             meta_attributes
         )
@@ -130,9 +124,9 @@ def _get_nodes_to_validate_against(env, tree):
     if not env.is_cib_live and env.is_corosync_conf_live:
         #we do not try to get corosync.conf from live cluster when cib is not
         #taken from live cluster
-        return get_nodes(tree=tree)
+        return get_existing_nodes_names_addrs(cib=tree)
 
-    return get_nodes(env.get_corosync_conf(), tree)
+    return get_existing_nodes_names_addrs(env.get_corosync_conf(), cib=tree)
 
 
 def _check_special_cases(
@@ -148,7 +142,7 @@ def _check_special_cases(
         #is needed for getting nodes to validate against
         return
 
-    nodes_to_validate_against = _get_nodes_to_validate_against(
+    existing_nodes_names, existing_nodes_addrs = _get_nodes_to_validate_against(
         env,
         resources_section
     )
@@ -156,14 +150,15 @@ def _check_special_cases(
     report_list = []
     report_list.extend(_validate_remote_connection(
         resource_agent,
-        nodes_to_validate_against,
+        existing_nodes_addrs,
         resource_id,
         instance_attributes,
         allow_not_suitable_command,
     ))
     report_list.extend(_validate_guest_change(
         resources_section,
-        nodes_to_validate_against,
+        existing_nodes_names,
+        existing_nodes_addrs,
         meta_attributes,
         allow_not_suitable_command,
     ))
@@ -172,7 +167,7 @@ def _check_special_cases(
 
 def create(
     env, resource_id, resource_agent_name,
-    operations, meta_attributes, instance_attributes,
+    operation_list, meta_attributes, instance_attributes,
     allow_absent_agent=False,
     allow_invalid_operation=False,
     allow_invalid_instance_attributes=False,
@@ -181,13 +176,14 @@ def create(
     wait=False,
     allow_not_suitable_command=False,
 ):
+    # pylint: disable=too-many-arguments, too-many-locals
     """
     Create resource in a cib.
 
     LibraryEnvironment env provides all for communication with externals
     string resource_id is identifier of resource
     string resource_agent_name contains name for the identification of agent
-    list of dict operations contains attributes for each entered operation
+    list of dict operation_list contains attributes for each entered operation
     dict meta_attributes contains attributes for primitive/meta_attributes
     dict instance_attributes contains attributes for
         primitive/instance_attributes
@@ -202,7 +198,7 @@ def create(
     bool use_default_operations is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
     bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    mixed wait is flag for controlling waiting for pacemaker iddle mechanism
+    mixed wait is flag for controlling waiting for pacemaker idle mechanism
     bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     """
     resource_agent = get_agent(
@@ -234,7 +230,7 @@ def create(
         primitive_element = resource.primitive.create(
             env.report_processor, resources_section,
             resource_id, resource_agent,
-            operations, meta_attributes, instance_attributes,
+            operation_list, meta_attributes, instance_attributes,
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
@@ -242,9 +238,9 @@ def create(
         if ensure_disabled:
             resource.common.disable(primitive_element)
 
-def _create_as_clone_common(
-    tag, env, resource_id, resource_agent_name,
-    operations, meta_attributes, instance_attributes, clone_meta_options,
+def create_as_clone(
+    env, resource_id, resource_agent_name,
+    operation_list, meta_attributes, instance_attributes, clone_meta_options,
     allow_absent_agent=False,
     allow_invalid_operation=False,
     allow_invalid_instance_attributes=False,
@@ -253,18 +249,14 @@ def _create_as_clone_common(
     wait=False,
     allow_not_suitable_command=False,
 ):
+    # pylint: disable=too-many-arguments, too-many-locals
     """
-    Create resource in some kind of clone (clone or master).
+    Create resource in a clone
 
-    Currently the only difference between commands "create_as_clone" and
-    "create_as_master" is in tag. So the commands create_as_clone and
-    create_as_master are created by passing tag with partial.
-
-    string tag is any clone tag. Currently it can be "clone" or "master".
     LibraryEnvironment env provides all for communication with externals
     string resource_id is identifier of resource
     string resource_agent_name contains name for the identification of agent
-    list of dict operations contains attributes for each entered operation
+    list of dict operation_list contains attributes for each entered operation
     dict meta_attributes contains attributes for primitive/meta_attributes
     dict instance_attributes contains attributes for
         primitive/instance_attributes
@@ -280,7 +272,7 @@ def _create_as_clone_common(
     bool use_default_operations is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
     bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    mixed wait is flag for controlling waiting for pacemaker iddle mechanism
+    mixed wait is flag for controlling waiting for pacemaker idle mechanism
     bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     """
     resource_agent = get_agent(
@@ -314,13 +306,12 @@ def _create_as_clone_common(
         primitive_element = resource.primitive.create(
             env.report_processor, resources_section,
             resource_id, resource_agent,
-            operations, meta_attributes, instance_attributes,
+            operation_list, meta_attributes, instance_attributes,
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
         )
         clone_element = resource.clone.append_new(
-            tag,
             resources_section,
             primitive_element,
             clone_meta_options,
@@ -330,7 +321,7 @@ def _create_as_clone_common(
 
 def create_in_group(
     env, resource_id, resource_agent_name, group_id,
-    operations, meta_attributes, instance_attributes,
+    operation_list, meta_attributes, instance_attributes,
     allow_absent_agent=False,
     allow_invalid_operation=False,
     allow_invalid_instance_attributes=False,
@@ -341,6 +332,7 @@ def create_in_group(
     wait=False,
     allow_not_suitable_command=False,
 ):
+    # pylint: disable=too-many-arguments, too-many-locals
     """
     Create resource in a cib and put it into defined group
 
@@ -348,7 +340,7 @@ def create_in_group(
     string resource_id is identifier of resource
     string resource_agent_name contains name for the identification of agent
     string group_id is identificator for group to put primitive resource inside
-    list of dict operations contains attributes for each entered operation
+    list of dict operation_list contains attributes for each entered operation
     dict meta_attributes contains attributes for primitive/meta_attributes
     bool allow_absent_agent is a flag for allowing agent that is not installed
         in a system
@@ -364,7 +356,7 @@ def create_in_group(
     string adjacent_resource_id identify neighbor of a newly created resource
     bool put_after_adjacent is flag to put a newly create resource befor/after
         adjacent resource
-    mixed wait is flag for controlling waiting for pacemaker iddle mechanism
+    mixed wait is flag for controlling waiting for pacemaker idle mechanism
     bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     """
     resource_agent = get_agent(
@@ -396,7 +388,7 @@ def create_in_group(
         primitive_element = resource.primitive.create(
             env.report_processor, resources_section,
             resource_id, resource_agent,
-            operations, meta_attributes, instance_attributes,
+            operation_list, meta_attributes, instance_attributes,
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
@@ -411,12 +403,9 @@ def create_in_group(
             put_after_adjacent,
         )
 
-create_as_clone = partial(_create_as_clone_common, resource.clone.TAG_CLONE)
-create_as_master = partial(_create_as_clone_common, resource.clone.TAG_MASTER)
-
 def create_into_bundle(
     env, resource_id, resource_agent_name,
-    operations, meta_attributes, instance_attributes,
+    operation_list, meta_attributes, instance_attributes,
     bundle_id,
     allow_absent_agent=False,
     allow_invalid_operation=False,
@@ -427,13 +416,14 @@ def create_into_bundle(
     allow_not_suitable_command=False,
     allow_not_accessible_resource=False,
 ):
+    # pylint: disable=too-many-arguments, too-many-locals
     """
     Create a new resource in a cib and put it into an existing bundle
 
     LibraryEnvironment env provides all for communication with externals
     string resource_id is identifier of resource
     string resource_agent_name contains name for the identification of agent
-    list of dict operations contains attributes for each entered operation
+    list of dict operation_list contains attributes for each entered operation
     dict meta_attributes contains attributes for primitive/meta_attributes
     dict instance_attributes contains attributes for
         primitive/instance_attributes
@@ -449,7 +439,7 @@ def create_into_bundle(
     bool use_default_operations is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
     bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    mixed wait is flag for controlling waiting for pacemaker iddle mechanism
+    mixed wait is flag for controlling waiting for pacemaker idle mechanism
     bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     bool allow_not_accessible_resource -- flag for
         FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE
@@ -484,7 +474,7 @@ def create_into_bundle(
         primitive_element = resource.primitive.create(
             env.report_processor, resources_section,
             resource_id, resource_agent,
-            operations, meta_attributes, instance_attributes,
+            operation_list, meta_attributes, instance_attributes,
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
@@ -517,6 +507,7 @@ def bundle_create(
     ensure_disabled=False,
     wait=False,
 ):
+    # pylint: disable=too-many-arguments
     """
     Create a new bundle containing no resources
 
@@ -538,6 +529,13 @@ def bundle_create(
     storage_map = storage_map or []
     meta_attributes = meta_attributes or {}
 
+    required_cib_version = Version(2, 8, 0)
+    if container_type == "rkt":
+        required_cib_version = Version(2, 10, 0)
+    if "promoted-max" in container_options:
+        required_cib_version = Version(3, 0, 0)
+    if container_type == "podman":
+        required_cib_version = Version(3, 2, 0)
     with resource_environment(
         env,
         wait,
@@ -547,7 +545,7 @@ def bundle_create(
             or
             resource.common.are_meta_disabled(meta_attributes)
         ),
-        required_cib_version=Version(2, 8, 0)
+        required_cib_version=required_cib_version
     ) as resources_section:
         # no need to run validations related to remote and guest nodes as those
         # nodes can only be created from primitive resources
@@ -586,6 +584,7 @@ def bundle_update(
     force_options=False,
     wait=False,
 ):
+    # pylint: disable=too-many-arguments
     """
     Modify an existing bundle (does not touch encapsulated resources)
 
@@ -609,11 +608,14 @@ def bundle_update(
     storage_map_remove = storage_map_remove or []
     meta_attributes = meta_attributes or {}
 
+    required_cib_version = Version(2, 8, 0)
+    if "promoted-max" in container_options:
+        required_cib_version = Version(3, 0, 0)
     with resource_environment(
         env,
         wait,
         [bundle_id],
-        required_cib_version=Version(2, 8, 0)
+        required_cib_version=required_cib_version
     ) as resources_section:
         # no need to run validations related to remote and guest nodes as those
         # nodes can only be created from primitive resources
@@ -706,7 +708,7 @@ def _resource_list_enable_disable(resource_el_list, func, cluster_state):
             report_list.append(
                 reports.id_not_found(
                     res_id,
-                    ["primitive", "clone", "master", "group", "bundle"]
+                    ["primitive", "clone", "group", "bundle"]
                )
             )
     return report_list
@@ -792,6 +794,7 @@ def manage(env, resource_ids, with_monitor=False):
 def get_failcounts(
     env, resource=None, node=None, operation=None, interval=None
 ):
+    # pylint: disable=redefined-outer-name
     """
     List resources failcounts, optionally filtered by a resource, node or op
 
@@ -848,7 +851,16 @@ def _find_resources_or_raise(
                     find_element_by_tag_and_id(
                         resource_tags,
                         resources_section,
-                        res_id
+                        res_id,
+                        # pacemaker-2.0 deprecated masters. We treat masters as
+                        # clones. Do not report we were looking for a master,
+                        # say we were looking for a clone instead. Since we
+                        # look for all resource types including clones, just
+                        # drop the master.
+                        id_types=[
+                            tag for tag in resource_tags
+                            if tag != resource.clone.TAG_MASTER
+                        ]
                     )
                 )
             )
