@@ -1,11 +1,6 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from functools import partial
 from textwrap import dedent
+from unittest import TestCase
 
 from pcs.common import report_codes
 from pcs.lib import reports
@@ -16,41 +11,44 @@ from pcs.lib.errors import (
 )
 from pcs.test.tools import fixture
 from pcs.test.tools.command_env import get_env_tools
-from pcs.test.tools.misc import skip_unless_pacemaker_supports_bundle
-from pcs.test.tools.pcs_unittest import TestCase
-
-
-TIMEOUT=10
-
-get_env_tools = partial(
-    get_env_tools,
-    base_cib_filename="cib-empty-2.8.xml"
+from pcs.test.tools.misc import (
+    ParametrizedTestMetaClass,
+    skip_unless_pacemaker_supports_bundle,
 )
 
 
-def simple_bundle_create(env, wait=TIMEOUT, disabled=False):
+TIMEOUT = 10
+
+get_env_tools = partial(
+    get_env_tools,
+    base_cib_filename="cib-empty.xml"
+)
+
+def simple_bundle_create(
+    env, wait=TIMEOUT, disabled=False, container_type="docker"
+):
     return resource.bundle_create(
-        env, "B1", "docker",
+        env, "B1", container_type,
         container_options={"image": "pcs:test"},
         ensure_disabled=disabled,
         wait=wait,
     )
 
-fixture_cib_pre = "<resources />"
-fixture_resources_bundle_simple = """
-    <resources>
-        <bundle id="B1">
-            <docker image="pcs:test" />
-        </bundle>
-    </resources>
-"""
+def fixture_resources_bundle_simple(container_type="docker"):
+    return """
+        <resources>
+            <bundle id="B1">
+                <{container_type} image="pcs:test" />
+            </bundle>
+        </resources>
+    """.format(container_type=container_type)
 
 class MinimalCreate(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
         (self.config
             .runner.cib.load()
-            .env.push_cib(resources=fixture_resources_bundle_simple)
+            .env.push_cib(resources=fixture_resources_bundle_simple())
         )
 
     def test_success(self):
@@ -80,7 +78,7 @@ class MinimalCreate(TestCase):
                     {
                         "option_name": "container type",
                         "option_value": "nonsense",
-                        "allowed_values": ("docker", ),
+                        "allowed_values": {"docker", "podman", "rkt"},
                     },
                     None
                 ),
@@ -91,7 +89,7 @@ class MinimalCreate(TestCase):
         (self.config
             .runner.cib.load(
                 name="load_cib_old_version",
-                filename="cib-empty.xml",
+                filename="cib-empty-2.0.xml",
                 before="runner.cib.load"
             )
             .runner.cib.upgrade(before="runner.cib.load")
@@ -110,64 +108,143 @@ class MinimalCreate(TestCase):
         ])
 
 
-class CreateDocker(TestCase):
+class CreateParametrized(TestCase):
     allowed_options = [
         "image",
         "masters",
         "network",
         "options",
+        "promoted-max",
         "replicas",
         "replicas-per-host",
         "run-command",
     ]
+    container_type = None
 
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
-        self.config.runner.cib.load(resources=fixture_cib_pre)
+        self.config.runner.cib.load(filename="cib-empty-3.2.xml")
 
-    def test_minimal(self):
-        self.config.env.push_cib(resources=fixture_resources_bundle_simple)
-        simple_bundle_create(self.env_assist.get_env(), wait=False)
+    def _test_minimal(self):
+        self.config.env.push_cib(
+            resources=fixture_resources_bundle_simple(self.container_type)
+        )
+        simple_bundle_create(
+            self.env_assist.get_env(),
+            wait=False,
+            container_type=self.container_type,
+        )
 
-    def test_all_options(self):
+    def _test_all_options(self):
         self.config.env.push_cib(
             resources="""
                 <resources>
                     <bundle id="B1">
-                        <docker
+                        <{container_type}
                             image="pcs:test"
-                            masters="0"
                             network="extra network settings"
                             options="extra options"
+                            promoted-max="0"
                             replicas="4"
                             replicas-per-host="2"
                             run-command="/bin/true"
                         />
                     </bundle>
                 </resources>
-            """
+            """.format(container_type=self.container_type)
         )
         resource.bundle_create(
-            self.env_assist.get_env(), "B1", "docker",
+            self.env_assist.get_env(), "B1", self.container_type,
             container_options={
                 "image": "pcs:test",
-                "masters": "0",
                 "network": "extra network settings",
                 "options": "extra options",
+                "promoted-max": "0",
                 "run-command": "/bin/true",
                 "replicas": "4",
                 "replicas-per-host": "2",
             }
         )
 
-    def test_options_errors(self):
+    def _test_cib_upgrade_promoted_max(self):
+        (self.config
+            .runner.cib.load(
+                name="load_cib_old_version",
+                filename="cib-empty-2.8.xml",
+                before="runner.cib.load"
+            )
+            .runner.cib.upgrade(before="runner.cib.load")
+            .env.push_cib(
+                resources="""
+                    <resources>
+                        <bundle id="B1">
+                            <{container_type} image="pcs:test" promoted-max="0" />
+                        </bundle>
+                    </resources>
+                """.format(container_type=self.container_type)
+            )
+        )
+
+        resource.bundle_create(
+            self.env_assist.get_env(), "B1", self.container_type,
+            container_options={
+                "image": "pcs:test",
+                "promoted-max": "0",
+            }
+        )
+
+        self.env_assist.assert_reports([
+            (
+                severities.INFO,
+                report_codes.CIB_UPGRADE_SUCCESSFUL,
+                {
+                },
+                None
+            ),
+        ])
+
+    def _test_deprecated_options(self):
+        # Setting both deprecated options and their new variants is tested in
+        # self.test_options_errors. This shows deprecated options emit warning
+        # even when not forced.
+        self.config.env.push_cib(
+            resources="""
+                <resources>
+                    <bundle id="B1">
+                        <{container_type} image="pcs:test" masters="1" />
+                    </bundle>
+                </resources>
+            """.format(container_type=self.container_type),
+        )
+        resource.bundle_create(
+            self.env_assist.get_env(), "B1", self.container_type,
+            {
+                "image": "pcs:test",
+                "masters": "1",
+            },
+        )
+        self.env_assist.assert_reports([
+            (
+                severities.WARNING,
+                report_codes.DEPRECATED_OPTION,
+                {
+                    "option_name": "masters",
+                    "option_type": "container",
+                    "replaced_by": ["promoted-max"],
+                },
+                None
+            ),
+        ])
+
+    def _test_options_errors(self):
         self.env_assist.assert_raise_library_error(
             lambda: resource.bundle_create(
-                self.env_assist.get_env(), "B1", "docker",
+                self.env_assist.get_env(), "B1", self.container_type,
                 container_options={
                     "replicas-per-host": "0",
                     "replicas": "0",
                     "masters": "-1",
+                    "promoted-max": "-2",
                 },
                 force_options=True
             ),
@@ -191,6 +268,25 @@ class CreateDocker(TestCase):
                     },
                     None
                 ),
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_name": "promoted-max",
+                        "option_value": "-2",
+                        "allowed_values": "a non-negative integer",
+                    },
+                    None
+                ),
+                (
+                    severities.ERROR,
+                    report_codes.MUTUALLY_EXCLUSIVE_OPTIONS,
+                    {
+                        "option_names": ["masters", "promoted-max", ],
+                        "option_type": "container",
+                    },
+                    None
+                ),
                 (
                     severities.ERROR,
                     report_codes.INVALID_OPTION_VALUE,
@@ -213,11 +309,23 @@ class CreateDocker(TestCase):
                 ),
             ]
         )
+        self.env_assist.assert_reports([
+            (
+                severities.WARNING,
+                report_codes.DEPRECATED_OPTION,
+                {
+                    "option_name": "masters",
+                    "option_type": "container",
+                    "replaced_by": ["promoted-max"],
+                },
+                None
+            ),
+        ])
 
-    def test_empty_image(self):
+    def _test_empty_image(self):
         self.env_assist.assert_raise_library_error(
             lambda: resource.bundle_create(
-                self.env_assist.get_env(), "B1", "docker",
+                self.env_assist.get_env(), "B1", self.container_type,
                 container_options={
                     "image": "",
                 },
@@ -237,10 +345,10 @@ class CreateDocker(TestCase):
             ]
         )
 
-    def test_unknow_option(self):
+    def _test_unknow_option(self):
         self.env_assist.assert_raise_library_error(
             lambda: resource.bundle_create(
-                self.env_assist.get_env(), "B1", "docker",
+                self.env_assist.get_env(), "B1", self.container_type,
                 container_options={
                     "image": "pcs:test",
                     "extra": "option",
@@ -261,18 +369,18 @@ class CreateDocker(TestCase):
             ]
         )
 
-    def test_unknow_option_forced(self):
+    def _test_unknow_option_forced(self):
         self.config.env.push_cib(
             resources="""
                 <resources>
                     <bundle id="B1">
-                        <docker image="pcs:test" extra="option" />
+                        <{container_type} image="pcs:test" extra="option" />
                     </bundle>
                 </resources>
-            """
+            """.format(container_type=self.container_type)
         )
         resource.bundle_create(
-            self.env_assist.get_env(), "B1", "docker",
+            self.env_assist.get_env(), "B1", self.container_type,
             container_options={
                 "image": "pcs:test",
                 "extra": "option",
@@ -294,6 +402,68 @@ class CreateDocker(TestCase):
         ])
 
 
+class CreateDocker(CreateParametrized, metaclass=ParametrizedTestMetaClass):
+    container_type = "docker"
+
+
+class CreatePodman(CreateParametrized, metaclass=ParametrizedTestMetaClass):
+    container_type = "podman"
+
+    def test_cib_upgrade(self):
+        (self.config
+            .runner.cib.load(
+                name="load_cib_old_version",
+                filename="cib-empty-3.1.xml",
+                before="runner.cib.load"
+            )
+            .runner.cib.upgrade(before="runner.cib.load")
+            .env.push_cib(
+                resources=fixture_resources_bundle_simple(
+                    container_type=self.container_type
+                )
+            )
+        )
+
+        simple_bundle_create(
+            self.env_assist.get_env(),
+            wait=False,
+            container_type=self.container_type,
+        )
+
+        self.env_assist.assert_reports([
+            fixture.info(report_codes.CIB_UPGRADE_SUCCESSFUL)
+        ])
+
+
+class CreateRkt(CreateParametrized, metaclass=ParametrizedTestMetaClass):
+    container_type = "rkt"
+
+    def test_cib_upgrade(self):
+        (self.config
+            .runner.cib.load(
+                name="load_cib_old_version",
+                filename="cib-empty-2.9.xml",
+                before="runner.cib.load"
+            )
+            .runner.cib.upgrade(before="runner.cib.load")
+            .env.push_cib(
+                resources=fixture_resources_bundle_simple(
+                    container_type=self.container_type
+                )
+            )
+        )
+
+        simple_bundle_create(
+            self.env_assist.get_env(),
+            wait=False,
+            container_type=self.container_type,
+        )
+
+        self.env_assist.assert_reports([
+            fixture.info(report_codes.CIB_UPGRADE_SUCCESSFUL)
+        ])
+
+
 class CreateWithNetwork(TestCase):
     allowed_options = [
         "control-port",
@@ -304,11 +474,11 @@ class CreateWithNetwork(TestCase):
 
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
-        self.config.runner.cib.load(resources=fixture_cib_pre)
+        self.config.runner.cib.load()
 
 
     def test_no_options(self):
-        self.config.env.push_cib(resources=fixture_resources_bundle_simple)
+        self.config.env.push_cib(resources=fixture_resources_bundle_simple())
         resource.bundle_create(
             self.env_assist.get_env(), "B1", "docker",
             {"image": "pcs:test", },
@@ -446,10 +616,10 @@ class CreateWithPortMap(TestCase):
 
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
-        self.config.runner.cib.load(resources=fixture_cib_pre)
+        self.config.runner.cib.load()
 
     def test_no_options(self):
-        self.config.env.push_cib(resources=fixture_resources_bundle_simple)
+        self.config.env.push_cib(resources=fixture_resources_bundle_simple())
         resource.bundle_create(
             self.env_assist.get_env(), "B1", "docker",
             {"image": "pcs:test", },
@@ -714,7 +884,7 @@ class CreateWithStorageMap(TestCase):
 
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
-        self.config.runner.cib.load(resources=fixture_cib_pre)
+        self.config.runner.cib.load()
 
 
     def test_several_mappings_and_handle_their_ids(self):
@@ -923,7 +1093,7 @@ class CreateWithStorageMap(TestCase):
 class CreateWithMeta(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
-        self.config.runner.cib.load(resources=fixture_cib_pre)
+        self.config.runner.cib.load()
 
     def test_success(self):
         self.config.env.push_cib(
@@ -970,10 +1140,11 @@ class CreateWithMeta(TestCase):
             ensure_disabled=True
         )
 
+
 class CreateWithAllOptions(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
-        self.config.runner.cib.load(resources=fixture_cib_pre)
+        self.config.runner.cib.load()
 
     def test_success(self):
         self.config.env.push_cib(
@@ -982,9 +1153,9 @@ class CreateWithAllOptions(TestCase):
                     <bundle id="B1">
                         <docker
                             image="pcs:test"
-                            masters="0"
                             network="extra network settings"
                             options="extra options"
+                            promoted-max="0"
                             replicas="4"
                             replicas-per-host="2"
                             run-command="/bin/true"
@@ -1038,7 +1209,7 @@ class CreateWithAllOptions(TestCase):
             self.env_assist.get_env(), "B1", "docker",
             container_options={
                 "image": "pcs:test",
-                "masters": "0",
+                "promoted-max": "0",
                 "network": "extra network settings",
                 "options": "extra options",
                 "run-command": "/bin/true",
@@ -1139,7 +1310,7 @@ class Wait(TestCase):
         self.env_assist, self.config = get_env_tools(test_case=self)
         (self.config
             .runner.pcmk.can_wait()
-            .runner.cib.load(resources=fixture_cib_pre)
+            .runner.cib.load()
         )
 
     def test_wait_fail(self):
@@ -1151,7 +1322,7 @@ class Wait(TestCase):
             """
         ).strip()
         self.config.env.push_cib(
-            resources=fixture_resources_bundle_simple,
+            resources=fixture_resources_bundle_simple(),
             wait=TIMEOUT,
             exception=LibraryError(
                 reports.wait_for_idle_timed_out(wait_error_message)
@@ -1169,7 +1340,7 @@ class Wait(TestCase):
     def test_wait_ok_run_ok(self):
         (self.config
             .env.push_cib(
-                resources=fixture_resources_bundle_simple,
+                resources=fixture_resources_bundle_simple(),
                 wait=TIMEOUT
             )
             .runner.pcmk.load_state(resources=self.fixture_status_running)
@@ -1185,7 +1356,7 @@ class Wait(TestCase):
     def test_wait_ok_run_fail(self):
         (self.config
             .env.push_cib(
-                resources=fixture_resources_bundle_simple,
+                resources=fixture_resources_bundle_simple(),
                 wait=TIMEOUT
             )
             .runner.pcmk.load_state(resources=self.fixture_status_not_running)
