@@ -1,8 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import TestCase
 
 from pcs.common import report_codes
 from pcs.lib import reports
@@ -14,19 +10,18 @@ from pcs.test.tools.misc import (
     outdent,
     skip_unless_pacemaker_supports_bundle,
 )
-from pcs.test.tools.pcs_unittest import TestCase
 
 
-TIMEOUT=10
+TIMEOUT = 10
 
 def create(
-    env, wait=False, disabled=False, meta_attributes=None, operations=None,
+    env, wait=False, disabled=False, meta_attributes=None, operation_list=None,
     allow_invalid_operation=False
 ):
     return resource.create(
         env,
         "A", "ocf:heartbeat:Dummy",
-        operations=operations if operations else [],
+        operation_list=operation_list if operation_list else [],
         meta_attributes=meta_attributes if meta_attributes else {},
         instance_attributes={},
         wait=wait,
@@ -34,27 +29,11 @@ def create(
         allow_invalid_operation=allow_invalid_operation
     )
 
-def create_master(
-    env, wait=TIMEOUT, disabled=False, meta_attributes=None,
-    master_meta_options=None
-):
-    return resource.create_as_master(
-        env,
-        "A", "ocf:heartbeat:Dummy",
-        operations=[],
-        meta_attributes=meta_attributes if meta_attributes else {},
-        instance_attributes={},
-        clone_meta_options=master_meta_options if master_meta_options
-            else {}
-        ,
-        wait=wait,
-        ensure_disabled=disabled
-    )
 def create_group(env, wait=TIMEOUT, disabled=False, meta_attributes=None):
     return resource.create_in_group(
         env,
         "A", "ocf:heartbeat:Dummy", "G",
-        operations=[],
+        operation_list=[],
         meta_attributes=meta_attributes if meta_attributes else {},
         instance_attributes={},
         wait=wait,
@@ -67,7 +46,7 @@ def create_clone(
     return resource.create_as_clone(
         env,
         "A", "ocf:heartbeat:Dummy",
-        operations=[],
+        operation_list=[],
         meta_attributes=meta_attributes if meta_attributes else {},
         instance_attributes={},
         clone_meta_options=clone_options if clone_options else {},
@@ -75,16 +54,20 @@ def create_clone(
         ensure_disabled=disabled
     )
 
-def create_bundle(env, wait=TIMEOUT, disabled=False, meta_attributes=None):
+def create_bundle(
+    env, wait=TIMEOUT, disabled=False, meta_attributes=None,
+    allow_not_accessible_resource=False,
+):
     return resource.create_into_bundle(
         env,
         "A", "ocf:heartbeat:Dummy",
-        operations=[],
+        operation_list=[],
         meta_attributes=meta_attributes if meta_attributes else {},
         instance_attributes={},
         bundle_id="B",
         wait=wait,
-        ensure_disabled=disabled
+        ensure_disabled=disabled,
+        allow_not_accessible_resource=allow_not_accessible_resource,
     )
 
 wait_error_message = outdent(
@@ -150,98 +133,6 @@ fixture_cib_resources_xml_simplest_disabled = """<resources>
     </primitive>
 </resources>"""
 
-fixture_cib_resources_xml_master_simplest = """<resources>
-    <master id="A-master">
-        <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
-            <operations>
-                <op id="A-migrate_from-interval-0s" interval="0s"
-                    name="migrate_from" timeout="20"
-                />
-                <op id="A-migrate_to-interval-0s" interval="0s"
-                    name="migrate_to" timeout="20"
-                />
-                <op id="A-monitor-interval-10" interval="10" name="monitor"
-                    timeout="20"
-                />
-                <op id="A-reload-interval-0s" interval="0s" name="reload"
-                    timeout="20"
-                />
-                <op id="A-start-interval-0s" interval="0s" name="start"
-                    timeout="20"
-                />
-                <op id="A-stop-interval-0s" interval="0s" name="stop"
-                    timeout="20"
-                />
-            </operations>
-        </primitive>
-    </master>
-</resources>"""
-
-
-fixture_cib_resources_xml_master_simplest_disabled = """<resources>
-    <master id="A-master">
-        <meta_attributes id="A-master-meta_attributes">
-            <nvpair id="A-master-meta_attributes-target-role" name="target-role"
-                value="Stopped"
-            />
-        </meta_attributes>
-        <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
-            <operations>
-                <op id="A-migrate_from-interval-0s" interval="0s"
-                    name="migrate_from" timeout="20"
-                />
-                <op id="A-migrate_to-interval-0s" interval="0s"
-                    name="migrate_to" timeout="20"
-                />
-                <op id="A-monitor-interval-10" interval="10" name="monitor"
-                    timeout="20"
-                />
-                <op id="A-reload-interval-0s" interval="0s" name="reload"
-                    timeout="20"
-                />
-                <op id="A-start-interval-0s" interval="0s" name="start"
-                    timeout="20"
-                />
-                <op id="A-stop-interval-0s" interval="0s" name="stop"
-                    timeout="20"
-                />
-            </operations>
-        </primitive>
-    </master>
-</resources>"""
-
-fixture_cib_resources_xml_master_simplest_disabled_meta_after = """<resources>
-    <master id="A-master">
-        <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
-            <operations>
-                <op id="A-migrate_from-interval-0s" interval="0s"
-                    name="migrate_from" timeout="20"
-                />
-                <op id="A-migrate_to-interval-0s" interval="0s"
-                    name="migrate_to" timeout="20"
-                />
-                <op id="A-monitor-interval-10" interval="10" name="monitor"
-                    timeout="20"
-                />
-                <op id="A-reload-interval-0s" interval="0s" name="reload"
-                    timeout="20"
-                />
-                <op id="A-start-interval-0s" interval="0s" name="start"
-                    timeout="20"
-                />
-                <op id="A-stop-interval-0s" interval="0s" name="stop"
-                    timeout="20"
-                />
-            </operations>
-        </primitive>
-        <meta_attributes id="A-master-meta_attributes">
-            <nvpair id="A-master-meta_attributes-target-role" name="target-role"
-                value="Stopped"
-            />
-        </meta_attributes>
-    </master>
-</resources>"""
-
 fixture_cib_resources_xml_group_simplest = """<resources>
     <group id="G">
         <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
@@ -443,7 +334,7 @@ class Create(TestCase):
 
         create(
             self.env_assist.get_env(),
-            operations=[
+            operation_list=[
                 {"name": "monitor", "timeout": "10s", "interval": "10"}
             ]
         )
@@ -451,7 +342,9 @@ class Create(TestCase):
     def test_sanitize_operation_id_from_agent(self):
         self.config.runner.pcmk.load_agent(
             instead="runner.pcmk.load_agent",
-            agent_filename="resource_agent_ocf_heartbeat_dummy_insane_action.xml"
+            agent_filename=(
+                "resource_agent_ocf_heartbeat_dummy_insane_action.xml"
+            ),
         )
         self.config.env.push_cib(
             resources=self.fixture_sanitized_operation
@@ -464,7 +357,7 @@ class Create(TestCase):
         )
         create(
             self.env_assist.get_env(),
-            operations=[
+            operation_list=[
                 {"name": "moni*tor", "timeout": "20", "interval": "20"}
             ],
             allow_invalid_operation=True
@@ -601,295 +494,6 @@ class CreateWait(TestCase):
             )
         ])
 
-class CreateAsMaster(TestCase):
-    def setUp(self):
-        self.env_assist, self.config = get_env_tools(test_case=self)
-        (self.config
-            .runner.pcmk.load_agent()
-            .runner.pcmk.can_wait()
-            .runner.cib.load()
-        )
-
-    def test_simplest_resource(self):
-        (self.config
-            .remove(name="runner.pcmk.can_wait")
-            .env.push_cib(
-                resources=fixture_cib_resources_xml_master_simplest
-            )
-        )
-        create_master(self.env_assist.get_env(), wait=False)
-
-    def test_fail_wait(self):
-        self.config.env.push_cib(
-            resources=fixture_cib_resources_xml_master_simplest,
-            wait=TIMEOUT,
-            exception=LibraryError(
-                reports.wait_for_idle_timed_out(wait_error_message)
-            )
-        )
-        self.env_assist.assert_raise_library_error(
-            lambda: create_master(self.env_assist.get_env()),
-            [
-                fixture.report_wait_for_idle_timed_out(wait_error_message)
-            ],
-            expected_in_processor=False
-        )
-
-    def test_wait_ok_run_fail(self):
-        (self.config
-            .env.push_cib(
-                resources=fixture_cib_resources_xml_master_simplest,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict(failed="true"))
-        )
-        self.env_assist.assert_raise_library_error(
-            lambda: create_master(self.env_assist.get_env()),
-            [
-                fixture.error(
-                    report_codes.RESOURCE_DOES_NOT_RUN,
-                    resource_id="A"
-                )
-            ]
-        )
-
-    def test_wait_ok_run_ok(self):
-        (self.config
-            .env.push_cib(
-                resources=fixture_cib_resources_xml_master_simplest,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict())
-        )
-        create_master(self.env_assist.get_env())
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_RUNNING_ON_NODES,
-                roles_with_nodes={"Started": ["node1"]},
-                resource_id="A",
-            )
-        ])
-
-    def test_wait_ok_disable_fail(self):
-        (self.config
-            .env.push_cib(
-                resources=fixture_cib_resources_xml_master_simplest_disabled,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict())
-        )
-
-        self.env_assist.assert_raise_library_error(
-            lambda: create_master(self.env_assist.get_env(), disabled=True),
-            [
-                fixture.error(
-                    report_codes.RESOURCE_RUNNING_ON_NODES,
-                    roles_with_nodes={'Started': ['node1']},
-                    resource_id='A'
-                )
-            ],
-        )
-
-    def test_wait_ok_disable_ok(self):
-        (self.config
-            .env.push_cib(
-                resources=fixture_cib_resources_xml_master_simplest_disabled,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict(role="Stopped"))
-        )
-        create_master(self.env_assist.get_env(), disabled=True)
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_DOES_NOT_RUN,
-                resource_id="A",
-            )
-        ])
-
-    def test_wait_ok_disable_ok_by_target_role(self):
-        (self.config
-            .env.push_cib(
-                resources="""
-                    <resources>
-                        <master id="A-master">
-                            <primitive class="ocf" id="A" provider="heartbeat"
-                                type="Dummy"
-                            >
-                                <meta_attributes id="A-meta_attributes">
-                                    <nvpair id="A-meta_attributes-target-role"
-                                        name="target-role" value="Stopped"
-                                    />
-                                </meta_attributes>
-                                <operations>
-                                    <op id="A-migrate_from-interval-0s"
-                                        interval="0s" name="migrate_from"
-                                        timeout="20"
-                                    />
-                                    <op id="A-migrate_to-interval-0s"
-                                        interval="0s" name="migrate_to"
-                                        timeout="20"
-                                    />
-                                    <op id="A-monitor-interval-10" interval="10"
-                                        name="monitor" timeout="20"
-                                    />
-                                    <op id="A-reload-interval-0s" interval="0s"
-                                        name="reload" timeout="20"
-                                    />
-                                    <op id="A-start-interval-0s" interval="0s"
-                                        name="start" timeout="20"
-                                    />
-                                    <op id="A-stop-interval-0s" interval="0s"
-                                        name="stop" timeout="20"
-                                    />
-                                </operations>
-                            </primitive>
-                        </master>
-                    </resources>
-                """,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict(role="Stopped"))
-        )
-        create_master(
-            self.env_assist.get_env(),
-            meta_attributes={"target-role": "Stopped"}
-        )
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_DOES_NOT_RUN,
-                resource_id="A",
-            )
-        ])
-
-    def test_wait_ok_disable_ok_by_target_role_in_master(self):
-        (self.config
-            .env.push_cib(resources
-                =fixture_cib_resources_xml_master_simplest_disabled_meta_after,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict(role="Stopped"))
-        )
-        create_master(
-            self.env_assist.get_env(),
-            master_meta_options={"target-role": "Stopped"}
-        )
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_DOES_NOT_RUN,
-                resource_id="A",
-            )
-        ])
-
-    def test_wait_ok_disable_ok_by_clone_max(self):
-        (self.config
-            .env.push_cib(
-                resources="""
-                    <resources>
-                        <master id="A-master">
-                            <primitive class="ocf" id="A" provider="heartbeat"
-                                type="Dummy"
-                            >
-                                <operations>
-                                    <op id="A-migrate_from-interval-0s"
-                                        interval="0s" name="migrate_from"
-                                        timeout="20"
-                                    />
-                                    <op id="A-migrate_to-interval-0s"
-                                        interval="0s" name="migrate_to"
-                                        timeout="20"
-                                    />
-                                    <op id="A-monitor-interval-10" interval="10"
-                                        name="monitor" timeout="20"
-                                    />
-                                    <op id="A-reload-interval-0s" interval="0s"
-                                        name="reload" timeout="20"
-                                    />
-                                    <op id="A-start-interval-0s" interval="0s"
-                                        name="start" timeout="20"
-                                    />
-                                    <op id="A-stop-interval-0s" interval="0s"
-                                        name="stop" timeout="20"
-                                    />
-                                </operations>
-                            </primitive>
-                            <meta_attributes id="A-master-meta_attributes">
-                                <nvpair id="A-master-meta_attributes-clone-max"
-                                    name="clone-max" value="0"
-                                />
-                            </meta_attributes>
-                        </master>
-                    </resources>
-                """,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict(role="Stopped"))
-        )
-        create_master(
-            self.env_assist.get_env(),
-            master_meta_options={"clone-max": "0"}
-        )
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_DOES_NOT_RUN,
-                resource_id="A",
-            )
-        ])
-
-    def test_wait_ok_disable_ok_by_clone_node_max(self):
-        (self.config
-            .env.push_cib(
-                resources="""
-                    <resources>
-                        <master id="A-master">
-                            <primitive class="ocf" id="A" provider="heartbeat"
-                                type="Dummy"
-                            >
-                                <operations>
-                                    <op id="A-migrate_from-interval-0s"
-                                        interval="0s" name="migrate_from"
-                                        timeout="20"
-                                    />
-                                    <op id="A-migrate_to-interval-0s"
-                                        interval="0s" name="migrate_to"
-                                        timeout="20"
-                                    />
-                                    <op id="A-monitor-interval-10" interval="10"
-                                        name="monitor" timeout="20"
-                                    />
-                                    <op id="A-reload-interval-0s" interval="0s"
-                                        name="reload" timeout="20"
-                                    />
-                                    <op id="A-start-interval-0s" interval="0s"
-                                        name="start" timeout="20"
-                                    />
-                                    <op id="A-stop-interval-0s" interval="0s"
-                                        name="stop" timeout="20"
-                                    />
-                                </operations>
-                            </primitive>
-                            <meta_attributes id="A-master-meta_attributes">
-                                <nvpair
-                                    id="A-master-meta_attributes-clone-node-max"
-                                    name="clone-node-max" value="0"
-                                />
-                            </meta_attributes>
-                        </master>
-                    </resources>
-                """,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(raw_resources=dict(role="Stopped"))
-        )
-        create_master(
-            self.env_assist.get_env(),
-            master_meta_options={"clone-node-max": "0"}
-        )
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_DOES_NOT_RUN,
-                resource_id="A",
-            )
-        ])
 
 class CreateInGroup(TestCase):
     def setUp(self):
@@ -1378,13 +982,16 @@ class CreateInToBundle(TestCase):
 
     fixture_resources_pre = """
         <resources>
-            <bundle id="B"/>
+            <bundle id="B">
+                <network control-port="12345" ip-range-start="192.168.100.200"/>
+            </bundle>
         </resources>
     """
 
-    fixture_resources_post_simple = """
+    fixture_resource_post_simple_without_network = """
         <resources>
             <bundle id="B">
+                {network}
                 <primitive
                     class="ocf" id="A" provider="heartbeat" type="Dummy"
                 >
@@ -1413,9 +1020,17 @@ class CreateInToBundle(TestCase):
         </resources>
     """
 
+    fixture_resources_post_simple = \
+        fixture_resource_post_simple_without_network.format(
+            network="""
+                <network control-port="12345" ip-range-start="192.168.100.200"/>
+            """
+        )
+
     fixture_resources_post_disabled = """
         <resources>
             <bundle id="B">
+                <network control-port="12345" ip-range-start="192.168.100.200"/>
                 <primitive
                     class="ocf" id="A" provider="heartbeat" type="Dummy"
                 >
@@ -1497,7 +1112,7 @@ class CreateInToBundle(TestCase):
         (self.config
             .runner.pcmk.load_agent()
             .runner.cib.load(
-                filename="cib-empty.xml",
+                filename="cib-empty-2.0.xml",
                 name="load_cib_old_version"
             )
             .runner.cib.upgrade()
@@ -1568,6 +1183,7 @@ class CreateInToBundle(TestCase):
                 resources="""
                     <resources>
                         <bundle id="B">
+                            <network control-port="12345"/>
                             <primitive id="P"/>
                         </bundle>
                     </resources>
@@ -1693,3 +1309,87 @@ class CreateInToBundle(TestCase):
                 )
             ]
         )
+
+    @skip_unless_pacemaker_supports_bundle
+    def test_no_port_no_ip(self):
+        resources_fixture = """
+            <resources>
+                <bundle id="B"/>
+            </resources>
+        """
+        (self.config
+            .runner.pcmk.load_agent()
+            .runner.cib.load(resources=resources_fixture)
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: create_bundle(self.env_assist.get_env(), wait=False),
+            [
+                fixture.error(
+                    report_codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE,
+                    bundle_id="B",
+                    inner_resource_id="A",
+                    force_code=
+                        report_codes.FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE
+                )
+            ]
+        )
+
+    @skip_unless_pacemaker_supports_bundle
+    def test_no_port_no_ip_forced(self):
+        resources_fixture = """
+            <resources>
+                <bundle id="B"/>
+            </resources>
+        """
+        (self.config
+            .runner.pcmk.load_agent()
+            .runner.cib.load(resources=resources_fixture)
+            .env.push_cib(
+                resources=
+                    self.fixture_resource_post_simple_without_network.format(
+                        network=""
+                    )
+            )
+        )
+        create_bundle(
+            self.env_assist.get_env(),
+            wait=False,
+            allow_not_accessible_resource=True,
+        )
+        self.env_assist.assert_reports([
+            fixture.warn(
+                report_codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE,
+                bundle_id="B",
+                inner_resource_id="A",
+            )
+        ])
+
+    def _test_with_network_defined(self, network):
+        resources_fixture = """
+            <resources>
+                <bundle id="B">
+                    {network}
+                </bundle>
+            </resources>
+        """.format(network=network)
+        (self.config
+            .runner.pcmk.load_agent()
+            .runner.cib.load(resources=resources_fixture)
+            .env.push_cib(
+                resources=
+                    self.fixture_resource_post_simple_without_network.format(
+                        network=network
+                    )
+            )
+        )
+        create_bundle(self.env_assist.get_env(), wait=False)
+
+    @skip_unless_pacemaker_supports_bundle
+    def test_port_defined(self):
+        self._test_with_network_defined('<network control-port="12345"/>')
+
+    @skip_unless_pacemaker_supports_bundle
+    def test_ip_range_defined(self):
+        self._test_with_network_defined(
+            '<network ip-range-start="192.168.100.200"/>'
+        )
