@@ -1,8 +1,5 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+# pylint: disable=too-many-lines
+from unittest import TestCase
 
 from pcs.common import report_codes
 from pcs.lib import reports
@@ -17,10 +14,9 @@ from pcs.test.tools.misc import (
     outdent,
     skip_unless_pacemaker_supports_bundle,
 )
-from pcs.test.tools.pcs_unittest import TestCase
 
 
-TIMEOUT=10
+TIMEOUT = 10
 
 fixture_primitive_cib_enabled = """
     <resources>
@@ -532,12 +528,12 @@ fixture_bundle_status_unmanaged = """
     </resources>
 """
 
-def fixture_report_unmanaged(resource):
+def fixture_report_unmanaged(resource_id):
     return (
         severities.WARNING,
         report_codes.RESOURCE_IS_UNMANAGED,
         {
-            "resource_id": resource,
+            "resource_id": resource_id,
         },
         None
     )
