@@ -1,15 +1,10 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import TestCase
 
 from pcs.common import report_codes
 from pcs.lib.commands import resource
 from pcs.lib.errors import ReportItemSeverity as severities
 from pcs.test.tools import fixture
 from pcs.test.tools.command_env import get_env_tools
-from pcs.test.tools.pcs_unittest import TestCase
 
 
 fixture_primitive_cib_managed = """
@@ -643,12 +638,12 @@ fixture_bundle_cib_unmanaged_both_op_disabled = """
     </resources>
 """
 
-def fixture_report_no_monitors(resource):
+def fixture_report_no_monitors(resource_id):
     return (
         severities.WARNING,
         report_codes.RESOURCE_MANAGED_NO_MONITOR_ENABLED,
         {
-            "resource_id": resource,
+            "resource_id": resource_id,
         },
         None
     )
