@@ -1,44 +1,16 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+# pylint: disable=too-many-lines
 import json
+from unittest import mock, TestCase
 
 from pcs import settings
 from pcs.common import report_codes
 from pcs.lib.commands.sbd import enable_sbd, ALLOWED_SBD_OPTION_LIST
 from pcs.test.tools import fixture
 from pcs.test.tools.command_env import get_env_tools
-from pcs.test.tools.pcs_unittest import TestCase, mock
 from pcs.test.tools.misc import get_test_resource, outdent
 from pcs.lib.corosync.config_parser import parse_string
 
 
-def _check_sbd_comm_success_fixture(node, watchdog, device_list):
-    return dict(
-        label=node,
-        output=json.dumps({
-            "sbd": {
-                "installed": True,
-            },
-            "watchdog": {
-                "exist": True,
-                "path": watchdog,
-            },
-            "device_list": [
-                dict(path=dev, exist=True, block_device=True)
-                for dev in device_list
-            ],
-        }),
-        param_list=[
-            ("watchdog", watchdog),
-            ("device_list", json.dumps(device_list)),
-        ]
-    )
-
-
 def _get_corosync_conf_text_with_atb(orig_cfg_file):
     corosync_conf = parse_string(open(get_test_resource(orig_cfg_file)).read())
     for quorum in corosync_conf.get_sections(name="quorum"):
@@ -66,7 +38,9 @@ def _sbd_enable_successful_report_list_fixture(
     if atb_set:
         report_list += (
             [
-                fixture.warn(report_codes.SBD_REQUIRES_ATB),
+                fixture.warn(
+                    report_codes.COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD
+                ),
                 fixture.info(report_codes.COROSYNC_NOT_RUNNING_CHECK_STARTED),
             ]
             +
@@ -162,7 +136,7 @@ class OddNumOfNodesSuccess(TestCase):
         self.watchdog_dict = {
             node: "/dev/watchdog-{0}".format(node) for node in self.node_list
         }
-        self.config.runner.corosync.version()
+        self.config.env.set_known_nodes(self.node_list)
         self.config.corosync_conf.load(filename=self.corosync_conf_name)
         self.config.http.host.check_auth(node_labels=self.node_list)
 
@@ -178,7 +152,7 @@ class OddNumOfNodesSuccess(TestCase):
         )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     node, self.watchdog_dict[node], device_dict[node]
                 ) for node in self.node_list
             ]
@@ -210,14 +184,11 @@ class OddNumOfNodesSuccess(TestCase):
         )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     node, self.watchdog_dict[node], []
                 ) for node in self.node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename=self.corosync_conf_name, name="corosync_conf.load2",
-        )
         self.config.http.sbd.set_sbd_config(
             config_generator=config_generator, node_labels=self.node_list,
         )
@@ -251,7 +222,7 @@ class OddNumOfNodesDefaultsSuccess(TestCase):
         SBD_WATCHDOG_TIMEOUT=5
         """)
         self.watchdog = "/dev/watchdog"
-        self.config.runner.corosync.version()
+        self.config.env.set_known_nodes(self.node_list)
         self.config.corosync_conf.load(filename=self.corosync_conf_name)
         self.config.http.host.check_auth(node_labels=self.node_list)
 
@@ -263,7 +234,7 @@ class OddNumOfNodesDefaultsSuccess(TestCase):
         )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     node, self.watchdog, device_list
                 ) for node in self.node_list
             ]
@@ -292,13 +263,10 @@ class OddNumOfNodesDefaultsSuccess(TestCase):
         )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename=self.corosync_conf_name, name="corosync_conf.load2",
-        )
         self.config.http.sbd.set_sbd_config(
             config_generator=config_generator, node_labels=self.node_list,
         )
@@ -317,6 +285,110 @@ class OddNumOfNodesDefaultsSuccess(TestCase):
         )
 
 
+class WatchdogValidations(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(self)
+        self.corosync_conf_name = "corosync-3nodes.conf"
+        self.node_list = ["rh7-1", "rh7-2", "rh7-3"]
+        self.sbd_config_template = outdent("""\
+        # This file has been generated by pcs.
+        SBD_DELAY_START=no
+        SBD_OPTS="-n {node_name}"
+        SBD_PACEMAKER=yes
+        SBD_STARTMODE=always
+        SBD_WATCHDOG_DEV=/dev/watchdog
+        SBD_WATCHDOG_TIMEOUT=5
+        """)
+        self.watchdog = "/dev/watchdog"
+        self.config.env.set_known_nodes(self.node_list)
+        self.config.corosync_conf.load(filename=self.corosync_conf_name)
+        self.config.http.host.check_auth(node_labels=self.node_list)
+
+    def test_watchdog_not_supported(self):
+        self.config.http.sbd.check_sbd(
+            communication_list=[
+                fixture.check_sbd_comm_success_fixture(
+                    node, self.watchdog, []
+                ) for node in self.node_list[:2]
+            ] + [
+                dict(
+                    label=self.node_list[2],
+                    output=json.dumps({
+                        "sbd": {
+                            "installed": True,
+                        },
+                        "watchdog": {
+                            "exist": True,
+                            "path": self.watchdog,
+                            "is_supported": False,
+                        },
+                        "device_list": [],
+                    }),
+                    param_list=[
+                        ("watchdog", self.watchdog),
+                        ("device_list", "[]"),
+                    ]
+                )
+            ]
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: enable_sbd(
+                self.env_assist.get_env(),
+                default_watchdog=self.watchdog,
+                watchdog_dict={},
+                sbd_options={},
+            ),
+            []
+        )
+        self.env_assist.assert_reports(
+            [fixture.info(report_codes.SBD_CHECK_STARTED)]
+            +
+            [
+                fixture.error(
+                    report_codes.SBD_WATCHDOG_NOT_SUPPORTED,
+                    node=self.node_list[2],
+                    watchdog=self.watchdog,
+                )
+            ]
+            +
+            [
+                fixture.info(
+                    report_codes.SBD_CHECK_SUCCESS, node=node
+                ) for node in self.node_list[:2]
+            ]
+        )
+
+    def test_no_watchdog_validation(self):
+        config_generator = lambda node: self.sbd_config_template.format(
+            node_name=node,
+        )
+        self.config.http.sbd.check_sbd(
+            communication_list=[
+                fixture.check_sbd_comm_success_fixture(node, "", [])
+                for node in self.node_list
+            ]
+        )
+        self.config.http.sbd.set_sbd_config(
+            config_generator=config_generator, node_labels=self.node_list,
+        )
+        self.config.http.pcmk.remove_stonith_watchdog_timeout(
+            node_labels=[self.node_list[0]]
+        )
+        self.config.http.sbd.enable_sbd(node_labels=self.node_list)
+        enable_sbd(
+            self.env_assist.get_env(),
+            default_watchdog=self.watchdog,
+            watchdog_dict={},
+            sbd_options={},
+            no_watchdog_validation=True,
+        )
+        self.env_assist.assert_reports(
+            _sbd_enable_successful_report_list_fixture(self.node_list) + [
+                fixture.warn(report_codes.SBD_WATCHDOG_VALIDATION_INACTIVE)
+            ]
+        )
+
+
 class EvenNumOfNodes(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
@@ -332,7 +404,7 @@ class EvenNumOfNodes(TestCase):
         SBD_WATCHDOG_TIMEOUT=5
         """)
         self.watchdog = "/dev/watchdog"
-        self.config.runner.corosync.version()
+        self.config.env.set_known_nodes(self.node_list)
         self.config.corosync_conf.load(filename=self.corosync_conf_name)
         self.config.http.host.check_auth(node_labels=self.node_list)
 
@@ -344,7 +416,7 @@ class EvenNumOfNodes(TestCase):
         )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     node, self.watchdog, device_list
                 ) for node in self.node_list
             ]
@@ -374,13 +446,10 @@ class EvenNumOfNodes(TestCase):
         )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename=self.corosync_conf_name, name="corosync_conf.load2",
-        )
         self.config.http.corosync.check_corosync_offline(
             node_labels=self.node_list
         )
@@ -412,16 +481,17 @@ class EvenNumOfNodes(TestCase):
         config_generator = lambda node: self.sbd_config_template.format(
             node_name=node, devices="",
         )
+        self.config.corosync_conf.load(
+            filename=self.corosync_conf_name,
+            auto_tie_breaker=True,
+            instead="corosync_conf.load",
+        )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename=self.corosync_conf_name, name="corosync_conf.load2",
-            auto_tie_breaker=True,
-        )
         self.config.http.sbd.set_sbd_config(
             config_generator=config_generator, node_labels=self.node_list,
         )
@@ -443,15 +513,16 @@ class EvenNumOfNodes(TestCase):
         config_generator = lambda node: self.sbd_config_template.format(
             node_name=node, devices="",
         )
+        self.config.corosync_conf.load(
+            filename="corosync-qdevice.conf",
+            instead="corosync_conf.load",
+        )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename="corosync-qdevice.conf", name="corosync_conf.load2",
-        )
         self.config.http.sbd.set_sbd_config(
             config_generator=config_generator, node_labels=self.node_list,
         )
@@ -500,7 +571,7 @@ class OfflineNodes(TestCase):
                 ) for node in self.offline_node_list
             ]
         )
-        self.config.runner.corosync.version()
+        self.config.env.set_known_nodes(node_list)
         self.config.corosync_conf.load(filename=self.corosync_conf_name)
         self.config.http.host.check_auth(
             communication_list=self.offline_communication_list
@@ -529,15 +600,16 @@ class OfflineNodes(TestCase):
         )
 
     def test_ignore_offline_nodes(self):
+        self.config.corosync_conf.load(
+            filename="corosync-qdevice.conf",
+            instead="corosync_conf.load",
+        )
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.online_node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename="corosync-qdevice.conf", name="corosync_conf.load2",
-        )
         self.config.http.sbd.set_sbd_config(
             config_generator=self.sbd_config_generator,
             node_labels=self.online_node_list,
@@ -568,13 +640,10 @@ class OfflineNodes(TestCase):
     def test_ignore_offline_nodes_atb_needed(self):
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.online_node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename=self.corosync_conf_name, name="corosync_conf.load2",
-        )
         self.config.http.corosync.check_corosync_offline(
             communication_list=self.offline_communication_list
         )
@@ -607,13 +676,13 @@ class OfflineNodes(TestCase):
             )
         )
 
-
+# watchdog validations are in WatchdogValidations
 class Validations(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.corosync_conf_name = "corosync.conf"
         self.node_list = ["rh7-1", "rh7-2"]
-        self.config.runner.corosync.version()
+        self.config.env.set_known_nodes(self.node_list)
         self.config.corosync_conf.load(filename=self.corosync_conf_name)
 
     def test_non_existing_node_in_watchdogs(self):
@@ -821,7 +890,7 @@ class Validations(TestCase):
         self.config.http.host.check_auth(node_labels=self.node_list)
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     self.node_list[0], watchdog, []
                 ),
                 dict(
@@ -873,7 +942,7 @@ class Validations(TestCase):
         self.config.http.host.check_auth(node_labels=self.node_list)
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     self.node_list[0], watchdog, []
                 ),
                 dict(
@@ -928,7 +997,7 @@ class Validations(TestCase):
         self.config.http.host.check_auth(node_labels=self.node_list)
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     self.node_list[0], watchdog, device_list
                 ),
                 dict(
@@ -1041,6 +1110,11 @@ class Validations(TestCase):
                     device_list=["dev", "/dev0", "/dev1", "/dev2"],
                     max_devices=max_dev_num,
                 ),
+                fixture.error(
+                    report_codes.SBD_DEVICE_PATH_NOT_ABSOLUTE,
+                    device="dev",
+                    node="rh7-1",
+                ),
                 fixture.error(
                     report_codes.INVALID_OPTIONS,
                     option_names=["SBD_WATCHDOG_DEV"],
@@ -1102,18 +1176,15 @@ class FailureHandling(TestCase):
                 label=self.node_list[1],
             )
         ]
-        self.config.runner.corosync.version()
+        self.config.env.set_known_nodes(self.node_list)
         self.config.corosync_conf.load(filename=self.corosync_conf_name)
         self.config.http.host.check_auth(node_labels=self.node_list)
         self.config.http.sbd.check_sbd(
             communication_list=[
-                _check_sbd_comm_success_fixture(node, self.watchdog, [])
+                fixture.check_sbd_comm_success_fixture(node, self.watchdog, [])
                 for node in self.node_list
             ]
         )
-        self.config.corosync_conf.load(
-            filename=self.corosync_conf_name, name="corosync_conf.load2",
-        )
         self.config.http.corosync.check_corosync_offline(
             node_labels=self.node_list
         )
@@ -1130,8 +1201,8 @@ class FailureHandling(TestCase):
             node_labels=[self.node_list[0]]
         )
 
-    def _remove_calls(self, n):
-        for name in self.config.calls.names[-n:]:
+    def _remove_calls(self, count):
+        for name in self.config.calls.names[-count:]:
             self.config.calls.remove(name)
 
     @mock.patch("pcs.lib.external.is_systemctl", lambda: True)
@@ -1520,7 +1591,7 @@ class FailureHandling(TestCase):
         )
 
     def test_check_sbd_invalid_data_format(self):
-        self._remove_calls(12)
+        self._remove_calls(11)
         self.config.http.sbd.check_sbd(
             communication_list=[
                 dict(
@@ -1560,7 +1631,7 @@ class FailureHandling(TestCase):
         )
 
     def test_check_sbd_failure(self):
-        self._remove_calls(12)
+        self._remove_calls(11)
         self.config.http.sbd.check_sbd(
             communication_list=[
                 dict(
@@ -1572,7 +1643,7 @@ class FailureHandling(TestCase):
                     response_code=400,
                     output=self.reason,
                 ),
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     self.node_list[1], self.watchdog, []
                 )
             ]
@@ -1603,7 +1674,7 @@ class FailureHandling(TestCase):
         )
 
     def test_check_sbd_not_connected(self):
-        self._remove_calls(12)
+        self._remove_calls(11)
         self.config.http.sbd.check_sbd(
             communication_list=[
                 dict(
@@ -1616,7 +1687,7 @@ class FailureHandling(TestCase):
                     error_msg=self.reason,
                     was_connected=False,
                 ),
-                _check_sbd_comm_success_fixture(
+                fixture.check_sbd_comm_success_fixture(
                     self.node_list[1], self.watchdog, []
                 )
             ]
@@ -1647,7 +1718,7 @@ class FailureHandling(TestCase):
         )
 
     def test_get_online_targets_failed(self):
-        self._remove_calls(14)
+        self._remove_calls(13)
         self.config.http.host.check_auth(
             communication_list=self.communication_list_failure
         )
@@ -1672,7 +1743,7 @@ class FailureHandling(TestCase):
         )
 
     def test_get_online_targets_not_connected(self):
-        self._remove_calls(14)
+        self._remove_calls(13)
         self.config.http.host.check_auth(
             communication_list=self.communication_list_not_connected
         )
@@ -1696,3 +1767,129 @@ class FailureHandling(TestCase):
                 )
             ]
         )
+
+
+class UnknownHosts(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(self)
+        self.node_list = ["rh7-1", "rh7-2"]
+        self.known_hosts = self.node_list[:-1]
+        self.unknown_hosts = self.node_list[-1:]
+        self.config.corosync_conf.load()
+
+    def test_one_node_not_auth(self):
+        self.config.env.set_known_nodes(self.known_hosts)
+        report_list = [
+            fixture.error(
+                report_codes.HOST_NOT_FOUND,
+                force_code=report_codes.SKIP_OFFLINE_NODES,
+                host_list=self.unknown_hosts
+            )
+        ]
+        self.env_assist.assert_raise_library_error(
+            lambda: enable_sbd(
+                self.env_assist.get_env(),
+                default_watchdog=None,
+                watchdog_dict={},
+                sbd_options={},
+            ),
+            report_list,
+            expected_in_processor=False
+        )
+        self.env_assist.assert_reports(report_list)
+
+    def test_one_node_not_auth_skip_offline(self):
+        sbd_config_generator = outdent("""\
+        # This file has been generated by pcs.
+        SBD_DELAY_START=no
+        SBD_OPTS="-n {0}"
+        SBD_PACEMAKER=yes
+        SBD_STARTMODE=always
+        SBD_WATCHDOG_DEV=/dev/watchdog
+        SBD_WATCHDOG_TIMEOUT=5
+        """).format
+        (self.config
+            .corosync_conf.load(
+                filename="corosync-qdevice.conf",
+                instead="corosync_conf.load"
+            )
+            .env.set_known_nodes(self.known_hosts)
+            .http.host.check_auth(self.known_hosts)
+            .http.sbd.check_sbd(
+                communication_list=[
+                    fixture.check_sbd_comm_success_fixture(
+                        node, "/dev/watchdog", []
+                    ) for node in self.known_hosts
+                ]
+            )
+            .http.sbd.set_sbd_config(
+                config_generator=sbd_config_generator,
+                node_labels=self.known_hosts,
+            )
+            .http.pcmk.remove_stonith_watchdog_timeout(
+                node_labels=[self.known_hosts[0]]
+            )
+            .http.sbd.enable_sbd(node_labels=self.known_hosts)
+        )
+
+        enable_sbd(
+            self.env_assist.get_env(),
+            default_watchdog=None,
+            watchdog_dict={},
+            sbd_options={},
+            ignore_offline_nodes=True,
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    report_codes.HOST_NOT_FOUND, host_list=self.unknown_hosts,
+                )
+            ]
+            +
+            _sbd_enable_successful_report_list_fixture(self.known_hosts)
+        )
+
+    def test_all_nodes_not_auth(self):
+        report_list = [
+            fixture.error(
+                report_codes.HOST_NOT_FOUND,
+                force_code=report_codes.SKIP_OFFLINE_NODES,
+                host_list=self.node_list
+            ),
+            fixture.error(report_codes.NONE_HOST_FOUND)
+        ]
+        self.env_assist.assert_raise_library_error(
+            lambda: enable_sbd(
+                self.env_assist.get_env(),
+                default_watchdog=None,
+                watchdog_dict={},
+                sbd_options={},
+            ),
+            report_list,
+            expected_in_processor=False
+        )
+        self.env_assist.assert_reports(report_list)
+
+    def test_all_node_not_auth_skip_offline(self):
+        report_list = [fixture.error(report_codes.NONE_HOST_FOUND)]
+        self.env_assist.assert_raise_library_error(
+            lambda: enable_sbd(
+                self.env_assist.get_env(),
+                default_watchdog=None,
+                watchdog_dict={},
+                sbd_options={},
+                ignore_offline_nodes=True,
+            ),
+            report_list,
+            expected_in_processor=False
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    report_codes.HOST_NOT_FOUND, host_list=self.node_list
+                ),
+            ]
+            +
+            report_list
+        )
