@@ -1,11 +1,6 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from functools import partial
 import logging
+from unittest import mock, TestCase
 
 from pcs.common import report_codes
 from pcs.lib.errors import ReportItemSeverity as Severities
@@ -13,7 +8,6 @@ from pcs.lib.env import LibraryEnvironment
 from pcs.lib.external import CommandRunner
 from pcs.test.tools.command_env import get_env_tools
 from pcs.test.tools.custom_mock import MockLibraryReportProcessor
-from pcs.test.tools.pcs_unittest import mock, TestCase
 
 import pcs.lib.commands.alert as cmd_alert
 
@@ -89,7 +83,7 @@ class CreateAlertTest(TestCase):
     def test_create_upgrade(self):
         (self.config
             .runner.cib.load(
-                filename="cib-empty.xml",
+                filename="cib-empty-2.0.xml",
                 name="load_cib_old_version"
             )
             .runner.cib.upgrade()
