@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import json
 
 from pcs.common.node_communicator import RequestData
@@ -11,17 +5,24 @@ from pcs.lib import reports
 from pcs.lib.communication.tools import (
     AllAtOnceStrategyMixin,
     AllSameDataMixin,
+    OneByOneStrategyMixin,
     RunRemotelyBase,
     SkipOfflineMixin,
 )
+from pcs.lib.errors import ReportItemSeverity
+from pcs.lib.node_communication import response_to_report_item
 
 
 class CheckCorosyncOffline(
     SkipOfflineMixin, AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase
 ):
-    def __init__(self, report_processor, skip_offline_targets=False):
+    def __init__(
+        self, report_processor,
+        skip_offline_targets=False, allow_skip_offline=True,
+    ):
         super(CheckCorosyncOffline, self).__init__(report_processor)
-        self._set_skip_offline(skip_offline_targets)
+        if allow_skip_offline:
+            self._set_skip_offline(skip_offline_targets)
 
     def _get_request_data(self):
         return RequestData("remote/status")
@@ -45,7 +46,7 @@ class CheckCorosyncOffline(
                 report = reports.corosync_not_running_on_node_ok(node_label)
             else:
                 report = reports.corosync_running_on_node_fail(node_label)
-        except (ValueError, LookupError):
+        except (KeyError, json.JSONDecodeError):
             report = reports.corosync_not_running_check_node_error(
                 node_label, self._failure_severity, self._failure_forceable
             )
@@ -59,11 +60,13 @@ class DistributeCorosyncConf(
     SkipOfflineMixin, AllSameDataMixin, AllAtOnceStrategyMixin, RunRemotelyBase
 ):
     def __init__(
-        self, report_processor, config_text, skip_offline_targets=False
+        self, report_processor, config_text, skip_offline_targets=False,
+        allow_skip_offline=True,
     ):
         super(DistributeCorosyncConf, self).__init__(report_processor)
         self._config_text = config_text
-        self._set_skip_offline(skip_offline_targets)
+        if allow_skip_offline:
+            self._set_skip_offline(skip_offline_targets)
 
     def _get_request_data(self):
         return RequestData(
@@ -87,3 +90,50 @@ class DistributeCorosyncConf(
 
     def before(self):
         self._report(reports.corosync_config_distribution_started())
+
+
+class ReloadCorosyncConf(
+    AllSameDataMixin, OneByOneStrategyMixin, RunRemotelyBase
+):
+    __was_successful = False
+    __has_failures = False
+
+    def _get_request_data(self):
+        return RequestData("remote/reload_corosync_conf")
+
+    def _process_response(self, response):
+        report = response_to_report_item(
+            response, severity=ReportItemSeverity.WARNING
+        )
+        node = response.request.target.label
+        if report is not None:
+            self.__has_failures = True
+            self._report(report)
+            return self._get_next_list()
+        try:
+            output = json.loads(response.data)
+            if output["code"] == "reloaded":
+                self.__was_successful = True
+                self._report(reports.corosync_config_reloaded(node))
+                return []
+
+            if output["code"] == "not_running":
+                self._report(reports.corosync_config_reload_not_possible(node))
+            else:
+                self.__has_failures = True
+                self._report(reports.corosync_config_reload_error(
+                    output["message"],
+                    node=node,
+                    severity=ReportItemSeverity.WARNING,
+                ))
+        except (ValueError, LookupError):
+            self._report(reports.invalid_response_format(
+                node,
+                severity=ReportItemSeverity.WARNING,
+            ))
+
+        return self._get_next_list()
+
+    def on_complete(self):
+        if not self.__was_successful and self.__has_failures:
+            self._report(reports.unable_to_perform_operation_on_any_node())
