@@ -1,10 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from pcs.test.tools.pcs_unittest import TestCase
+from unittest import TestCase
 
 class CheckCorosyncOffline(TestCase):
     """
@@ -19,3 +13,12 @@ class DistributeCorosyncConf(TestCase):
         pcs.lib.test.test_env.PushCorosyncConfLiveNoQdeviceTest
         pcs.lib.commands.test.sbd.test_enable_sbd
     """
+
+class ReloadCorosyncConf(TestCase):
+    """
+    tested in:
+        pcs.lib.commands.test.cluster.test_add_nodes.AddNodesSuccessMinimal
+        pcs.lib.commands.test.cluster.test_add_nodes.AddNodeFull
+        pcs.lib.commands.test.cluster.test_add_nodes.FailureReloadCorosyncConf
+        pcs.lib.commands.test.cluster.test_remove_nodes.FailureCorosyncReload
+    """
