@@ -1,11 +1,4 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from pcs.lib.communication import qdevice_net
-from pcs.test.tools.pcs_unittest import TestCase
+from unittest import TestCase
 
 class GetCaCert(TestCase):
     """
