@@ -1,22 +1,9 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-import os.path
-
-from pcs import settings
-from pcs.common.node_communicator import (
-    NodeCommunicatorFactory,
-    NodeTargetFactory
-)
+from pcs.common.node_communicator import NodeCommunicatorFactory
 from pcs.common.tools import Version
 from pcs.lib import reports
 from pcs.lib.booth.env import BoothEnv
 from pcs.lib.cib.tools import get_cib_crm_feature_set
 from pcs.lib.pacemaker.env import PacemakerEnv
-from pcs.lib.cluster_conf_facade import ClusterConfFacade
 from pcs.lib.communication import qdevice
 from pcs.lib.communication.corosync import (
     CheckCorosyncOffline,
@@ -28,19 +15,18 @@ from pcs.lib.communication.tools import (
 )
 from pcs.lib.corosync.config_facade import ConfigFacade as CorosyncConfigFacade
 from pcs.lib.corosync.live import (
-    exists_local_corosync_conf,
     get_local_corosync_conf,
-    get_local_cluster_conf,
     reload_config as reload_corosync_config,
 )
 from pcs.lib.external import (
-    is_cman_cluster,
     is_service_running,
     CommandRunner,
-    NodeCommunicator,
 )
 from pcs.lib.errors import LibraryError
-from pcs.lib.node_communication import LibCommunicatorLogger
+from pcs.lib.node_communication import (
+    LibCommunicatorLogger,
+    NodeTargetLibFactory,
+)
 from pcs.lib.pacemaker.live import (
     diff_cibs_xml,
     ensure_cib_version,
@@ -57,8 +43,10 @@ from pcs.lib.pacemaker.values import get_valid_timeout_seconds
 from pcs.lib.tools import write_tmpfile
 from pcs.lib.xml_tools import etree_to_str
 
-class LibraryEnvironment(object):
-    # pylint: disable=too-many-instance-attributes
+MIN_FEATURE_SET_VERSION_FOR_DIFF = Version(3, 0, 9)
+
+class LibraryEnvironment:
+    # pylint: disable=too-many-instance-attributes, too-many-public-methods
 
     def __init__(
         self,
@@ -69,31 +57,28 @@ class LibraryEnvironment(object):
         cib_data=None,
         corosync_conf_data=None,
         booth=None,
-        pacemaker=None,
-        token_file_data_getter=None,
-        cluster_conf_data=None,
+        known_hosts_getter=None,
         request_timeout=None,
     ):
+        # pylint: disable=too-many-arguments
         self._logger = logger
         self._report_processor = report_processor
         self._user_login = user_login
         self._user_groups = [] if user_groups is None else user_groups
         self._cib_data = cib_data
         self._corosync_conf_data = corosync_conf_data
-        self._cluster_conf_data = cluster_conf_data
         self._booth = (
             BoothEnv(report_processor, booth) if booth is not None else None
         )
         #pacemaker is currently not mocked and it provides only an access to
         #the authkey
-        self._pacemaker =  PacemakerEnv()
+        self._pacemaker = PacemakerEnv()
         self._request_timeout = request_timeout
-        self._is_cman_cluster = None
         # TODO tokens probably should not be inserted from outside, but we're
         # postponing dealing with them, because it's not that easy to move
         # related code currently - it's in pcsd
-        self._token_file_data_getter = token_file_data_getter
-        self._token_file = None
+        self._known_hosts_getter = known_hosts_getter
+        self._known_hosts = None
         self._cib_upgrade_reported = False
         self._cib_data_tmp_file = None
         self.__loaded_cib_diff_source = None
@@ -124,12 +109,6 @@ class LibraryEnvironment(object):
     def user_groups(self):
         return self._user_groups
 
-    @property
-    def is_cman_cluster(self):
-        if self._is_cman_cluster is None:
-            self._is_cman_cluster = is_cman_cluster(self.cmd_runner())
-        return self._is_cman_cluster
-
     def get_cib(self, minimal_version=None):
         if self.__loaded_cib_diff_source is not None:
             raise AssertionError("CIB has already been loaded")
@@ -211,10 +190,14 @@ class LibraryEnvironment(object):
         # only check the version if a CIB has been loaded, otherwise the push
         # fails anyway. By my testing it seems that only the source CIB's
         # version matters.
-        if self.__loaded_cib_diff_source_feature_set < Version(3, 0, 9):
+        if(
+            self.__loaded_cib_diff_source_feature_set
+            <
+            MIN_FEATURE_SET_VERSION_FOR_DIFF
+        ):
             self.report_processor.process(
                 reports.cib_push_forced_full_due_to_crm_feature_set(
-                    Version(3, 0, 9),
+                    MIN_FEATURE_SET_VERSION_FOR_DIFF,
                     self.__loaded_cib_diff_source_feature_set
                 )
             )
@@ -290,7 +273,8 @@ class LibraryEnvironment(object):
         if self.is_corosync_conf_live:
             self._push_corosync_conf_live(
                 self.get_node_target_factory().get_target_list(
-                    corosync_conf_facade.get_nodes()
+                    corosync_conf_facade.get_nodes_names(),
+                    skip_non_existing=skip_offline_nodes,
                 ),
                 corosync_conf_data,
                 corosync_conf_facade.need_stopped_cluster,
@@ -335,39 +319,6 @@ class LibraryEnvironment(object):
             if report_list:
                 raise LibraryError()
 
-    def get_cluster_conf_data(self):
-        if self.is_cluster_conf_live:
-            return get_local_cluster_conf()
-        return self._cluster_conf_data
-
-
-    def get_cluster_conf(self):
-        return ClusterConfFacade.from_string(self.get_cluster_conf_data())
-
-
-    @property
-    def is_cluster_conf_live(self):
-        return self._cluster_conf_data is None
-
-
-    def is_node_in_cluster(self):
-        if self.is_cman_cluster:
-            #TODO --cluster_conf is not propagated here. So no live check not
-            #needed here. But this should not be permanently
-            return os.path.exists(settings.corosync_conf_file)
-
-        if not self.is_corosync_conf_live:
-            raise AssertionError(
-                "Cannot check if node is in cluster with mocked corosync_conf."
-            )
-        return exists_local_corosync_conf()
-
-    def command_expect_live_corosync_env(self):
-        if not self.is_corosync_conf_live:
-            raise LibraryError(
-                reports.live_environment_required(["COROSYNC_CONF"])
-            )
-
     @property
     def is_corosync_conf_live(self):
         return self._corosync_conf_data is None
@@ -405,34 +356,31 @@ class LibraryEnvironment(object):
     def communicator_factory(self):
         return self._communicator_factory
 
-    def get_node_communicator(self):
-        return self.communicator_factory.get_communicator()
-
-    def get_node_target_factory(self):
-        token_file = self.__get_token_file()
-        return NodeTargetFactory(token_file["tokens"], token_file["ports"])
-
-    # deprecated, use communicator_factory or get_node_communicator()
-    def node_communicator(self):
-        return NodeCommunicator(
-            self.logger,
-            self.report_processor,
-            self.__get_auth_tokens(),
-            self.user_login,
-            self.user_groups,
-            self._request_timeout
+    def get_node_communicator(self, request_timeout=None):
+        return self.communicator_factory.get_communicator(
+            request_timeout=request_timeout
         )
 
-    def __get_token_file(self):
-        if self._token_file is None:
-            if self._token_file_data_getter:
-                self._token_file = self._token_file_data_getter()
+    def get_node_target_factory(self):
+        return NodeTargetLibFactory(
+            self.__get_known_hosts(), self.report_processor
+        )
+
+    def get_known_hosts(self, host_name_list):
+        known_hosts = self.__get_known_hosts()
+        return [
+            known_hosts[host_name]
+            for host_name in host_name_list
+            if host_name in known_hosts
+        ]
+
+    def __get_known_hosts(self):
+        if self._known_hosts is None:
+            if self._known_hosts_getter:
+                self._known_hosts = self._known_hosts_getter()
             else:
-                self._token_file = {
-                    "tokens": {},
-                    "ports": {},
-                }
-        return self._token_file
+                self._known_hosts = {}
+        return self._known_hosts
 
     @property
     def booth(self):
