@@ -1,10 +1,5 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import mock, TestCase
 
-from pcs.test.tools.pcs_unittest import TestCase, mock
 from lxml import etree
 
 from pcs.test.tools.assertions import (
@@ -23,6 +18,8 @@ from pcs.lib.pacemaker.state import (
 from pcs.common import report_codes
 from pcs.lib.errors import ReportItemSeverity as severities
 
+# pylint: disable=no-self-use, protected-access
+
 class AttrsTest(TestCase):
     def test_get_declared_attr(self):
         attrs = _Attrs('test', {'node-name': 'node1'}, {'name': 'node-name'})
@@ -211,6 +208,7 @@ class GetPrimitiveRolesWithNodes(TestCase):
 
 
 class GetPrimitivesForStateCheck(TestCase):
+    # pylint: disable=too-many-public-methods
     status_xml = etree.fromstring("""
         <resources>
             <resource id="R01" failed="false" />
