@@ -1,11 +1,7 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from lxml import etree
+# pylint: disable=too-many-lines
 from functools import partial
+from unittest import mock, TestCase
+from lxml import etree
 
 from pcs.test.tools.assertions import (
     ExtendedAssertionsMixin,
@@ -14,8 +10,8 @@ from pcs.test.tools.assertions import (
     assert_xml_equal,
     start_tag_error_text,
 )
+from pcs.test.tools import fixture
 from pcs.test.tools.misc import create_patcher
-from pcs.test.tools.pcs_unittest import TestCase, mock
 from pcs.test.tools.xml import XmlManipulation
 
 from pcs.common import report_codes
@@ -23,6 +19,8 @@ from pcs.lib import resource_agent as lib_ra
 from pcs.lib.errors import ReportItemSeverity as severity, LibraryError
 from pcs.lib.external import CommandRunner
 
+# pylint: disable=protected-access
+
 patch_agent = create_patcher("pcs.lib.resource_agent")
 patch_agent_object = partial(mock.patch.object, lib_ra.Agent)
 
@@ -789,6 +787,7 @@ class AgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 }
@@ -823,6 +822,7 @@ class AgentMetadataGetParametersTest(TestCase):
                     "default": "default_value",
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
@@ -835,18 +835,22 @@ class AgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 }
             ]
         )
 
-    def test_remove_obsoletes_keep_deprecated(self, mock_metadata):
+    def test_obsoletes_deprecated(self, mock_metadata):
         xml = """
             <resource-agent>
                 <parameters>
-                    <parameter name="obsoletes" obsoletes="deprecated"/>
                     <parameter name="deprecated" deprecated="1"/>
+                    <parameter name="obsoleted" deprecated="1"/>
+                    <parameter name="obsoleting1" obsoletes="obsoleted"/>
+                    <parameter name="obsoleting2" obsoletes="obsoleted"/>
+                    <parameter name="double-obsoleting" obsoletes="obsoleting2"/>
                 </parameters>
             </resource-agent>
         """
@@ -863,9 +867,62 @@ class AgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": True,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
+                {
+                    "name": "obsoleted",
+                    "longdesc": "",
+                    "shortdesc": "",
+                    "type": "string",
+                    "required": False,
+                    "default": None,
+                    "advanced": False,
+                    "deprecated": True,
+                    "deprecated_by": ["obsoleting1", "obsoleting2"],
+                    "obsoletes": None,
+                    "pcs_deprecated_warning": "",
+                },
+                {
+                    "name": "obsoleting1",
+                    "longdesc": "",
+                    "shortdesc": "",
+                    "type": "string",
+                    "required": False,
+                    "default": None,
+                    "advanced": False,
+                    "deprecated": False,
+                    "deprecated_by": [],
+                    "obsoletes": "obsoleted",
+                    "pcs_deprecated_warning": "",
+                },
+                {
+                    "name": "obsoleting2",
+                    "longdesc": "",
+                    "shortdesc": "",
+                    "type": "string",
+                    "required": False,
+                    "default": None,
+                    "advanced": False,
+                    "deprecated": False,
+                    "deprecated_by": ["double-obsoleting"],
+                    "obsoletes": "obsoleted",
+                    "pcs_deprecated_warning": "",
+                },
+                {
+                    "name": "double-obsoleting",
+                    "longdesc": "",
+                    "shortdesc": "",
+                    "type": "string",
+                    "required": False,
+                    "default": None,
+                    "advanced": False,
+                    "deprecated": False,
+                    "deprecated_by": [],
+                    "obsoletes": "obsoleting2",
+                    "pcs_deprecated_warning": "",
+                },
             ]
         )
 
@@ -958,6 +1015,7 @@ class AgentMetadataGetActionsTest(TestCase):
         )
 
     def test_transfor_depth_to_OCF_CHECK_LEVEL(self, mock_metadata):
+        # pylint: disable=invalid-name
         xml = """
             <resource-agent>
                 <actions>
@@ -1136,6 +1194,7 @@ class AgentMetadataGetInfoTest(TestCase):
                         "default": "default_value",
                         "advanced": False,
                         "deprecated": False,
+                        "deprecated_by": [],
                         "obsoletes": None,
                         "pcs_deprecated_warning": "",
                     },
@@ -1148,6 +1207,7 @@ class AgentMetadataGetInfoTest(TestCase):
                         "default": None,
                         "advanced": False,
                         "deprecated": False,
+                        "deprecated_by": [],
                         "obsoletes": None,
                         "pcs_deprecated_warning": "",
                     }
@@ -1164,315 +1224,441 @@ class AgentMetadataGetInfoTest(TestCase):
         )
 
 
-@patch_agent_object("_get_metadata")
-class AgentMetadataValidateParametersValuesTest(TestCase):
+xml_for_validate_test = etree.XML("""
+    <resource-agent>
+        <parameters>
+            <parameter name="opt1_new" required="0"
+                obsoletes="opt1_old"
+            />
+            <parameter name="opt1_old" required="0"
+                deprecated="1"
+            />
+            <parameter name="opt2_new" required="0"
+                obsoletes="opt2_old"
+            />
+            <parameter name="opt2_old" required="0"
+                deprecated="1"
+            />
+            <parameter name="req1_new" required="1"
+                obsoletes="req1_old"
+            />
+            <parameter name="req1_old" required="1"
+                deprecated="1"
+            />
+            <parameter name="req2_new" required="1"
+                obsoletes="req2_old"
+            />
+            <parameter name="req2_old" required="1"
+                deprecated="1"
+            />
+        </parameters>
+    </resource-agent>
+""")
+@patch_agent_object("_get_metadata", lambda self: xml_for_validate_test)
+class AgentMetadataValidateParamsCreate(TestCase):
     def setUp(self):
         self.agent = lib_ra.Agent(
             mock.MagicMock(spec_set=CommandRunner)
         )
-        self.metadata = etree.XML("""
-            <resource-agent>
-                <parameters>
-                    <parameter name="test_param" required="0">
-                        <longdesc>Long description</longdesc>
-                        <shortdesc>short description</shortdesc>
-                        <content type="string" default="default_value" />
-                    </parameter>
-                    <parameter name="required_param" required="1">
-                        <content type="boolean" />
-                    </parameter>
-                    <parameter name="another_required_param" required="1">
-                        <content type="string" />
-                    </parameter>
-                </parameters>
-            </resource-agent>
-        """)
 
-    def test_all_required(self, mock_metadata):
-        mock_metadata.return_value = self.metadata
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-                "another_required_param": "value1",
-                "required_param": "value2",
-            }),
-            ([], [])
+    def test_all_required(self):
+        # set two required attrs, one deprecated and one obsoleting
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                }
+            ),
+            [
+            ]
         )
 
-    def test_all_required_and_optional(self, mock_metadata):
-        mock_metadata.return_value = self.metadata
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-                "another_required_param": "value1",
-                "required_param": "value2",
-                "test_param": "value3",
-            }),
-            ([], [])
+    def test_all_required_and_optional(self):
+        # set two required attrs, one deprecated and one obsoleting
+        # set two optional attrs, one deprecated and one obsoleting
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                    "opt1_new": "C",
+                    "opt2_old": "D",
+                }
+            ),
+            [
+            ]
         )
 
-    def test_all_required_and_invalid(self, mock_metadata):
-        mock_metadata.return_value = self.metadata
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-                "another_required_param": "value1",
-                "required_param": "value2",
-                "invalid_param": "value3",
-            }),
-            (["invalid_param"], [])
+    def test_all_required_and_optional_deprecated_and_obsoleting(self):
+        # set both deprecated and obsoleting variant of an attr
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                    "req1_new": "A",
+                    "req1_old": "B",
+                    "req2_new": "C",
+                    "req2_old": "D",
+                    "opt1_new": "E",
+                    "opt1_old": "F",
+                    "opt2_new": "G",
+                    "opt2_old": "H",
+                }
+            ),
+            [
+            ]
         )
 
-    def test_missing_required(self, mock_metadata):
-        mock_metadata.return_value = self.metadata
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-            }),
-            ([], ["required_param", "another_required_param"])
+    def test_all_required_and_invalid(self):
+        # set two required attrs, one deprecated and one obsoleting
+        # set an invalid attr
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                    "unknown1": "C",
+                    "unknown2": "D",
+                }
+            ),
+            [
+                fixture.error(
+                    report_codes.INVALID_OPTIONS,
+                    force_code=report_codes.FORCE_OPTIONS,
+                    option_names=["unknown1", "unknown2"],
+                    allowed=[
+                        "opt1_new",
+                        "opt1_old",
+                        "opt2_new",
+                        "opt2_old",
+                        "req1_new",
+                        "req1_old",
+                        "req2_new",
+                        "req2_old",
+                    ],
+                    option_type="agent",
+                ),
+            ]
         )
 
-    def test_missing_required_and_invalid(self, mock_metadata):
-        mock_metadata.return_value = self.metadata
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-                "another_required_param": "value1",
-                "invalid_param": "value3",
-            }),
-            (["invalid_param"], ["required_param"])
+    def test_all_required_and_invalid_force(self):
+        # set two required attrs, one deprecated and one obsoleting
+        # set an invalid attr
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                    "unknown1": "C",
+                    "unknown2": "D",
+                },
+                force=True
+            ),
+            [
+                fixture.warn(
+                    report_codes.INVALID_OPTIONS,
+                    option_names=["unknown1", "unknown2"],
+                    allowed=[
+                        "opt1_new",
+                        "opt1_old",
+                        "opt2_new",
+                        "opt2_old",
+                        "req1_new",
+                        "req1_old",
+                        "req2_new",
+                        "req2_old",
+                    ],
+                    option_type="agent",
+                ),
+            ]
         )
 
-    def test_ignore_obsoletes_use_deprecated(self, mock_metadata):
-        xml = """
-            <resource-agent>
-                <parameters>
-                    <parameter name="obsoletes" obsoletes="deprecated"
-                        required="1"
-                    />
-                    <parameter name="deprecated" deprecated="1" required="1"/>
-                </parameters>
-            </resource-agent>
-        """
-        mock_metadata.return_value = etree.XML(xml)
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-            }),
-            ([], ["deprecated"])
+    def test_missing_required(self):
+        # only obsoleting attrs are reported
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                }
+            ),
+            [
+                fixture.error(
+                    report_codes.REQUIRED_OPTION_IS_MISSING,
+                    force_code=report_codes.FORCE_OPTIONS,
+                    option_names=["req1_new", "req2_new"],
+                    option_type="agent",
+                ),
+            ]
         )
 
-    def test_dont_allow_obsoletes_use_deprecated(self, mock_metadata):
-        xml = """
-            <resource-agent>
-                <parameters>
-                    <parameter name="obsoletes" obsoletes="deprecated"
-                        required="1"
-                    />
-                    <parameter name="deprecated" deprecated="1" required="1"/>
-                </parameters>
-            </resource-agent>
-        """
-        mock_metadata.return_value = etree.XML(xml)
-        self.assertEqual(
-            self.agent.validate_parameters_values({
-                "obsoletes": "value",
-            }),
-            (["obsoletes"], ["deprecated"])
+    def test_missing_required_force(self):
+        # only obsoleting attrs are reported
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                },
+                force=True
+            ),
+            [
+                fixture.warn(
+                    report_codes.REQUIRED_OPTION_IS_MISSING,
+                    option_names=["req1_new", "req2_new"],
+                    option_type="agent",
+                ),
+            ]
         )
 
 
-class AgentMetadataValidateParameters(TestCase):
+@patch_agent_object("_get_metadata", lambda self: xml_for_validate_test)
+class AgentMetadataValidateParamsUpdate(TestCase):
     def setUp(self):
-        self.agent = lib_ra.Agent(mock.MagicMock(spec_set=CommandRunner))
-        self.metadata = etree.XML("""
-            <resource-agent>
-                <parameters>
-                    <parameter name="test_param" required="0">
-                        <longdesc>Long description</longdesc>
-                        <shortdesc>short description</shortdesc>
-                        <content type="string" default="default_value" />
-                    </parameter>
-                    <parameter name="required_param" required="1">
-                        <content type="boolean" />
-                    </parameter>
-                    <parameter name="another_required_param" required="1">
-                        <content type="string" />
-                    </parameter>
-                </parameters>
-            </resource-agent>
-        """)
-        patcher = patch_agent_object("_get_metadata")
-        self.addCleanup(patcher.stop)
-        self.get_metadata = patcher.start()
-        self.get_metadata.return_value = self.metadata
-
-    def test_returns_empty_report_when_all_required_there(self):
-        self.assertEqual(
-            [],
-            self.agent.validate_parameters({
-                "another_required_param": "value1",
-                "required_param": "value2",
-            }),
+        self.agent = lib_ra.Agent(
+            mock.MagicMock(spec_set=CommandRunner)
         )
 
-    def test_returns_empty_report_when_all_required_and_optional_there(self):
-        self.assertEqual(
-            [],
-            self.agent.validate_parameters({
-                "another_required_param": "value1",
-                "required_param": "value2",
-                "test_param": "value3",
-            })
-        )
-
-    def test_report_invalid_option(self):
+    def test_set_invalid(self):
         assert_report_item_list_equal(
-            self.agent.validate_parameters({
-                "another_required_param": "value1",
-                "required_param": "value2",
-                "invalid_param": "value3",
-            }),
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                    "unknown1": "c",
+                },
+                {
+
+                    "unknown1": "C",
+                    "unknown2": "D",
+                }
+            ),
             [
-                (
-                    severity.ERROR,
+                fixture.error(
                     report_codes.INVALID_OPTIONS,
-                    {
-                        "option_names": ["invalid_param"],
-                        "option_type": "resource",
-                        "allowed": [
-                            "another_required_param",
-                            "required_param",
-                            "test_param",
-                        ],
-                        "allowed_patterns": [],
-                    },
-                    report_codes.FORCE_OPTIONS
-                ),
-            ],
-        )
-
-    def test_report_missing_option(self):
-        assert_report_item_list_equal(
-            self.agent.validate_parameters({}),
-            [
-                (
-                    severity.ERROR,
-                    report_codes.REQUIRED_OPTION_IS_MISSING,
-                    {
-                        "option_names": [
-                            "required_param",
-                            "another_required_param",
-                        ],
-                        "option_type": "resource",
-                    },
-                    report_codes.FORCE_OPTIONS
-                ),
-            ],
-        )
-
-    def test_warn_missing_required(self):
-        assert_report_item_list_equal(
-            self.agent.validate_parameters({}, allow_invalid=True),
-            [
-                (
-                    severity.WARNING,
-                    report_codes.REQUIRED_OPTION_IS_MISSING,
-                    {
-                        "option_names": [
-                            "required_param",
-                            "another_required_param",
-                        ],
-                        "option_type": "resource",
-                    },
+                    force_code=report_codes.FORCE_OPTIONS,
+                    option_names=["unknown2"],
+                    allowed=[
+                        "opt1_new",
+                        "opt1_old",
+                        "opt2_new",
+                        "opt2_old",
+                        "req1_new",
+                        "req1_old",
+                        "req2_new",
+                        "req2_old",
+                    ],
+                    option_type="agent",
                 ),
             ]
         )
 
-    def test_ignore_obsoletes_use_deprecated(self):
-        xml = """
-            <resource-agent>
-                <parameters>
-                    <parameter name="obsoletes" obsoletes="deprecated"
-                        required="1"
-                    />
-                    <parameter name="deprecated" deprecated="1" required="1"/>
-                </parameters>
-            </resource-agent>
-        """
-        self.get_metadata.return_value = etree.XML(xml)
+    def test_remove_invalid(self):
         assert_report_item_list_equal(
-            self.agent.validate_parameters({}),
-            [
-                (
-                    severity.ERROR,
-                    report_codes.REQUIRED_OPTION_IS_MISSING,
-                    {
-                        "option_names": [
-                            "deprecated",
-                        ],
-                        "option_type": "resource",
-                    },
-                    report_codes.FORCE_OPTIONS
-                ),
-            ]
-        )
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                    "unknown1": "C",
+                },
+                {
 
-    def test_dont_allow_obsoletes_use_deprecated(self):
-        xml = """
-            <resource-agent>
-                <parameters>
-                    <parameter name="obsoletes" obsoletes="deprecated"
-                        required="1"
-                    />
-                    <parameter name="deprecated" deprecated="1" required="1"/>
-                </parameters>
-            </resource-agent>
-        """
-        self.get_metadata.return_value = etree.XML(xml)
-        assert_report_item_list_equal(
-            self.agent.validate_parameters({"obsoletes": "value"}),
+                    "unknown1": "",
+                    "unknown2": "",
+                }
+            ),
             [
-                (
-                    severity.ERROR,
-                    report_codes.REQUIRED_OPTION_IS_MISSING,
-                    {
-                        "option_names": [
-                            "deprecated",
-                        ],
-                        "option_type": "resource",
-                    },
-                    report_codes.FORCE_OPTIONS
-                ),
-                (
-                    severity.ERROR,
+                fixture.error(
                     report_codes.INVALID_OPTIONS,
-                    {
-                        "option_names": ["obsoletes"],
-                        "option_type": "resource",
-                        "allowed": [
-                            "deprecated",
-                        ],
-                        "allowed_patterns": [],
-                    },
-                    report_codes.FORCE_OPTIONS
+                    force_code=report_codes.FORCE_OPTIONS,
+                    option_names=["unknown2"],
+                    allowed=[
+                        "opt1_new",
+                        "opt1_old",
+                        "opt2_new",
+                        "opt2_old",
+                        "req1_new",
+                        "req1_old",
+                        "req2_new",
+                        "req2_old",
+                    ],
+                    option_type="agent",
                 ),
             ]
         )
 
-    def test_required_not_specified_on_update(self):
+    def test_remove_required_obsoleting(self):
         assert_report_item_list_equal(
-            self.agent.validate_parameters({
-                "test_param": "value",
-            }, update=True),
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                },
+                {
+
+                    "req1_new": "",
+                }
+            ),
             [
-            ],
+                fixture.error(
+                    report_codes.REQUIRED_OPTION_IS_MISSING,
+                    force_code=report_codes.FORCE_OPTIONS,
+                    option_names=["req1_new"],
+                    option_type="agent",
+                ),
+            ]
+        )
+
+    def test_remove_required_deprecated(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                },
+                {
+
+                    "req2_old": "",
+                }
+            ),
+            [
+                fixture.error(
+                    report_codes.REQUIRED_OPTION_IS_MISSING,
+                    force_code=report_codes.FORCE_OPTIONS,
+                    option_names=["req2_new"],
+                    option_type="agent",
+                ),
+            ]
+        )
+
+    def test_remove_required_deprecated_set_obsoleting(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                },
+                {
+
+                    "req2_old": "",
+                    "req2_new": "B",
+                }
+            ),
+            [
+            ]
+        )
+
+    def test_remove_required_obsoleting_set_deprecated(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                },
+                {
+
+                    "req1_old": "A",
+                    "req1_new": "",
+                }
+            ),
+            [
+            ]
+        )
+
+    def test_set_optional(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                },
+                {
+
+                    "opt1_new": "A",
+                }
+            ),
+            [
+            ]
+        )
+
+    def test_remove_optional(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_update(
+                {
+                    "req1_new": "A",
+                    "req2_old": "B",
+                },
+                {
+
+                    "opt1_new": "",
+                }
+            ),
+            [
+            ]
         )
 
 
-class StonithdMetadataGetMetadataTest(TestCase, ExtendedAssertionsMixin):
+xml_for_loop_test = etree.XML("""
+    <resource-agent>
+        <parameters>
+            <parameter name="opt_loop1" required="1"
+                obsoletes="opt_loop1" deprecated="1"
+            />
+            <parameter name="opt_loop2" required="1"
+                obsoletes="opt_loop2" deprecated="0"
+            />
+            <parameter name="opt1" required="1"
+                obsoletes="opt2" deprecated="1"
+            />
+            <parameter name="opt2" required="1"
+                obsoletes="opt1" deprecated="1"
+            />
+            <parameter name="opt3" required="1"
+                obsoletes="opt4" deprecated="0"
+            />
+            <parameter name="opt4" required="1"
+                obsoletes="opt3" deprecated="0"
+            />
+        </parameters>
+    </resource-agent>
+""")
+@patch_agent_object("_get_metadata", lambda self: xml_for_loop_test)
+class AgentMetadataValidateParamsWithLoop(TestCase):
+    # Meta-data are broken - there are obsoleting loops. The point of the test
+    # is to make sure pcs does not crach or loop forever. Error reports are not
+    # that important, since meta-data are broken.
+    def setUp(self):
+        self.agent = lib_ra.Agent(
+            mock.MagicMock(spec_set=CommandRunner)
+        )
+
+    def test_create(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_create(
+                {
+                }
+            ),
+            [
+            ]
+        )
+
+    def test_update(self):
+        assert_report_item_list_equal(
+            self.agent.validate_parameters_update(
+                {
+                },
+                {
+                }
+            ),
+            [
+            ]
+        )
+
+class FencedMetadataGetMetadataTest(TestCase, ExtendedAssertionsMixin):
     def setUp(self):
         self.mock_runner = mock.MagicMock(spec_set=CommandRunner)
-        self.agent = lib_ra.StonithdMetadata(self.mock_runner)
+        self.agent = lib_ra.FencedMetadata(self.mock_runner)
 
     def test_success(self):
         metadata = """
             <resource-agent>
-                <shortdesc>stonithd test metadata</shortdesc>
+                <shortdesc>pacemaker-fenced test metadata</shortdesc>
             </resource-agent>
         """
         self.mock_runner.run.return_value = (metadata, "", 0)
@@ -1483,7 +1669,7 @@ class StonithdMetadataGetMetadataTest(TestCase, ExtendedAssertionsMixin):
         )
 
         self.mock_runner.run.assert_called_once_with(
-            ["/usr/libexec/pacemaker/stonithd", "metadata"]
+            ["/usr/libexec/pacemaker/pacemaker-fenced", "metadata"]
         )
 
     def test_failed_to_get_xml(self):
@@ -1493,13 +1679,13 @@ class StonithdMetadataGetMetadataTest(TestCase, ExtendedAssertionsMixin):
             lib_ra.UnableToGetAgentMetadata,
             self.agent._get_metadata,
             {
-                "agent": "stonithd",
+                "agent": "pacemaker-fenced",
                 "message": "some error",
             }
         )
 
         self.mock_runner.run.assert_called_once_with(
-            ["/usr/libexec/pacemaker/stonithd", "metadata"]
+            ["/usr/libexec/pacemaker/pacemaker-fenced", "metadata"]
         )
 
     def test_invalid_xml(self):
@@ -1509,20 +1695,20 @@ class StonithdMetadataGetMetadataTest(TestCase, ExtendedAssertionsMixin):
             lib_ra.UnableToGetAgentMetadata,
             self.agent._get_metadata,
             {
-                "agent": "stonithd",
+                "agent": "pacemaker-fenced",
                 "message": start_tag_error_text(),
             }
         )
 
         self.mock_runner.run.assert_called_once_with(
-            ["/usr/libexec/pacemaker/stonithd", "metadata"]
+            ["/usr/libexec/pacemaker/pacemaker-fenced", "metadata"]
         )
 
 
 @patch_agent_object("_get_metadata")
-class StonithdMetadataGetParametersTest(TestCase):
+class FencedMetadataGetParametersTest(TestCase):
     def setUp(self):
-        self.agent = lib_ra.StonithdMetadata(
+        self.agent = lib_ra.FencedMetadata(
             mock.MagicMock(spec_set=CommandRunner)
         )
 
@@ -1558,6 +1744,7 @@ class StonithdMetadataGetParametersTest(TestCase):
                     "default": "default_value",
                     "advanced": True,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
@@ -1570,6 +1757,7 @@ class StonithdMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 }
@@ -1703,7 +1891,7 @@ class StonithAgentMetadataGetMetadataTest(TestCase, ExtendedAssertionsMixin):
         )
 
     def tearDown(self):
-        lib_ra.StonithAgent._stonithd_metadata = None
+        lib_ra.StonithAgent._fenced_metadata = None
 
     def test_success(self):
         metadata = """
@@ -1740,7 +1928,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
         )
 
     def tearDown(self):
-        lib_ra.StonithAgent._stonithd_metadata = None
+        lib_ra.StonithAgent._fenced_metadata = None
 
     def test_success(self):
         metadata = """
@@ -1759,16 +1947,16 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                 </parameters>
             </resource-agent>
         """
-        stonithd_metadata = """
+        fenced_metadata = """
             <resource-agent>
                 <parameters>
-                    <parameter name="stonithd_param"/>
+                    <parameter name="fenced_param"/>
                 </parameters>
             </resource-agent>
         """
         self.mock_runner.run.side_effect = [
             (metadata, "", 0),
-            (stonithd_metadata, "", 0),
+            (fenced_metadata, "", 0),
         ]
 
         self.assertEqual(
@@ -1783,6 +1971,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
@@ -1795,6 +1984,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
@@ -1807,6 +1997,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
@@ -1819,6 +2010,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": True,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "Specifying 'action' is"
                         " deprecated and not necessary with current Pacemaker"
@@ -1835,11 +2027,12 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
                 {
-                    "name": "stonithd_param",
+                    "name": "fenced_param",
                     "longdesc": "",
                     "shortdesc": "",
                     "type": "string",
@@ -1847,6 +2040,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                     "default": None,
                     "advanced": False,
                     "deprecated": False,
+                    "deprecated_by": [],
                     "obsoletes": None,
                     "pcs_deprecated_warning": "",
                 },
@@ -1866,7 +2060,7 @@ class StonithAgentMetadataGetParametersTest(TestCase):
                  }
             ),
             mock.call(
-                ["/usr/libexec/pacemaker/stonithd", "metadata"]
+                ["/usr/libexec/pacemaker/pacemaker-fenced", "metadata"]
             ),
         ])
 
@@ -1880,7 +2074,7 @@ class StonithAgentMetadataGetProvidesUnfencingTest(TestCase):
         )
 
     def tearDown(self):
-        lib_ra.StonithAgent._stonithd_metadata = None
+        lib_ra.StonithAgent._fenced_metadata = None
 
     def test_true(self, mock_metadata):
         xml = """
@@ -1946,12 +2140,14 @@ class ResourceAgentTest(TestCase):
         )
 
     def test_does_not_raise_on_valid_name(self):
+        # pylint: disable=no-self-use
         lib_ra.ResourceAgent(mock.MagicMock(), "ocf:heardbeat:name")
 
 
 @patch_agent_object("_get_metadata")
 class ResourceAgentGetParameters(TestCase):
-    def fixture_metadata(self, params):
+    @staticmethod
+    def fixture_metadata(params):
         return etree.XML("""
             <resource-agent>
                 <parameters>{0}</parameters>
@@ -2002,6 +2198,7 @@ class ResourceAgentGetParameters(TestCase):
 
 
 class FindResourceAgentByNameTest(TestCase):
+    # pylint: disable=invalid-name
     def setUp(self):
         self.report_processor = mock.MagicMock()
         self.runner = mock.MagicMock()
@@ -2016,7 +2213,7 @@ class FindResourceAgentByNameTest(TestCase):
     def test_returns_guessed_agent(self, mock_guess, mock_report):
         #setup
         name = "Delay"
-        guessed_name =  "ocf:heartbeat:Delay"
+        guessed_name = "ocf:heartbeat:Delay"
         report = "AGENT_NAME_GUESSED"
 
         agent = mock.MagicMock(get_name=mock.Mock(return_value=guessed_name))
@@ -2105,6 +2302,7 @@ class FindResourceAgentByNameTest(TestCase):
 
 
 class FindStonithAgentByName(TestCase):
+    # pylint: disable=invalid-name
     # It is quite similar to find_valid_stonith_agent_by_name, so only minimum
     # tests here:
     # - test success
@@ -2152,7 +2350,7 @@ class FindStonithAgentByName(TestCase):
 class AbsentResourceAgentTest(TestCase):
     @mock.patch.object(lib_ra.CrmAgent, "_load_metadata")
     def test_behaves_like_a_proper_agent(self, load_metadata):
-        name =  "ocf:heartbeat:Absent"
+        name = "ocf:heartbeat:Absent"
         runner = mock.MagicMock(spec_set=CommandRunner)
         load_metadata.return_value = "<resource-agent/>"
 
@@ -2172,6 +2370,22 @@ class AbsentResourceAgentTest(TestCase):
         self.assertEqual(agent.get_longdesc(), absent.get_longdesc())
         self.assertEqual(agent.get_parameters(), absent.get_parameters())
         self.assertEqual(agent.get_actions(), absent.get_actions())
-        self.assertEqual(([], []), absent.validate_parameters_values({
-            "whatever": "anything"
-        }))
+        self.assertEqual(
+            [],
+            absent.validate_parameters_create(
+                {
+                    "whatever": "anything",
+                }
+            )
+        )
+        self.assertEqual(
+            [],
+            absent.validate_parameters_update(
+                {
+                    "whatever": "anything",
+                },
+                {
+                    "whatever": "anything",
+                }
+            )
+        )
