@@ -1,18 +1,14 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from lxml import etree
 import re
+from unittest import TestCase
+from lxml import etree
 
 from pcs.common import report_codes
 from pcs.lib import validate
 from pcs.lib.cib.tools import IdProvider
 from pcs.lib.errors import ReportItemSeverity as severities
 from pcs.test.tools.assertions import assert_report_item_list_equal
-from pcs.test.tools.pcs_unittest import TestCase
+
+# pylint: disable=no-self-use
 
 class ValuesToPairs(TestCase):
     def test_create_from_plain_values(self):
@@ -217,7 +213,7 @@ class ValueCondTest(TestCase):
             ]
         )
 
-    def test_support_OptionValuePair(self):
+    def test_support_option_value_pair(self):
         assert_report_item_list_equal(
             validate.value_cond("a", self.predicate, "test")(
                 {"a": validate.ValuePair(original="b", normalized="c")}
@@ -285,7 +281,7 @@ class ValueCondTest(TestCase):
                 self.predicate,
                 "test",
                 code_to_allow_extra_values="FORCE",
-                allow_extra_values=True
+                extra_values_allowed=True
             )(
                 {"a": "c"}
             ),
@@ -505,7 +501,7 @@ class ValueIn(TestCase):
             ]
         )
 
-    def test_support_OptionValuePair(self):
+    def test_support_option_value_pair(self):
         assert_report_item_list_equal(
             validate.value_in("a", ["b"])(
                 {"a": validate.ValuePair(original="C", normalized="c")}
@@ -568,7 +564,7 @@ class ValueIn(TestCase):
                 "a",
                 ["b"],
                 code_to_allow_extra_values="FORCE",
-                allow_extra_values=True
+                extra_values_allowed=True
             )(
                 {"a": "c"}
             ),
@@ -587,6 +583,72 @@ class ValueIn(TestCase):
         )
 
 
+class ValueIntegerInRange(TestCase):
+    # The real code only calls value_cond and is_integer which are both heavily
+    # tested on their own => only basic tests here.
+    def fixture_validator(self):
+        return validate.value_integer_in_range("key", -5, 5)
+
+    def test_empty_report_on_valid_option(self):
+        assert_report_item_list_equal(
+            self.fixture_validator()({"key": "2"}),
+            []
+        )
+
+    def test_report_invalid_value(self):
+        assert_report_item_list_equal(
+            self.fixture_validator()({"key": "6"}),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_name": "key",
+                        "option_value": "6",
+                        "allowed_values": "-5..5",
+                    },
+                    None
+                ),
+            ]
+        )
+
+
+class ValueIpAddress(TestCase):
+    # The real code only calls value_cond and is_integer which are both heavily
+    # tested on their own => only basic tests here.
+    def fixture_validator(self):
+        return validate.value_ip_address("key")
+
+    def test_empty_report_on_ipv4(self):
+        assert_report_item_list_equal(
+            self.fixture_validator()({"key": "192.168.123.42"}),
+            []
+        )
+
+    def test_empty_report_on_ipv6(self):
+        assert_report_item_list_equal(
+            self.fixture_validator()({"key": "::192:168:123:42"}),
+            []
+        )
+
+    def test_report_invalid_value(self):
+        assert_report_item_list_equal(
+            self.fixture_validator()({"key": "abcd"}),
+            [
+                (
+                    severities.ERROR,
+                    report_codes.INVALID_OPTION_VALUE,
+                    {
+                        "option_name": "key",
+                        "option_value": "abcd",
+                        "allowed_values": "an IP address",
+                    },
+                    None
+                ),
+            ]
+        )
+
+
 class ValueNonnegativeInteger(TestCase):
     # The real code only calls value_cond => only basic tests here.
     def test_empty_report_on_valid_option(self):
@@ -878,7 +940,7 @@ class NamesIn(TestCase):
                 ["a", "b", "c"],
                 ["x", "y"],
                  #does now work without code_to_allow_extra_names
-                allow_extra_names=True,
+                extra_names_allowed=True,
             ),
             [
                 (
@@ -925,7 +987,7 @@ class NamesIn(TestCase):
                 ["x", "y"],
                 option_type="some option",
                 code_to_allow_extra_names="FORCE_CODE",
-                allow_extra_names=True,
+                extra_names_allowed=True,
             ),
             [
                 (
@@ -992,6 +1054,30 @@ class IsInteger(TestCase):
         self.assertFalse(validate.is_integer("7", 4, 6))
 
 
+class IsIpv4Address(TestCase):
+    def test_valid(self):
+        self.assertTrue(validate.is_ipv4_address("192.168.1.1"))
+        self.assertTrue(validate.is_ipv4_address("1.2.3.4"))
+        self.assertTrue(validate.is_ipv4_address("255.255.255.255"))
+        self.assertTrue(validate.is_ipv4_address("0.0.0.0"))
+
+    def test_bad(self):
+        self.assertFalse(validate.is_ipv4_address("abcd"))
+        self.assertFalse(validate.is_ipv4_address("192 168 1 1"))
+        self.assertFalse(validate.is_ipv4_address("3232235521"))
+        self.assertFalse(validate.is_ipv4_address("::1"))
+
+
+class IsIpv6Address(TestCase):
+    def test_valid(self):
+        self.assertTrue(validate.is_ipv6_address("fe80::5054:ff:fec6:8eaf"))
+        self.assertTrue(validate.is_ipv6_address("::abc:7:def"))
+
+    def test_bad(self):
+        self.assertFalse(validate.is_ipv6_address("abcd"))
+        self.assertFalse(validate.is_ipv6_address("192.168.1.1"))
+
+
 class IsPortNumber(TestCase):
     def test_valid_port(self):
         self.assertTrue(validate.is_port_number(1))
@@ -1044,7 +1130,7 @@ class IsEmptyString(TestCase):
 class IsTimeInterval(TestCase):
     def test_no_reports_for_valid_time_interval(self):
         for interval in ["0", "1s", "2sec", "3m", "4min", "5h", "6hr"]:
-            self.assertEquals(
+            self.assertEqual(
                 [],
                 validate.value_time_interval("a")({"a": interval}),
                 "interval: {0}".format(interval)
