@@ -31,16 +31,10 @@ and pairs_to_values.
 TODO provide parameters to provide forceable error/warning for functions that
      does not support it
 """
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from collections import namedtuple
+import ipaddress
 import re
 
-from pcs.common.tools import is_string
 from pcs.lib import reports
 from pcs.lib.pacemaker.values import (
     timeout_to_seconds,
@@ -168,7 +162,7 @@ def is_required_some_of(option_name_list, option_type=""):
             set(option_dict.keys()),
             set(option_name_list)
         )
-        if len(found_names) < 1:
+        if not found_names:
             return [reports.required_option_of_alternatives_is_missing(
                 sorted(option_name_list),
                 option_type,
@@ -200,12 +194,12 @@ def mutually_exclusive(mutually_exclusive_names, option_type="option"):
 
 def names_in(
     allowed_name_list, name_list, option_type="option",
-    code_to_allow_extra_names=None, allow_extra_names=False,
+    code_to_allow_extra_names=None, extra_names_allowed=False,
     allowed_option_patterns=None
 ):
     """
-    Return a list with report INVALID_OPTIONS when in name_list is a name that is
-    not in allowed_name_list.
+    Return a list with report INVALID_OPTIONS when in name_list is a name that
+    is not in allowed_name_list.
 
     list allowed_name_list contains names which are valid
     list name_list contains names for validation
@@ -213,7 +207,7 @@ def names_in(
     string code_to_allow_extra_names is code for forcing invalid names. If it is
         empty report INVALID_OPTIONS is non-forceable error. If it is not empty
         report INVALID_OPTIONS is forceable error or warning.
-    bool allow_extra_names is flag that complements code_to_allow_extra_names
+    bool extra_names_allowed is flag that complements code_to_allow_extra_names
         and determines wheter is report INVALID_OPTIONS forceable error or
         warning.
     mixed allowed_option_patterns -- option patterns to be added to a report
@@ -224,7 +218,7 @@ def names_in(
 
     create_report = reports.get_problem_creator(
         code_to_allow_extra_names,
-        allow_extra_names
+        extra_names_allowed
     )
     return [create_report(
         reports.invalid_options,
@@ -238,7 +232,7 @@ def names_in(
 
 def value_cond(
     option_name, predicate, value_type_or_enum, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Return a validation  function that takes option_dict and returns report list
@@ -252,7 +246,7 @@ def value_cond(
     string code_to_allow_extra_values is code for forcing invalid names. If it
         is empty report INVALID_OPTION_VALUE is non-forceable error. If it is
         not empty report INVALID_OPTION_VALUE is forceable error or warning.
-    bool allow_extra_values is flag that complements code_to_allow_extra_values
+    bool extra_values_allowed flag that complements code_to_allow_extra_values
         and determines wheter is report INVALID_OPTION_VALUE forceable error or
         warning.
     """
@@ -263,7 +257,7 @@ def value_cond(
         if not predicate(value.normalized):
             create_report = reports.get_problem_creator(
                 code_to_allow_extra_values,
-                allow_extra_values
+                extra_values_allowed
             )
             return [create_report(
                 reports.invalid_option_value,
@@ -315,7 +309,7 @@ def value_id(option_name, option_name_for_report=None, id_provider=None):
 
 def value_in(
     option_name, allowed_values, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Special case of value_cond function.returned function checks whenever value
@@ -327,7 +321,7 @@ def value_in(
     code_to_allow_extra_values -- string, code for forcing invalid names. If it
         is empty report INVALID_OPTION_VALUE is non-forceable error. If it is
         not empty report INVALID_OPTION_VALUE is forceable error or warning.
-    allow_extra_values -- bool, flag that complements code_to_allow_extra_values
+    extra_values_allowed -- bool flag complementing code_to_allow_extra_values
         and determines wheter is report INVALID_OPTION_VALUE forceable error or
         warning.
     """
@@ -337,12 +331,58 @@ def value_in(
         allowed_values,
         option_name_for_report=option_name_for_report,
         code_to_allow_extra_values=code_to_allow_extra_values,
-        allow_extra_values=allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
+    )
+
+def value_integer_in_range(
+    option_name, at_least, at_most, option_name_for_report=None,
+    code_to_allow_extra_values=None, extra_values_allowed=False
+):
+    """
+    Get a validator reporting INVALID_OPTION_VALUE when the value is not an
+    integer such that at_least <= value <= at_most
+
+    string option_name -- name of the option to check
+    int at_least -- minimal allowed value
+    int at_most -- maximal allowed value
+    string option_name_for_report -- substitued by the option_name if not set
+    string code_to_allow_extra_values -- create a report forceable by this code
+    bool extra_values_allowed -- create a warning instead of an error if True
+    """
+    return value_cond(
+        option_name,
+        lambda value: is_integer(value, at_least, at_most),
+        "{min}..{max}".format(min=at_least, max=at_most),
+        option_name_for_report=option_name_for_report,
+        code_to_allow_extra_values=code_to_allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
+    )
+
+def value_ip_address(
+    option_name, option_name_for_report=None,
+    code_to_allow_extra_values=None, extra_values_allowed=False
+):
+    """
+    Get a validator reporting INVALID_OPTION_VALUE when the value is not
+    an IP address
+
+    string option_name -- name of the option to check
+    string option_name_for_report -- substitued by the option_name if not set
+    string code_to_allow_extra_values -- create a report forceable by this code
+    bool extra_values_allowed -- create a warning instead of an error if True
+    """
+    return value_cond(
+        option_name,
+        lambda value: is_ipv4_address(value) or is_ipv6_address(value),
+        "an IP address",
+        option_name_for_report=option_name_for_report,
+        code_to_allow_extra_values=code_to_allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
     )
 
 def value_nonnegative_integer(
     option_name, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Get a validator reporting INVALID_OPTION_VALUE when the value is not
@@ -351,7 +391,7 @@ def value_nonnegative_integer(
     string option_name -- name of the option to check
     string option_name_for_report -- substitued by the option_name if not set
     string code_to_allow_extra_values -- create a report forceable by this code
-    bool allow_extra_values -- create a warning instead of an error if True
+    bool extra_values_allowed -- create a warning instead of an error if True
     """
     return value_cond(
         option_name,
@@ -359,12 +399,12 @@ def value_nonnegative_integer(
         "a non-negative integer",
         option_name_for_report=option_name_for_report,
         code_to_allow_extra_values=code_to_allow_extra_values,
-        allow_extra_values=allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
     )
 
 def value_not_empty(
     option_name, value_type_or_enum, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Get a validator reporting INVALID_OPTION_VALUE when the value is empty
@@ -372,7 +412,7 @@ def value_not_empty(
     string option_name -- name of the option to check
     string option_name_for_report -- substitued by the option_name if not set
     string code_to_allow_extra_values -- create a report forceable by this code
-    bool allow_extra_values -- create a warning instead of an error if True
+    bool extra_values_allowed -- create a warning instead of an error if True
     """
     return value_cond(
         option_name,
@@ -380,12 +420,12 @@ def value_not_empty(
         value_type_or_enum,
         option_name_for_report=option_name_for_report,
         code_to_allow_extra_values=code_to_allow_extra_values,
-        allow_extra_values=allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
     )
 
 def value_port_number(
     option_name, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Get a validator reporting INVALID_OPTION_VALUE when the value is not a TCP
@@ -394,7 +434,7 @@ def value_port_number(
     string option_name -- name of the option to check
     string option_name_for_report -- substitued by the option_name if not set
     string code_to_allow_extra_values -- create a report forceable by this code
-    bool allow_extra_values -- create a warning instead of an error if True
+    bool extra_values_allowed -- create a warning instead of an error if True
     """
     return value_cond(
         option_name,
@@ -402,12 +442,12 @@ def value_port_number(
         "a port number (1-65535)",
         option_name_for_report=option_name_for_report,
         code_to_allow_extra_values=code_to_allow_extra_values,
-        allow_extra_values=allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
     )
 
 def value_port_range(
     option_name, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Get a validator reporting INVALID_OPTION_VALUE when the value is not a TCP
@@ -416,7 +456,7 @@ def value_port_range(
     string option_name -- name of the option to check
     string option_name_for_report -- substitued by the option_name if not set
     string code_to_allow_extra_values -- create a report forceable by this code
-    bool allow_extra_values -- create a warning instead of an error if True
+    bool extra_values_allowed -- create a warning instead of an error if True
     """
     return value_cond(
         option_name,
@@ -428,12 +468,12 @@ def value_port_range(
         "port-port",
         option_name_for_report=option_name_for_report,
         code_to_allow_extra_values=code_to_allow_extra_values,
-        allow_extra_values=allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
     )
 
 def value_positive_integer(
     option_name, option_name_for_report=None,
-    code_to_allow_extra_values=None, allow_extra_values=False
+    code_to_allow_extra_values=None, extra_values_allowed=False
 ):
     """
     Get a validator reporting INVALID_OPTION_VALUE when the value is not
@@ -442,7 +482,7 @@ def value_positive_integer(
     string option_name -- name of the option to check
     string option_name_for_report -- substitued by the option_name if not set
     string code_to_allow_extra_values -- create a report forceable by this code
-    bool allow_extra_values -- create a warning instead of an error if True
+    bool extra_values_allowed -- create a warning instead of an error if True
     """
     return value_cond(
         option_name,
@@ -450,7 +490,7 @@ def value_positive_integer(
         "a positive integer",
         option_name_for_report=option_name_for_report,
         code_to_allow_extra_values=code_to_allow_extra_values,
-        allow_extra_values=allow_extra_values,
+        extra_values_allowed=extra_values_allowed,
     )
 
 def value_time_interval(option_name, option_name_for_report=None):
@@ -485,7 +525,7 @@ def is_empty_string(value):
 
     mixed value -- value to check
     """
-    return is_string(value) and not value
+    return isinstance(value, str) and not value
 
 def is_integer(value, at_least=None, at_most=None):
     """
@@ -505,6 +545,40 @@ def is_integer(value, at_least=None, at_most=None):
         return False
     return True
 
+def is_ipv4_address(value):
+    """
+    Check if the specified value is an IPv4 address
+
+    string value -- value to check
+    """
+    try:
+        # ip_address accepts both strings and integers. We check for "." to
+        # make sure it is a string representation of an IP.
+        if "." in value:
+            ipaddress.IPv4Address(value)
+            return True
+        return False
+    except ValueError:
+        # not an IP address
+        return False
+
+def is_ipv6_address(value):
+    """
+    Check if the specified value is an IPv6 address
+
+    string value -- value to check
+    """
+    try:
+        # ip_address accepts both strings and integers. We check for ":" to
+        # make sure it is a string representation of an IP.
+        if ":" in value:
+            ipaddress.IPv6Address(value)
+            return True
+        return False
+    except ValueError:
+        # not an IP address
+        return False
+
 def is_port_number(value):
     """
     Check if the specified value is a TCP or UDP port number
@@ -524,6 +598,30 @@ def matches_regexp(value, regexp):
         regexp = re.compile(regexp)
     return regexp.match(value) is not None
 
+def allow_extra_values(code_to_allow, allow):
+    """
+    A usefull shortcut for calling validators
+
+    string code_to_allow -- code to force an error
+    bool allow -- make extra values emit a warning
+    """
+    return {
+        "code_to_allow_extra_values": code_to_allow,
+        "extra_values_allowed": allow,
+    }
+
+def allow_extra_names(code_to_allow, allow):
+    """
+    A usefull shortcut for calling validators
+
+    string code_to_allow -- code to force an error
+    bool allow -- make extra names emit a warning
+    """
+    return {
+        "code_to_allow_extra_names": code_to_allow,
+        "extra_names_allowed": allow,
+    }
+
 def _if_option_exists(option_name):
     def params_wrapper(validate_func):
         def prepare(option_dict):
