@@ -1,18 +1,16 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import re
 import xml.dom.minidom
 
 from pcs import utils
 
+# pylint: disable=not-callable
 
 # main functions
 
 def parse_argv(argv, extra_options=None):
+    """
+    Commandline options: no options
+    """
     options = {
         "id": None,
         "role": None,
@@ -37,6 +35,10 @@ def parse_argv(argv, extra_options=None):
     return options, argv
 
 def dom_rule_add(dom_element, options, rule_argv):
+    # pylint: disable=too-many-branches
+    """
+    Commandline options: no options
+    """
     # validate options
     if options.get("score") and options.get("score-attribute"):
         utils.err("can not specify both score and score-attribute")
@@ -101,7 +103,7 @@ def dom_rule_add(dom_element, options, rule_argv):
     return dom_element
 
 
-class ExportDetailed(object):
+class ExportDetailed:
 
     def __init__(self):
         self.show_detail = False
@@ -111,7 +113,7 @@ class ExportDetailed(object):
         return indent + ("\n" + indent).join(self.list_rule(rule))
 
     def list_rule(self, rule):
-        rule_parts = ["Rule: %s" % " ".join(self.list_attributes(rule))]
+        rule_parts = ["Rule: %s" % " ".join(self._list_attributes(rule))]
         for child in rule.childNodes:
             if child.nodeType == xml.dom.minidom.Node.TEXT_NODE:
                 continue
@@ -144,7 +146,7 @@ class ExportDetailed(object):
     def list_date_expression(self, expression):
         operation = expression.getAttribute("operation")
         if operation == "date_spec":
-            date_spec_parts = self.list_attributes(
+            date_spec_parts = self._list_attributes(
                 expression.getElementsByTagName("date_spec")[0]
             )
             exp_parts = ["Expression:"]
@@ -154,7 +156,7 @@ class ExportDetailed(object):
                 [" ".join(exp_parts)],
                 ["Date Spec: %s" % " ".join(date_spec_parts)]
             )
-        elif operation == "in_range":
+        if operation == "in_range":
             exp_parts = ["date", "in_range"]
             if expression.hasAttribute("start"):
                 exp_parts.extend([expression.getAttribute("start"), "to"])
@@ -163,7 +165,7 @@ class ExportDetailed(object):
             durations = expression.getElementsByTagName("duration")
             if durations:
                 exp_parts.append("duration")
-                duration_parts = self.list_attributes(durations[0])
+                duration_parts = self._list_attributes(durations[0])
             if self.show_detail:
                 exp_parts.append(" (id:%s)" % expression.getAttribute("id"))
             result = ["Expression: %s" % " ".join(exp_parts)]
@@ -173,28 +175,28 @@ class ExportDetailed(object):
                     ["Duration: %s" % " ".join(duration_parts)]
                 )
             return result
-        else:
-            exp_parts = ["date", expression.getAttribute("operation")]
-            if expression.hasAttribute("start"):
-                exp_parts.append(expression.getAttribute("start"))
-            if expression.hasAttribute("end"):
-                exp_parts.append(expression.getAttribute("end"))
-            if self.show_detail:
-                exp_parts.append(" (id:%s)" % expression.getAttribute("id"))
-            return ["Expression: " + " ".join(exp_parts)]
+        exp_parts = ["date", expression.getAttribute("operation")]
+        if expression.hasAttribute("start"):
+            exp_parts.append(expression.getAttribute("start"))
+        if expression.hasAttribute("end"):
+            exp_parts.append(expression.getAttribute("end"))
+        if self.show_detail:
+            exp_parts.append(" (id:%s)" % expression.getAttribute("id"))
+        return ["Expression: " + " ".join(exp_parts)]
 
-    def list_attributes(self, element):
+    def _list_attributes(self, element):
         attributes = utils.dom_attrs_to_list(element, with_id=False)
         if self.show_detail:
             attributes.append(" (id:%s)" % (element.getAttribute("id")))
         return attributes
 
-    def indent_append(self, target, source, indent="  "):
+    @staticmethod
+    def indent_append(target, source, indent="  "):
         for part in source:
             target.append(indent + part)
         return target
 
-class ExportAsExpression(object):
+class ExportAsExpression:
 
     def __init__(self):
         self.normalize = False
@@ -243,11 +245,11 @@ class ExportAsExpression(object):
     def string_date_expression(self, expression):
         operation = expression.getAttribute("operation")
         if operation == "date_spec":
-            exp_parts = ["date-spec"] + self.list_attributes(
+            exp_parts = ["date-spec"] + self._list_attributes(
                 expression.getElementsByTagName("date_spec")[0]
             )
             return " ".join(exp_parts)
-        elif operation == "in_range":
+        if operation == "in_range":
             exp_parts = ["date", "in_range"]
             if expression.hasAttribute("start"):
                 exp_parts.extend([expression.getAttribute("start"), "to"])
@@ -256,17 +258,17 @@ class ExportAsExpression(object):
             durations = expression.getElementsByTagName("duration")
             if durations:
                 exp_parts.append("duration")
-                exp_parts.extend(self.list_attributes(durations[0]))
-            return " ".join(exp_parts)
-        else:
-            exp_parts = ["date", expression.getAttribute("operation")]
-            if expression.hasAttribute("start"):
-                exp_parts.append(expression.getAttribute("start"))
-            if expression.hasAttribute("end"):
-                exp_parts.append(expression.getAttribute("end"))
+                exp_parts.extend(self._list_attributes(durations[0]))
             return " ".join(exp_parts)
+        exp_parts = ["date", expression.getAttribute("operation")]
+        if expression.hasAttribute("start"):
+            exp_parts.append(expression.getAttribute("start"))
+        if expression.hasAttribute("end"):
+            exp_parts.append(expression.getAttribute("end"))
+        return " ".join(exp_parts)
 
-    def list_attributes(self, element):
+    @staticmethod
+    def _list_attributes(element):
         attributes = utils.dom_attrs_to_list(element, with_id=False)
         # sort it always to get the same output for the same input as dict is
         # unordered
@@ -276,7 +278,7 @@ class ExportAsExpression(object):
 
 # generic parser
 
-class SymbolBase(object):
+class SymbolBase:
 
     END = "{end}"
     LITERAL = "{literal}"
@@ -335,7 +337,7 @@ class SymbolParenthesisOpen(SymbolBase):
 class SymbolOperator(SymbolBase):
 
     expression_func = None
-    allowed_child_ids = None
+    allowed_child_ids = []
 
     def __init__(self):
         self.children = []
@@ -431,7 +433,7 @@ class SymbolTernary(SymbolOperator):
         return self
 
 
-class SymbolTable(object):
+class SymbolTable:
 
     def __init__(self):
         self.table = dict()
@@ -462,7 +464,7 @@ class SymbolTable(object):
         return self.get_symbol(symbol_id)
 
 
-class Parser(object):
+class Parser:
 
     def __init__(self):
         self.current_symbol = None
@@ -515,7 +517,7 @@ class Parser(object):
                 self.symbol_table.has_symbol(token)
                 and
                 (
-                    len(symbolized_program) < 1
+                    not symbolized_program
                     or
                     not isinstance(symbolized_program[-1], SymbolType)
                 )
@@ -578,12 +580,13 @@ class UnexpectedEndOfInput(ParserException):
 
 
 class SyntaxError(ParserException):
+    # pylint: disable=redefined-builtin
     pass
 
 
 # rule parser specific code
 
-class DateCommonValue(object):
+class DateCommonValue:
 
     allowed_items = [
         "hours", "monthdays", "weekdays", "yeardays", "months", "weeks",
@@ -639,7 +642,7 @@ class DateCommonValue(object):
 class DateSpecValue(DateCommonValue):
 
     KEYWORD = "date-spec"
-    part_re = re.compile("^(?P<since>\d+)(-(?P<until>\d+))?$")
+    part_re = re.compile(r"^(?P<since>\d+)(-(?P<until>\d+))?$")
     part_limits = {
         "hours" : (0, 23),
         "monthdays" : (0, 31),
@@ -677,7 +680,8 @@ class DateSpecValue(DateCommonValue):
                 return False
         return True
 
-    def valid_part_limits(self, name, value):
+    @staticmethod
+    def valid_part_limits(name, value):
         if name not in DateSpecValue.part_limits:
             return True
         limits = DateSpecValue.part_limits[name]
@@ -773,9 +777,11 @@ class RuleParser(Parser):
 
         for operator in RuleParser.simple_type_list:
             symbol_class = self.new_symbol_type(operator, 70)
-        self.symbol_table.get_symbol("integer").value_re = re.compile("^-?\d+$")
+        self.symbol_table.get_symbol("integer").value_re = re.compile(
+            r"^-?\d+$"
+        )
         self.symbol_table.get_symbol("version").value_re = re.compile(
-            "^\d+(\.\d+)*$"
+            r"^\d+(\.\d+)*$"
         )
         symbol_class = self.new_symbol_type_date(DateSpecValue, 70)
         symbol_class = self.new_symbol_type_date(DateDurationValue, 70)
@@ -828,7 +834,7 @@ class RuleParser(Parser):
 
 # cib builder
 
-class CibBuilder(object):
+class CibBuilder:
 
     def build(self, dom_element, syntactic_tree, rule_id=None):
         dom_rule = self.add_element(
@@ -892,7 +898,11 @@ class CibBuilder(object):
             if isinstance(child, SymbolType):
                 dom_expression.setAttribute(
                     "type",
-                    "number" if child.symbol_id == "integer" else child.symbol_id
+                    (
+                        "number"
+                        if child.symbol_id == "integer"
+                        else child.symbol_id
+                    )
                 )
                 child = child.children[0]
             dom_expression.setAttribute("value", child.value)
@@ -950,7 +960,8 @@ class CibBuilder(object):
             else:
                 self.build_rule(dom_element, subtree)
 
-    def add_element(self, parent, tag_name, element_id):
+    @staticmethod
+    def add_element(parent, tag_name, element_id):
         dom = parent.ownerDocument
         child = parent.appendChild(dom.createElement(tag_name))
         child.setAttribute("id", utils.find_unique_id(dom, element_id))
@@ -967,7 +978,7 @@ class InvalidSyntacticTree(CibBuilderException):
 
 # token preprocessing
 
-class TokenPreprocessor(object):
+class TokenPreprocessor:
 
     def run(self, token_list):
         return self.convert_legacy_date(
@@ -976,7 +987,8 @@ class TokenPreprocessor(object):
             )
         )
 
-    def separate_parenthesis(self, input_list):
+    @staticmethod
+    def separate_parenthesis(input_list):
         output_list = []
         for token in input_list:
             if not (
@@ -1002,7 +1014,8 @@ class TokenPreprocessor(object):
                     output_list.append("".join(part))
         return output_list
 
-    def join_date_common(self, input_list):
+    @staticmethod
+    def join_date_common(input_list):
         output_list = []
         token_parts = []
         in_datecommon = False
@@ -1034,7 +1047,8 @@ class TokenPreprocessor(object):
                 output_list.append(" ".join(token_parts[1:]))
         return output_list
 
-    def convert_legacy_date(self, input_list):
+    @staticmethod
+    def convert_legacy_date(input_list):
         output_list = []
         in_date = False
         date_start = ""
@@ -1069,4 +1083,3 @@ class TokenPreprocessor(object):
         if token_parts:
             output_list.extend(token_parts)
         return output_list
-
