@@ -1,17 +1,10 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import shutil
-
+from unittest import TestCase
 from lxml import etree
 
 from pcs.test.tools.cib import get_assert_pcs_effect_mixin
 from pcs.test.tools.misc import  get_test_resource as rc
 from pcs.test.tools.pcs_runner import PcsRunner
-from pcs.test.tools.pcs_unittest import TestCase
 
 def get_cib_resources(cib):
     return etree.tostring(etree.parse(cib).findall(".//resources")[0])
