@@ -1,14 +1,8 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from lxml import etree
 import shutil
+from unittest import TestCase
+from lxml import etree
 
 from pcs.test.tools.cib import get_assert_pcs_effect_mixin
-from pcs.test.tools.pcs_unittest import TestCase
 from pcs.test.tools.misc import get_test_resource as rc
 from pcs.test.tools.pcs_runner import PcsRunner
 
@@ -34,15 +28,15 @@ class ManageUnmanage(
                     />
                 </meta_attributes>
                 <operations>
-                    <op id="A-monitor-interval-10" interval="10"
-                        name="monitor" timeout="20"
+                    <op id="A-monitor-interval-10s" interval="10s"
+                        name="monitor" timeout="20s"
                     />
                 </operations>
             </primitive>
             <primitive class="ocf" id="B" provider="heartbeat" type="Dummy">
                 <operations>
-                    <op id="B-monitor-interval-10" interval="10"
-                        name="monitor" timeout="20"
+                    <op id="B-monitor-interval-10s" interval="10s"
+                        name="monitor" timeout="20s"
                     />
                 </operations>
             </primitive>
@@ -68,13 +62,13 @@ class ManageUnmanage(
             )
 
     def test_unmanage_none(self):
-        self.assert_pcs_fail_regardless_of_force(
+        self.assert_pcs_fail(
             "resource unmanage",
             "Error: You must specify resource(s) to unmanage\n"
         )
 
     def test_manage_none(self):
-        self.assert_pcs_fail_regardless_of_force(
+        self.assert_pcs_fail(
             "resource manage",
             "Error: You must specify resource(s) to manage\n"
         )
@@ -102,8 +96,8 @@ class ManageUnmanage(
                         />
                     </meta_attributes>
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20" enabled="false"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s" enabled="false"
                         />
                     </operations>
                 </primitive>
@@ -124,8 +118,8 @@ class ManageUnmanage(
                         />
                     </meta_attributes>
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
@@ -141,8 +135,8 @@ class ManageUnmanage(
             <resources>
                 <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
@@ -158,8 +152,8 @@ class ManageUnmanage(
             <resources>
                 <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20" enabled="false"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s" enabled="false"
                         />
                     </operations>
                 </primitive>
@@ -183,8 +177,8 @@ class ManageUnmanage(
                         />
                     </meta_attributes>
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
@@ -195,8 +189,8 @@ class ManageUnmanage(
                         />
                     </meta_attributes>
                     <operations>
-                        <op id="B-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="B-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
@@ -213,15 +207,15 @@ class ManageUnmanage(
             <resources>
                 <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
                 <primitive class="ocf" id="B" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="B-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="B-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
@@ -234,15 +228,15 @@ class ManageUnmanage(
 
         self.assert_pcs_fail(
             "resource unmanage A B",
-            "Error: bundle/clone/group/master/resource 'B' does not exist\n"
+            "Error: bundle/clone/group/resource 'B' does not exist\n"
         )
         self.assert_resources_xml_in_cib(
             """
             <resources>
                 <primitive class="ocf" id="A" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
@@ -255,7 +249,7 @@ class ManageUnmanage(
 
         self.assert_pcs_fail(
             "resource manage A B",
-            "Error: bundle/clone/group/master/resource 'B' does not exist\n"
+            "Error: bundle/clone/group/resource 'B' does not exist\n"
         )
         self.assert_resources_xml_in_cib(
             """
@@ -267,8 +261,8 @@ class ManageUnmanage(
                         />
                     </meta_attributes>
                     <operations>
-                        <op id="A-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="A-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                     </operations>
                 </primitive>
