@@ -1,16 +1,10 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import shutil
+from unittest import TestCase
 
 from pcs.test.cib_resource.common import get_cib_resources
 from pcs.test.tools.cib import get_assert_pcs_effect_mixin
 from pcs.test.tools.misc import  get_test_resource as rc
 from pcs.test.tools.pcs_runner import PcsRunner
-from pcs.test.tools.pcs_unittest import TestCase
 
 
 class OperationAdd(
@@ -61,8 +55,8 @@ class OperationAdd(
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="R-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="R-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                         <op id="R-start-interval-20s" interval="20s"
                             name="start"
@@ -73,6 +67,7 @@ class OperationAdd(
         )
 
     def test_add_with_OCF_CHECK_LEVEL(self):
+        # pylint: disable=invalid-name
         self.assert_effect(
             "resource op add R start interval=20s OCF_CHECK_LEVEL=1"
                 " description=test-description"
@@ -80,8 +75,8 @@ class OperationAdd(
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="R-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="R-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                         <op description="test-description" name="start"
                             id="R-start-interval-20s" interval="20s"
@@ -106,8 +101,8 @@ class OperationAdd(
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="R-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="R-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                         <op id="R-start-interval-20s" interval="20s"
                             name="start"
@@ -121,8 +116,8 @@ class OperationAdd(
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="R-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="R-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                         <op id="R-start-interval-20s" interval="20s"
                             name="start"
@@ -141,8 +136,8 @@ class OperationAdd(
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
-                        <op id="R-monitor-interval-10" interval="10"
-                            name="monitor" timeout="20"
+                        <op id="R-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
                         />
                         <op id="abcd" interval="0s" name="start" timeout="30" />
                     </operations>
@@ -162,3 +157,12 @@ class OperationAdd(
             "resource op add R start timeout=30 id=R",
             "Error: id 'R' is already in use, please specify another one\n"
         )
+
+    def test_unknown_option(self):
+        self.assert_pcs_fail(
+            "resource op add R start timeout=30 requires=quorum",
+            (
+                "Error: requires is not a valid op option (use --force to "
+                "override)\n"
+            )
+        )
