@@ -1,21 +1,6 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-import re
-
-from pcs import utils
 from pcs.test.cib_resource.common import ResourceTest
-from pcs.test.tools import pcs_unittest as unittest
 from pcs.test.cib_resource.stonith_common import need_load_xvm_fence_agent
 
-need_fence_scsi_providing_unfencing = unittest.skipUnless(
-    not utils.is_rhel6(),
-    "test requires system where stonith agent 'fence_scsi' provides unfencing"
-)
-
 class PlainStonith(ResourceTest):
     @need_load_xvm_fence_agent
     def test_simplest(self):
@@ -32,7 +17,6 @@ class PlainStonith(ResourceTest):
             </resources>"""
         )
 
-    @need_fence_scsi_providing_unfencing
     def test_base_with_agent_that_provides_unfencing(self):
         self.assert_effect(
             "stonith create S fence_scsi",
@@ -64,12 +48,12 @@ class PlainStonith(ResourceTest):
     def test_error_when_not_valid_agent(self):
         self.assert_pcs_fail(
             "stonith create S absent",
-            # pacemaker 1.1.18 changes -5 to Input/output error
-            stdout_regexp=re.compile("^"
+            stdout_full=(
                 "Error: Agent 'absent' is not installed or does not provide "
-                "valid metadata: Metadata query for stonith:absent failed: "
-                "(-5|Input/output error), use --force to override\n"
-                "$", re.MULTILINE
+                "valid metadata: Agent absent not found or does not support "
+                "meta-data: Invalid argument (22)\n"
+                "Metadata query for stonith:absent failed: Input/output error, "
+                "use --force to override\n"
             )
         )
 
@@ -85,12 +69,11 @@ class PlainStonith(ResourceTest):
                     </operations>
                 </primitive>
             </resources>""",
-            # pacemaker 1.1.18 changes -5 to Input/output error
-            output_regexp=re.compile("^"
+            output=(
                 "Warning: Agent 'absent' is not installed or does not provide "
-                    "valid metadata: Metadata query for stonith:absent failed: "
-                    "(-5|Input/output error)\n"
-                "$", re.MULTILINE
+                "valid metadata: Agent absent not found or does not support "
+                "meta-data: Invalid argument (22)\n"
+                "Metadata query for stonith:absent failed: Input/output error\n"
             )
         )
 
@@ -116,18 +99,18 @@ class PlainStonith(ResourceTest):
 
     def test_debug_and_verbose_allowed(self):
         self.assert_effect(
-            "stonith create S fence_apc login=l ipaddr=i verbose=v debug=d",
+            "stonith create S fence_apc ip=i username=u verbose=v debug=d",
             """<resources>
                 <primitive class="stonith" id="S" type="fence_apc">
                     <instance_attributes id="S-instance_attributes">
                         <nvpair id="S-instance_attributes-debug"
                             name="debug" value="d"
                         />
-                        <nvpair id="S-instance_attributes-ipaddr"
-                            name="ipaddr" value="i"
+                        <nvpair id="S-instance_attributes-ip"
+                            name="ip" value="i"
                         />
-                        <nvpair id="S-instance_attributes-login"
-                            name="login" value="l"
+                        <nvpair id="S-instance_attributes-username"
+                            name="username" value="u"
                         />
                         <nvpair id="S-instance_attributes-verbose"
                             name="verbose" value="v"
@@ -195,7 +178,6 @@ class WithMeta(ResourceTest):
             </resources>"""
         )
 
-    @need_fence_scsi_providing_unfencing
     def test_base_with_agent_that_provides_unfencing_with_meta_provides(self):
         self.assert_effect(
             "stonith create S fence_scsi meta provides=something",
