@@ -1,32 +1,24 @@
-
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
-
 import shutil
+import unittest
 
 from pcs.test.tools.misc import (
     get_test_resource as rc,
-    is_minimum_pacemaker_version,
+    skip_unless_pacemaker_version,
     outdent,
+    ParametrizedTestMetaClass,
 )
 from pcs.test.tools.assertions import AssertPcsMixin
 from pcs.test.tools.pcs_runner import PcsRunner
-from pcs.test.tools import pcs_unittest as unittest
 
 
-old_cib = rc("cib-empty.xml")
+old_cib = rc("cib-empty-2.0.xml")
 empty_cib = rc("cib-empty-2.5.xml")
 temp_cib = rc("temp-cib.xml")
 
-
-ALERTS_SUPPORTED = is_minimum_pacemaker_version(1, 1, 15)
-ALERTS_NOT_SUPPORTED_MSG = "Pacemaker version is too old (must be >= 1.1.15)" +\
-    " to test alerts"
-
+skip_unless_alerts_supported = skip_unless_pacemaker_version(
+    (1, 1, 15),
+    "alerts"
+)
 
 class PcsAlertTest(unittest.TestCase, AssertPcsMixin):
     def setUp(self):
@@ -34,7 +26,7 @@ class PcsAlertTest(unittest.TestCase, AssertPcsMixin):
         self.pcs_runner = PcsRunner(temp_cib)
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
+@skip_unless_alerts_supported
 class AlertCibUpgradeTest(unittest.TestCase, AssertPcsMixin):
     def setUp(self):
         shutil.copy(old_cib, temp_cib)
@@ -63,7 +55,7 @@ Alerts:
         )
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
+@skip_unless_alerts_supported
 class CreateAlertTest(PcsAlertTest):
     def test_create_multiple_without_id(self):
         self.assert_pcs_success(
@@ -151,7 +143,7 @@ Alerts:
         )
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
+@skip_unless_alerts_supported
 class UpdateAlertTest(PcsAlertTest):
     def test_update_everything(self):
         self.assert_pcs_success(
@@ -192,18 +184,26 @@ Alerts:
 
     def test_not_existing_alert(self):
         self.assert_pcs_fail(
-            "alert update alert1", "Error: Alert 'alert1' not found.\n"
+            "alert update alert1", "Error: alert 'alert1' does not exist\n"
         )
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
-class RemoveAlertTest(PcsAlertTest):
-    def test_not_existing_alert(self):
+class DeleteRemoveAlertTest(PcsAlertTest):
+    command = None
+
+    def _test_usage(self):
         self.assert_pcs_fail(
-            "alert remove alert1", "Error: Alert 'alert1' not found.\n"
+            f"alert {self.command}",
+            stdout_start=f"\nUsage: pcs alert <command>\n    {self.command} <"
         )
 
-    def test_one(self):
+    def _test_not_existing_alert(self):
+        self.assert_pcs_fail(
+            f"alert {self.command} alert1",
+            "Error: alert 'alert1' does not exist\n"
+        )
+
+    def _test_one(self):
         self.assert_pcs_success(
             "alert config", outdent("""\
                 Alerts:
@@ -220,7 +220,7 @@ class RemoveAlertTest(PcsAlertTest):
                 """
             )
         )
-        self.assert_pcs_success("alert remove alert1")
+        self.assert_pcs_success(f"alert {self.command} alert1")
         self.assert_pcs_success(
             "alert config", outdent("""\
                 Alerts:
@@ -229,7 +229,7 @@ class RemoveAlertTest(PcsAlertTest):
             )
         )
 
-    def test_multiple(self):
+    def _test_multiple(self):
         self.assert_pcs_success(
             "alert config", outdent("""\
                 Alerts:
@@ -250,7 +250,7 @@ class RemoveAlertTest(PcsAlertTest):
                 """
             )
         )
-        self.assert_pcs_success("alert remove alert1 alert3")
+        self.assert_pcs_success(f"alert {self.command} alert1 alert3")
         self.assert_pcs_success(
             "alert config", outdent("""\
                 Alerts:
@@ -260,7 +260,23 @@ class RemoveAlertTest(PcsAlertTest):
         )
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
+@skip_unless_alerts_supported
+class DeleteAlertTest(
+    DeleteRemoveAlertTest,
+    metaclass=ParametrizedTestMetaClass
+):
+    command = "delete"
+
+
+@skip_unless_alerts_supported
+class RemoveAlertTest(
+    DeleteRemoveAlertTest,
+    metaclass=ParametrizedTestMetaClass
+):
+    command = "remove"
+
+
+@skip_unless_alerts_supported
 class AddRecipientTest(PcsAlertTest):
     def test_success(self):
         self.assert_pcs_success("alert create path=test")
@@ -356,7 +372,7 @@ Alerts:
 
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
+@skip_unless_alerts_supported
 class UpdateRecipientAlert(PcsAlertTest):
     def test_success(self):
         self.assert_pcs_success("alert create path=test")
@@ -470,7 +486,7 @@ Alerts:
     def test_no_recipient(self):
         self.assert_pcs_fail(
             "alert recipient update rec description=desc",
-            "Error: Recipient 'rec' does not exist\n"
+            "Error: recipient 'rec' does not exist\n"
         )
 
     def test_empty_value(self):
@@ -484,9 +500,18 @@ Alerts:
         )
 
 
-@unittest.skipUnless(ALERTS_SUPPORTED, ALERTS_NOT_SUPPORTED_MSG)
-class RemoveRecipientTest(PcsAlertTest):
-    def test_one(self):
+class DeleteRemoveRecipientTest(PcsAlertTest):
+    command = None
+
+    def _test_usage(self):
+        self.assert_pcs_fail(
+            f"alert recipient {self.command}",
+            stdout_start=outdent(f"""
+                Usage: pcs alert <command>
+                    recipient {self.command} <""")
+        )
+
+    def _test_one(self):
         self.assert_pcs_success("alert create path=test")
         self.assert_pcs_success(
             "alert recipient add alert value=rec_value id=rec"
@@ -500,7 +525,7 @@ class RemoveRecipientTest(PcsAlertTest):
                 """
             )
         )
-        self.assert_pcs_success("alert recipient remove rec")
+        self.assert_pcs_success(f"alert recipient {self.command} rec")
         self.assert_pcs_success(
             "alert config", outdent("""\
                 Alerts:
@@ -509,7 +534,7 @@ class RemoveRecipientTest(PcsAlertTest):
             )
         )
 
-    def test_multiple(self):
+    def _test_multiple(self):
         self.assert_pcs_success("alert create path=test id=alert1")
         self.assert_pcs_success("alert create path=test id=alert2")
         self.assert_pcs_success(
@@ -538,7 +563,9 @@ class RemoveRecipientTest(PcsAlertTest):
                 """
             )
         )
-        self.assert_pcs_success("alert recipient remove rec1 rec2 rec4")
+        self.assert_pcs_success(
+            f"alert recipient {self.command} rec1 rec2 rec4"
+        )
         self.assert_pcs_success(
             "alert config", outdent("""\
                 Alerts:
@@ -550,15 +577,15 @@ class RemoveRecipientTest(PcsAlertTest):
             )
         )
 
-    def test_no_recipient(self):
+    def _test_no_recipient(self):
         self.assert_pcs_success("alert create path=test id=alert1")
         self.assert_pcs_success(
             "alert recipient add alert1 value=rec_value1 id=rec1"
         )
         self.assert_pcs_fail(
-            "alert recipient remove rec1 rec2 rec3", outdent("""\
-                Error: Recipient 'rec2' does not exist
-                Error: Recipient 'rec3' does not exist
+            f"alert recipient {self.command} rec1 rec2 rec3", outdent("""\
+                Error: recipient 'rec2' does not exist
+                Error: recipient 'rec3' does not exist
                 """
             )
         )
@@ -571,3 +598,17 @@ class RemoveRecipientTest(PcsAlertTest):
                 """
             )
         )
+
+
+class DeleteRecipientTest(
+    DeleteRemoveRecipientTest,
+    metaclass=ParametrizedTestMetaClass
+):
+    command = "delete"
+
+
+class RemoveRecipientTest(
+    DeleteRemoveRecipientTest,
+    metaclass=ParametrizedTestMetaClass
+):
+    command = "remove"
