@@ -1,14 +1,7 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from pcs.test.tools.pcs_unittest import TestCase
 import base64
 import logging
+from unittest import mock, TestCase
 
-from pcs.test.tools.pcs_unittest import mock
 from pcs.test.tools.assertions import (
     assert_raise_library_error,
     assert_report_item_list_equal,
@@ -36,86 +29,9 @@ class QdeviceTestCase(TestCase):
         self.lib_env = LibraryEnvironment(self.mock_logger, self.mock_reporter)
 
 
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: True)
-class QdeviceDisabledOnCmanTest(QdeviceTestCase):
-    def base_test(self, func):
-        assert_raise_library_error(
-            func,
-            (
-                severity.ERROR,
-                report_codes.CMAN_UNSUPPORTED_COMMAND,
-                {}
-            )
-        )
-
-    def test_setup(self):
-        self.base_test(
-            lambda: lib.qdevice_setup(self.lib_env, "bad model", False, False)
-        )
-
-    def test_destroy(self):
-        self.base_test(
-            lambda: lib.qdevice_destroy(self.lib_env, "bad model")
-        )
-
-    def test_status_text(self):
-        self.base_test(
-            lambda: lib.qdevice_status_text(self.lib_env, "bad model")
-        )
-
-    def test_enable(self):
-        self.base_test(
-            lambda: lib.qdevice_enable(self.lib_env, "bad model")
-        )
-
-    def test_disable(self):
-        self.base_test(
-            lambda: lib.qdevice_disable(self.lib_env, "bad model")
-        )
-
-    def test_start(self):
-        self.base_test(
-            lambda: lib.qdevice_start(self.lib_env, "bad model")
-        )
-
-    def test_stop(self):
-        self.base_test(
-            lambda: lib.qdevice_stop(self.lib_env, "bad model")
-        )
-
-    def test_kill(self):
-        self.base_test(
-            lambda: lib.qdevice_kill(self.lib_env, "bad model")
-        )
-
-    def test_qdevice_net_sign_certificate_request(self):
-        self.base_test(
-            lambda: lib.qdevice_net_sign_certificate_request(
-                self.lib_env,
-                "certificate request",
-                "cluster name"
-            )
-        )
-
-    def test_client_net_setup(self):
-        self.base_test(
-            lambda: lib.client_net_setup(self.lib_env, "ca certificate")
-        )
-
-    def test_client_net_import_certificate(self):
-        self.base_test(
-            lambda: lib.client_net_import_certificate(self.lib_env, "cert")
-        )
-
-    def test_client_net_destroy(self):
-        self.base_test(
-            lambda: lib.client_net_destroy(self.lib_env)
-        )
-
-
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 class QdeviceBadModelTest(QdeviceTestCase):
-    def base_test(self, func):
+    @staticmethod
+    def base_test(func):
         assert_raise_library_error(
             func,
             (
@@ -173,7 +89,6 @@ class QdeviceBadModelTest(QdeviceTestCase):
 @mock.patch("pcs.lib.external.start_service")
 @mock.patch("pcs.lib.external.enable_service")
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.qdevice_setup")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -348,7 +263,6 @@ class QdeviceNetSetupTest(QdeviceTestCase):
 @mock.patch("pcs.lib.external.stop_service")
 @mock.patch("pcs.lib.external.disable_service")
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.qdevice_destroy")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -608,7 +522,6 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
 
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.qdevice_status_cluster_text")
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.qdevice_status_generic_text")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -619,7 +532,7 @@ class TestQdeviceNetStatusTextTest(QdeviceTestCase):
         mock_status_generic.return_value = "generic status info\n"
         mock_status_cluster.return_value = "cluster status info\n"
 
-        self.assertEquals(
+        self.assertEqual(
             lib.qdevice_status_text(self.lib_env, "net"),
              "generic status info\ncluster status info\n"
         )
@@ -631,7 +544,7 @@ class TestQdeviceNetStatusTextTest(QdeviceTestCase):
         mock_status_generic.return_value = "generic status info\n"
         mock_status_cluster.return_value = "cluster status info\n"
 
-        self.assertEquals(
+        self.assertEqual(
             lib.qdevice_status_text(self.lib_env, "net", verbose=True),
              "generic status info\ncluster status info\n"
         )
@@ -643,13 +556,15 @@ class TestQdeviceNetStatusTextTest(QdeviceTestCase):
         mock_status_generic.return_value = "generic status info\n"
         mock_status_cluster.return_value = "cluster status info\n"
 
-        self.assertEquals(
+        self.assertEqual(
             lib.qdevice_status_text(self.lib_env, "net", cluster="name"),
              "generic status info\ncluster status info\n"
         )
 
         mock_status_generic.assert_called_once_with("mock_runner", False)
-        mock_status_cluster.assert_called_once_with("mock_runner", "name", False)
+        mock_status_cluster.assert_called_once_with(
+            "mock_runner", "name", False
+        )
 
     def test_error_generic_status(
         self, mock_status_generic, mock_status_cluster
@@ -681,7 +596,6 @@ class TestQdeviceNetStatusTextTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.external.enable_service")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -725,7 +639,6 @@ class QdeviceNetEnableTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.external.disable_service")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -775,7 +688,6 @@ class QdeviceNetDisableTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.external.start_service")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -839,7 +751,6 @@ class QdeviceNetStartTest(QdeviceTestCase):
 
 @mock.patch("pcs.lib.corosync.qdevice_net.qdevice_status_cluster_text")
 @mock.patch("pcs.lib.external.stop_service")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -959,7 +870,6 @@ class QdeviceNetStopTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.external.kill_services")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -1011,7 +921,6 @@ class QdeviceNetKillTest(QdeviceTestCase):
 @mock.patch(
     "pcs.lib.commands.qdevice.qdevice_net.qdevice_sign_certificate_request"
 )
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -1064,7 +973,6 @@ class QdeviceNetSignCertificateRequestTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.client_setup")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -1103,7 +1011,6 @@ class ClientNetSetupTest(QdeviceTestCase):
 @mock.patch(
     "pcs.lib.commands.qdevice.qdevice_net.client_import_certificate_and_key"
 )
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 @mock.patch.object(
     LibraryEnvironment,
     "cmd_runner",
@@ -1146,9 +1053,7 @@ class ClientNetImportCertificateTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.client_destroy")
-@mock.patch("pcs.lib.env.is_cman_cluster", lambda self: False)
 class ClientNetDestroyTest(QdeviceTestCase):
     def test_success(self, mock_qdevice_func):
         lib.client_net_destroy(self.lib_env)
         mock_qdevice_func.assert_called_once_with()
-
