@@ -1,17 +1,11 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
-from pcs.test.tools.misc import outdent
-from pcs.test.tools.pcs_unittest import TestCase, mock
+from unittest import mock, TestCase
 
 from pcs.test.tools.assertions import (
     assert_raise_library_error,
     assert_report_item_list_equal,
 )
 from pcs.test.tools.custom_mock import MockLibraryReportProcessor
+from pcs.test.tools.misc import outdent
 
 from pcs import settings
 from pcs.common import report_codes
@@ -30,6 +24,7 @@ class TestException(Exception):
 
 
 class EvenNumberOfNodesAndNoQdevice(TestCase):
+    # pylint: disable=protected-access
     def setUp(self):
         self.mock_corosync_conf = mock.MagicMock(spec_set=CorosyncConfigFacade)
 
@@ -388,6 +383,7 @@ class GetLocalSbdDeviceListTest(TestCase):
         self.assertEqual(0, mock_sbd_config.call_count)
 
     def test_config_read_error(self, mock_sbd_config, mock_config_exists):
+        # pylint: disable=no-self-use
         mock_config_exists.return_value = True
         node = "local node"
         error = "error string"
@@ -482,7 +478,9 @@ class GetDeviceSbdHeaderDumpTest(TestCase):
         device = "device"
         self.mock_runner.run.return_value = output, "", 1
         assert_raise_library_error(
-            lambda: lib_sbd.get_device_sbd_header_dump(self.mock_runner, device),
+            lambda: lib_sbd.get_device_sbd_header_dump(
+                self.mock_runner, device
+            ),
             (
                 Severities.ERROR,
                 report_codes.SBD_DEVICE_DUMP_ERROR,
@@ -529,3 +527,66 @@ class SetMessageTest(TestCase):
         self.mock_runner.run.assert_called_once_with([
             settings.sbd_binary, "-d", "device", "message", "node", "test"
         ])
+
+
+class ValidateDeviceDictTest(TestCase):
+    def test_all_ok(self):
+        device_dict = {
+            "node1": ["/dev1", "/dev2"],
+            "node2": ["/dev1"],
+        }
+        self.assertEqual([], lib_sbd.validate_nodes_devices(device_dict))
+
+    def test_some_not_ok(self):
+        # pylint: disable=no-self-use
+        too_many_devices = [
+            "/dev" + str(i) for i in range(settings.sbd_max_device_num)
+        ] + ["dev/sda2"]
+        device_dict = {
+            "node1": [],
+            "node2": too_many_devices,
+            "node3": ["/dev/vda"],
+            "node4": ["/dev/vda1", "../dev/sda2"],
+        }
+        assert_report_item_list_equal(
+            lib_sbd.validate_nodes_devices(device_dict),
+            [
+                (
+                    Severities.ERROR,
+                    report_codes.SBD_NO_DEVICE_FOR_NODE,
+                    {
+                        "node": "node1",
+                    }
+                ),
+                (
+                    Severities.ERROR,
+                    report_codes.SBD_TOO_MANY_DEVICES_FOR_NODE,
+                    {
+                        "node": "node2",
+                        "device_list": too_many_devices,
+                        "max_devices": settings.sbd_max_device_num,
+                    }
+                ),
+                (
+                    Severities.ERROR,
+                    report_codes.SBD_DEVICE_PATH_NOT_ABSOLUTE,
+                    {
+                        "node": "node2",
+                        "device": "dev/sda2",
+                    }
+                ),
+                (
+                    Severities.ERROR,
+                    report_codes.SBD_DEVICE_PATH_NOT_ABSOLUTE,
+                    {
+                        "node": "node4",
+                        "device": "../dev/sda2",
+                    }
+                ),
+            ]
+        )
+
+class GetAvailableWatchdogs(TestCase):
+    """
+    Tested in pcs.lib.commands.test.sbd.test_watchdog_list
+    """
