@@ -1,11 +1,6 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+# pylint: disable=too-many-lines
 import shutil
-from pcs.test.tools import pcs_unittest as unittest
+from unittest import TestCase
 import xml.dom.minidom
 
 from pcs import rule
@@ -13,10 +8,12 @@ from pcs.test.tools.assertions import ac
 from pcs.test.tools.misc import get_test_resource as rc
 from pcs.test.tools.pcs_runner import pcs
 
+# pylint: disable=invalid-name, line-too-long
+
 empty_cib = rc("cib-empty.xml")
 temp_cib = rc("temp-cib.xml")
 
-class DateValueTest(unittest.TestCase):
+class DateValueTest(TestCase):
 
     def testParse(self):
         for value, item in enumerate(rule.DateCommonValue.allowed_items, 1):
@@ -195,7 +192,7 @@ class DateValueTest(unittest.TestCase):
             self.assertEqual(syntax_error, str(e))
 
 
-class ParserTest(unittest.TestCase):
+class ParserTest(TestCase):
 
     def setUp(self):
         self.parser = rule.RuleParser()
@@ -779,7 +776,7 @@ class ParserTest(unittest.TestCase):
             self.assertEqual(syntax_error, str(e))
 
 
-class CibBuilderTest(unittest.TestCase):
+class CibBuilderTest(TestCase):
 
     def setUp(self):
         self.parser = rule.RuleParser()
@@ -1255,7 +1252,7 @@ class CibBuilderTest(unittest.TestCase):
         )
 
 
-class TokenPreprocessorTest(unittest.TestCase):
+class TokenPreprocessorTest(TestCase):
 
     def setUp(self):
         self.preprocessor = rule.TokenPreprocessor()
@@ -1299,7 +1296,7 @@ class TokenPreprocessorTest(unittest.TestCase):
             self.preprocessor.run([
                 "date-spec",
                 "hours=1", "monthdays=2", "weekdays=3", "yeardays=4",
-                "months=5","weeks=6", "years=7", "weekyears=8", "moon=9"
+                "months=5", "weeks=6", "years=7", "weekyears=8", "moon=9"
             ])
         )
         self.assertEqual(
@@ -1347,7 +1344,7 @@ class TokenPreprocessorTest(unittest.TestCase):
             self.preprocessor.run([
                 "duration",
                 "hours=1", "monthdays=2", "weekdays=3", "yeardays=4",
-                "months=5","weeks=6", "years=7", "weekyears=8", "moon=9"
+                "months=5", "weeks=6", "years=7", "weekyears=8", "moon=9"
             ])
         )
         self.assertEqual(
@@ -1597,7 +1594,7 @@ class TokenPreprocessorTest(unittest.TestCase):
             self.preprocessor.run(["(aA(", "(", "(bB)cC)"])
         )
 
-class ExportAsExpressionTest(unittest.TestCase):
+class ExportAsExpressionTest(TestCase):
 
     def test_success(self):
         self.assertXmlExport(
@@ -1641,7 +1638,8 @@ class ExportAsExpressionTest(unittest.TestCase):
             "(#uname eq string \"node3 4\" and foo gt version 1.2) or (date in_range 2014-07-26 to duration months=1 and date-spec hours=12-23 weekdays=1-5)"
         )
 
-    def assertXmlExport(self, rule_xml, export, export_normalized):
+    @staticmethod
+    def assertXmlExport(rule_xml, export, export_normalized):
         ac(
             export + "\n",
             rule.ExportAsExpression().get_string(
@@ -1658,7 +1656,7 @@ class ExportAsExpressionTest(unittest.TestCase):
         )
 
 
-class DomRuleAddTest(unittest.TestCase):
+class DomRuleAddTest(TestCase):
 
     def setUp(self):
         shutil.copy(empty_cib, temp_cib)
@@ -1927,7 +1925,8 @@ Location Constraints:
         )
         self.assertEqual(1, returnVal)
 
-    def assertExpressionXml(self, rule_expression, rule_xml):
+    @staticmethod
+    def assertExpressionXml(rule_expression, rule_xml):
         cib_dom = xml.dom.minidom.parse(empty_cib)
         constraints = cib_dom.getElementsByTagName("constraints")[0]
         constraint_el = constraints.appendChild(
