@@ -1,21 +1,16 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import shutil
 from textwrap import dedent
+from unittest import TestCase
 
 from pcs.test.tools.assertions import AssertPcsMixin
 from pcs.test.tools.misc import get_test_resource as rc
 from pcs.test.tools.pcs_runner import PcsRunner
-from pcs.test.tools.pcs_unittest import TestCase
 
 
 class StonithWarningTest(TestCase, AssertPcsMixin):
     empty_cib = rc("cib-empty.xml")
     temp_cib = rc("temp-cib.xml")
+    corosync_conf = rc("corosync.conf")
 
     def setUp(self):
         shutil.copy(self.empty_cib, self.temp_cib)
@@ -23,7 +18,7 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
 
     def fixture_stonith_action(self):
         self.assert_pcs_success(
-            "stonith create Sa fence_apc ipaddr=i login=l action=reboot --force",
+            "stonith create Sa fence_apc ip=i username=u action=reboot --force",
             "Warning: stonith option 'action' is deprecated and should not be"
                 " used, use pcmk_off_action, pcmk_reboot_action instead\n"
         )
@@ -46,11 +41,15 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
     def test_warning_stonith_action(self):
         self.fixture_stonith_action()
         self.fixture_resource()
+        self.pcs_runner.corosync_conf_opt = self.corosync_conf
         self.assert_pcs_success(
             "status",
             stdout_start=dedent("""\
                 Cluster name: test99
-                WARNING: following stonith devices have the 'action' option set, it is recommended to set 'pcmk_off_action', 'pcmk_reboot_action' instead: Sa
+
+                WARNINGS:
+                Following stonith devices have the 'action' option set, it is recommended to set 'pcmk_off_action', 'pcmk_reboot_action' instead: Sa
+
                 Stack: unknown
                 Current DC: NONE
             """)
@@ -59,11 +58,15 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
     def test_warning_stonith_method_cycle(self):
         self.fixture_stonith_cycle()
         self.fixture_resource()
+        self.pcs_runner.corosync_conf_opt = self.corosync_conf
         self.assert_pcs_success(
             "status",
             stdout_start=dedent("""\
                 Cluster name: test99
-                WARNING: following stonith devices have the 'method' option set to 'cycle' which is potentially dangerous, please consider using 'onoff': Sc
+
+                WARNINGS:
+                Following stonith devices have the 'method' option set to 'cycle' which is potentially dangerous, please consider using 'onoff': Sc
+
                 Stack: unknown
                 Current DC: NONE
             """)
@@ -73,23 +76,31 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
         self.fixture_stonith_action()
         self.fixture_stonith_cycle()
         self.fixture_resource()
+        self.pcs_runner.corosync_conf_opt = self.corosync_conf
         self.assert_pcs_success(
             "status",
             stdout_start=dedent("""\
                 Cluster name: test99
-                WARNING: following stonith devices have the 'action' option set, it is recommended to set 'pcmk_off_action', 'pcmk_reboot_action' instead: Sa
-                WARNING: following stonith devices have the 'method' option set to 'cycle' which is potentially dangerous, please consider using 'onoff': Sc
+
+                WARNINGS:
+                Following stonith devices have the 'action' option set, it is recommended to set 'pcmk_off_action', 'pcmk_reboot_action' instead: Sa
+                Following stonith devices have the 'method' option set to 'cycle' which is potentially dangerous, please consider using 'onoff': Sc
+
                 Stack: unknown
                 Current DC: NONE
             """)
         )
 
     def test_warn_when_no_stonith(self):
+        self.pcs_runner.corosync_conf_opt = self.corosync_conf
         self.assert_pcs_success(
             "status",
             stdout_start=dedent("""\
                 Cluster name: test99
-                WARNING: no stonith devices and stonith-enabled is not false
+
+                WARNINGS:
+                No stonith devices and stonith-enabled is not false
+
                 Stack: unknown
                 Current DC: NONE
             """)
@@ -97,6 +108,7 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
 
     def test_disabled_stonith_does_not_care_about_missing_devices(self):
         self.assert_pcs_success("property set stonith-enabled=false")
+        self.pcs_runner.corosync_conf_opt = self.corosync_conf
         self.assert_pcs_success(
             "status",
             stdout_start=dedent("""\
