@@ -1,41 +1,31 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
+# pylint: disable=too-many-lines
+from io import StringIO
 import sys
-from pcs.test.tools import pcs_unittest as unittest
+from time import sleep
+from unittest import mock, TestCase
 import xml.dom.minidom
 import xml.etree.cElementTree as ET
-from time import sleep
-
-try:
-    from cStringIO import StringIO
-except ImportError:
-    #python 3
-    from io import StringIO
 
 from pcs.test.tools.xml import dom_get_child_elements
 from pcs.test.tools.misc import get_test_resource as rc
-from pcs.test.tools.pcs_unittest import mock
 
 from pcs import utils
-from pcs.lib import reports
-from pcs.lib.errors import ReportItemSeverity
+
+# pylint: disable=too-many-public-methods, too-many-statements, line-too-long, invalid-name
 
 cib_with_nodes = rc("cib-empty-withnodes.xml")
 empty_cib = rc("cib-empty.xml")
 temp_cib = rc("temp-cib.xml")
 
-unittest.TestCase.maxDiff = None
+TestCase.maxDiff = None
 
-class UtilsTest(unittest.TestCase):
-
-    def get_cib_empty(self):
+class UtilsTest(TestCase):
+    @staticmethod
+    def get_cib_empty():
         return xml.dom.minidom.parse(empty_cib)
 
-    def get_cib_with_nodes_minidom(self):
+    @staticmethod
+    def get_cib_with_nodes_minidom():
         return xml.dom.minidom.parse(cib_with_nodes)
 
     def get_cib_resources(self):
@@ -580,7 +570,7 @@ class UtilsTest(unittest.TestCase):
         )
 
         message = (
-            "%s is a master/slave resource, you should use the master id: "
+            "%s is a clone resource, you should use the clone id: "
             "%s when adding constraints. Use --force to override."
         )
         self.assertEqual(
@@ -1069,7 +1059,7 @@ class UtilsTest(unittest.TestCase):
         )
 
     def test_get_operations_from_transitions(self):
-        transitions = utils.parse(rc("transitions01.xml"))
+        transitions = xml.dom.minidom.parse(rc("transitions01.xml"))
         self.assertEqual(
             [
                 {
@@ -1112,7 +1102,7 @@ class UtilsTest(unittest.TestCase):
             utils.get_operations_from_transitions(transitions)
         )
 
-        transitions = utils.parse(rc("transitions02.xml"))
+        transitions = xml.dom.minidom.parse(rc("transitions02.xml"))
         self.assertEqual(
             [
                 {
@@ -1394,8 +1384,7 @@ class UtilsTest(unittest.TestCase):
 
     def test_dom_get_node(self):
         cib = self.get_cib_with_nodes_minidom()
-        #assertIsNone is not supported in python 2.6
-        self.assertTrue(utils.dom_get_node(cib, "non-existing-node") is None)
+        self.assertIsNone(utils.dom_get_node(cib, "non-existing-node"))
         node = utils.dom_get_node(cib, "rh7-1")
         self.assertEqual(node.getAttribute("uname"), "rh7-1")
         self.assertEqual(node.getAttribute("id"), "1")
@@ -1687,14 +1676,14 @@ class UtilsTest(unittest.TestCase):
 
     def test_get_cluster_property_from_xml(self):
         el = ET.fromstring("""
-        <parameter name="default-resource-stickiness" unique="0">
+        <parameter name="an-integer-property" unique="0">
             <shortdesc lang="en"></shortdesc>
             <content type="integer" default="0"/>
             <longdesc lang="en"></longdesc>
         </parameter>
         """)
         expected = {
-            "name": "default-resource-stickiness",
+            "name": "an-integer-property",
             "shortdesc": "",
             "longdesc": "",
             "type": "integer",
@@ -1702,53 +1691,6 @@ class UtilsTest(unittest.TestCase):
         }
         self.assertEqual(expected, utils.get_cluster_property_from_xml(el))
 
-    def test_get_cluster_property_default(self):
-        definition = {
-            "default-resource-stickiness": {
-                "name": "default-resource-stickiness",
-                "shortdesc": "",
-                "longdesc": "",
-                "type": "integer",
-                "default": "0",
-                "source": "pengine"
-            },
-            "no-quorum-policy": {
-                "name": "no-quorum-policy",
-                "shortdesc": "What to do when the cluster does not have quorum",
-                "longdesc": "What to do when the cluster does not have quorum  Allowed values: stop, freeze, ignore, suicide",
-                "type": "enum",
-                "default": "stop",
-                "enum": ["stop", "freeze", "ignore", "suicide"],
-                "source": "pengine"
-            },
-            "enable-acl": {
-                "name": "enable-acl",
-                "shortdesc": "Enable CIB ACL",
-                "longdesc": "Enable CIB ACL",
-                "type": "boolean",
-                "default": "false",
-                "source": "cib"
-            }
-        }
-        self.assertEqual(
-            utils.get_cluster_property_default(
-                definition, "default-resource-stickiness"
-            ),
-            "0"
-        )
-        self.assertEqual(
-            utils.get_cluster_property_default(definition, "no-quorum-policy"),
-            "stop"
-        )
-        self.assertEqual(
-            utils.get_cluster_property_default(definition, "enable-acl"),
-            "false"
-        )
-        self.assertRaises(
-            utils.UnknownPropertyException,
-            utils.get_cluster_property_default, definition, "non-existing"
-        )
-
     def test_is_valid_cib_value_unknown_type(self):
         # should be always true
         self.assertTrue(utils.is_valid_cib_value("unknown", "test"))
@@ -1815,25 +1757,28 @@ class UtilsTest(unittest.TestCase):
 
     def test_validate_cluster_property(self):
         definition = {
-            "default-resource-stickiness": {
-                "name": "default-resource-stickiness",
-                "shortdesc": "",
-                "longdesc": "",
+            "property-int": {
+                "name": "property-int",
+                "shortdesc": "int description",
+                "longdesc": "long int description",
                 "type": "integer",
                 "default": "0",
-                "source": "pengine"
+                "source": "pacemaker-schedulerd"
             },
-            "no-quorum-policy": {
-                "name": "no-quorum-policy",
+            "property-enum": {
+                "name": "property-enum",
                 "shortdesc": "What to do when the cluster does not have quorum",
-                "longdesc": "What to do when the cluster does not have quorum  Allowed values: stop, freeze, ignore, suicide",
+                "longdesc": (
+                    "What to do when the cluster does not have quorum  "
+                    "Allowed values: stop, freeze, ignore, suicide"
+                ),
                 "type": "enum",
                 "default": "stop",
                 "enum": ["stop", "freeze", "ignore", "suicide"],
-                "source": "pengine"
+                "source": "pacemaker-schedulerd"
             },
-            "enable-acl": {
-                "name": "enable-acl",
+            "property-bool": {
+                "name": "property-bool",
                 "shortdesc": "Enable CIB ACL",
                 "longdesc": "Enable CIB ACL",
                 "type": "boolean",
@@ -1842,40 +1787,40 @@ class UtilsTest(unittest.TestCase):
             }
         }
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "default-resource-stickiness", "10"
+            definition, "property-int", "10"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "default-resource-stickiness", "-1"
+            definition, "property-int", "-1"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "no-quorum-policy", "freeze"
+            definition, "property-enum", "freeze"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "no-quorum-policy", "suicide"
+            definition, "property-enum", "suicide"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "enable-acl", "true"
+            definition, "property-bool", "true"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "enable-acl", "false"
+            definition, "property-bool", "false"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "enable-acl", "on"
+            definition, "property-bool", "on"
         ))
         self.assertTrue(utils.is_valid_cluster_property(
-            definition, "enable-acl", "OFF"
+            definition, "property-bool", "OFF"
         ))
         self.assertFalse(utils.is_valid_cluster_property(
-            definition, "default-resource-stickiness", "test"
+            definition, "property-int", "test"
         ))
         self.assertFalse(utils.is_valid_cluster_property(
-            definition, "default-resource-stickiness", "1.2"
+            definition, "property-int", "1.2"
         ))
         self.assertFalse(utils.is_valid_cluster_property(
-            definition, "no-quorum-policy", "invalid"
+            definition, "property-enum", "invalid"
         ))
         self.assertFalse(utils.is_valid_cluster_property(
-            definition, "enable-acl", "not"
+            definition, "property-bool", "not"
         ))
         self.assertRaises(
             utils.UnknownPropertyException,
@@ -1892,8 +1837,9 @@ class UtilsTest(unittest.TestCase):
             self.assertEqual(node.tagName, tag)
 
 
-class RunParallelTest(unittest.TestCase):
-    def fixture_create_worker(self, log, name, sleepSeconds=0):
+class RunParallelTest(TestCase):
+    @staticmethod
+    def fixture_create_worker(log, name, sleepSeconds=0):
         def worker():
             sleep(sleepSeconds)
             log.append(name)
@@ -1915,44 +1861,7 @@ class RunParallelTest(unittest.TestCase):
         )
 
 
-class PrepareNodeNamesTest(unittest.TestCase):
-    def test_return_original_when_is_in_pacemaker_nodes(self):
-        node = 'test'
-        self.assertEqual(
-            node,
-            utils.prepare_node_name(node, {1: node}, {})
-        )
-
-    def test_return_original_when_is_not_in_corosync_nodes(self):
-        node = 'test'
-        self.assertEqual(
-            node,
-            utils.prepare_node_name(node, {}, {})
-        )
-
-    def test_return_original_when_corosync_id_not_in_pacemaker(self):
-        node = 'test'
-        self.assertEqual(
-            node,
-            utils.prepare_node_name(node, {}, {1: node})
-        )
-
-    def test_return_modified_name(self):
-        node = 'test'
-        self.assertEqual(
-            'another (test)',
-            utils.prepare_node_name(node, {1: 'another'}, {1: node})
-        )
-
-    def test_return_modified_name_with_pm_null_case(self):
-        node = 'test'
-        self.assertEqual(
-            '*Unknown* (test)',
-            utils.prepare_node_name(node, {1: '(null)'}, {1: node})
-        )
-
-
-class NodeActionTaskTest(unittest.TestCase):
+class NodeActionTaskTest(TestCase):
     def test_can_run_action(self):
         def action(node, arg, kwarg=None):
             return (0, ':'.join([node, arg, kwarg]))
@@ -1967,796 +1876,7 @@ class NodeActionTaskTest(unittest.TestCase):
         self.assertEqual(['node|0|node:arg:kwarg'], report_list)
 
 
-class ParseCmanQuorumInfoTest(unittest.TestCase):
-    def test_error_empty_string(self):
-        parsed = utils.parse_cman_quorum_info("")
-        self.assertEqual(None, parsed)
-
-    def test_quorate_no_qdevice(self):
-        parsed = utils.parse_cman_quorum_info("""\
-Version: 6.2.0
-Config Version: 23
-Cluster Name: cluster66
-Cluster Id: 22265
-Cluster Member: Yes
-Cluster Generation: 3612
-Membership state: Cluster-Member
-Nodes: 3
-Expected votes: 3
-Total votes: 3
-Node votes: 1
-Quorum: 2 
-Active subsystems: 8
-Flags: 
-Ports Bound: 0 
-Node name: rh66-node2
-Node ID: 2
-Multicast addresses: 239.192.86.80
-Node addresses: 192.168.122.61
----Votes---
-1 M 3 rh66-node1
-2 M 2 rh66-node2
-3 M 1 rh66-node3
-""")
-        self.assertEqual(True, parsed["quorate"])
-        self.assertEqual(2, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh66-node1", "votes": 3, "local": False},
-                {"name": "rh66-node2", "votes": 2, "local": True},
-                {"name": "rh66-node3", "votes": 1, "local": False},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual([], parsed["qdevice_list"])
-
-    def test_no_quorate_no_qdevice(self):
-        parsed = utils.parse_cman_quorum_info("""\
-Version: 6.2.0
-Config Version: 23
-Cluster Name: cluster66
-Cluster Id: 22265
-Cluster Member: Yes
-Cluster Generation: 3612
-Membership state: Cluster-Member
-Nodes: 3
-Expected votes: 3
-Total votes: 3
-Node votes: 1
-Quorum: 2 Activity blocked
-Active subsystems: 8
-Flags: 
-Ports Bound: 0 
-Node name: rh66-node1
-Node ID: 1
-Multicast addresses: 239.192.86.80
-Node addresses: 192.168.122.61
----Votes---
-1 M 3 rh66-node1
-2 X 2 rh66-node2
-3 X 1 rh66-node3
-""")
-        self.assertEqual(False, parsed["quorate"])
-        self.assertEqual(2, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh66-node1", "votes": 3, "local": True},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual([], parsed["qdevice_list"])
-
-    def test_error_missing_quorum(self):
-        parsed = utils.parse_cman_quorum_info("""\
-Version: 6.2.0
-Config Version: 23
-Cluster Name: cluster66
-Cluster Id: 22265
-Cluster Member: Yes
-Cluster Generation: 3612
-Membership state: Cluster-Member
-Nodes: 3
-Expected votes: 3
-Total votes: 3
-Node votes: 1
-Quorum: 
-Active subsystems: 8
-Flags: 
-Ports Bound: 0 
-Node name: rh66-node2
-Node ID: 2
-Multicast addresses: 239.192.86.80
-Node addresses: 192.168.122.61
----Votes---
-1 M 3 rh66-node1
-2 M 2 rh66-node2
-3 M 1 rh66-node3
-""")
-        self.assertEqual(None, parsed)
-
-    def test_error_quorum_garbage(self):
-        parsed = utils.parse_cman_quorum_info("""\
-Version: 6.2.0
-Config Version: 23
-Cluster Name: cluster66
-Cluster Id: 22265
-Cluster Member: Yes
-Cluster Generation: 3612
-Membership state: Cluster-Member
-Nodes: 3
-Expected votes: 3
-Total votes: 3
-Node votes: 1
-Quorum: Foo
-Active subsystems: 8
-Flags: 
-Ports Bound: 0 
-Node name: rh66-node2
-Node ID: 2
-Multicast addresses: 239.192.86.80
-Node addresses: 192.168.122.61
----Votes---
-1 M 3 rh66-node1
-2 M 2 rh66-node2
-3 M 1 rh66-node3
-""")
-        self.assertEqual(None, parsed)
-
-    def test_error_node_votes_garbage(self):
-        parsed = utils.parse_cman_quorum_info("""\
-Version: 6.2.0
-Config Version: 23
-Cluster Name: cluster66
-Cluster Id: 22265
-Cluster Member: Yes
-Cluster Generation: 3612
-Membership state: Cluster-Member
-Nodes: 3
-Expected votes: 3
-Total votes: 3
-Node votes: 1
-Quorum: 4
-Active subsystems: 8
-Flags: 
-Ports Bound: 0 
-Node name: rh66-node2
-Node ID: 2
-Multicast addresses: 239.192.86.80
-Node addresses: 192.168.122.61
----Votes---
-1 M 3 rh66-node1
-2 M Foo rh66-node2
-3 M 1 rh66-node3
-""")
-        self.assertEqual(None, parsed)
-
-
-class ParseQuorumtoolOutputTest(unittest.TestCase):
-    def test_error_empty_string(self):
-        parsed = utils.parse_quorumtool_output("")
-        self.assertEqual(None, parsed)
-
-    def test_quorate_no_qdevice(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:28 2015
-Quorum provider:  corosync_votequorum
-Nodes:            3
-Node ID:          1
-Ring ID:          19860
-Quorate:          Yes
-
-Votequorum information
-----------------------
-Expected votes:   3
-Highest expected: 3
-Total votes:      3
-Quorum:           2
-Flags:            Quorate
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          3         NR rh70-node1
-         2          2         NR rh70-node2 (local)
-         3          1         NR rh70-node3
-""")
-        self.assertEqual(True, parsed["quorate"])
-        self.assertEqual(2, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh70-node1", "votes": 3, "local": False},
-                {"name": "rh70-node2", "votes": 2, "local": True},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual([], parsed["qdevice_list"])
-
-    def test_quorate_with_qdevice(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:28 2015
-Quorum provider:  corosync_votequorum
-Nodes:            3
-Node ID:          1
-Ring ID:          19860
-Quorate:          Yes
-
-Votequorum information
-----------------------
-Expected votes:   10
-Highest expected: 10
-Total votes:      10
-Quorum:           6
-Flags:            Quorate Qdevice
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          3    A,V,MNW rh70-node1
-         2          2    A,V,MNW rh70-node2 (local)
-         3          1    A,V,MNW rh70-node3
-         0          4            Qdevice
-""")
-        self.assertEqual(True, parsed["quorate"])
-        self.assertEqual(6, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh70-node1", "votes": 3, "local": False},
-                {"name": "rh70-node2", "votes": 2, "local": True},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual(
-            [
-                {"name": "Qdevice", "votes": 4, "local": False},
-            ],
-            parsed["qdevice_list"]
-        )
-
-    def test_quorate_with_qdevice_lost(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:28 2015
-Quorum provider:  corosync_votequorum
-Nodes:            3
-Node ID:          1
-Ring ID:          19860
-Quorate:          Yes
-
-Votequorum information
-----------------------
-Expected votes:   10
-Highest expected: 10
-Total votes:      6
-Quorum:           6
-Flags:            Quorate Qdevice
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          3   NA,V,MNW rh70-node1
-         2          2   NA,V,MNW rh70-node2 (local)
-         3          1   NA,V,MNW rh70-node3
-         0          0            Qdevice (votes 4)
-""")
-        self.assertEqual(True, parsed["quorate"])
-        self.assertEqual(6, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh70-node1", "votes": 3, "local": False},
-                {"name": "rh70-node2", "votes": 2, "local": True},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual(
-            [
-                {"name": "Qdevice", "votes": 0, "local": False},
-            ],
-            parsed["qdevice_list"]
-        )
-
-    def test_no_quorate_no_qdevice(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:35 2015
-Quorum provider:  corosync_votequorum
-Nodes:            1
-Node ID:          1
-Ring ID:          19868
-Quorate:          No
-
-Votequorum information
-----------------------
-Expected votes:   3
-Highest expected: 3
-Total votes:      1
-Quorum:           2 Activity blocked
-Flags:            
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-             1          1         NR rh70-node1 (local)
-""")
-        self.assertEqual(False, parsed["quorate"])
-        self.assertEqual(2, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh70-node1", "votes": 1, "local": True},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual([], parsed["qdevice_list"])
-
-    def test_no_quorate_with_qdevice(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:35 2015
-Quorum provider:  corosync_votequorum
-Nodes:            1
-Node ID:          1
-Ring ID:          19868
-Quorate:          No
-
-Votequorum information
-----------------------
-Expected votes:   3
-Highest expected: 3
-Total votes:      1
-Quorum:           2 Activity blocked
-Flags:            Qdevice
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          1         NR rh70-node1 (local)
-         0          0            Qdevice (votes 1)
-""")
-        self.assertEqual(False, parsed["quorate"])
-        self.assertEqual(2, parsed["quorum"])
-        self.assertEqual(
-            [
-                {"name": "rh70-node1", "votes": 1, "local": True},
-            ],
-            parsed["node_list"]
-        )
-        self.assertEqual(
-            [
-                {"name": "Qdevice", "votes": 0, "local": False},
-            ],
-            parsed["qdevice_list"]
-        )
-
-    def test_error_missing_quorum(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:28 2015
-Quorum provider:  corosync_votequorum
-Nodes:            3
-Node ID:          1
-Ring ID:          19860
-Quorate:          Yes
-
-Votequorum information
-----------------------
-Expected votes:   3
-Highest expected: 3
-Total votes:      3
-Quorum:           
-Flags:            Quorate
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          1         NR rh70-node1 (local)
-         2          1         NR rh70-node2
-         3          1         NR rh70-node3
-""")
-        self.assertEqual(None, parsed)
-
-    def test_error_quorum_garbage(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:28 2015
-Quorum provider:  corosync_votequorum
-Nodes:            3
-Node ID:          1
-Ring ID:          19860
-Quorate:          Yes
-
-Votequorum information
-----------------------
-Expected votes:   3
-Highest expected: 3
-Total votes:      3
-Quorum:           Foo
-Flags:            Quorate
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          1         NR rh70-node1 (local)
-         2          1         NR rh70-node2
-         3          1         NR rh70-node3
-""")
-        self.assertEqual(None, parsed)
-
-    def test_error_node_votes_garbage(self):
-        parsed = utils.parse_quorumtool_output("""\
-Quorum information
-------------------
-Date:             Fri Jan 16 13:03:28 2015
-Quorum provider:  corosync_votequorum
-Nodes:            3
-Node ID:          1
-Ring ID:          19860
-Quorate:          Yes
-
-Votequorum information
-----------------------
-Expected votes:   3
-Highest expected: 3
-Total votes:      3
-Quorum:           2
-Flags:            Quorate
-
-Membership information
-----------------------
-    Nodeid      Votes    Qdevice Name
-         1          1         NR rh70-node1 (local)
-         2        foo         NR rh70-node2
-         3          1         NR rh70-node3
-""")
-        self.assertEqual(None, parsed)
-
-
-class IsNodeStopCauseQuorumLossTest(unittest.TestCase):
-    def test_not_quorate(self):
-        quorum_info = {
-            "quorate": False,
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(quorum_info, True)
-        )
-
-    def test_local_node_not_in_list(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 1,
-            "node_list": [
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(quorum_info, True)
-        )
-
-    def test_local_node_alone_in_list(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 1,
-            "node_list": [
-                {"name": "rh70-node3", "votes": 1, "local": True},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            True,
-            utils.is_node_stop_cause_quorum_loss(quorum_info, True)
-        )
-
-    def test_local_node_still_quorate(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": False},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": True},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(quorum_info, True)
-        )
-
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": False},
-                {"name": "rh70-node2", "votes": 2, "local": True},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(quorum_info, True)
-        )
-
-    def test_local_node_quorum_loss(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            True,
-            utils.is_node_stop_cause_quorum_loss(quorum_info, True)
-        )
-
-    def test_one_node_still_quorate(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node3"]
-            )
-        )
-
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2"]
-            )
-        )
-
-    def test_one_node_quorum_loss(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            True,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node1"]
-            )
-        )
-
-    def test_more_nodes_still_quorate(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 4, "local": True},
-                {"name": "rh70-node2", "votes": 1, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2", "rh70-node3"]
-            )
-        )
-
-    def test_more_nodes_quorum_loss(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 3, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [],
-        }
-        self.assertEqual(
-            True,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2", "rh70-node3"]
-            )
-        )
-
-    def test_qdevice_still_quorate(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 3,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 1, "local": True},
-                {"name": "rh70-node2", "votes": 1, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [
-                {"name": "Qdevice", "votes": 1, "local": False},
-            ],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2"]
-            )
-        )
-
-    def test_qdevice_quorum_lost(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 3,
-            "node_list": [
-                {"name": "rh70-node1", "votes": 1, "local": True},
-                {"name": "rh70-node2", "votes": 1, "local": False},
-                {"name": "rh70-node3", "votes": 1, "local": False},
-            ],
-            "qdevice_list": [
-                {"name": "Qdevice", "votes": 1, "local": False},
-            ],
-        }
-        self.assertEqual(
-            True,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2", "rh70-node3"]
-            )
-        )
-
-    def test_qdevice_lost_still_quorate(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4, # expect qdevice votes == 1
-            "node_list": [
-                {"name": "rh70-node1", "votes": 2, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 2, "local": False},
-            ],
-            "qdevice_list": [
-                {"name": "Qdevice", "votes": 0, "local": False},
-            ],
-        }
-        self.assertEqual(
-            False,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2"]
-            )
-        )
-
-    def test_qdevice_lost_quorum_lost(self):
-        quorum_info = {
-            "quorate": True,
-            "quorum": 4, # expect qdevice votes == 1
-            "node_list": [
-                {"name": "rh70-node1", "votes": 2, "local": True},
-                {"name": "rh70-node2", "votes": 2, "local": False},
-                {"name": "rh70-node3", "votes": 2, "local": False},
-            ],
-            "qdevice_list": [
-                {"name": "Qdevice", "votes": 0, "local": False},
-            ],
-        }
-        self.assertEqual(
-            True,
-            utils.is_node_stop_cause_quorum_loss(
-                quorum_info, False, ["rh70-node2", "rh70-node3"]
-            )
-        )
-
-class CanAddNodeToCluster(unittest.TestCase):
-    def setUp(self):
-        patcher = mock.patch("pcs.utils.run_com_cmd")
-        self.addCleanup(patcher.stop)
-        self.check_can_add = patcher.start()
-
-    def assert_report_list_cause_result(self, report_list, can_add, message):
-        def side_effect(node_communicator, com_cmd):
-            com_cmd._report_items.extend(
-                report_list if isinstance(report_list, list) else [report_list]
-            )
-        self.check_can_add.side_effect = side_effect
-
-        result_can_add, result_message = utils.canAddNodeToCluster(
-            None, "node1"
-        )
-
-        self.assertEqual((result_can_add, result_message), (can_add, message))
-
-    def assert_report_list_cause_success(self, report_list):
-        self.assert_report_list_cause_result(
-            report_list,
-            can_add=True,
-            message="",
-        )
-
-    def assert_report_list_cause_fail(self, report_list, message):
-        self.assert_report_list_cause_result(
-            report_list,
-            can_add=False,
-            message=message,
-        )
-
-    def test_sucess_on_empty_reports(self):
-        self.assert_report_list_cause_success([])
-
-    def test_sucess_when_no_error_there(self):
-        self.assert_report_list_cause_success(
-            reports.node_communication_error_not_authorized(
-                "node1", "command", "reason",
-                severity=ReportItemSeverity.WARNING
-            )
-        )
-
-    def test_deals_with_no_authorized(self):
-        self.assert_report_list_cause_fail(
-            reports.node_communication_error_not_authorized(
-                "node1", "command", "reason"
-            ),
-            "unable to authenticate to node"
-        )
-
-    def test_deals_with_running_pacemaker_remote(self):
-        self.assert_report_list_cause_fail(
-            reports.cannot_add_node_is_running_service(
-                "node1",
-                "pacemaker_remote"
-            ),
-            "node is running pacemaker_remote"
-        )
-
-    def test_deals_with_node_is_in_cluster(self):
-        self.assert_report_list_cause_fail(
-            reports.cannot_add_node_is_in_cluster("node1"),
-            "node is already in a cluster"
-        )
-
-    def test_deals_with_invalid_response(self):
-        self.assert_report_list_cause_fail(
-            reports.invalid_response_format("node1"),
-            "response parsing error"
-        )
-
-    def test_deals_with_any_other_connection_error(self):
-        self.assert_report_list_cause_fail(
-            reports.node_communication_error_timed_out(
-                "node1", "command", "reason",
-            ),
-            "error checking node availability: reason"
-        )
-
-class TouchCibFile(unittest.TestCase):
+class TouchCibFile(TestCase):
     @mock.patch("pcs.utils.os.path.isfile", mock.Mock(return_value=False))
     @mock.patch(
         "pcs.utils.write_empty_cib",
@@ -2764,6 +1884,7 @@ class TouchCibFile(unittest.TestCase):
     )
     @mock.patch("pcs.utils.err")
     def test_exception_is_transformed_correctly(self, err):
+        # pylint: disable=no-self-use
         filename = "/fake/filename"
         utils.touch_cib_file(filename)
         err.assert_called_once_with(
