@@ -1,21 +1,34 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-    unicode_literals,
-)
-
+import difflib
 import doctest
+import re
 from lxml.doctestcompare import LXMLOutputChecker
 from lxml.etree import LXML_VERSION
-import re
+from pcs.lib.errors import ReportItemSeverity
 
 from pcs.lib.errors import LibraryError
-from pcs.test.tools.misc import prepare_diff
+
+# pylint: disable=invalid-name, no-self-use
 
 # cover python2 vs. python3 differences
 _re_object_type = type(re.compile(""))
 
+def prepare_diff(first, second):
+    """
+    Return a string containing a diff of first and second
+    """
+    return "".join(
+        difflib.Differ().compare(first.splitlines(1), second.splitlines(1))
+    )
+
+def ac(a, b):
+    """
+    Compare the actual output 'a' and an expected output 'b', print diff b a
+    """
+    if a != b:
+        raise AssertionError(
+            "strings not equal:\n{0}".format(prepare_diff(b, a))
+        )
+
 def start_tag_error_text():
     """lxml 3.7+ gives a longer 'start tag expected' error message,
     handle it here so multiple tests can just get the appropriate
@@ -30,7 +43,7 @@ def console_report(*lines):
     #after lines append last new line
     return "\n".join(lines + ("",))
 
-class AssertPcsMixin(object):
+class AssertPcsMixin:
     """Run pcs command and assert its result"""
 
     def assert_pcs_success_all(self, command_list):
@@ -97,7 +110,7 @@ class AssertPcsMixin(object):
             for stdout in (stdout_full, stdout_start, stdout_regexp)
             if stdout is not None
         ]
-        if len(specified_stdout) < 1:
+        if not specified_stdout:
             raise Exception(msg + ", none specified")
         elif len(specified_stdout) > 1:
             raise Exception(msg + ", both specified")
@@ -185,7 +198,7 @@ class AssertPcsMixin(object):
         return sorted(used_flags)
 
 
-class ExtendedAssertionsMixin(object):
+class ExtendedAssertionsMixin:
     def assert_raises(
         self, expected_exception, callable_obj, property_dict=None
     ):
@@ -229,6 +242,36 @@ def assert_xml_equal(expected_xml, got_xml, context_explanation=""):
             )
         )
 
+SEVERITY_SHORTCUTS = {
+    ReportItemSeverity.INFO: "I",
+    ReportItemSeverity.WARNING: "W",
+    ReportItemSeverity.ERROR: "E",
+    ReportItemSeverity.DEBUG: "D",
+}
+
+def _format_report_item_info(info):
+    return ", ".join([
+        "{0}:{1}".format(key, repr(value)) for key, value in info.items()
+    ])
+
+def _expected_report_item_format(report_item_expectation):
+    return "{0} {1} {{{2}}} ! {3}".format(
+        SEVERITY_SHORTCUTS.get(
+            report_item_expectation[0], report_item_expectation[0]
+        ),
+        report_item_expectation[1],
+        _format_report_item_info(report_item_expectation[2]),
+        report_item_expectation[3] if len(report_item_expectation) > 3 else None
+    )
+
+def _format_report_item(report_item):
+    return _expected_report_item_format((
+        report_item.severity,
+        report_item.code,
+        report_item.info,
+        report_item.forceable
+    ))
+
 def assert_report_item_equal(real_report_item, report_item_info):
     if not __report_item_equal(real_report_item, report_item_info):
         raise AssertionError(
@@ -240,59 +283,90 @@ def assert_report_item_equal(real_report_item, report_item_info):
                     report_item_info[2],
                     None if len(report_item_info) < 4 else report_item_info[3]
                 )),
-                repr((
-                    real_report_item.severity,
-                    real_report_item.code,
-                    real_report_item.info,
-                    real_report_item.forceable
-                ))
+                _format_report_item(real_report_item)
             )
         )
 
-def assert_report_item_list_equal(real_report_item_list, report_info_list):
-    for report_item in real_report_item_list:
-        report_info_list.remove(
-            __find_report_info(report_info_list, report_item)
+def _unexpected_report_given(
+    all_expected_report_info_list,
+    expected_report_info_list, real_report_item, real_report_item_list
+):
+    return AssertionError(
+        (
+            "\n  Unexpected real report given:"
+            "\n  =============================\n    {0}\n"
+            "\n  remaining expected reports ({1}) are:"
+            "\n  ------------------------------------\n    {2}\n"
+            "\n  all expected reports ({3}) are:"
+            "\n  ------------------------------\n    {4}\n"
+            "\n  all real reports ({5}):"
+            "\n  ---------------------\n    {6}"
         )
-    if report_info_list:
-        raise AssertionError(
-            "LibraryError is missing expected ReportItems ("
-            +str(len(report_info_list))+"):\n"
-            + "\n".join(map(repr, report_info_list))
+        .format(
+            _format_report_item(real_report_item),
+            len(expected_report_info_list),
+            "\n    ".join(map(
+                _expected_report_item_format, expected_report_info_list
+                )) if expected_report_info_list
+                else "No other report is expected!"
+            ,
+            len(all_expected_report_info_list),
+            "\n    ".join(map(
+                    _expected_report_item_format, all_expected_report_info_list
+                )) if all_expected_report_info_list
+                else "No report is expected!"
+            ,
+            len(real_report_item_list),
+            "\n    ".join(map(_format_report_item, real_report_item_list)),
+        )
+    )
 
-            + "\nreal ReportItems ("+str(len(real_report_item_list))+"):\n"
-            + "\n".join(map(repr, real_report_item_list))
+def assert_report_item_list_equal(
+    real_report_item_list, expected_report_info_list, hint=""
+):
+    all_expected_report_info_list = expected_report_info_list[:]
+    for real_report_item in real_report_item_list:
+        found_report_info = __find_report_info(
+            expected_report_info_list,
+            real_report_item
+        )
+        if found_report_info is None:
+            raise _unexpected_report_given(
+                all_expected_report_info_list,
+                expected_report_info_list,
+                real_report_item,
+                real_report_item_list,
+            )
+        expected_report_info_list.remove(found_report_info)
+    if expected_report_info_list:
+        def format_items(item_type, item_list):
+            caption = "{0} ReportItems({1})".format(item_type, len(item_list))
+            return "{0}\n{1}\n{2}".format(
+                caption,
+                "-"*len(caption),
+                "\n".join(map(repr, item_list))
+            )
+
+        raise AssertionError(
+            "\nExpected LibraryError is missing\n{0}\n\n{1}\n\n{2}".format(
+                "{0}\n".format(hint) if hint else "",
+                format_items("expected", expected_report_info_list),
+                format_items("real", real_report_item_list),
+            )
         )
 
 def assert_raise_library_error(callableObj, *report_info_list):
-    if not report_info_list:
-        raise AssertionError(
-            "Raising LibraryError expected, but no report item specified."
-            + " Please specify report items, that you expect in LibraryError"
-        )
     try:
         callableObj()
         raise AssertionError("LibraryError not raised")
     except LibraryError as e:
         assert_report_item_list_equal(e.args, list(report_info_list))
 
-def __find_report_info(report_info_list, report_item):
-    for report_info in report_info_list:
-        if __report_item_equal(report_item, report_info):
+def __find_report_info(expected_report_info_list, real_report_item):
+    for report_info in expected_report_info_list:
+        if __report_item_equal(real_report_item, report_info):
             return report_info
-    raise AssertionError(
-        "Unexpected report given: \n{0} \nexpected reports are: \n{1}"
-        .format(
-            repr((
-                report_item.severity,
-                report_item.code,
-                report_item.info,
-                report_item.forceable
-            )),
-            "\n".join(map(repr, report_info_list)) if report_info_list
-                else "  No report is expected!"
-        )
-    )
+    return None
 
 def __report_item_equal(real_report_item, report_item_info):
     return (
