@@ -1,10 +1,5 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
+from unittest import TestCase
 
-from pcs.test.tools.pcs_unittest import TestCase
 from pcs.test.tools.misc import outdent
 
 class OutdentTest(TestCase):
