@@ -1,9 +1,3 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 from pcs.test.tools.command_env.calls import Queue, CallListBuilder
 from pcs.test.tools.command_env.mock_runner import Runner as NewRunner
 
@@ -13,7 +7,7 @@ from pcs.test.tools.command_env.mock_runner import Runner as NewRunner
 
 
 
-class Runner(object):
+class Runner:
     def __init__(self):
         self.set_runs([])
 
