@@ -55,7 +55,7 @@ end
 
 def add_node_attr(auth_user, node, key, value)
   stdout, stderr, retval = run_cmd(
-    auth_user, PCS, "property", "set", "--node", node, key.to_s + '=' + value.to_s
+    auth_user, PCS, "node", "attribute", node, key.to_s + '=' + value.to_s
   )
   return retval
 end
@@ -75,7 +75,7 @@ def add_meta_attr(auth_user, resource, key, value)
 end
 
 def add_location_constraint(
-  auth_user, resource, node, score, force=false, autocorrect=true
+  auth_user, resource, node, score, force=false
 )
   if node == ""
     return "Bad node"
@@ -89,14 +89,13 @@ def add_location_constraint(
 
   cmd = [PCS, "constraint", "location", resource, "prefers", nodescore]
   cmd << '--force' if force
-  cmd << '--autocorrect' if autocorrect
 
   stdout, stderr, retval = run_cmd(auth_user, *cmd)
   return retval, stderr.join(' ')
 end
 
 def add_location_constraint_rule(
-  auth_user, resource, rule, score, force=false, autocorrect=true
+  auth_user, resource, rule, score, force=false
 )
   cmd = [PCS, "constraint", "location", resource, "rule"]
   if score != ''
@@ -108,14 +107,13 @@ def add_location_constraint_rule(
   end
   cmd.concat(rule.shellsplit())
   cmd << '--force' if force
-  cmd << '--autocorrect' if autocorrect
   stdout, stderr, retval = run_cmd(auth_user, *cmd)
   return retval, stderr.join(' ')
 end
 
 def add_order_constraint(
     auth_user, resourceA, resourceB, actionA, actionB, score, symmetrical=true,
-    force=false, autocorrect=true
+    force=false
 )
   sym = symmetrical ? "symmetrical" : "nonsymmetrical"
   if score != ""
@@ -126,42 +124,34 @@ def add_order_constraint(
     score, sym
   ]
   command << '--force' if force
-  command << '--autocorrect' if autocorrect
   stdout, stderr, retval = run_cmd(auth_user, *command)
   return retval, stderr.join(' ')
 end
 
-def add_order_set_constraint(
-  auth_user, resource_set_list, force=false, autocorrect=true
-)
+def add_order_set_constraint(auth_user, resource_set_list, force=false)
   command = [PCS, "constraint", "order"]
   resource_set_list.each { |resource_set|
     command << "set"
     command.concat(resource_set)
   }
   command << '--force' if force
-  command << '--autocorrect' if autocorrect
   stdout, stderr, retval = run_cmd(auth_user, *command)
   return retval, stderr.join(' ')
 end
 
-def add_colocation_set_constraint(
-  auth_user, resource_set_list, force=false, autocorrect=true
-)
+def add_colocation_set_constraint(auth_user, resource_set_list, force=false)
   command = [PCS, "constraint", "colocation"]
   resource_set_list.each { |resource_set|
     command << "set"
     command.concat(resource_set)
   }
   command << '--force' if force
-  command << '--autocorrect' if autocorrect
   stdout, stderr, retval = run_cmd(auth_user, *command)
   return retval, stderr.join(' ')
 end
 
 def add_ticket_constraint(
-    auth_user, ticket, resource_id, role, loss_policy,
-    force=false, autocorrect=true
+    auth_user, ticket, resource_id, role, loss_policy, force=false
 )
   command = [PCS, "constraint", "ticket", "add", ticket]
   if role
@@ -170,14 +160,12 @@ def add_ticket_constraint(
   command << resource_id
   command << 'loss-policy=' + loss_policy unless loss_policy.strip().empty?()
   command << '--force' if force
-  command << '--autocorrect' if autocorrect
   stdout, stderr, retval = run_cmd(auth_user, *command)
   return retval, stderr.join(' ')
 end
 
 def add_ticket_set_constraint(
-  auth_user, ticket, loss_policy, resource_set_list, force=false,
-  autocorrect=true
+  auth_user, ticket, loss_policy, resource_set_list, force=false
 )
   command = [PCS, 'constraint', 'ticket']
   resource_set_list.each { |resource_set|
@@ -193,7 +181,7 @@ def add_ticket_set_constraint(
 end
 
 def add_colocation_constraint(
-  auth_user, resourceA, resourceB, score, force=false, autocorrect=true
+  auth_user, resourceA, resourceB, score, force=false
 )
   if score == "" or score == nil
     score = "INFINITY"
@@ -202,7 +190,6 @@ def add_colocation_constraint(
     PCS, "constraint", "colocation", "add", resourceA, resourceB, score
   ]
   command << '--force' if force
-  command << '--autocorrect' if autocorrect
   stdout, stderr, retval = run_cmd(auth_user, *command)
   return retval, stderr.join(' ')
 end
@@ -347,20 +334,6 @@ def send_nodes_request_with_token(auth_user, nodes, request, post=false, data={}
   code = 0
   $logger.info("SNRWT: " + request)
 
-  # If we're removing nodes, we don't send this to one of the nodes we're
-  # removing, unless we're removing all nodes
-  if request == "/remove_nodes"
-    new_nodes = nodes.dup
-    data.each {|k,v|
-      if new_nodes.include? v
-        new_nodes.delete v
-      end
-    }
-    if new_nodes.length > 0
-      nodes = new_nodes
-    end
-  end
-
   for node in nodes
     $logger.info "SNRWT Node: #{node} Request: #{request}"
     code, out = send_request_with_token(
@@ -403,22 +376,35 @@ end
 
 def send_request_with_token(
   auth_user, node, request, post=false, data={}, remote=true, raw_data=nil,
-  timeout=nil, additional_tokens={}, additional_ports={}
+  timeout=nil, additional_known_hosts={}
 )
-  token_file_data = read_token_file()
-  token = additional_tokens[node] || token_file_data.tokens[node]
   $logger.info "SRWT Node: #{node} Request: #{request}"
-  if not token
+  target_info = additional_known_hosts[node] || get_known_hosts()[node] || nil
+  if not target_info
+    $logger.error "Unable to connect to node #{node}, the node is not known"
+    return 400,'{"notoken":true}'
+  end
+  target_token = target_info.token
+  if not target_token
     $logger.error "Unable to connect to node #{node}, no token available"
     return 400,'{"notoken":true}'
   end
-  port = additional_ports[node] || token_file_data.ports[node]
+  target_addr = target_info.first_dest()['addr']
+  target_port = target_info.first_dest()['port']
+  if not target_addr
+    $logger.error "Unable to connect to node #{node}, its address is not known"
+    return 400,'{"notoken":true}'
+  end
+  if not target_port
+    $logger.error "Unable to connect to node #{node}, its port is not known"
+    return 400,'{"notoken":true}'
+  end
   cookies_data = {
-    'token' => token,
+    'token' => target_token,
   }
   return send_request(
-    auth_user, node, request, post, data, remote, raw_data, timeout,
-    cookies_data, port
+    auth_user, target_addr, target_port, request, post, data, remote, raw_data,
+    timeout, cookies_data
   )
 end
 
@@ -460,8 +446,8 @@ def _transform_data(data)
 end
 
 def send_request(
-  auth_user, node, request, post=false, data={}, remote=true, raw_data=nil,
-  timeout=nil, cookies_data=nil, port=nil
+  auth_user, node, port, request, post=false, data={}, remote=true,
+  raw_data=nil, timeout=nil, cookies_data=nil
 )
   cookies_data = {} if not cookies_data
   if request.start_with?("/")
@@ -473,8 +459,6 @@ def send_request(
     node6 = "[#{node}]"
   end
 
-  port ||= PCSD_DEFAULT_PORT
-
   if remote
     url = "https://#{node6}:#{port}/remote/#{request}"
   else
@@ -502,6 +486,8 @@ def send_request(
   rescue
   end
 
+  $logger.info "Connecting to: #{url}"
+
   req = Ethon::Easy.new()
   req.set_attributes({
     :url => url,
@@ -513,6 +499,7 @@ def send_request(
     :httpget => (post ? 0 : 1),
     :nosignal => 1, # required for multi-threading
   })
+  req.compose_header('Expect', '')
   return_code = req.perform
   if return_code == :ok
     return req.response_code, req.response_body
@@ -540,69 +527,6 @@ def is_proxy_set(env_var_hash)
   return false
 end
 
-def add_node(
-  auth_user, new_nodename, all=false, auto_start=true, watchdog=nil,
-  device_list=nil
-)
-  if all
-    command = [PCS, "cluster", "node", "add", new_nodename]
-    if watchdog and not watchdog.strip.empty?
-      command << "--watchdog=#{watchdog.strip}"
-    end
-    if device_list
-      device_list.each { |device|
-        if device and not device.strip.empty?
-          command << "--device=#{device.strip}"
-        end
-      }
-    end
-    if auto_start
-      command << '--start'
-      command << '--enable'
-    end
-    out, stderror, retval = run_cmd(auth_user, *command)
-  else
-    out, stderror, retval = run_cmd(
-      auth_user, PCS, "cluster", "localnode", "add", new_nodename
-    )
-  end
-  $logger.info("Adding #{new_nodename} to pcs_settings.conf")
-  corosync_nodes = get_corosync_nodes()
-  pcs_config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
-  pcs_config.update_cluster($cluster_name, corosync_nodes)
-  sync_config = Cfgsync::PcsdSettings.from_text(pcs_config.text())
-  # on version conflict just go on, config will be corrected eventually
-  # by displaying the cluster in the web UI
-  Cfgsync::save_sync_new_version(
-    sync_config, corosync_nodes, $cluster_name, true
-  )
-  return retval, out.join("\n") + stderror.join("\n")
-end
-
-def remove_node(auth_user, new_nodename, all=false)
-  if all
-    # we check for a quorum loss warning in remote_remove_nodes
-    out, stderror, retval = run_cmd(
-      auth_user, PCS, "cluster", "node", "remove", new_nodename, "--force"
-    )
-  else
-    out, stderror, retval = run_cmd(
-      auth_user, PCS, "cluster", "localnode", "remove", new_nodename
-    )
-  end
-  $logger.info("Removing #{new_nodename} from pcs_settings.conf")
-  corosync_nodes = get_corosync_nodes()
-  pcs_config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
-  pcs_config.update_cluster($cluster_name, corosync_nodes)
-  sync_config = Cfgsync::PcsdSettings.from_text(pcs_config.text())
-  # on version conflict just go on, config will be corrected eventually
-  # by displaying the cluster in the web UI
-  Cfgsync::save_sync_new_version(
-    sync_config, corosync_nodes, $cluster_name, true
-  )
-  return retval, out + stderror
-end
-
 def get_current_node_name()
   stdout, stderror, retval = run_cmd(
     PCSAuth.getSuperuserAuth(), CRM_NODE, "-n"
@@ -614,27 +538,6 @@ def get_current_node_name()
 end
 
 def get_local_node_id()
-  if ISRHEL6
-    out, errout, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(), COROSYNC_CMAPCTL, "cluster.cman"
-    )
-    if retval != 0
-      return ""
-    end
-    match = /cluster\.nodename=(.*)/.match(out.join("\n"))
-    if not match
-      return ""
-    end
-    local_node_name = match[1]
-    out, errout, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(),
-      CMAN_TOOL, "nodes", "-F", "id", "-n", local_node_name
-    )
-    if retval != 0
-      return ""
-    end
-    return out[0].strip()
-  end
   out, errout, retval = run_cmd(
     PCSAuth.getSuperuserAuth(),
     COROSYNC_CMAPCTL, "-g", "runtime.votequorum.this_node_id"
@@ -646,24 +549,21 @@ def get_local_node_id()
   end
 end
 
+def has_corosync_conf()
+  return Cfgsync::cluster_cfg_class.exist?()
+end
+
 def get_corosync_conf()
   return Cfgsync::cluster_cfg_class.from_file().text()
 end
 
-def get_corosync_nodes()
-  stdout, stderror, retval = run_cmd(
-    PCSAuth.getSuperuserAuth(), PCS, "status", "nodes", "corosync"
-  )
-  if retval != 0
-    return []
+def get_corosync_nodes_names()
+  if has_corosync_conf()
+    return CorosyncConf::get_corosync_nodes_names(
+      CorosyncConf::parse_string(get_corosync_conf())
+    )
   end
-
-  stdout.each {|x| x.strip!}
-  corosync_online = stdout[1].sub(/^.*Online:/,"").strip
-  corosync_offline = stdout[2].sub(/^.*Offline:/,"").strip
-  corosync_nodes = (corosync_online.split(/ /)) + (corosync_offline.split(/ /))
-
-  return corosync_nodes
+  return []
 end
 
 def get_nodes()
@@ -724,46 +624,6 @@ def get_nodes_status()
   }
 end
 
-def need_ring1_address?()
-  out, errout, retval = run_cmd(PCSAuth.getSuperuserAuth(), COROSYNC_CMAPCTL)
-  if retval != 0
-    return false
-  else
-    udpu_transport = false
-    rrp = false
-    out.each { |line|
-      # support both corosync-objctl and corosync-cmapctl format
-      if /^\s*totem\.transport(\s+.*)?=\s*udpu$/.match(line)
-        udpu_transport = true
-      elsif /^\s*totem\.rrp_mode(\s+.*)?=\s*(passive|active)$/.match(line)
-        rrp = true
-      end
-    }
-    # on rhel6 ring1 address is required regardless of transport
-    # it has to be added to cluster.conf in order to set up ring1
-    # in corosync by cman
-    return ((ISRHEL6 and rrp) or (rrp and udpu_transport))
-  end
-end
-
-def is_cman_with_udpu_transport?
-  if not ISRHEL6
-    return false
-  end
-  begin
-    cluster_conf = Cfgsync::ClusterConf.from_file().text()
-    conf_dom = REXML::Document.new(cluster_conf)
-    conf_dom.elements.each("cluster/cman") { |elem|
-      if elem.attributes["transport"].downcase == "udpu"
-        return true
-      end
-    }
-  rescue
-    return false
-  end
-  return false
-end
-
 def get_resource_agents_avail(auth_user, params)
   code, result = send_cluster_request_with_token(
     auth_user, params[:cluster], 'get_avail_resource_agents'
@@ -799,53 +659,20 @@ def get_stonith_agents_avail(auth_user, params)
 end
 
 def get_cluster_name()
-  if ISRHEL6
-    stdout, stderror, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(), COROSYNC_CMAPCTL, "cluster"
+  if has_corosync_conf()
+    corosync_conf = CorosyncConf::parse_string(
+      Cfgsync::CorosyncConf.from_file().text()
     )
-    if retval == 0
-      stdout.each { |line|
-        match = /^cluster\.name=(.*)$/.match(line)
-        return match[1] if match
+    # mimic corosync behavior - the last cluster_name found is used
+    cluster_name = ''
+    corosync_conf.sections('totem').each { |totem|
+      totem.attributes('cluster_name').each { |attrib|
+        cluster_name = attrib[1]
       }
-    end
-    begin
-      cluster_conf = Cfgsync::ClusterConf.from_file().text()
-    rescue
-      return ''
-    end
-    conf_dom = REXML::Document.new(cluster_conf)
-    if conf_dom.root and conf_dom.root.name == 'cluster'
-      return conf_dom.root.attributes['name']
-    end
-    return ''
-  end
-
-  stdout, stderror, retval = run_cmd(
-    PCSAuth.getSuperuserAuth(), COROSYNC_CMAPCTL, "totem.cluster_name"
-  )
-  if retval != 0 and not ISRHEL6
-    # Cluster probably isn't running, try to get cluster name from
-    # corosync.conf
-    begin
-      corosync_conf = CorosyncConf::parse_string(
-        Cfgsync::CorosyncConf.from_file().text()
-      )
-      # mimic corosync behavior - the last cluster_name found is used
-      cluster_name = nil
-      corosync_conf.sections('totem').each { |totem|
-        totem.attributes('cluster_name').each { |attrib|
-          cluster_name = attrib[1]
-        }
-      }
-      return cluster_name if cluster_name
-    rescue
-      return ''
-    end
-    return ""
-  else
-    return stdout.join().gsub(/.*= /,"").strip
+    }
+    return cluster_name
   end
+  return ''
 end
 
 def get_node_attributes(auth_user, cib_dom=nil)
@@ -956,14 +783,18 @@ def get_acls(auth_user, cib_dom=nil)
   return acls
 end
 
-def enable_cluster(auth_user)
-  stdout, stderror, retval = run_cmd(auth_user, PCS, "cluster", "enable")
+def enable_cluster(auth_user, all)
+  cmd = [PCS, "cluster", "enable"]
+  cmd << '--all' if all == '1'
+  stdout, stderror, retval = run_cmd(auth_user, *cmd)
   return false if retval != 0
   return true
 end
 
-def disable_cluster(auth_user)
-  stdout, stderror, retval = run_cmd(auth_user, PCS, "cluster", "disable")
+def disable_cluster(auth_user, all)
+  cmd = [PCS, "cluster", "disable"]
+  cmd << '--all' if all == '1'
+  stdout, stderror, retval = run_cmd(auth_user, *cmd)
   return false if retval != 0
   return true
 end
@@ -1010,23 +841,6 @@ def get_pacemaker_version()
   return nil
 end
 
-def get_cman_version()
-  begin
-    stdout, stderror, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(), CMAN_TOOL, "-V"
-    )
-  rescue
-    stdout = []
-  end
-  if retval == 0
-    match = /(\d+)\.(\d+)\.(\d+)/.match(stdout.join())
-    if match
-      return match[1..3].collect { | x | x.to_i }
-    end
-  end
-  return nil
-end
-
 def get_rhel_version()
   if File.exists?('/etc/system-release')
     release = File.open('/etc/system-release').read
@@ -1038,21 +852,6 @@ def get_rhel_version()
   return nil
 end
 
-def pcsd_restart()
-  # restart in a separate process so we can send a response to the restart
-  # request
-  fork {
-    # let us send the response to the restart request
-    # we need little bit more time to finish some things when setting up cluster
-    sleep(10)
-    if ISSYSTEMCTL
-      exec("systemctl", "restart", "pcsd")
-    else
-      exec("service", "pcsd", "restart")
-    end
-  }
-end
-
 def get_pcsd_version()
   return PCS_VERSION.split(".").collect { | x | x.to_i }
 end
@@ -1111,104 +910,35 @@ def is_cib_true(var)
   return ['true', 'on', 'yes', 'y', '1'].include?(var.downcase)
 end
 
-def read_token_file()
-  return PCSTokens.new(Cfgsync::PcsdTokens.from_file().text())
+def get_known_hosts()
+  return CfgKnownHosts.new(
+    Cfgsync::PcsdKnownHosts.from_file().text()
+  ).known_hosts
 end
 
-def read_tokens()
-  return read_token_file().tokens
-end
-
-def get_nodes_ports()
-  return read_token_file().ports
-end
-
-def write_tokens(tokens)
-  begin
-    cfg = read_token_file()
-    cfg.tokens = tokens
-    Cfgsync::PcsdTokens.from_text(cfg.text()).save()
-  rescue
-    return false
-  end
-  return true
-end
-
-def get_tokens_of_nodes(nodes)
-  tokens = {}
-  read_tokens.each { |node, token|
-    if nodes.include? node
-      tokens[node] = token
-    end
-  }
-  return tokens
-end
-
-def get_node_token(node)
-  tokens = read_tokens()
-  if tokens.include? node
-    return tokens[node]
-  else
-    return nil
-  end
-end
-
-def get_token_node_list()
-  return read_tokens.keys
-end
-
-def add_prefix_to_keys(hash, prefix)
-  new_hash = {}
-  hash.each { |k,v|
-    new_hash["#{prefix}#{k}"] = v
-  }
-  return new_hash
-end
-
-def check_gui_status_of_nodes(auth_user, nodes, check_mutuality=false, timeout=10, ports=nil)
-  options = {}
-  options[:check_auth_only] = '' if not check_mutuality
+def is_auth_against_nodes(auth_user, node_names, timeout=10)
   threads = []
   not_authorized_nodes = []
   online_nodes = []
   offline_nodes = []
-  token_file = read_token_file()
 
-  nodes = nodes.uniq.sort
-  nodes.each { |node|
-    if ports and ports[node] != token_file.ports[node]
-      not_authorized_nodes << node
-      next
-    end
+  node_names.uniq.each { |node_name|
     threads << Thread.new {
       code, response = send_request_with_token(
-        auth_user, node, 'check_auth', false, options, true, nil, timeout
+        auth_user, node_name, 'check_auth', false, {}, true, nil, timeout
       )
       if code == 200
-        if check_mutuality
-          begin
-            parsed_response = JSON.parse(response)
-            if parsed_response['node_list'] and parsed_response['node_list'].uniq.sort == nodes
-              online_nodes << node
-            else
-              not_authorized_nodes << node
-            end
-          rescue
-            not_authorized_nodes << node
-          end
-        else
-          online_nodes << node
-        end
+        online_nodes << node_name
       else
         begin
           parsed_response = JSON.parse(response)
           if parsed_response['notauthorized'] or parsed_response['notoken']
-            not_authorized_nodes << node
+            not_authorized_nodes << node_name
           else
-            offline_nodes << node
+            offline_nodes << node_name
           end
         rescue JSON::ParserError
-          not_authorized_nodes << node
+          not_authorized_nodes << node_name
         end
       end
     }
@@ -1217,121 +947,139 @@ def check_gui_status_of_nodes(auth_user, nodes, check_mutuality=false, timeout=1
   return online_nodes, offline_nodes, not_authorized_nodes
 end
 
-def pcs_auth(auth_user, nodes, username, password, force=false, local=true)
-  # nodes is hash, (nodename -> port)
-  # if no sync is needed, do not report a sync error
-  sync_successful = true
-  sync_failed_nodes = []
-  sync_responses = {}
-  # check for already authorized nodes
-  if not force
-    online, offline, not_authenticated = check_gui_status_of_nodes(
-      auth_user, nodes.keys, true, 10, nodes
-    )
-    if not_authenticated.length < 1
-      result = {}
-      online.each { |node| result[node] = {'status' => 'already_authorized'} }
-      offline.each { |node| result[node] = {'status' => 'noresponse'} }
-      return result, sync_successful, sync_failed_nodes, sync_responses
-    end
-  end
-
-  # authorize the nodes locally (i.e. not bidirectionally)
-  auth_responses = run_auth_requests(
-    auth_user, nodes, nodes, username, password, force, true
-  )
-
-  # get the tokens and sync them within the local cluster
-  new_tokens = {}
-  ports = {}
-  auth_responses.each { |node, response|
-    if 'ok' == response['status']
-      new_tokens[node] = response['token']
-      ports[node] = nodes[node] || PCSD_DEFAULT_PORT
-    end
-  }
-  if not new_tokens.empty?
-    tokens_cfg = Cfgsync::PcsdTokens.from_file()
-    # only tokens used in pcsd-to-pcsd communication can and need to be synced
-    # those are accessible only when running under root account
-    if Process.uid != 0
-      # other tokens just need to be stored localy for the user
-      sync_successful, sync_responses = Cfgsync::save_sync_new_tokens(
-        tokens_cfg, new_tokens, [], nil, ports
-      )
-      return auth_responses, sync_successful, sync_failed_nodes, sync_responses
-    end
-    cluster_nodes = get_corosync_nodes()
-    sync_successful, sync_responses = Cfgsync::save_sync_new_tokens(
-      tokens_cfg, new_tokens, cluster_nodes, $cluster_name, ports
-    )
-    sync_not_supported_nodes = []
-    sync_responses.each { |node, response|
-      if 'not_supported' == response['status']
-        sync_not_supported_nodes << node
-      elsif response['status'] != 'ok'
-        sync_failed_nodes << node
-      else
-        node_result = response['result'][Cfgsync::PcsdTokens.name]
-        if 'not_supported' == node_result
-          sync_not_supported_nodes << node
-        elsif not ['accepted', 'rejected'].include?(node_result)
-          sync_failed_nodes << node
-        end
-      end
-    }
-    if not local
-      # authorize nodes outside of the local cluster and nodes not supporting
-      # the tokens file synchronization in the other direction
-      nodes_to_auth = {}
-      nodes.each { |node, port|
-        nodes_to_auth[node] = port if sync_not_supported_nodes.include?(node)
-        nodes_to_auth[node] = port if not cluster_nodes.include?(node)
-      }
-      auth_responses2 = run_auth_requests(
-        auth_user, nodes_to_auth, nodes, username, password, force, false
-      )
-      auth_responses.update(auth_responses2)
-    end
-  end
-
-  return auth_responses, sync_successful, sync_failed_nodes, sync_responses
-end
-
-def run_auth_requests(auth_user, nodes_to_send, nodes_to_auth, username, password, force=false, local=true)
-  data = {}
-  index = 0
-  nodes_to_auth.each { |node, port|
-    data["node-#{index}"] = node
-    data["port-#{node}"] = port if port
-    index += 1
-  }
-  data['username'] = username
-  data['password'] = password
-  data['bidirectional'] = 1 if not local
-  data['force'] = 1 if force
+def pcs_auth(auth_user, nodes)
+  # nodes is a hash of hashes:
+  # {
+  #   'node name' => {
+  #     'username' => a username used for auth
+  #     'password' => a password used for auth
+  #     'dest_list' => [ # currently only the first item is used
+  #       {'addr' => addr, 'port' => port} # how to connect to a node
+  #     ]
+  #   }
+  # }
 
+  # authorize against the nodes
   auth_responses = {}
   threads = []
-  nodes_to_send.each { |node, port|
+  nodes.each { |node_name, node_data|
     threads << Thread.new {
-      code, response = send_request(
-        auth_user, node, 'auth', true, data, true, nil, nil, nil, port
-      )
-      if 200 == code
-        token = response.strip
-        if '' == token
-          auth_responses[node] = {'status' => 'bad_password'}
+      begin
+        addr = node_data.fetch('dest_list').fetch(0).fetch('addr')
+        port = node_data.fetch('dest_list').fetch(0).fetch('port')
+        request_data = {
+          :username => node_data.fetch('username'),
+          :password => node_data.fetch('password'),
+        }
+        code, response = send_request(
+          auth_user, addr, port, 'auth', true, request_data, true
+        )
+        if 200 == code
+          token = response.strip
+          if '' == token
+            auth_responses[node_name] = {'status' => 'bad_password'}
+          else
+            auth_responses[node_name] = {'status' => 'ok', 'token' => token}
+          end
         else
-          auth_responses[node] = {'status' => 'ok', 'token' => token}
+          auth_responses[node_name] = {'status' => 'noresponse'}
         end
-      else
-        auth_responses[node] = {'status' => 'noresponse'}
+      rescue => e
+        auth_responses[node_name] = {'status' => 'error', 'error' => e}
       end
     }
   }
   threads.each { |t| t.join }
-  return auth_responses
+
+  # get the tokens form the response
+  new_hosts = []
+  auth_responses.each { |node_name, response|
+    if 'ok' == response['status']
+      new_hosts << PcsKnownHost.new(
+        node_name,
+        response['token'],
+        [nodes[node_name]['dest_list'][0]]
+      )
+    end
+  }
+
+  # sync known hosts within the local cluster
+  sync_successful = true
+  sync_failed_nodes = []
+  sync_responses = {}
+  if new_hosts.empty?
+    return auth_responses, sync_successful, sync_failed_nodes, sync_responses
+  end
+  # Only tokens used in pcsd-to-pcsd communication can and need to be synced.
+  # Those are accessible only when running under root account.
+  if Process.uid != 0
+    # Other tokens just need to be stored localy for a user.
+    sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
+      new_hosts, [], [], nil
+    )
+    return auth_responses, sync_successful, sync_failed_nodes, sync_responses
+  end
+  cluster_nodes = get_corosync_nodes_names()
+  sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
+    new_hosts, [], cluster_nodes, $cluster_name
+  )
+  sync_responses.each { |node, response|
+    if response['status'] != 'ok'
+      sync_failed_nodes << node
+    else
+      node_result = response['result'][Cfgsync::PcsdKnownHosts.name]
+      if not ['accepted', 'rejected'].include?(node_result)
+        sync_failed_nodes << node
+      end
+    end
+  }
+  return auth_responses, sync_successful, sync_failed_nodes, sync_responses
+end
+
+def pcs_deauth(auth_user, host_names)
+  # sync known hosts within the local cluster
+  sync_successful = true
+  sync_failed_nodes = []
+  sync_responses = {}
+  hosts_not_found = []
+
+  if host_names.empty?
+    return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
+  end
+  known_hosts_names = get_known_hosts().keys()
+  host_names.each { |name_to_remove|
+    if not known_hosts_names.include?(name_to_remove)
+      hosts_not_found << name_to_remove
+    end
+  }
+  if hosts_not_found.length > 0
+    return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
+  end
+
+  # Only tokens used in pcsd-to-pcsd communication can and need to be synced.
+  # Those are accessible only when running under root account.
+  if Process.uid != 0
+    # Other tokens just need to be stored localy for a user.
+    sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
+      [], host_names, [], nil
+    )
+    return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
+  end
+  cluster_nodes = get_corosync_nodes_names()
+  sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
+    [], host_names, cluster_nodes, $cluster_name
+  )
+  sync_responses.each { |node, response|
+    if response['status'] != 'ok'
+      sync_failed_nodes << node
+    else
+      node_result = response['result'][Cfgsync::PcsdKnownHosts.name]
+      if not ['accepted', 'rejected'].include?(node_result)
+        sync_failed_nodes << node
+      end
+    end
+  }
+  return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
 end
 
 def send_local_configs_to_nodes(
@@ -1349,147 +1097,6 @@ def send_local_configs_to_nodes(
   return publisher.send(force)
 end
 
-def send_local_certs_to_nodes(auth_user, nodes)
-  begin
-    data = {
-      'ssl_cert' => File.read(CRT_FILE),
-      'ssl_key' => File.read(KEY_FILE),
-      'cookie_secret' => File.read(COOKIE_FILE),
-    }
-  rescue => e
-    return {
-      'status' => 'error',
-      'text' => "Unable to read certificates: #{e}",
-      'node_status' => {},
-    }
-  end
-
-  crt_errors = verify_cert_key_pair(data['ssl_cert'], data['ssl_key'])
-  if crt_errors and not crt_errors.empty?
-    return {
-      'status' => 'error',
-      'text' => "Invalid certificate and/or key: #{crt_errors.join}",
-      'node_status' => {},
-    }
-  end
-  secret_errors = verify_cookie_secret(data['cookie_secret'])
-  if secret_errors and not secret_errors.empty?
-    return {
-      'status' => 'error',
-      'text' => "Invalid cookie secret: #{secret_errors.join}",
-      'node_status' => {},
-    }
-  end
-
-  node_response = {}
-  threads = []
-  nodes.each { |node|
-    threads << Thread.new {
-      code, response = send_request_with_token(
-        auth_user, node, '/set_certs', true, data
-      )
-      node_response[node] = [code, response]
-    }
-  }
-  threads.each { |t| t.join }
-
-  node_error = []
-  node_status = {}
-  node_response.each { |node, response|
-    if response[0] == 200
-      node_status[node] = {
-        'status' => 'ok',
-        'text' => 'Success',
-      }
-    else
-      text = response[1]
-      if response[0] == 401
-        text = "Unable to authenticate, try running 'pcs cluster auth'"
-      elsif response[0] == 400
-        begin
-          parsed_response = JSON.parse(response[1], {:symbolize_names => true})
-          if parsed_response[:noresponse]
-            text = "Unable to connect"
-          elsif parsed_response[:notoken] or parsed_response[:notauthorized]
-            text = "Unable to authenticate, try running 'pcs cluster auth'"
-          end
-        rescue JSON::ParserError
-        end
-      end
-      node_status[node] = {
-        'status' => 'error',
-        'text' => text
-      }
-      node_error << node
-    end
-  }
-  return {
-    'status' => node_error.empty?() ? 'ok' : 'error',
-    'text' => node_error.empty?() ? 'Success' : \
-      "Unable to save pcsd certificates to nodes: #{node_error.join(', ')}",
-    'node_status' => node_status,
-  }
-end
-
-def pcsd_restart_nodes(auth_user, nodes)
-  node_response = {}
-  threads = []
-  nodes.each { |node|
-    threads << Thread.new {
-      code, response = send_request_with_token(
-        auth_user, node, '/pcsd_restart', true
-      )
-      node_response[node] = [code, response]
-    }
-  }
-  threads.each { |t| t.join }
-
-  node_error = []
-  node_status = {}
-  node_response.each { |node, response|
-    if response[0] == 200
-      my_status = {
-        'status' => 'ok',
-        'text' => 'Success',
-      }
-      begin
-        parsed_response = JSON.parse(response[1], {:symbolize_names => true})
-        if parsed_response[:instance_signature]
-          my_status["instance_signature"] = parsed_response[:instance_signature]
-        end
-      rescue JSON::ParserError
-      end
-      node_status[node] = my_status
-    else
-      text = response[1]
-      if response[0] == 401
-        text = "Unable to authenticate, try running 'pcs cluster auth'"
-      elsif response[0] == 400
-        begin
-          parsed_response = JSON.parse(response[1], {:symbolize_names => true})
-          if parsed_response[:noresponse]
-            text = "Unable to connect"
-          elsif parsed_response[:notoken] or parsed_response[:notauthorized]
-            text = "Unable to authenticate, try running 'pcs cluster auth'"
-          end
-        rescue JSON::ParserError
-        end
-      end
-      node_status[node] = {
-        'status' => 'error',
-        'text' => text
-      }
-      node_error << node
-    end
-  }
-  return {
-    'status' => node_error.empty?() ? 'ok' : 'error',
-    'text' => node_error.empty?() ? 'Success' : \
-      "Unable to restart pcsd on nodes: #{node_error.join(', ')}",
-    'node_status' => node_status,
-  }
-end
-
 def get_uid(username)
   return Etc.getpwnam(username).uid
 end
@@ -1501,7 +1108,10 @@ end
 def write_file_lock(path, perm, data, binary=false, user=nil, group=nil)
   file = nil
   begin
-    file = File.open(path, binary ? 'wb' : 'w', perm)
+    # File.open(path, mode, options)
+    # File.open(path, mode, perm, options)
+    # In order to set permissions, the method must be called with 4 arguments.
+    file = File.open(path, binary ? 'wb' : 'w', perm, {})
     file.flock(File::LOCK_EX)
     if user or group
       File.chown(get_uid(user), get_gid(group), path)
@@ -1575,13 +1185,6 @@ def verify_cert_key_pair(cert, key)
   return errors
 end
 
-def verify_cookie_secret(secret)
-  if secret.empty?
-    return ['Cookie secret is empty']
-  end
-  return []
-end
-
 def cluster_status_from_nodes(auth_user, cluster_nodes, cluster_name)
   node_map = {}
   forbidden_nodes = {}
@@ -1859,8 +1462,6 @@ def get_node_status(auth_user, cib_dom)
           # :rcs_order => []
       },
       :cluster_settings => {},
-      :need_ring1_address => need_ring1_address?,
-      :is_cman_with_udpu_transport => is_cman_with_udpu_transport?,
       :acls => get_acls(auth_user, cib_dom),
       :username => auth_user[:username],
       :fence_levels => get_fence_levels(auth_user, cib_dom),
@@ -1936,7 +1537,7 @@ def get_resources(cib_dom, crm_dom=nil, get_operations=false)
     )
   end
   cib_dom.elements.each('/cib/configuration/resources/master') do |e|
-    resource_list << ClusterEntity::MasterSlave.new(
+    resource_list << ClusterEntity::Clone.new(
       e, crm_dom, rsc_status, nil, operations
     )
   end
@@ -1968,7 +1569,7 @@ def get_resource_by_id(id, cib_dom, crm_dom=nil, rsc_status=nil, operations=fals
     when 'clone'
       return ClusterEntity::Clone.new(e, crm_dom, rsc_status, nil, operations)
     when 'master'
-      return ClusterEntity::MasterSlave.new(e, crm_dom, rsc_status, nil, operations)
+      return ClusterEntity::Clone.new(e, crm_dom, rsc_status, nil, operations)
     else
       return nil
   end
@@ -1990,7 +1591,7 @@ end
 
 def get_cib_dom(auth_user)
   begin
-    stdout, _, retval = run_cmd(auth_user, 'cibadmin', '-Q', '-l')
+    stdout, _, retval = run_cmd(auth_user, CIBADMIN, '-Q', '-l')
     if retval == 0
       return REXML::Document.new(stdout.join("\n"))
     end
@@ -2017,7 +1618,7 @@ end
 
 def status_v1_to_v2(status)
   new_status = status.select { |k,_|
-    [:cluster_name, :username, :is_cman_with_udpu_transport,
+    [:cluster_name, :username,
      :need_ring1_address, :cluster_settings, :constraints,
      :corosync_online, :corosync_offline, :pacemaker_online, :pacemaker_standby,
      :pacemaker_offline, :acls, :fence_levels
@@ -2034,7 +1635,7 @@ def status_v1_to_v2(status)
   }
   new_status[:resource_list] = resources_hash
   new_status[:node] = status.select { |k,_|
-    [:uptime, :corosync, :pacemaker, :cman, :corosync_enabled,
+    [:uptime, :corosync, :pacemaker, :corosync_enabled,
      :pacemaker_enabled, :pcsd_enabled
     ].include?(k)
   }
@@ -2064,7 +1665,7 @@ def get_group_list_from_tree_of_resources(tree)
       group_list << resource.id
     end
     if (
-      resource.kind_of?(ClusterEntity::MultiInstance) and
+      resource.kind_of?(ClusterEntity::MultiInstancePcmk1) and
       resource.member.instance_of?(ClusterEntity::Group)
     )
       group_list << resource.member.id
@@ -2286,3 +1887,72 @@ def get_alerts(auth_user)
     return nil
   end
 end
+
+def get_service_info(service_name)
+  return {
+    :installed => is_service_installed?(service_name),
+    :enabled => is_service_enabled?(service_name),
+    :running => is_service_running?(service_name),
+    :version => nil,
+  }
+end
+
+def get_pcs_internal_output_format(status, status_msg=nil)
+  return {
+    :status => status,
+    :status_msg => status_msg,
+    :report_list => [],
+    :data => nil,
+  }
+end
+
+def pcs_internal_proxy(auth_user, data, cmd)
+  begin
+    input_data = JSON.parse(data)
+    return JSON.generate(run_pcs_internal(auth_user, cmd, input_data))
+  rescue JSON::ParserError => e
+    $logger.error("Invalid input data format: #{e}")
+    return JSON.generate(get_pcs_internal_output_format(
+      'input_error', "Invalid input data format: #{e}"
+    ))
+  end
+end
+
+def run_pcs_internal(auth_user, cmd, data, request_timeout=nil)
+  input_data = {
+    :cmd => cmd,
+    :cmd_data => data,
+    :options => {
+      :request_timeout => request_timeout,
+    },
+  }
+  stdout, stderr, return_val = run_cmd_options(
+    auth_user,
+    {'stdin' => JSON.generate(input_data)},
+    PCS_INTERNAL
+  )
+  if return_val != 0
+    return get_pcs_internal_output_format(
+      'exception', "Command failed: #{stderr.join("\n")}"
+    )
+  end
+  begin
+    parsed_output = JSON.parse(stdout.join("\n"))
+    if (
+      parsed_output.include?('report_list') \
+      and \
+      parsed_output['report_list'].kind_of?(Array) \
+    )
+      # Remove all debug messages as they may containt sensitive info.
+      parsed_output['report_list'].delete_if { |report_item|
+        report_item["severity"] == "DEBUG"
+      }
+    end
+    return parsed_output
+  rescue JSON::ParserError => e
+    $logger.error("Invalid output data format of command '#{cmd}': #{e}")
+    return get_pcs_internal_output_format(
+      'exception', "Invalid data format #{e}"
+    )
+  end
+end
