@@ -4,14 +4,14 @@ require 'rubygems'
 require 'etc'
 require 'json'
 require 'stringio'
-require 'orderedhash'
 
 require 'bootstrap.rb'
 require 'pcs.rb'
 require 'auth.rb'
+require 'remote.rb'
 
 def cli_format_response(status, text=nil, data=nil)
-  response = OrderedHash.new
+  response = Hash.new
   response['status'] = status
   response['text'] = text if text
   response['data'] = data if data
@@ -31,6 +31,10 @@ PCS = get_pcs_path()
 $logger_device = StringIO.new
 $logger = configure_logger($logger_device)
 
+capabilities, capabilities_pcsd = get_capabilities($logger)
+CAPABILITIES = capabilities.freeze
+CAPABILITIES_PCSD = capabilities_pcsd.freeze
+
 # check and set user
 uid = Process.uid
 if 0 == uid
@@ -62,19 +66,45 @@ $cluster_name = get_cluster_name()
 # get params and run a command
 command = ARGV[0]
 allowed_commands = {
-  'read_tokens' => {
-    # returns tokens of the user who runs pcsd-cli, thus no permission check
+  'read_known_hosts' => {
+    # returns hosts of the user who runs pcsd-cli, thus no permission check
     'only_superuser' => false,
     'permissions' => nil,
-    'call' => lambda { |params, auth_user_| read_tokens() },
+    'call' => lambda { |params, auth_user_|
+      out_hosts = {}
+      get_known_hosts().each { |name, host|
+        out_hosts[name] = {
+          'dest_list' => host.dest_list,
+          'token' => host.token,
+        }
+      }
+      return {
+        'known_hosts' => out_hosts,
+      }
+    },
+  },
+  'remove_known_hosts' => {
+    # changes hosts of the user who runs pcsd-cli, thus no permission check
+    'only_superuser' => false,
+    'permissions' => nil,
+    'call' => lambda { |params, auth_user_|
+      sync_successful, sync_nodes_err, sync_responses, hosts_not_found = pcs_deauth(
+        auth_user_, params.fetch('host_names')
+      )
+      return {
+        'hosts_not_found' => hosts_not_found,
+        'sync_successful' => sync_successful,
+        'sync_nodes_err' => sync_nodes_err,
+        'sync_responses' => sync_responses,
+      }
+    },
   },
   'auth' => {
     'only_superuser' => false,
     'permissions' => nil,
     'call' => lambda { |params, auth_user_|
       auth_responses, sync_successful, sync_nodes_err, sync_responses = pcs_auth(
-        auth_user_, params['nodes'] || [], params['username'] || '',
-        params['password'] || '', params['force'], params['local']
+        auth_user_, params.fetch('nodes')
       )
       return {
         'auth_responses' => auth_responses,
@@ -98,22 +128,22 @@ allowed_commands = {
       )
     }
   },
-  'send_local_certs' => {
-    'only_superuser' => false,
+  'node_status' => {
+    'only_superuser' => true,
     'permissions' => Permissions::FULL,
     'call' => lambda { |params, auth_user_|
-      send_local_certs_to_nodes(auth_user_, params['nodes'] || [])
-    }
-  },
-  'pcsd_restart_nodes' => {
-    'only_superuser' => false,
-    'permissions' => nil,
-    'call' => lambda { |params, auth_user_|
-      pcsd_restart_nodes(auth_user_, params['nodes'] || [])
+      return JSON.parse(node_status(
+        {
+          :version => '2',
+          :operations => '1',
+          :skip_auth_check => '1',
+        },
+        {},
+        auth_user_
+      ))
     }
   },
 }
-
 if allowed_commands.key?(command)
   begin
     params = JSON.parse(STDIN.read)
