@@ -29,20 +29,16 @@ def remote(params, request, auth_user)
       :cluster_status => method(:cluster_status_remote),
       :auth => method(:auth),
       :check_auth => method(:check_auth),
-      :setup_cluster => method(:setup_cluster),
-      :create_cluster => method(:create_cluster),
+      :cluster_setup => method(:cluster_setup),
       :get_quorum_info => method(:get_quorum_info),
       :get_cib => method(:get_cib),
       :get_corosync_conf => method(:get_corosync_conf_remote),
-      :set_cluster_conf => method(:set_cluster_conf),
       :set_corosync_conf => method(:set_corosync_conf),
       :get_sync_capabilities => method(:get_sync_capabilities),
       :set_sync_options => method(:set_sync_options),
       :get_configs => method(:get_configs),
       :set_configs => method(:set_configs),
       :set_certs => method(:set_certs),
-      :pcsd_restart => method(:remote_pcsd_restart),
-      :pcsd_instance_signature => method(:pcsd_instance_signature),
       :get_permissions => method(:get_permissions_remote),
       :set_permissions => method(:set_permissions_remote),
       :cluster_start => method(:cluster_start),
@@ -56,21 +52,13 @@ def remote(params, request, auth_user)
       :cluster_disable => method(:cluster_disable),
       :resource_status => method(:resource_status),
       :get_sw_versions => method(:get_sw_versions),
+      # TODO Not used anymore in pcs-0.10. Should we keep it for older versions?
       :node_available => method(:remote_node_available),
-      :add_node_all => lambda { |params_, request_, auth_user_|
-        remote_add_node(params_, request_, auth_user_, true)
-      },
-      :add_node => lambda { |params_, request_, auth_user_|
-        remote_add_node(params_, request_, auth_user_, false)
-      },
-      :remove_nodes => method(:remote_remove_nodes),
-      :remove_node => method(:remote_remove_node),
+      :cluster_add_nodes => method(:cluster_add_nodes),
+      :cluster_remove_nodes => method(:cluster_remove_nodes),
       :cluster_destroy => method(:cluster_destroy),
-      :get_wizard => method(:get_wizard),
-      :wizard_submit => method(:wizard_submit),
-      :get_tokens => method(:get_tokens),
-      :get_cluster_tokens => method(:get_cluster_tokens),
-      :save_tokens => method(:save_tokens),
+      :get_cluster_known_hosts => method(:get_cluster_known_hosts),
+      :known_hosts_change => method(:known_hosts_change),
       :get_cluster_properties_definition => method(:get_cluster_properties_definition),
       :check_sbd => method(:check_sbd),
       :set_sbd_config => method(:set_sbd_config),
@@ -96,7 +84,9 @@ def remote(params, request, auth_user)
       :put_file => method(:put_file),
       :remove_file => method(:remove_file),
       :manage_services => method(:manage_services),
-
+      :check_host => method(:check_host),
+      :reload_corosync_conf => method(:reload_corosync_conf),
+      :remove_nodes_from_cib => method(:remove_nodes_from_cib),
   }
   remote_cmd_with_pacemaker = {
       :pacemaker_node_status => method(:remote_pacemaker_node_status),
@@ -124,7 +114,7 @@ def remote(params, request, auth_user)
       :add_acl => method(:add_acl_remote),
       :remove_acl => method(:remove_acl_remote),
       :resource_change_group => method(:resource_change_group),
-      :resource_master => method(:resource_master),
+      :resource_promotable => method(:resource_promotable),
       :resource_clone => method(:resource_clone),
       :resource_unclone => method(:resource_unclone),
       :resource_ungroup => method(:resource_ungroup),
@@ -167,10 +157,6 @@ def capabilities(params, request, auth_user)
   })
 end
 
-def param_to_bool(obj)
-  return ['true', '1', 'on'].include?(obj)
-end
-
 # provides remote cluster status to a local gui
 def cluster_status_gui(auth_user, cluster_name, dont_update_config=false)
   cluster_nodes = get_cluster_nodes(cluster_name)
@@ -196,7 +182,7 @@ def cluster_status_gui(auth_user, cluster_name, dont_update_config=false)
       # on version conflict just go on, config will be corrected eventually
       # by displaying the cluster in the web UI
       Cfgsync::save_sync_new_version(
-          sync_config, get_corosync_nodes(), $cluster_name, true
+          sync_config, get_corosync_nodes_names(), $cluster_name, true
       )
       return cluster_status_gui(auth_user, cluster_name, true)
     end
@@ -233,16 +219,34 @@ def cluster_status_remote(params, request, auth_user)
   return JSON.generate(status)
 end
 
-def _cluster_start_stop(action, params, request, auth_user)
-  if not ['start', 'stop'].include?(action)
-    return [400, "Action can be 'start' or 'stop', got '#{action}'"]
+def cluster_start(params, request, auth_user)
+  if params[:name]
+    code, response = send_request_with_token(
+      auth_user, params[:name], 'cluster_start', true
+    )
+  else
+    if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
+      return 403, 'Permission denied'
+    end
+    cmd = [PCS, 'cluster', 'start']
+    cmd << '--all' if params[:all] == '1'
+    $logger.info "Starting Daemons"
+    output, stderr, retval = run_cmd(auth_user, *cmd)
+    if retval != 0
+      return [400, (output + stderr).join]
+    else
+      return output
+    end
   end
+end
+
+def cluster_stop(params, request, auth_user)
   if params[:name]
     params_without_name = params.reject {|key, value|
       key == "name" or key == :name
     }
     code, response = send_request_with_token(
-      auth_user, params[:name], "cluster_#{action}", true, params_without_name
+      auth_user, params[:name], 'cluster_stop', true, params_without_name
     )
   else
     if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
@@ -256,31 +260,20 @@ def _cluster_start_stop(action, params, request, auth_user)
         options << "--corosync"
       end
     end
-    if action == "stop"
-      options << "--force" if params["force"]
-      $logger.info "Stopping Daemons"
-    else
-      $logger.info "Starting Daemons"
-    end
+    options << "--force" if params["force"]
+    options << '--all' if params[:all] == '1'
+    $logger.info "Stopping Daemons"
     stdout, stderr, retval = run_cmd(
-      auth_user, PCS, 'cluster', action, *options
+      auth_user, PCS, "cluster", "stop", *options
     )
     if retval != 0
-      return [400, (stdout + stderr).join]
+      return [400, stderr.join]
     else
       return stdout.join
     end
   end
 end
 
-def cluster_start(params, request, auth_user)
-  return _cluster_start_stop('start', params, request, auth_user)
-end
-
-def cluster_stop(params, request, auth_user)
-  return _cluster_start_stop('stop', params, request, auth_user)
-end
-
 def config_backup(params, request, auth_user)
   if params[:name]
     code, response = send_request_with_token(
@@ -391,7 +384,7 @@ def cluster_enable(params, request, auth_user)
     if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
       return 403, 'Permission denied'
     end
-    success = enable_cluster(auth_user)
+    success = enable_cluster(auth_user, params[:all])
     if not success
       return JSON.generate({"error" => "true"})
     end
@@ -408,7 +401,7 @@ def cluster_disable(params, request, auth_user)
     if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
       return 403, 'Permission denied'
     end
-    success = disable_cluster(auth_user)
+    success = disable_cluster(auth_user, params[:all])
     if not success
       return JSON.generate({"error" => "true"})
     end
@@ -420,32 +413,15 @@ def get_quorum_info(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::READ)
     return 403, 'Permission denied'
   end
-  if ISRHEL6
-    stdout_status, stderr_status, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(), CMAN_TOOL, "status"
-    )
-    stdout_nodes, stderr_nodes, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(),
-      CMAN_TOOL, "nodes", "-F", "id,type,votes,name"
-    )
-    if stderr_status.length > 0
-      return stderr_status.join
-    elsif stderr_nodes.length > 0
-      return stderr_nodes.join
-    else
-      return stdout_status.join + "\n---Votes---\n" + stdout_nodes.join
-    end
+  stdout, stderr, _retval = run_cmd(
+    PCSAuth.getSuperuserAuth(), COROSYNC_QUORUMTOOL, "-p", "-s"
+  )
+  # retval is 0 on success if node is not in partition with quorum
+  # retval is 1 on error OR on success if node has quorum
+  if stderr.length > 0
+    return stderr.join
   else
-    stdout, stderr, retval = run_cmd(
-      PCSAuth.getSuperuserAuth(), COROSYNC_QUORUMTOOL, "-p", "-s"
-    )
-    # retval is 0 on success if node is not in partition with quorum
-    # retval is 1 on error OR on success if node has quorum
-    if stderr.length > 0
-      return stderr.join
-    else
-      return stdout.join
-    end
+    return stdout.join
   end
 end
 
@@ -471,20 +447,8 @@ def get_corosync_conf_remote(params, request, auth_user)
   return get_corosync_conf()
 end
 
-def set_cluster_conf(params, request, auth_user)
-  if not allowed_for_local_cluster(auth_user, Permissions::FULL)
-    return 403, 'Permission denied'
-  end
-  if params[:cluster_conf] != nil and params[:cluster_conf].strip != ""
-    Cfgsync::ClusterConf.backup()
-    Cfgsync::ClusterConf.from_text(params[:cluster_conf]).save()
-    return 200, 'Updated cluster.conf...'
-  else
-    $logger.info "Invalid cluster.conf file"
-    return 400, 'Failed to update cluster.conf...'
-  end
-end
-
+# deprecated, use /remote/put_file (note that put_file doesn't support backup
+# yet)
 def set_corosync_conf(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::FULL)
     return 403, 'Permission denied'
@@ -519,7 +483,7 @@ def set_sync_options(params, request, auth_user)
   end
 
   if params['sync_thread_disable']
-    if Cfgsync::ConfigSyncControl.sync_thread_disable($semaphore_cfgsync)
+    if Cfgsync::ConfigSyncControl.sync_thread_disable()
       return 'sync thread disabled'
     else
       return [400, 'sync thread disable error']
@@ -543,9 +507,7 @@ def set_sync_options(params, request, auth_user)
   end
 
   if params['sync_thread_pause']
-    if Cfgsync::ConfigSyncControl.sync_thread_pause(
-        $semaphore_cfgsync, params['sync_thread_pause']
-      )
+    if Cfgsync::ConfigSyncControl.sync_thread_pause(params['sync_thread_pause'])
       return 'sync thread paused'
     else
       return [400, 'sync thread pause error']
@@ -594,36 +556,34 @@ def set_configs(params, request, auth_user)
     return JSON.generate({'status' => 'wrong_cluster_name'})
   end
 
-  $semaphore_cfgsync.synchronize {
-    force = configs_json['force']
-    remote_configs, unknown_cfg_names = Cfgsync::sync_msg_to_configs(configs_json)
-    local_configs = Cfgsync::get_configs_local
+  force = configs_json['force']
+  remote_configs, unknown_cfg_names = Cfgsync::sync_msg_to_configs(configs_json)
+  local_configs = Cfgsync::get_configs_local
 
-    result = {}
-    unknown_cfg_names.each { |name| result[name] = 'not_supported' }
-    remote_configs.each { |name, remote_cfg|
-      begin
-        # Save a remote config if it is a newer version than local. If the config
-        # is not present on a local node, the node is beeing added to a cluster,
-        # so we need to save the config as well.
-        if force or not local_configs.key?(name) or remote_cfg > local_configs[name]
-          local_configs[name].class.backup() if local_configs.key?(name)
-          remote_cfg.save()
-          result[name] = 'accepted'
-        elsif remote_cfg == local_configs[name]
-          # Someone wants this node to have a config that it already has.
-          # So the desired state is met and the result is a success then.
-          result[name] = 'accepted'
-        else
-          result[name] = 'rejected'
-        end
-      rescue => e
-        $logger.error("Error saving config '#{name}': #{e}")
-        result[name] = 'error'
+  result = {}
+  unknown_cfg_names.each { |name| result[name] = 'not_supported' }
+  remote_configs.each { |name, remote_cfg|
+    begin
+      # Save a remote config if it is a newer version than local. If the config
+      # is not present on a local node, the node is beeing added to a cluster,
+      # so we need to save the config as well.
+      if force or not local_configs.key?(name) or remote_cfg > local_configs[name]
+        local_configs[name].class.backup() if local_configs.key?(name)
+        remote_cfg.save()
+        result[name] = 'accepted'
+      elsif remote_cfg == local_configs[name]
+        # Someone wants this node to have a config that it already has.
+        # So the desired state is met and the result is a success then.
+        result[name] = 'accepted'
+      else
+        result[name] = 'rejected'
       end
-    }
-    return JSON.generate({'status' => 'ok', 'result' => result})
+    rescue => e
+      $logger.error("Error saving config '#{name}': #{e}")
+      result[name] = 'error'
+    end
   }
+  return JSON.generate({'status' => 'ok', 'result' => result})
 end
 
 def set_certs(params, request, auth_user)
@@ -656,17 +616,6 @@ def set_certs(params, request, auth_user)
     end
   end
 
-  if params['cookie_secret']
-    cookie_secret = params['cookie_secret'].strip
-    if !cookie_secret.empty?
-      begin
-        write_file_lock(COOKIE_FILE, 0700, cookie_secret)
-      rescue => e
-        return [400, "cannot save cookie secret: #{e}"]
-      end
-    end
-  end
-
   return [200, 'success']
 end
 
@@ -770,40 +719,27 @@ def set_permissions_remote(params, request, auth_user)
     pcs_config.permissions_local = perm_set
     sync_config = Cfgsync::PcsdSettings.from_text(pcs_config.text())
     pushed, _ = Cfgsync::save_sync_new_version(
-      sync_config, get_corosync_nodes(), $cluster_name, true
+      sync_config, get_corosync_nodes_names(), $cluster_name, true
     )
     return [200, 'Permissions saved'] if pushed
   }
   return 400, 'Unable to save permissions'
 end
 
-def remote_pcsd_restart(params, request, auth_user)
-  pcsd_restart()
-  return JSON.generate({
-    :success => true,
-    :instance_signature => DAEMON_INSTANCE_SIGNATURE,
-  })
-end
-
-def pcsd_instance_signature(params, request, auth_user)
-  return [200, DAEMON_INSTANCE_SIGNATURE]
-end
-
 def get_sw_versions(params, request, auth_user)
   versions = {
     "rhel" => get_rhel_version(),
     "pcs" => get_pcsd_version(),
     "pacemaker" => get_pacemaker_version(),
     "corosync" => get_corosync_version(),
-    "cman" => get_cman_version(),
   }
   return JSON.generate(versions)
 end
 
+# TODO Not used anymore in pcs-0.10. Should we keep it for older versions?
 def remote_node_available(params, request, auth_user)
   if (
-    (not ISRHEL6 and File.exist?(Cfgsync::CorosyncConf.file_path)) or
-    (ISRHEL6 and File.exist?(Cfgsync::ClusterConf.file_path)) or
+    File.exist?(Cfgsync::CorosyncConf.file_path) or \
     File.exist?("/var/lib/pacemaker/cib/cib.xml")
   )
     return JSON.generate({:node_available => false})
@@ -823,180 +759,31 @@ def remote_node_available(params, request, auth_user)
   return JSON.generate({:node_available => true})
 end
 
-def remote_add_node(params, request, auth_user, all=false)
+def cluster_add_nodes(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::FULL)
     return 403, 'Permission denied'
   end
-  auto_start = false
-  if params[:auto_start] and params[:auto_start] == "1"
-    auto_start = true
-  end
-
-  if params[:new_nodename] != nil
-    node = params[:new_nodename]
-    if params[:new_ring1addr] != nil
-      node += ',' + params[:new_ring1addr]
-    end
-    device_list = []
-    if params[:devices].kind_of?(Array)
-      device_list = params[:devices]
-    end
-    retval, output = add_node(
-      auth_user, node, all, auto_start, params[:watchdog], device_list,
-      param_to_bool(params[:no_watchdog_validation]),
-    )
-  end
-
-  if retval == 0
-    return [200, JSON.generate([retval, get_corosync_conf()])]
-  end
-
-  return [400,output]
-end
-
-def remote_remove_nodes(params, request, auth_user)
-  if not allowed_for_local_cluster(auth_user, Permissions::FULL)
-    return 403, 'Permission denied'
-  end
-  count = 0
-  out = ""
-  node_list = []
-  options = []
-  while params["nodename-" + count.to_s]
-    node_list << params["nodename-" + count.to_s]
-    count = count + 1
-  end
-  options << "--force" if params["force"]
-
-  cur_node = get_current_node_name()
-  if i = node_list.index(cur_node)
-    node_list.push(node_list.delete_at(i))
-  end
-
-  # stop the nodes at once in order to:
-  # - prevent resources from moving pointlessly
-  # - get possible quorum loss warning
-  stop_params = node_list + options
-  stdout, stderr, retval = run_cmd(
-    auth_user, PCS, "cluster", "stop", *stop_params
+  return pcs_internal_proxy(
+    auth_user, params.fetch(:data_json, ""), "cluster.add_nodes"
   )
-  if retval != 0 and not params['force']
-    # If forced, keep going even if unable to stop all nodes (they may be dead).
-    # Add info this error is forceable if pcs did not do it (e.g. when unable
-    # to connect to some nodes).
-    message = stderr.join
-    if not message.include?(', use --force to override')
-      message += ', use --force to override'
-    end
-    return [400, message]
-  end
-
-  node_list.each {|node|
-    retval, output = remove_node(auth_user, node, true)
-    out = out + output.join("\n")
-  }
-  config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
-  if config.get_nodes($cluster_name) == nil or config.get_nodes($cluster_name).length == 0
-    return [200,"No More Nodes"]
-  end
-  if retval != 0
-    return [400, out]
-  else
-    return [200, out]
-  end
 end
 
-def remote_remove_node(params, request, auth_user)
+def cluster_remove_nodes(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::FULL)
     return 403, 'Permission denied'
   end
-  if params[:remove_nodename] != nil
-    retval, output = remove_node(auth_user, params[:remove_nodename])
-  else
-    return 400, "No nodename specified"
-  end
-
-  if retval == 0
-    return JSON.generate([retval, get_corosync_conf()])
-  end
-
-  return JSON.generate([retval,output])
+  return pcs_internal_proxy(
+    auth_user, params.fetch(:data_json, ""), "cluster.remove_nodes"
+  )
 end
 
-def setup_cluster(params, request, auth_user)
+def cluster_setup(params, request, auth_user)
   if not allowed_for_superuser(auth_user)
     return 403, 'Permission denied'
   end
-  $logger.info("Setting up cluster: " + params.inspect)
-  nodes_rrp = params[:nodes].split(';')
-  options = []
-  myoptions = JSON.parse(params[:options])
-  transport_udp = false
-  options_udp = []
-  myoptions.each { |o,v|
-    if ["wait_for_all", "last_man_standing", "auto_tie_breaker"].include?(o)
-      options << "--" + o + "=1"
-    end
-
-    options << "--" + o + "=" + v if [
-        "token", "token_coefficient", "join", "consensus", "miss_count_const",
-        "fail_recv_const", "last_man_standing_window",
-      ].include?(o)
-
-    if o == "transport" and v == "udp"
-      options << "--transport=udp"
-      transport_udp = true
-    end
-    if o == "transport" and v == "udpu"
-      options << "--transport=udpu"
-      transport_udp = false
-    end
-
-    if ["addr0", "addr1", "mcast0", "mcast1", "mcastport0", "mcastport1", "ttl0", "ttl1"].include?(o)
-      options_udp << "--" + o + "=" + v
-    end
-
-    if ["broadcast0", "broadcast1"].include?(o)
-      options_udp << "--" + o
-    end
-
-    if o == "ipv6"
-      options << "--ipv6"
-    end
-  }
-  if transport_udp
-    nodes = []
-    nodes_rrp.each { |node| nodes << node.split(',')[0] }
-  else
-    nodes = nodes_rrp
-  end
-  nodes_options = nodes + options
-  nodes_options += options_udp if transport_udp
-  if ['0', '1'].include?(params[:encryption])
-      nodes_options << "--encryption=#{params[:encryption]}"
-  end
-  stdout, stderr, retval = run_cmd(
-    auth_user, PCS, "cluster", "setup", "--enable", "--start", "--async",
-    "--name",  params[:clustername], *nodes_options
+  return pcs_internal_proxy(
+    auth_user, params.fetch(:data_json, ""), "cluster.setup"
   )
-  if retval != 0
-    return [
-      400,
-      (stdout + [''] + stderr).collect { |line| line.rstrip() }.join("\n")
-    ]
-  end
-  return 200
-end
-
-def create_cluster(params, request, auth_user)
-  if not allowed_for_superuser(auth_user)
-    return 403, 'Permission denied'
-  end
-  if set_corosync_conf(params, request, auth_user)
-    cluster_start(params, request, auth_user)
-  else
-    return "Failed"
-  end
 end
 
 def remote_pacemaker_node_status(params, request, auth_user)
@@ -1042,10 +829,9 @@ def node_status(params, request, auth_user)
   node = ClusterEntity::Node.load_current_node(crm_dom)
 
   if params[:skip_auth_check] != '1'
-    _,_,not_authorized_nodes = check_gui_status_of_nodes(
+    _,_,not_authorized_nodes = is_auth_against_nodes(
       auth_user,
       status[:known_nodes],
-      false,
       3
     )
 
@@ -1100,7 +886,6 @@ def node_status(params, request, auth_user)
     :uptime => node.uptime,
     :corosync => node.corosync,
     :pacemaker => node.pacemaker,
-    :cman => node.cman,
     :corosync_enabled => node.corosync_enabled,
     :pacemaker_enabled => node.pacemaker_enabled,
     :pacemaker_remote => node.services[:pacemaker_remote][:running],
@@ -1120,7 +905,6 @@ def node_status(params, request, auth_user)
     :node_attr => node_attr,
     :fence_levels => status[:fence_levels],
     :need_ring1_address => status[:need_ring1_address],
-    :is_cman_with_udpu_transport => status[:is_cman_with_udpu_transport],
     :acls => status[:acls],
     :username => status[:username]
   }
@@ -1178,7 +962,7 @@ def status_all(params, request, auth_user, nodes=[], dont_update_config=false)
       # on version conflict just go on, config will be corrected eventually
       # by displaying the cluster in the web UI
       Cfgsync::save_sync_new_version(
-        sync_config, get_corosync_nodes(), $cluster_name, true
+        sync_config, get_corosync_nodes_names(), $cluster_name, true
       )
       return status_all(params, request, auth_user, node_list, true)
     end
@@ -1205,10 +989,9 @@ def clusters_overview(params, request, auth_user)
         'resource_list' => []
       }
       overview_cluster = nil
-      online, offline, not_authorized_nodes = check_gui_status_of_nodes(
+      online, offline, not_authorized_nodes = is_auth_against_nodes(
         auth_user,
         get_cluster_nodes(cluster.name),
-        false,
         3
       )
       not_supported = false
@@ -1341,7 +1124,7 @@ def clusters_overview(params, request, auth_user)
     # on version conflict just go on, config will be corrected eventually
     # by displaying the cluster in the web UI
     Cfgsync::save_sync_new_version(
-      sync_config, get_corosync_nodes(), $cluster_name, true
+      sync_config, get_corosync_nodes_names(), $cluster_name, true
     )
   end
 
@@ -1355,34 +1138,12 @@ def clusters_overview(params, request, auth_user)
 end
 
 def auth(params, request, auth_user)
-  token = PCSAuth.validUser(params['username'],params['password'], true)
-  # If we authorized to this machine, attempt to authorize everywhere
-  nodes = {}
-  if token and params["bidirectional"]
-    params.each { |k,v|
-      if k.start_with?("node-")
-        nodes[v] = params["port-#{v}"]
-      end
-    }
-    if nodes.length > 0
-      pcs_auth(
-        auth_user, nodes, params['username'], params['password'],
-        params["force"] == "1"
-      )
-    end
-  end
-  return token
+  return PCSAuth.validUser(params['username'], params['password'])
 end
 
-# If we get here, we're already authorized
 def check_auth(params, request, auth_user)
-  if params.include?("check_auth_only")
-    return [200, "{\"success\":true}"]
-  end
-  return JSON.generate({
-    'success' => true,
-    'node_list' => get_token_node_list,
-  })
+  # If we get here, we're already authorized
+  return [200, '{"success":true}']
 end
 
 # not used anymore, left here for backward compatability reasons
@@ -1509,9 +1270,9 @@ def update_resource (params, request, auth_user)
     if params[:resource_clone] and params[:resource_clone] != ""
       name = resource_group ? resource_group : params[:name]
       run_cmd(auth_user, PCS, "resource", "clone", name)
-    elsif params[:resource_ms] and params[:resource_ms] != ""
+    elsif params[:resource_promotable] and params[:resource_promotable] != ""
       name = resource_group ? resource_group : params[:name]
-      run_cmd(auth_user, PCS, "resource", "master", name)
+      run_cmd(auth_user, PCS, "resource", "promotable", name)
     end
 
     return JSON.generate({})
@@ -1554,8 +1315,8 @@ def update_resource (params, request, auth_user)
   if params[:resource_clone] and params[:_orig_resource_clone] == "false"
     run_cmd(auth_user, PCS, "resource", "clone", params[:resource_id])
   end
-  if params[:resource_ms] and params[:_orig_resource_ms] == "false"
-    run_cmd(auth_user, PCS, "resource", "master", params[:resource_id])
+  if params[:resource_promotable] and params[:_orig_resource_promotable] == "false"
+    run_cmd(auth_user, PCS, "resource", "promotable", params[:resource_id])
   end
 
   if params[:_orig_resource_clone] == "true" and not params[:resource_clone]
@@ -1563,7 +1324,7 @@ def update_resource (params, request, auth_user)
       auth_user, PCS, "resource", "unclone", params[:resource_id].sub(/:.*/,'')
     )
   end
-  if params[:_orig_resource_ms] == "true" and not params[:resource_ms]
+  if params[:_orig_resource_promotable] == "true" and not params[:resource_promotable]
     run_cmd(
       auth_user, PCS, "resource", "unclone", params[:resource_id].sub(/:.*/,'')
     )
@@ -1843,8 +1604,7 @@ def add_constraint_remote(params, request, auth_user)
   when "loc"
     retval, error = add_location_constraint(
       auth_user,
-      params["res_id"], params["node_id"], params["score"], params["force"],
-      !params['disable_autocorrect']
+      params["res_id"], params["node_id"], params["score"], params["force"]
     )
   when "ord"
     resA = params["res_id"]
@@ -1858,8 +1618,7 @@ def add_constraint_remote(params, request, auth_user)
 
     retval, error = add_order_constraint(
       auth_user,
-      resA, resB, actionA, actionB, params["score"], true, params["force"],
-      !params['disable_autocorrect']
+      resA, resB, actionA, actionB, params["score"], true, params["force"]
     )
   when "col"
     resA = params["res_id"]
@@ -1874,14 +1633,13 @@ def add_constraint_remote(params, request, auth_user)
     end
 
     retval, error = add_colocation_constraint(
-      auth_user,
-      resA, resB, score, params["force"], !params['disable_autocorrect']
+      auth_user, resA, resB, score, params["force"]
     )
   when "ticket"
     retval, error = add_ticket_constraint(
       auth_user,
       params["ticket"], params["res_id"], params["role"], params["loss-policy"],
-      params["force"], !params['disable_autocorrect']
+      params["force"]
     )
   else
     return [400, "Unknown constraint type: #{params['c_type']}"]
@@ -1902,7 +1660,6 @@ def add_constraint_rule_remote(params, request, auth_user)
     retval, error = add_location_constraint_rule(
       auth_user,
       params["res_id"], params["rule"], params["score"], params["force"],
-      !params['disable_autocorrect']
     )
   else
     return [400, "Unknown constraint type: #{params["c_type"]}"]
@@ -1922,13 +1679,11 @@ def add_constraint_set_remote(params, request, auth_user)
   case params["c_type"]
   when "ord"
     retval, error = add_order_set_constraint(
-      auth_user,
-      params["resources"].values, params["force"], !params['disable_autocorrect']
+      auth_user, params["resources"].values, params["force"]
     )
   when "col"
     retval, error = add_colocation_set_constraint(
-      auth_user,
-      params["resources"].values, params["force"], !params['disable_autocorrect']
+      auth_user, params["resources"].values, params["force"]
     )
   when "ticket"
     unless params["options"]["ticket"]
@@ -1940,7 +1695,6 @@ def add_constraint_set_remote(params, request, auth_user)
       (params["options"]["loss-policy"] or ""),
       params["resources"].values,
       params["force"],
-      !params['disable_autocorrect']
     )
   else
     return [400, "Unknown constraint type: #{params["c_type"]}"]
@@ -2061,7 +1815,11 @@ def cluster_destroy(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::FULL)
     return 403, 'Permission denied'
   end
-  out, errout, retval = run_cmd(auth_user, PCS, "cluster", "destroy")
+  cmd = [PCS, "cluster", "destroy"]
+  if params[:all] == '1'
+    cmd << '--all'
+  end
+  out, errout, retval = run_cmd(auth_user, *cmd)
   if retval == 0
     return [200, "Successfully destroyed cluster"]
   else
@@ -2069,94 +1827,60 @@ def cluster_destroy(params, request, auth_user)
   end
 end
 
-def get_wizard(params, request, auth_user)
-  if not allowed_for_local_cluster(auth_user, Permissions::READ)
-    return 403, 'Permission denied'
-  end
-  wizard = PCSDWizard.getWizard(params["wizard"])
-  if wizard != nil
-    return erb wizard.collection_page
-  else
-    return "Error finding Wizard - #{params["wizard"]}"
-  end
-end
-
-def wizard_submit(params, request, auth_user)
-  if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
-    return 403, 'Permission denied'
-  end
-  wizard = PCSDWizard.getWizard(params["wizard"])
-  if wizard != nil
-    return erb wizard.process_responses(params)
-  else
-    return "Error finding Wizard - #{params["wizard"]}"
-  end
-
-end
-
-# not used anymore, left here for backward compatability reasons
-def get_tokens(params, request, auth_user)
-  # pcsd runs as root thus always returns hacluster's tokens
-  if not allowed_for_local_cluster(auth_user, Permissions::FULL)
-    return 403, 'Permission denied'
-  end
-  return [200, JSON.generate(read_tokens)]
-end
-
-def get_cluster_tokens(params, request, auth_user)
+def get_cluster_known_hosts(params, request, auth_user)
   # pcsd runs as root thus always returns hacluster's tokens
   if not allowed_for_local_cluster(auth_user, Permissions::FULL)
     return 403, "Permission denied"
   end
-  on, off = get_nodes
-  nodes = on + off
-  nodes.uniq!
-  token_file_data = read_token_file()
-  tokens = token_file_data.tokens.select {|k,v| nodes.include?(k)}
-  if params["with_ports"] != '1'
-    return [200, JSON.generate(tokens)]
-  end
-  data = {
-    :tokens => tokens,
-    :ports => token_file_data.ports.select {|k,v| nodes.include?(k)},
+  on, off = get_nodes()
+  nodes = (on + off).uniq()
+  data = {}
+  get_known_hosts().each { |host_name, host_obj|
+    if nodes.include?(host_name)
+      data[host_name] = {
+        'dest_list' => host_obj.dest_list,
+        'token' => host_obj.token,
+      }
+    end
   }
   return [200, JSON.generate(data)]
 end
 
-def save_tokens(params, request, auth_user)
-  # pcsd runs as root thus always returns hacluster's tokens
+def known_hosts_change(params, request, auth_user)
+  # pcsd runs as root thus always works with hacluster's tokens
   if not allowed_for_local_cluster(auth_user, Permissions::FULL)
     return 403, "Permission denied"
   end
 
-  new_tokens = {}
-  new_ports = {}
+  new_hosts = []
+  remove_hosts = []
+  begin
+    data = JSON.parse(params.fetch('data_json'))
+    data.fetch('known_hosts_add').each { |host_name, host_data|
+      new_hosts << PcsKnownHost.new(
+        host_name,
+        host_data.fetch('token'),
+        host_data.fetch('dest_list')
+      )
+    }
+    data.fetch('known_hosts_remove').each { |host_name|
+      remove_hosts << host_name
+    }
+  rescue => e
+    return 400, "Incorrect format of request data: #{e}"
+  end
 
-  params.each{|nodes|
-    if nodes[0].start_with?"node:" and nodes[0].length > 5
-      node = nodes[0][5..-1]
-      new_tokens[node] = nodes[1]
-      port = (params["port:#{node}"] || '').strip
-      if port == ''
-        port = nil
-      end
-      new_ports[node] = port
-    end
-  }
-
-  tokens_cfg = Cfgsync::PcsdTokens.from_file()
-  sync_successful, sync_responses = Cfgsync::save_sync_new_tokens(
-    tokens_cfg, new_tokens, get_corosync_nodes(), $cluster_name, new_ports
+  sync_successful, _sync_responses = Cfgsync::save_sync_new_known_hosts(
+    new_hosts, remove_hosts, get_corosync_nodes_names(), $cluster_name
   )
-
   if sync_successful
-    return [200, JSON.generate(read_tokens())]
+    return [200, '']
   else
-    return [400, "Cannot update tokenfile."]
+    return [400, 'Cannot update known-hosts file.']
   end
 end
 
-def resource_master(params, request, auth_user)
+def resource_promotable(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
     return 403, 'Permission denied'
   end
@@ -2165,10 +1889,10 @@ def resource_master(params, request, auth_user)
     return [400, 'resource_id has to be specified.']
   end
   _, stderr, retval = run_cmd(
-    auth_user, PCS, 'resource', 'master', params[:resource_id]
+    auth_user, PCS, 'resource', 'promotable', params[:resource_id]
   )
   if retval != 0
-    return [400, 'Unable to create master/slave resource from ' +
+    return [400, 'Unable to create promotable resource from ' +
       "'#{params[:resource_id]}': #{stderr.join('')}"
     ]
   end
@@ -2408,7 +2132,10 @@ def check_sbd(param, request, auth_user)
         :path => watchdog,
         :exist => exists,
         :is_supported => (
-          exists and available_watchdogs[watchdog]['caution'] == nil
+          # this method is not reliable so all watchdog devices listed by SBD
+          # will be listed as supported for now
+          # exists and available_watchdogs[watchdog]['caution'] == nil
+          exists
         ),
       }
     rescue JSON::ParserError
@@ -2536,17 +2263,13 @@ def remote_enable_sbd(params, request, auth_user)
 
   arg_list = []
 
-  if param_to_bool(params[:ignore_offline_nodes])
+  if ['true', '1', 'on'].include?(params[:ignore_offline_nodes])
     arg_list << '--skip-offline'
   end
 
-  if param_to_bool(params[:no_watchdog_validation])
-    arg_list << '--no-watchdog-validation'
-  end
-
   params[:watchdog].each do |node, watchdog|
     unless watchdog.strip.empty?
-      arg_list << "--watchdog=#{watchdog.strip}@#{node}"
+      arg_list << "watchdog=#{watchdog.strip}@#{node}"
     end
   end
 
@@ -2848,8 +2571,8 @@ def booth_save_files(params, request, auth_user)
 
     code_result_map = {
       :written => :saved,
-      :rewritten => :saved,
-      :same_content => :saved,
+      :rewritten => :existing,
+      :same_content => :existing,
       :conflict => :existing,
     }
 
@@ -2929,6 +2652,11 @@ def put_file(params, request, auth_user)
     files = check_request_data_for_json(params, auth_user)
     PcsdExchangeFormat::validate_item_map_is_Hash('files', files)
 
+    operation_types = files.map{ |id, data| data[:type] }.uniq
+    if operation_types & ['corosync_conf']
+      check_permissions(auth_user, Permissions::FULL)
+    end
+
     return pcsd_success(
       JSON.generate({"files" => Hash[files.map{|id, file_data|
         PcsdExchangeFormat::validate_item_is_Hash('file', id, file_data)
@@ -3163,3 +2891,87 @@ def check_request_data_for_json(params, auth_user)
     raise PcsdRequestException.new('Invalid input data format')
   end
 end
+
+def check_host(params, request, auth_user)
+  if not allowed_for_local_cluster(auth_user, Permissions::READ)
+    return 403, 'Permission denied'
+  end
+  service_list = [
+    :pacemaker, :pacemaker_remote, :corosync, :pcsd, :sbd, :qdevice, :booth
+  ]
+  service_version_getter = {
+    :pacemaker => method(:get_pacemaker_version),
+    :corosync => method(:get_corosync_version),
+    :pcsd => method(:get_pcsd_version),
+    # TODO: add version getters for all services
+  }
+  output = {
+    :services => {},
+    :cluster_configuration_exists => (
+      File.exist?(Cfgsync::CorosyncConf.file_path) or File.exist?(CIB_PATH)
+    )
+  }
+  service_list.each do |service|
+    output[:services][service] = get_service_info(service.to_s)
+  end
+  service_version_getter.each do |service, version_getter|
+    version = version_getter.call()
+    output[:services][service][:version] = (
+      version == nil ? version : version.join('.')
+    )
+  end
+  return [200, JSON.generate(output)]
+end
+
+def reload_corosync_conf(params, request, auth_user)
+  if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
+    return 403, 'Permission denied'
+  end
+
+  if is_service_running?('corosync')
+    output, stderr, retval = run_cmd(
+      auth_user, File.join(COROSYNC_BINARIES, "corosync-cfgtool"), "-R"
+    )
+    if retval != 0
+      msg_lines = output + stderr
+      if not msg_lines.empty? and msg_lines[0].strip() == 'Reloading corosync.conf...'
+        msg_lines.delete_at(0)
+      end
+      result = PcsdExchangeFormat::result(
+        :failed,
+        "Unable to reload corosync configuration: #{msg_lines.join("\n").strip()}"
+      )
+    else
+      result = PcsdExchangeFormat::result(:reloaded)
+    end
+  else
+    result = PcsdExchangeFormat::result(:not_running)
+  end
+
+  return JSON.generate(result)
+end
+
+def remove_nodes_from_cib(params, request, auth_user)
+  begin
+    check_permissions(auth_user, Permissions::WRITE)
+    data = check_request_data_for_json(params, auth_user)
+    PcsdExchangeFormat::validate_item_map_is_Hash("data_json", data)
+    PcsdExchangeFormat::validate_item_is_Array("node_list", data[:node_list])
+
+    stdout, stderr, retval = run_cmd(
+      auth_user, PCS, "cluster", "remove_nodes_from_cib", *data[:node_list]
+    )
+    if retval == 0
+      result = PcsdExchangeFormat::result(:success)
+    else
+      result = PcsdExchangeFormat::result(
+        :failed, (stdout + stderr).join("\n").strip()
+      )
+    end
+    return JSON.generate(result)
+  rescue PcsdRequestException => e
+    return e.code, e.message
+  rescue PcsdExchangeFormat::Error => e
+    return 400, "Invalid input data format: #{e.message}"
+  end
+end
