@@ -1,25 +1,25 @@
 PCS_EXEC = '/usr/sbin/pcs'
+PCS_INTERNAL_EXEC = '/usr/lib/pcs/pcs_internal'
 PCSD_EXEC_LOCATION = '/usr/lib/pcsd/'
 PCSD_VAR_LOCATION = '/var/lib/pcsd/'
 PCSD_DEFAULT_PORT = 2224
 
 CRT_FILE = PCSD_VAR_LOCATION + 'pcsd.crt'
 KEY_FILE = PCSD_VAR_LOCATION + 'pcsd.key'
-COOKIE_FILE = PCSD_VAR_LOCATION + 'pcsd.cookiesecret'
+KNOWN_HOSTS_FILE_NAME = 'known-hosts'
+PCSD_SETTINGS_CONF_LOCATION = PCSD_VAR_LOCATION + "pcs_settings.conf"
+PCSD_USERS_CONF_LOCATION = PCSD_VAR_LOCATION + "pcs_users.conf"
 
-PENGINE = "/usr/libexec/pacemaker/pengine"
-CIB_BINARY = '/usr/libexec/pacemaker/cib'
 CRM_MON = "/usr/sbin/crm_mon"
 CRM_NODE = "/usr/sbin/crm_node"
-CRM_ATTRIBUTE = "/usr/sbin/crm_attribute"
 COROSYNC_BINARIES = "/usr/sbin/"
-CMAN_TOOL = "/usr/sbin/cman_tool"
 PACEMAKERD = "/usr/sbin/pacemakerd"
 CIBADMIN = "/usr/sbin/cibadmin"
 SBD_CONFIG = '/etc/sysconfig/sbd'
 CIB_PATH='/var/lib/pacemaker/cib/cib.xml'
 BOOTH_CONFIG_DIR='/etc/booth'
 PACEMAKER_AUTHKEY='/etc/pacemaker/authkey'
+COROSYNC_CONF = '/etc/corosync/corosync.conf'
 
 COROSYNC_QDEVICE_NET_SERVER_CERTS_DIR = "/etc/corosync/qnetd/nssdb"
 COROSYNC_QDEVICE_NET_SERVER_CA_FILE = (
@@ -30,4 +30,3 @@ COROSYNC_AUTHKEY = "/etc/corosync/authkey"
 
 SUPERUSER = 'hacluster'
 ADMIN_GROUP = 'haclient'
-$user_pass_file = "pcs_users.conf"
