@@ -4,66 +4,35 @@ require 'thread'
 
 require 'pcsd_test_utils.rb'
 require 'cfgsync.rb'
+require 'config.rb'
 
 
 class TestCfgsync < Test::Unit::TestCase
   def test_compare_version()
-    cfg1 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="1" name="test1"/>'
+    cfg1 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 1, "format_version": 2}'
     )
-    cfg2 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="1" name="test1"/>'
+    cfg2 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 1, "format_version": 2}'
     )
-    cfg3 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="2" name="test1"/>'
+    cfg3 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 2, "format_version": 2}'
     )
-    cfg4 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="2" name="test2"/>'
+    cfg4 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 2, "clusters": [], "format_version": 2}'
     )
 
     assert(cfg1 == cfg2)
     assert(cfg1 < cfg3)
     assert(cfg1 < cfg4)
     assert(cfg3 > cfg1)
-    assert_equal("0ebab34c8034fd1cb268d1170de935a183d156cf", cfg3.hash)
-    assert_equal("0f22e8a496ae00815d8bcbf005fd7b645ba9f617", cfg4.hash)
-    assert(cfg3 < cfg4)
+    assert_equal("e28c7dfa675fdba4c55b8e3e7a854a252426514f", cfg3.hash)
+    assert_equal("21ceb5ff1c8b35b9b79adabcfdac30849666a6f7", cfg4.hash)
+    assert(cfg3 > cfg4)
 
     newest = [cfg1, cfg2, cfg3, cfg4].shuffle!.max
     assert_equal(2, newest.version)
-    assert_equal('0f22e8a496ae00815d8bcbf005fd7b645ba9f617', newest.hash)
-  end
-end
-
-
-class TestClusterConf < Test::Unit::TestCase
-  def setup()
-    FileUtils.cp(File.join(CURRENT_DIR, "cluster.conf"), CFG_CLUSTER_CONF)
-  end
-
-  def test_basics()
-    assert_equal("cluster.conf", Cfgsync::ClusterConf.name)
-    text = '<cluster config_version="3" name="test1"/>'
-
-    cfg = Cfgsync::ClusterConf.from_text(text)
-    assert_equal(text, cfg.text)
-    assert_equal(3, cfg.version)
-    assert_equal("1c0ff62f0749bea0b877599a02f6557573f286e2", cfg.hash)
-
-    cfg.version = 4
-    assert_equal(4, cfg.version)
-    assert_equal("<cluster config_version='4' name='test1'/>", cfg.text)
-    assert_equal('589e22aaff926907cc1f4db48eeeb5e269e41c39', cfg.hash)
-
-    assert_equal(4, cfg.version)
-    assert_equal("<cluster config_version='4' name='test1'/>", cfg.text)
-    assert_equal('589e22aaff926907cc1f4db48eeeb5e269e41c39', cfg.hash)
-  end
-
-  def test_file()
-    cfg = Cfgsync::ClusterConf.from_file()
-    assert_equal(9, cfg.version)
-    assert_equal("198bda4b748ef646de867cb850cd3ad208c36d8b", cfg.hash)
+    assert_equal('e28c7dfa675fdba4c55b8e3e7a854a252426514f', newest.hash)
   end
 end
 
@@ -104,7 +73,7 @@ totem {
   def test_file()
     cfg = Cfgsync::CorosyncConf.from_file()
     assert_equal(9, cfg.version)
-    assert_equal('cd8faaf2367ceafba281387fb9dfe70eba51769c', cfg.hash)
+    assert_equal('3711fd79c5972b21877a477d0d88c9eeb0d10a22', cfg.hash)
   end
 
   def test_version()
@@ -220,60 +189,59 @@ class TestPcsdSettings < Test::Unit::TestCase
 end
 
 
-class TestPcsdTokens < Test::Unit::TestCase
+class TestPcsdKnownHosts < Test::Unit::TestCase
   def teardown()
-    FileUtils.rm(CFG_PCSD_TOKENS, {:force => true})
+    FileUtils.rm(CFG_PCSD_KNOWN_HOSTS, {:force => true})
   end
 
   def test_basics()
-    assert_equal('tokens', Cfgsync::PcsdTokens.name)
-    text =
+    assert_equal('known-hosts', Cfgsync::PcsdKnownHosts.name)
+    template =
 '{
-  "format_version": 2,
-  "data_version": 3,
-  "tokens": {
-    "rh7-1": "token-rh7-1",
-    "rh7-2": "token-rh7-2"
+  "format_version": 1,
+  "data_version": %d,
+  "known_hosts": {
+    "node1": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.1",
+          "port": 2224
+        }
+      ],
+      "token": "abcde"
+    }
   }
 }'
 
-    cfg = Cfgsync::PcsdTokens.from_text(text)
+    text = template % 2
+    cfg = Cfgsync::PcsdKnownHosts.from_text(text)
     assert_equal(text, cfg.text)
+    assert_equal(2, cfg.version)
+    assert_equal('b34d5dde2727156d3a0f652e83aa1ed1c14104f5', cfg.hash)
+
+    cfg.version = 3
     assert_equal(3, cfg.version)
-    assert_equal('c362c4354ceb0b0425c71ed955d43f89c3d4304a', cfg.hash)
+    assert_equal('146e2be5708980d47bceb531729ba4f6a6e4a4e8', cfg.hash)
 
-    cfg.version = 4
+    cfg.text = template % 4
     assert_equal(4, cfg.version)
-    assert_equal('9586d6ce66f6fc649618f7f55005d8ddfe54db9b', cfg.hash)
-
-    cfg.text =
-'{
-  "format_version": 2,
-  "data_version": 4,
-  "tokens": {
-    "rh7-1": "token-rh7-1",
-    "rh7-2": "token-rh7-2"
-  }
-}'
-    assert_equal(4, cfg.version)
-    assert_equal('9586d6ce66f6fc649618f7f55005d8ddfe54db9b', cfg.hash)
+    assert_equal('f9c01aa74cf6dee7eea447c6ffcf253d3bb5b660', cfg.hash)
   end
 
   def test_file()
-    FileUtils.cp(File.join(CURRENT_DIR, 'tokens'), CFG_PCSD_TOKENS)
-    cfg = Cfgsync::PcsdTokens.from_file()
-    assert_equal(9, cfg.version)
-    assert_equal('571afb6abc603f527462818e7dfe278a8a1f64a7', cfg.hash)
+    FileUtils.cp(File.join(CURRENT_DIR, 'known-hosts'), CFG_PCSD_KNOWN_HOSTS)
+    cfg = Cfgsync::PcsdKnownHosts.from_file()
+    assert_equal(5, cfg.version)
+    assert_equal('dcf0e2f53084b3bc26451753b639d7c1e28ac1a7', cfg.hash)
   end
 
   def test_file_missing()
-    cfg = Cfgsync::PcsdTokens.from_file()
+    cfg = Cfgsync::PcsdKnownHosts.from_file()
     assert_equal(0, cfg.version)
     assert_equal('da39a3ee5e6b4b0d3255bfef95601890afd80709', cfg.hash)
   end
 end
 
-
 class TestConfigSyncControll < Test::Unit::TestCase
   def setup()
     file = File.open(CFG_SYNC_CONTROL, 'w')
@@ -333,14 +301,12 @@ class TestConfigSyncControll < Test::Unit::TestCase
   end
 
   def test_paused()
-    semaphore = Mutex.new
-
     assert(Cfgsync::ConfigSyncControl.sync_thread_resume())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(semaphore))
+    assert(Cfgsync::ConfigSyncControl.sync_thread_pause())
     assert(Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_allowed?())
@@ -350,7 +316,7 @@ class TestConfigSyncControll < Test::Unit::TestCase
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(semaphore, 2))
+    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(2))
     assert(Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_allowed?())
@@ -359,7 +325,7 @@ class TestConfigSyncControll < Test::Unit::TestCase
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(semaphore, '2'))
+    assert(Cfgsync::ConfigSyncControl.sync_thread_pause('2'))
     assert(Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_allowed?())
@@ -368,21 +334,19 @@ class TestConfigSyncControll < Test::Unit::TestCase
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(semaphore, 'abcd'))
+    assert(Cfgsync::ConfigSyncControl.sync_thread_pause('abcd'))
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
   end
 
   def test_disable()
-    semaphore = Mutex.new
-
     assert(Cfgsync::ConfigSyncControl.sync_thread_enable())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_disable(semaphore))
+    assert(Cfgsync::ConfigSyncControl.sync_thread_disable())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_allowed?())
@@ -501,17 +465,17 @@ class TestConfigFetcher < Test::Unit::TestCase
   end
 
   def test_find_newest_config()
-    cfg1 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="1" name="test1"/>'
+    cfg1 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 1, "format_version": 2}'
     )
-    cfg2 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="1" name="test1"/>'
+    cfg2 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 1, "format_version": 2}'
     )
-    cfg3 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="2" name="test1"/>'
+    cfg3 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 2, "clusters": [], "format_version": 2}'
     )
-    cfg4 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="2" name="test2"/>'
+    cfg4 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 2, "format_version": 2}'
     )
     assert(cfg1 == cfg2)
     assert(cfg1 < cfg3)
@@ -542,24 +506,24 @@ class TestConfigFetcher < Test::Unit::TestCase
   end
 
   def test_fetch()
-    cfg1 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="1" name="test1"/>'
+    cfg1 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 1, "format_version": 2}'
     )
-    cfg2 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="1" name="test1"/>'
+    cfg2 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 1, "format_version": 2}'
     )
-    cfg3 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="2" name="test1"/>'
+    cfg3 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 2, "clusters": [], "format_version": 2}'
     )
-    cfg4 = Cfgsync::ClusterConf.from_text(
-      '<cluster config_version="2" name="test2"/>'
+    cfg4 = Cfgsync::PcsdSettings.from_text(
+      '{"data_version": 2, "format_version": 2}'
     )
     assert(cfg1 == cfg2)
     assert(cfg1 < cfg3)
     assert(cfg1 < cfg4)
     assert(cfg3 < cfg4)
-    cfg_name = Cfgsync::ClusterConf.name
-    fetcher = ConfigFetcherMock.new({}, [Cfgsync::ClusterConf], nil, nil)
+    cfg_name = Cfgsync::PcsdSettings.name
+    fetcher = ConfigFetcherMock.new({}, [Cfgsync::PcsdSettings], nil, nil)
 
     # local config is synced
     fetcher.set_configs_local({cfg_name => cfg1})
@@ -691,241 +655,390 @@ class TestConfigFetcher < Test::Unit::TestCase
 end
 
 
-class TestMergeTokens < Test::Unit::TestCase
+class TestMergeKnownHosts < Test::Unit::TestCase
   def setup()
-    FileUtils.cp(File.join(CURRENT_DIR, 'tokens'), CFG_PCSD_TOKENS)
+    FileUtils.cp(File.join(CURRENT_DIR, 'known-hosts'), CFG_PCSD_KNOWN_HOSTS)
+  end
+
+  def teardown()
+    FileUtils.rm(CFG_PCSD_KNOWN_HOSTS, {:force => true})
+  end
+
+  def fixture_old_cfg()
+    return (
+'{
+  "format_version": 1,
+  "data_version": 5,
+  "known_hosts": {
+    "node1": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.1",
+          "port": 2224
+        }
+      ],
+      "token": "token1"
+    },
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2234
+        },
+        {
+          "addr": "10.0.2.2",
+          "port": 2235
+        }
+      ],
+      "token": "token2"
+    }
+  }
+}')
+  end
+
+  def fixture_old_cfg_with_nodex()
+    return (
+'{
+  "format_version": 1,
+  "data_version": 5,
+  "known_hosts": {
+    "node1": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.1",
+          "port": 2224
+        }
+      ],
+      "token": "token1"
+    },
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2234
+        },
+        {
+          "addr": "10.0.2.2",
+          "port": 2235
+        }
+      ],
+      "token": "token2"
+    },
+    "nodeX": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.100",
+          "port": 2224
+        }
+      ],
+      "token": "tokenX"
+    }
+  }
+}')
+  end
+
+  def fixture_new_cfg(version=5)
+    return (
+'{
+  "format_version": 1,
+  "data_version": %d,
+  "known_hosts": {
+    "node1": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.1",
+          "port": 2224
+        }
+      ],
+      "token": "token1"
+    },
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2a"
+    },
+    "node3": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.3",
+          "port": 2224
+        }
+      ],
+      "token": "token3"
+    }
+  }
+}' % version)
+  end
+
+  def fixture_node2()
+    return PcsKnownHost.new(
+      'node2',
+      'token2a',
+      [
+        {'addr' => '10.0.1.2', 'port' => 2224}
+      ]
+    )
+  end
+
+  def fixture_node3()
+    return PcsKnownHost.new(
+      'node3',
+      'token3',
+      [
+        {'addr' => '10.0.1.3', 'port' => 2224}
+      ]
+    )
+  end
+
+  def fixture_old_text()
+    return (
+'{
+  "format_version": 1,
+  "data_version": 2,
+  "known_hosts": {
+    "node1": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.1",
+          "port": 2224
+        }
+      ],
+      "token": "token1a"
+  }
+}')
   end
 
   def test_nothing_to_merge()
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, nil, {})
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg())
+    new_cfg = Cfgsync::merge_known_host_files(old_cfg, nil, [], [])
     assert_equal(old_cfg.text.strip, new_cfg.text.strip)
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, nil, {'rh7-4' => 'token4'})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 9,
-  "tokens": {
-    "rh7-1": "2a8b40aa-b539-4713-930a-483468d62ef4",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "55844951-9ae5-4103-bb4a-64f9c1ea0a71",
-    "rh7-4": "token4"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, nil, {'rh7-3' => 'token3'})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 9,
-  "tokens": {
-    "rh7-1": "2a8b40aa-b539-4713-930a-483468d62ef4",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "token3"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
   end
 
-  def test_only_old_to_merge()
-    to_merge = [
-      Cfgsync::PcsdTokens.from_text(
-'{
-  "format_version": 2,
-  "data_version": 1,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-4": "token4a"
-  }
-}'
-      )
-    ]
+  def test_extra_hosts()
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg_with_nodex())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [],
+      [fixture_node2(), fixture_node3()],
+      ['nodeX', 'node3', 'nodeY']
+    )
+    assert_equal(fixture_new_cfg, new_cfg.text.strip)
+  end
 
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, to_merge, {})
+  def test_older_file()
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [Cfgsync::PcsdKnownHosts.from_text(fixture_old_text)],
+      [],
+      []
+    )
     assert_equal(old_cfg.text.strip, new_cfg.text.strip)
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, to_merge, {'rh7-4' => 'token4'})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 9,
-  "tokens": {
-    "rh7-1": "2a8b40aa-b539-4713-930a-483468d62ef4",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "55844951-9ae5-4103-bb4a-64f9c1ea0a71",
-    "rh7-4": "token4"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, to_merge, {'rh7-3' => 'token3'})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 9,
-  "tokens": {
-    "rh7-1": "2a8b40aa-b539-4713-930a-483468d62ef4",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "token3"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
   end
 
-  def test_one_to_merge()
-    to_merge = [
-      Cfgsync::PcsdTokens.from_text(
-'{
-  "format_version": 2,
-  "data_version": 11,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-4": "token4a"
-  }
-}'
-      )
-    ]
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, to_merge, {})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 11,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "55844951-9ae5-4103-bb4a-64f9c1ea0a71",
-    "rh7-4": "token4a"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, to_merge, {'rh7-4' => 'token4'})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 11,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "55844951-9ae5-4103-bb4a-64f9c1ea0a71",
-    "rh7-4": "token4"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(old_cfg, to_merge, {'rh7-3' => 'token3'})
-    new_cfg_text =
-'{
-  "format_version": 2,
-  "data_version": 11,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-2": "76174e2c-09e8-4435-b318-5c6b8250a22c",
-    "rh7-3": "token3",
-    "rh7-4": "token4a"
-  }
-}'
-    assert_equal(new_cfg_text, new_cfg.text.strip)
+  def test_older_file_and_extra_hosts()
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg_with_nodex())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [Cfgsync::PcsdKnownHosts.from_text(fixture_old_text)],
+      [fixture_node2(), fixture_node3()],
+      ['nodeX', 'node3']
+    )
+    assert_equal(fixture_new_cfg, new_cfg.text.strip)
   end
 
-  def test_more_to_merge()
-    to_merge_12 = Cfgsync::PcsdTokens.from_text(
+  def test_newer_file()
+    new_text =
 '{
-  "format_version": 2,
-  "data_version": 12,
-  "tokens": {
-    "rh7-2": "token2",
-    "rh7-4": "token4b"
-  }
-}'
-    )
-    to_merge_11 = Cfgsync::PcsdTokens.from_text(
-'{
-  "format_version": 2,
-  "data_version": 11,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-4": "token4a"
+  "format_version": 1,
+  "data_version": 7,
+  "known_hosts": {
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2a"
+    },
+    "node3": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.3",
+          "port": 2224
+        }
+      ],
+      "token": "token3"
+    }
   }
 }'
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [Cfgsync::PcsdKnownHosts.from_text(new_text)],
+      [],
+      []
     )
+    assert_equal(fixture_new_cfg(7), new_cfg.text.strip)
+  end
 
-    new_cfg_text =
+  def test_newer_file_and_extra_hosts()
+    new_text =
 '{
-  "format_version": 2,
-  "data_version": 12,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-2": "token2",
-    "rh7-3": "55844951-9ae5-4103-bb4a-64f9c1ea0a71",
-    "rh7-4": "token4b"
+  "format_version": 1,
+  "data_version": 7,
+  "known_hosts": {
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.122.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2aaaaaaaa"
+    },
+    "node3": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.3",
+          "port": 2224
+        }
+      ],
+      "token": "token3"
+    },
+    "nodeY": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.101",
+          "port": 2224
+        }
+      ],
+      "token": "tokenX"
+    }
   }
 }'
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(
-      old_cfg, [to_merge_11, to_merge_12], {}
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg_with_nodex())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [Cfgsync::PcsdKnownHosts.from_text(new_text)],
+      [fixture_node2()],
+      ['node2', 'nodeX', 'nodeY']
     )
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(
-      old_cfg, [to_merge_12, to_merge_11], {}
-    )
-    assert_equal(new_cfg_text, new_cfg.text.strip)
+    assert_equal(fixture_new_cfg(7), new_cfg.text.strip)
+  end
 
-    new_cfg_text =
+  def test_newer_files()
+    new_text1 =
 '{
-  "format_version": 2,
-  "data_version": 12,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-2": "token2",
-    "rh7-3": "55844951-9ae5-4103-bb4a-64f9c1ea0a71",
-    "rh7-4": "token4"
+  "format_version": 1,
+  "data_version": 6,
+  "known_hosts": {
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2aaaaaaaaaa"
+    },
+    "node3": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.3",
+          "port": 2224
+        }
+      ],
+      "token": "token3"
+    }
   }
 }'
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(
-      old_cfg, [to_merge_11, to_merge_12], {'rh7-4' => 'token4'}
+    new_text2 =
+'{
+  "format_version": 1,
+  "data_version": 7,
+  "known_hosts": {
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2a"
+    }
+  }
+}'
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [
+        Cfgsync::PcsdKnownHosts.from_text(new_text1),
+        Cfgsync::PcsdKnownHosts.from_text(new_text2),
+      ],
+      [],
+      []
     )
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(
-      old_cfg, [to_merge_12, to_merge_11], {'rh7-4' => 'token4'}
-    )
-    assert_equal(new_cfg_text, new_cfg.text.strip)
+    assert_equal(fixture_new_cfg(7), new_cfg.text.strip)
+  end
 
-    new_cfg_text =
+  def test_newer_files_and_extra_hosts()
+    new_text1 =
 '{
-  "format_version": 2,
-  "data_version": 12,
-  "tokens": {
-    "rh7-1": "token1",
-    "rh7-2": "token2",
-    "rh7-3": "token3",
-    "rh7-4": "token4b"
+  "format_version": 1,
+  "data_version": 6,
+  "known_hosts": {
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2aaaaaaaaaa"
+    },
+    "node3": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.3",
+          "port": 2224
+        }
+      ],
+      "token": "token3aaaaaaaaaa"
+    }
   }
 }'
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(
-      old_cfg, [to_merge_11, to_merge_12], {'rh7-3' => 'token3'}
+    new_text2 =
+'{
+  "format_version": 1,
+  "data_version": 7,
+  "known_hosts": {
+    "node2": {
+      "dest_list": [
+        {
+          "addr": "10.0.1.2",
+          "port": 2224
+        }
+      ],
+      "token": "token2a"
+    }
+  }
+}'
+    old_cfg = Cfgsync::PcsdKnownHosts.from_text(fixture_old_cfg())
+    new_cfg = Cfgsync::merge_known_host_files(
+      old_cfg,
+      [
+        Cfgsync::PcsdKnownHosts.from_text(new_text1),
+        Cfgsync::PcsdKnownHosts.from_text(new_text2),
+      ],
+      [fixture_node3()],
+      []
     )
-    assert_equal(new_cfg_text, new_cfg.text.strip)
-    old_cfg = Cfgsync::PcsdTokens.from_file()
-    new_cfg = Cfgsync::merge_tokens_files(
-      old_cfg, [to_merge_12, to_merge_11], {'rh7-3' => 'token3'}
-    )
-    assert_equal(new_cfg_text, new_cfg.text.strip)
+    assert_equal(fixture_new_cfg(7), new_cfg.text.strip)
   end
 end
-
